{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "import matplotlib.pyplot as plt\n",
    "%matplotlib inline\n",
    "import matplotlib_inline\n",
    "matplotlib_inline.backend_inline.set_matplotlib_formats('svg')\n",
    "import seaborn as sns\n",
    "sns.set_context(\"paper\")\n",
    "sns.set_style(\"ticks\")\n",
    "\n",
    "# Uncomment the next two lines if running for the book\n",
    "# import warnings\n",
    "# warnings.filterwarnings(\"ignore\")\n",
    "\n",
    "import jax\n",
    "from jax import vmap\n",
    "import jax.random as jrandom\n",
    "import jax.numpy as jnp\n",
    "import jax.scipy.stats as jstats\n",
    "import pandas as pd\n",
    "import numpy as np\n",
    "import gpjax as gpx\n",
    "from flax import nnx\n",
    "import optax\n",
    "import equinox as eqx\n",
    "from typing import Optional\n",
    "from jaxtyping import Float, Array\n",
    "\n",
    "jax.config.update(\"jax_enable_x64\", True)\n",
    "key = jrandom.PRNGKey(0);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Example of Gaussian Process Surrogate"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Model for subcutaneous autoinjectors\n",
    "\n",
    "In this notebook, we'll repeat the neural network surrogate hands-on activity, but this time we'll use a gaussian process (GP) as the surrogate. \n",
    "Recall that our goal is to replicate [Sree et. al. (2023)](https://doi.org/10.1016/j.jmbbm.2023.105695), i.e., create a surrogate of an expensive biomechanical model.\n",
    "\n",
    "Just to recap: We have a high-fidelity, finite-element-based model $f$ of drug autoinjections. \n",
    "The model takes inputs $x$ like drug viscosity, tissue biomechanical properties, etc. and calculates various outputs $y=f(x)$. \n",
    "To train a surrogate $\\hat{f}$ of this model, we have a dataset  containing thousands of evaluations of $f$. \n",
    "For further details about the model or dataset, see the neural network surrogate hands-on activity. \n",
    "\n",
    "Let's get the data imported. (We'll follow the same preprocessing steps as the neural network surrogate hands-on activity, except we won't re-explain the steps here&mdash;we'll just do them.)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "class StandardScaler:\n",
    "    \"\"\"A transform that standarizes the data to have mean=0 and stdev=1.\n",
    "    \n",
    "    Parameters\n",
    "    ----------\n",
    "    data : Float[Array, \"N d\"]\n",
    "        The data to be standarized. Shape is (N, d)=(number of samples, dimensionality).\n",
    "    pretransform_forward : Optional[callable]\n",
    "        An optional transformation to apply to the data before standarizing.\n",
    "    pretransform_inverse : Optional[callable]\n",
    "        The inverse of pretransform_forward.\n",
    "    \"\"\"\n",
    "    def __init__(\n",
    "        self, \n",
    "        data: Float[Array, \"N d\"], \n",
    "        pretransform_forward: Optional[callable] = None, \n",
    "        pretransform_inverse: Optional[callable] = None\n",
    "    ):\n",
    "        # Set up pre-transform functions\n",
    "        if (pretransform_forward is None) ^ (pretransform_inverse is None):\n",
    "            raise ValueError(\"Both pretransform_forward and pretransform_inverse must be provided.\")\n",
    "        elif pretransform_forward is None:\n",
    "            pretransform_forward = lambda x: x\n",
    "            pretransform_inverse = lambda x: x\n",
    "        self.pre_forward = pretransform_forward\n",
    "        self.pre_inverse = pretransform_inverse\n",
    "        \n",
    "        # Compute parameters for the standardizer\n",
    "        pretransformed_data = vmap(self.pre_forward)(data)\n",
    "        self.mean = jnp.mean(pretransformed_data, axis=0)\n",
    "        self.std = jnp.std(pretransformed_data, axis=0)        \n",
    "    \n",
    "    def forward(self, x):\n",
    "        return (self.pre_forward(x) - self.mean) / self.std\n",
    "    \n",
    "    def inverse(self, y):\n",
    "        return self.pre_inverse(y * self.std + self.mean)\n",
    "\n",
    "# Define new names for each input/output variable\n",
    "old_input_names = ['mu', 'fill_volume', 'hGap0', 'lNeedle', 'dNeedle', 'FSpring0', 'kSpring', 'kappa5', 'kappa6', 'kappa7']\n",
    "INPUT_NAMES = ['viscosity_cP', 'fill_volume_mL', 'air_gap_height_mm', 'needle_length_mm', 'needle_diameter_mm', 'spring_force_N', 'spring_constant_N_per_mm', 'kappa5', 'kappa6', 'kappa7']\n",
    "old_output_names = ['Needle displacement (m)', 'Injection time (s)', 'max. acceleration (m/s^2)', 'max. deceleration (m/s^2)']\n",
    "OUTPUT_NAMES = ['needle_displacement_m', 'injection_time_s', 'max_acceleration_m_per_s2', 'max_deceleration_m_per_s2']\n",
    "column_name_mapper = dict(zip(old_input_names + old_output_names, INPUT_NAMES + OUTPUT_NAMES))\n",
    "\n",
    "# Load the data\n",
    "train_data = pd.read_excel(\"../../data/training_data.xlsx\", index_col=0).rename(columns=column_name_mapper).sample(frac=1).reset_index(drop=True)\n",
    "test_data = pd.read_excel(\"../../data/test_data.xlsx\", index_col=0).rename(columns=column_name_mapper).sample(frac=1).reset_index(drop=True)\n",
    "\n",
    "# Split data. Pass in column names to ensure correct order.\n",
    "X_train = pd.DataFrame(train_data[INPUT_NAMES], columns=INPUT_NAMES)  \n",
    "y_train = pd.DataFrame(train_data[OUTPUT_NAMES], columns=OUTPUT_NAMES)\n",
    "X_test = pd.DataFrame(test_data[INPUT_NAMES], columns=INPUT_NAMES)\n",
    "y_test = pd.DataFrame(test_data[OUTPUT_NAMES], columns=OUTPUT_NAMES)\n",
    "\n",
    "input_transform = StandardScaler(X_train.values)\n",
    "\n",
    "def partial_log_transform(x):\n",
    "    return jnp.hstack([x[0], jnp.log(x[1]), jnp.log(x[2]), x[3]])\n",
    "\n",
    "def partial_exp_transform(y):\n",
    "    return jnp.array([y[0], jnp.exp(y[1]), jnp.exp(y[2]), y[3]])\n",
    "\n",
    "output_transform = StandardScaler(y_train.values, pretransform_forward=partial_log_transform, pretransform_inverse=partial_exp_transform)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "X_train_scaled = vmap(input_transform.forward)(X_train.values)\n",
    "X_test_scaled = vmap(input_transform.forward)(X_test.values)\n",
    "y_train_scaled = vmap(output_transform.forward)(y_train.values)\n",
    "y_test_scaled = vmap(output_transform.forward)(y_test.values)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The data are now imported and standardized. Let's visualize to make sure things look good:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"1073.664pt\" height=\"145.152pt\" viewBox=\"0 0 1073.664 145.152\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:39:41.396062</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 145.152 \n",
       "L 1073.664 145.152 \n",
       "L 1073.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 7.2 121.604125 \n",
       "L 103.7952 121.604125 \n",
       "L 103.7952 48.7203 \n",
       "L 7.2 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m00fd23b375\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"30.144995\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.128307 136.203) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"55.499349\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.052537 136.203) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"80.853704\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(78.406892 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 11.590691 121.604125 \n",
       "L 15.981382 121.604125 \n",
       "L 15.981382 52.328683 \n",
       "L 11.590691 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 15.981382 121.604125 \n",
       "L 20.372073 121.604125 \n",
       "L 20.372073 52.879581 \n",
       "L 15.981382 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 20.372073 121.604125 \n",
       "L 24.762764 121.604125 \n",
       "L 24.762764 52.879581 \n",
       "L 20.372073 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 24.762764 121.604125 \n",
       "L 29.153455 121.604125 \n",
       "L 29.153455 52.879581 \n",
       "L 24.762764 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 29.153455 121.604125 \n",
       "L 33.544145 121.604125 \n",
       "L 33.544145 52.741856 \n",
       "L 29.153455 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 33.544145 121.604125 \n",
       "L 37.934836 121.604125 \n",
       "L 37.934836 52.604132 \n",
       "L 33.544145 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 37.934836 121.604125 \n",
       "L 42.325527 121.604125 \n",
       "L 42.325527 52.879581 \n",
       "L 37.934836 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 42.325527 121.604125 \n",
       "L 46.716218 121.604125 \n",
       "L 46.716218 52.741856 \n",
       "L 42.325527 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 46.716218 121.604125 \n",
       "L 51.106909 121.604125 \n",
       "L 51.106909 52.741856 \n",
       "L 46.716218 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 51.106909 121.604125 \n",
       "L 55.4976 121.604125 \n",
       "L 55.4976 52.741856 \n",
       "L 51.106909 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 55.4976 121.604125 \n",
       "L 59.888291 121.604125 \n",
       "L 59.888291 52.741856 \n",
       "L 55.4976 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 59.888291 121.604125 \n",
       "L 64.278982 121.604125 \n",
       "L 64.278982 52.741856 \n",
       "L 59.888291 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 64.278982 121.604125 \n",
       "L 68.669673 121.604125 \n",
       "L 68.669673 52.741856 \n",
       "L 64.278982 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 68.669673 121.604125 \n",
       "L 73.060364 121.604125 \n",
       "L 73.060364 52.741856 \n",
       "L 68.669673 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 73.060364 121.604125 \n",
       "L 77.451055 121.604125 \n",
       "L 77.451055 52.741856 \n",
       "L 73.060364 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path d=\"M 77.451055 121.604125 \n",
       "L 81.841745 121.604125 \n",
       "L 81.841745 52.741856 \n",
       "L 77.451055 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path d=\"M 81.841745 121.604125 \n",
       "L 86.232436 121.604125 \n",
       "L 86.232436 52.741856 \n",
       "L 81.841745 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_20\">\n",
       "    <path d=\"M 86.232436 121.604125 \n",
       "L 90.623127 121.604125 \n",
       "L 90.623127 52.741856 \n",
       "L 86.232436 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_21\">\n",
       "    <path d=\"M 90.623127 121.604125 \n",
       "L 95.013818 121.604125 \n",
       "L 95.013818 52.741856 \n",
       "L 90.623127 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_22\">\n",
       "    <path d=\"M 95.013818 121.604125 \n",
       "L 99.404509 121.604125 \n",
       "L 99.404509 52.741856 \n",
       "L 95.013818 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p3c675d26bb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_23\">\n",
       "    <path d=\"M 30.144995 121.604125 \n",
       "L 80.853704 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_4\">\n",
       "    <!-- viscosity_cP -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(29.09085 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-79\" d=\"M 397 -1278 \n",
       "L 334 -750 \n",
       "Q 519 -800 656 -800 \n",
       "Q 844 -800 956 -737 \n",
       "Q 1069 -675 1141 -563 \n",
       "Q 1194 -478 1313 -144 \n",
       "Q 1328 -97 1363 -6 \n",
       "L 103 3319 \n",
       "L 709 3319 \n",
       "L 1400 1397 \n",
       "Q 1534 1031 1641 628 \n",
       "Q 1738 1016 1872 1384 \n",
       "L 2581 3319 \n",
       "L 3144 3319 \n",
       "L 1881 -56 \n",
       "Q 1678 -603 1566 -809 \n",
       "Q 1416 -1088 1222 -1217 \n",
       "Q 1028 -1347 759 -1347 \n",
       "Q 597 -1347 397 -1278 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-76\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"122.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"172.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"227.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"277.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"300.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-79\" x=\"327.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"377.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"433.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-50\" x=\"483.447266\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_24\">\n",
       "    <path d=\"M 114.1632 121.604125 \n",
       "L 210.7584 121.604125 \n",
       "L 210.7584 48.7203 \n",
       "L 114.1632 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"137.112146\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(132.095458 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"162.46196\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(160.015147 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"187.811773\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(185.364961 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\"/>\n",
       "   <g id=\"patch_25\">\n",
       "    <path d=\"M 118.553891 121.604125 \n",
       "L 122.944582 121.604125 \n",
       "L 122.944582 52.741856 \n",
       "L 118.553891 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_26\">\n",
       "    <path d=\"M 122.944582 121.604125 \n",
       "L 127.335273 121.604125 \n",
       "L 127.335273 52.741856 \n",
       "L 122.944582 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_27\">\n",
       "    <path d=\"M 127.335273 121.604125 \n",
       "L 131.725964 121.604125 \n",
       "L 131.725964 52.741856 \n",
       "L 127.335273 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_28\">\n",
       "    <path d=\"M 131.725964 121.604125 \n",
       "L 136.116655 121.604125 \n",
       "L 136.116655 52.741856 \n",
       "L 131.725964 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_29\">\n",
       "    <path d=\"M 136.116655 121.604125 \n",
       "L 140.507345 121.604125 \n",
       "L 140.507345 52.741856 \n",
       "L 136.116655 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_30\">\n",
       "    <path d=\"M 140.507345 121.604125 \n",
       "L 144.898036 121.604125 \n",
       "L 144.898036 52.741856 \n",
       "L 140.507345 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_31\">\n",
       "    <path d=\"M 144.898036 121.604125 \n",
       "L 149.288727 121.604125 \n",
       "L 149.288727 52.741856 \n",
       "L 144.898036 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_32\">\n",
       "    <path d=\"M 149.288727 121.604125 \n",
       "L 153.679418 121.604125 \n",
       "L 153.679418 52.741856 \n",
       "L 149.288727 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_33\">\n",
       "    <path d=\"M 153.679418 121.604125 \n",
       "L 158.070109 121.604125 \n",
       "L 158.070109 52.741856 \n",
       "L 153.679418 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_34\">\n",
       "    <path d=\"M 158.070109 121.604125 \n",
       "L 162.4608 121.604125 \n",
       "L 162.4608 52.741856 \n",
       "L 158.070109 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_35\">\n",
       "    <path d=\"M 162.4608 121.604125 \n",
       "L 166.851491 121.604125 \n",
       "L 166.851491 52.741856 \n",
       "L 162.4608 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_36\">\n",
       "    <path d=\"M 166.851491 121.604125 \n",
       "L 171.242182 121.604125 \n",
       "L 171.242182 52.741856 \n",
       "L 166.851491 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_37\">\n",
       "    <path d=\"M 171.242182 121.604125 \n",
       "L 175.632873 121.604125 \n",
       "L 175.632873 52.741856 \n",
       "L 171.242182 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_38\">\n",
       "    <path d=\"M 175.632873 121.604125 \n",
       "L 180.023564 121.604125 \n",
       "L 180.023564 52.741856 \n",
       "L 175.632873 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_39\">\n",
       "    <path d=\"M 180.023564 121.604125 \n",
       "L 184.414255 121.604125 \n",
       "L 184.414255 52.741856 \n",
       "L 180.023564 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_40\">\n",
       "    <path d=\"M 184.414255 121.604125 \n",
       "L 188.804945 121.604125 \n",
       "L 188.804945 52.741856 \n",
       "L 184.414255 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_41\">\n",
       "    <path d=\"M 188.804945 121.604125 \n",
       "L 193.195636 121.604125 \n",
       "L 193.195636 52.879581 \n",
       "L 188.804945 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_42\">\n",
       "    <path d=\"M 193.195636 121.604125 \n",
       "L 197.586327 121.604125 \n",
       "L 197.586327 52.604132 \n",
       "L 193.195636 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_43\">\n",
       "    <path d=\"M 197.586327 121.604125 \n",
       "L 201.977018 121.604125 \n",
       "L 201.977018 53.017306 \n",
       "L 197.586327 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_44\">\n",
       "    <path d=\"M 201.977018 121.604125 \n",
       "L 206.367709 121.604125 \n",
       "L 206.367709 52.466407 \n",
       "L 201.977018 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#p012b5edbad)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_45\">\n",
       "    <path d=\"M 137.112146 121.604125 \n",
       "L 187.811773 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_8\">\n",
       "    <!-- fill_volume_mL -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(130.4493 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-4c\" d=\"M 469 0 \n",
       "L 469 4581 \n",
       "L 1075 4581 \n",
       "L 1075 541 \n",
       "L 3331 541 \n",
       "L 3331 0 \n",
       "L 469 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-66\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"27.783203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"94.433594\"/>\n",
       "     <use xlink:href=\"#ArialMT-76\" x=\"150.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"200.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-75\" x=\"277.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"333.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"416.796875\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"472.412109\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"528.027344\"/>\n",
       "     <use xlink:href=\"#ArialMT-4c\" x=\"611.328125\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_46\">\n",
       "    <path d=\"M 221.1264 121.604125 \n",
       "L 317.7216 121.604125 \n",
       "L 317.7216 48.7203 \n",
       "L 221.1264 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"244.071185\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(239.054497 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"269.425843\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(266.97903 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"294.7805\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(292.333688 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\"/>\n",
       "   <g id=\"patch_47\">\n",
       "    <path d=\"M 225.517091 121.604125 \n",
       "L 229.907782 121.604125 \n",
       "L 229.907782 52.741856 \n",
       "L 225.517091 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_48\">\n",
       "    <path d=\"M 229.907782 121.604125 \n",
       "L 234.298473 121.604125 \n",
       "L 234.298473 52.741856 \n",
       "L 229.907782 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_49\">\n",
       "    <path d=\"M 234.298473 121.604125 \n",
       "L 238.689164 121.604125 \n",
       "L 238.689164 52.604132 \n",
       "L 234.298473 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_50\">\n",
       "    <path d=\"M 238.689164 121.604125 \n",
       "L 243.079855 121.604125 \n",
       "L 243.079855 52.741856 \n",
       "L 238.689164 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_51\">\n",
       "    <path d=\"M 243.079855 121.604125 \n",
       "L 247.470545 121.604125 \n",
       "L 247.470545 52.879581 \n",
       "L 243.079855 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_52\">\n",
       "    <path d=\"M 247.470545 121.604125 \n",
       "L 251.861236 121.604125 \n",
       "L 251.861236 52.466407 \n",
       "L 247.470545 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_53\">\n",
       "    <path d=\"M 251.861236 121.604125 \n",
       "L 256.251927 121.604125 \n",
       "L 256.251927 52.879581 \n",
       "L 251.861236 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_54\">\n",
       "    <path d=\"M 256.251927 121.604125 \n",
       "L 260.642618 121.604125 \n",
       "L 260.642618 52.879581 \n",
       "L 256.251927 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_55\">\n",
       "    <path d=\"M 260.642618 121.604125 \n",
       "L 265.033309 121.604125 \n",
       "L 265.033309 52.741856 \n",
       "L 260.642618 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_56\">\n",
       "    <path d=\"M 265.033309 121.604125 \n",
       "L 269.424 121.604125 \n",
       "L 269.424 52.741856 \n",
       "L 265.033309 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_57\">\n",
       "    <path d=\"M 269.424 121.604125 \n",
       "L 273.814691 121.604125 \n",
       "L 273.814691 52.741856 \n",
       "L 269.424 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_58\">\n",
       "    <path d=\"M 273.814691 121.604125 \n",
       "L 278.205382 121.604125 \n",
       "L 278.205382 52.604132 \n",
       "L 273.814691 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_59\">\n",
       "    <path d=\"M 278.205382 121.604125 \n",
       "L 282.596073 121.604125 \n",
       "L 282.596073 52.879581 \n",
       "L 278.205382 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_60\">\n",
       "    <path d=\"M 282.596073 121.604125 \n",
       "L 286.986764 121.604125 \n",
       "L 286.986764 52.741856 \n",
       "L 282.596073 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_61\">\n",
       "    <path d=\"M 286.986764 121.604125 \n",
       "L 291.377455 121.604125 \n",
       "L 291.377455 52.741856 \n",
       "L 286.986764 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_62\">\n",
       "    <path d=\"M 291.377455 121.604125 \n",
       "L 295.768145 121.604125 \n",
       "L 295.768145 52.741856 \n",
       "L 291.377455 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_63\">\n",
       "    <path d=\"M 295.768145 121.604125 \n",
       "L 300.158836 121.604125 \n",
       "L 300.158836 52.741856 \n",
       "L 295.768145 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_64\">\n",
       "    <path d=\"M 300.158836 121.604125 \n",
       "L 304.549527 121.604125 \n",
       "L 304.549527 52.741856 \n",
       "L 300.158836 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_65\">\n",
       "    <path d=\"M 304.549527 121.604125 \n",
       "L 308.940218 121.604125 \n",
       "L 308.940218 52.879581 \n",
       "L 304.549527 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_66\">\n",
       "    <path d=\"M 308.940218 121.604125 \n",
       "L 313.330909 121.604125 \n",
       "L 313.330909 52.604132 \n",
       "L 308.940218 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p7e48deb2fc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_67\">\n",
       "    <path d=\"M 244.071185 121.604125 \n",
       "L 294.7805 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_12\">\n",
       "    <!-- air_gap_height_mm -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(227.001 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-67\" d=\"M 319 -275 \n",
       "L 866 -356 \n",
       "Q 900 -609 1056 -725 \n",
       "Q 1266 -881 1628 -881 \n",
       "Q 2019 -881 2231 -725 \n",
       "Q 2444 -569 2519 -288 \n",
       "Q 2563 -116 2559 434 \n",
       "Q 2191 0 1641 0 \n",
       "Q 956 0 581 494 \n",
       "Q 206 988 206 1678 \n",
       "Q 206 2153 378 2554 \n",
       "Q 550 2956 876 3175 \n",
       "Q 1203 3394 1644 3394 \n",
       "Q 2231 3394 2613 2919 \n",
       "L 2613 3319 \n",
       "L 3131 3319 \n",
       "L 3131 450 \n",
       "Q 3131 -325 2973 -648 \n",
       "Q 2816 -972 2473 -1159 \n",
       "Q 2131 -1347 1631 -1347 \n",
       "Q 1038 -1347 672 -1080 \n",
       "Q 306 -813 319 -275 \n",
       "z\n",
       "M 784 1719 \n",
       "Q 784 1066 1043 766 \n",
       "Q 1303 466 1694 466 \n",
       "Q 2081 466 2343 764 \n",
       "Q 2606 1063 2606 1700 \n",
       "Q 2606 2309 2336 2618 \n",
       "Q 2066 2928 1684 2928 \n",
       "Q 1309 2928 1046 2623 \n",
       "Q 784 2319 784 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-68\" d=\"M 422 0 \n",
       "L 422 4581 \n",
       "L 984 4581 \n",
       "L 984 2938 \n",
       "Q 1378 3394 1978 3394 \n",
       "Q 2347 3394 2619 3248 \n",
       "Q 2891 3103 3008 2847 \n",
       "Q 3125 2591 3125 2103 \n",
       "L 3125 0 \n",
       "L 2563 0 \n",
       "L 2563 2103 \n",
       "Q 2563 2525 2380 2717 \n",
       "Q 2197 2909 1863 2909 \n",
       "Q 1613 2909 1392 2779 \n",
       "Q 1172 2650 1078 2428 \n",
       "Q 984 2206 984 1816 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-61\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"111.132812\"/>\n",
       "     <use xlink:href=\"#ArialMT-67\" x=\"166.748047\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"222.363281\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"277.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"333.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-68\" x=\"389.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"444.824219\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"500.439453\"/>\n",
       "     <use xlink:href=\"#ArialMT-67\" x=\"522.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-68\" x=\"578.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"633.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"661.669922\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"717.285156\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_68\">\n",
       "    <path d=\"M 328.0896 121.604125 \n",
       "L 424.6848 121.604125 \n",
       "L 424.6848 48.7203 \n",
       "L 328.0896 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"351.031812\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(346.015124 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"376.392328\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.945516 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"401.752845\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(399.306032 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\"/>\n",
       "   <g id=\"patch_69\">\n",
       "    <path d=\"M 332.480291 121.604125 \n",
       "L 336.870982 121.604125 \n",
       "L 336.870982 52.741856 \n",
       "L 332.480291 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_70\">\n",
       "    <path d=\"M 336.870982 121.604125 \n",
       "L 341.261673 121.604125 \n",
       "L 341.261673 52.741856 \n",
       "L 336.870982 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_71\">\n",
       "    <path d=\"M 341.261673 121.604125 \n",
       "L 345.652364 121.604125 \n",
       "L 345.652364 52.604132 \n",
       "L 341.261673 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_72\">\n",
       "    <path d=\"M 345.652364 121.604125 \n",
       "L 350.043055 121.604125 \n",
       "L 350.043055 52.879581 \n",
       "L 345.652364 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_73\">\n",
       "    <path d=\"M 350.043055 121.604125 \n",
       "L 354.433745 121.604125 \n",
       "L 354.433745 52.741856 \n",
       "L 350.043055 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_74\">\n",
       "    <path d=\"M 354.433745 121.604125 \n",
       "L 358.824436 121.604125 \n",
       "L 358.824436 52.741856 \n",
       "L 354.433745 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_75\">\n",
       "    <path d=\"M 358.824436 121.604125 \n",
       "L 363.215127 121.604125 \n",
       "L 363.215127 52.741856 \n",
       "L 358.824436 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_76\">\n",
       "    <path d=\"M 363.215127 121.604125 \n",
       "L 367.605818 121.604125 \n",
       "L 367.605818 52.879581 \n",
       "L 363.215127 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_77\">\n",
       "    <path d=\"M 367.605818 121.604125 \n",
       "L 371.996509 121.604125 \n",
       "L 371.996509 52.604132 \n",
       "L 367.605818 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_78\">\n",
       "    <path d=\"M 371.996509 121.604125 \n",
       "L 376.3872 121.604125 \n",
       "L 376.3872 52.879581 \n",
       "L 371.996509 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_79\">\n",
       "    <path d=\"M 376.3872 121.604125 \n",
       "L 380.777891 121.604125 \n",
       "L 380.777891 52.741856 \n",
       "L 376.3872 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_80\">\n",
       "    <path d=\"M 380.777891 121.604125 \n",
       "L 385.168582 121.604125 \n",
       "L 385.168582 52.604132 \n",
       "L 380.777891 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_81\">\n",
       "    <path d=\"M 385.168582 121.604125 \n",
       "L 389.559273 121.604125 \n",
       "L 389.559273 52.879581 \n",
       "L 385.168582 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_82\">\n",
       "    <path d=\"M 389.559273 121.604125 \n",
       "L 393.949964 121.604125 \n",
       "L 393.949964 52.879581 \n",
       "L 389.559273 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_83\">\n",
       "    <path d=\"M 393.949964 121.604125 \n",
       "L 398.340655 121.604125 \n",
       "L 398.340655 52.466407 \n",
       "L 393.949964 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_84\">\n",
       "    <path d=\"M 398.340655 121.604125 \n",
       "L 402.731345 121.604125 \n",
       "L 402.731345 53.15503 \n",
       "L 398.340655 53.15503 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_85\">\n",
       "    <path d=\"M 402.731345 121.604125 \n",
       "L 407.122036 121.604125 \n",
       "L 407.122036 52.879581 \n",
       "L 402.731345 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_86\">\n",
       "    <path d=\"M 407.122036 121.604125 \n",
       "L 411.512727 121.604125 \n",
       "L 411.512727 52.328683 \n",
       "L 407.122036 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_87\">\n",
       "    <path d=\"M 411.512727 121.604125 \n",
       "L 415.903418 121.604125 \n",
       "L 415.903418 53.017306 \n",
       "L 411.512727 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_88\">\n",
       "    <path d=\"M 415.903418 121.604125 \n",
       "L 420.294109 121.604125 \n",
       "L 420.294109 52.328683 \n",
       "L 415.903418 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#pb7cbb96aef)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_89\">\n",
       "    <path d=\"M 351.031812 121.604125 \n",
       "L 401.752845 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- needle_length_mm -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(335.56245 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"378.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-67\" x=\"489.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"544.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-68\" x=\"572.753906\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"628.369141\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"683.984375\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"767.285156\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_5\">\n",
       "   <g id=\"patch_90\">\n",
       "    <path d=\"M 435.0528 121.604125 \n",
       "L 531.648 121.604125 \n",
       "L 531.648 48.7203 \n",
       "L 435.0528 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_9\">\n",
       "    <g id=\"xtick_13\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"458.000826\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(452.984139 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_14\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"483.358278\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(480.911466 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_15\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"508.71573\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(506.268918 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_10\"/>\n",
       "   <g id=\"patch_91\">\n",
       "    <path d=\"M 439.443491 121.604125 \n",
       "L 443.834182 121.604125 \n",
       "L 443.834182 52.741856 \n",
       "L 439.443491 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_92\">\n",
       "    <path d=\"M 443.834182 121.604125 \n",
       "L 448.224873 121.604125 \n",
       "L 448.224873 52.741856 \n",
       "L 443.834182 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_93\">\n",
       "    <path d=\"M 448.224873 121.604125 \n",
       "L 452.615564 121.604125 \n",
       "L 452.615564 52.879581 \n",
       "L 448.224873 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_94\">\n",
       "    <path d=\"M 452.615564 121.604125 \n",
       "L 457.006255 121.604125 \n",
       "L 457.006255 52.604132 \n",
       "L 452.615564 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_95\">\n",
       "    <path d=\"M 457.006255 121.604125 \n",
       "L 461.396945 121.604125 \n",
       "L 461.396945 53.017306 \n",
       "L 457.006255 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_96\">\n",
       "    <path d=\"M 461.396945 121.604125 \n",
       "L 465.787636 121.604125 \n",
       "L 465.787636 52.604132 \n",
       "L 461.396945 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_97\">\n",
       "    <path d=\"M 465.787636 121.604125 \n",
       "L 470.178327 121.604125 \n",
       "L 470.178327 52.604132 \n",
       "L 465.787636 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_98\">\n",
       "    <path d=\"M 470.178327 121.604125 \n",
       "L 474.569018 121.604125 \n",
       "L 474.569018 52.879581 \n",
       "L 470.178327 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_99\">\n",
       "    <path d=\"M 474.569018 121.604125 \n",
       "L 478.959709 121.604125 \n",
       "L 478.959709 52.604132 \n",
       "L 474.569018 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_100\">\n",
       "    <path d=\"M 478.959709 121.604125 \n",
       "L 483.3504 121.604125 \n",
       "L 483.3504 53.017306 \n",
       "L 478.959709 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_101\">\n",
       "    <path d=\"M 483.3504 121.604125 \n",
       "L 487.741091 121.604125 \n",
       "L 487.741091 52.741856 \n",
       "L 483.3504 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_102\">\n",
       "    <path d=\"M 487.741091 121.604125 \n",
       "L 492.131782 121.604125 \n",
       "L 492.131782 52.466407 \n",
       "L 487.741091 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_103\">\n",
       "    <path d=\"M 492.131782 121.604125 \n",
       "L 496.522473 121.604125 \n",
       "L 496.522473 52.879581 \n",
       "L 492.131782 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_104\">\n",
       "    <path d=\"M 496.522473 121.604125 \n",
       "L 500.913164 121.604125 \n",
       "L 500.913164 52.879581 \n",
       "L 496.522473 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_105\">\n",
       "    <path d=\"M 500.913164 121.604125 \n",
       "L 505.303855 121.604125 \n",
       "L 505.303855 52.604132 \n",
       "L 500.913164 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_106\">\n",
       "    <path d=\"M 505.303855 121.604125 \n",
       "L 509.694545 121.604125 \n",
       "L 509.694545 52.879581 \n",
       "L 505.303855 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_107\">\n",
       "    <path d=\"M 509.694545 121.604125 \n",
       "L 514.085236 121.604125 \n",
       "L 514.085236 52.604132 \n",
       "L 509.694545 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_108\">\n",
       "    <path d=\"M 514.085236 121.604125 \n",
       "L 518.475927 121.604125 \n",
       "L 518.475927 52.879581 \n",
       "L 514.085236 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_109\">\n",
       "    <path d=\"M 518.475927 121.604125 \n",
       "L 522.866618 121.604125 \n",
       "L 522.866618 53.017306 \n",
       "L 518.475927 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_110\">\n",
       "    <path d=\"M 522.866618 121.604125 \n",
       "L 527.257309 121.604125 \n",
       "L 527.257309 52.190958 \n",
       "L 522.866618 52.190958 \n",
       "z\n",
       "\" clip-path=\"url(#p5b5421daa0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_111\">\n",
       "    <path d=\"M 458.000826 121.604125 \n",
       "L 508.71573 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_20\">\n",
       "    <!-- needle_diameter_mm -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(436.92915 42.7203) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"489.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"572.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"656.054688\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"711.669922\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"744.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"883.886719\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_6\">\n",
       "   <g id=\"patch_112\">\n",
       "    <path d=\"M 542.016 121.604125 \n",
       "L 638.6112 121.604125 \n",
       "L 638.6112 48.7203 \n",
       "L 542.016 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_11\">\n",
       "    <g id=\"xtick_16\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"564.96841\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(559.951722 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_17\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"590.326189\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(587.879376 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_18\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"615.683968\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(613.237155 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_12\"/>\n",
       "   <g id=\"patch_113\">\n",
       "    <path d=\"M 546.406691 121.604125 \n",
       "L 550.797382 121.604125 \n",
       "L 550.797382 52.741856 \n",
       "L 546.406691 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_114\">\n",
       "    <path d=\"M 550.797382 121.604125 \n",
       "L 555.188073 121.604125 \n",
       "L 555.188073 52.741856 \n",
       "L 550.797382 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_115\">\n",
       "    <path d=\"M 555.188073 121.604125 \n",
       "L 559.578764 121.604125 \n",
       "L 559.578764 52.741856 \n",
       "L 555.188073 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_116\">\n",
       "    <path d=\"M 559.578764 121.604125 \n",
       "L 563.969455 121.604125 \n",
       "L 563.969455 52.741856 \n",
       "L 559.578764 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_117\">\n",
       "    <path d=\"M 563.969455 121.604125 \n",
       "L 568.360145 121.604125 \n",
       "L 568.360145 52.741856 \n",
       "L 563.969455 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_118\">\n",
       "    <path d=\"M 568.360145 121.604125 \n",
       "L 572.750836 121.604125 \n",
       "L 572.750836 52.741856 \n",
       "L 568.360145 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_119\">\n",
       "    <path d=\"M 572.750836 121.604125 \n",
       "L 577.141527 121.604125 \n",
       "L 577.141527 52.741856 \n",
       "L 572.750836 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_120\">\n",
       "    <path d=\"M 577.141527 121.604125 \n",
       "L 581.532218 121.604125 \n",
       "L 581.532218 52.741856 \n",
       "L 577.141527 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_121\">\n",
       "    <path d=\"M 581.532218 121.604125 \n",
       "L 585.922909 121.604125 \n",
       "L 585.922909 53.017306 \n",
       "L 581.532218 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_122\">\n",
       "    <path d=\"M 585.922909 121.604125 \n",
       "L 590.3136 121.604125 \n",
       "L 590.3136 52.466407 \n",
       "L 585.922909 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_123\">\n",
       "    <path d=\"M 590.3136 121.604125 \n",
       "L 594.704291 121.604125 \n",
       "L 594.704291 53.568204 \n",
       "L 590.3136 53.568204 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_124\">\n",
       "    <path d=\"M 594.704291 121.604125 \n",
       "L 599.094982 121.604125 \n",
       "L 599.094982 52.190958 \n",
       "L 594.704291 52.190958 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_125\">\n",
       "    <path d=\"M 599.094982 121.604125 \n",
       "L 603.485673 121.604125 \n",
       "L 603.485673 52.466407 \n",
       "L 599.094982 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_126\">\n",
       "    <path d=\"M 603.485673 121.604125 \n",
       "L 607.876364 121.604125 \n",
       "L 607.876364 52.741856 \n",
       "L 603.485673 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_127\">\n",
       "    <path d=\"M 607.876364 121.604125 \n",
       "L 612.267055 121.604125 \n",
       "L 612.267055 53.843653 \n",
       "L 607.876364 53.843653 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_128\">\n",
       "    <path d=\"M 612.267055 121.604125 \n",
       "L 616.657745 121.604125 \n",
       "L 616.657745 52.190958 \n",
       "L 612.267055 52.190958 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_129\">\n",
       "    <path d=\"M 616.657745 121.604125 \n",
       "L 621.048436 121.604125 \n",
       "L 621.048436 52.604132 \n",
       "L 616.657745 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_130\">\n",
       "    <path d=\"M 621.048436 121.604125 \n",
       "L 625.439127 121.604125 \n",
       "L 625.439127 53.017306 \n",
       "L 621.048436 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_131\">\n",
       "    <path d=\"M 625.439127 121.604125 \n",
       "L 629.829818 121.604125 \n",
       "L 629.829818 52.466407 \n",
       "L 625.439127 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_132\">\n",
       "    <path d=\"M 629.829818 121.604125 \n",
       "L 634.220509 121.604125 \n",
       "L 634.220509 52.328683 \n",
       "L 629.829818 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#pe4b05cf494)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_133\">\n",
       "    <path d=\"M 564.96841 121.604125 \n",
       "L 615.683968 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_24\">\n",
       "    <!-- spring_force_N -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(557.76585 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-73\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "     <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "     <use xlink:href=\"#ArialMT-66\" x=\"327.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"411.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"444.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"494.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"550.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-4e\" x=\"605.908203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_7\">\n",
       "   <g id=\"patch_134\">\n",
       "    <path d=\"M 648.9792 121.604125 \n",
       "L 745.5744 121.604125 \n",
       "L 745.5744 48.7203 \n",
       "L 648.9792 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_13\">\n",
       "    <g id=\"xtick_19\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"671.933578\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(666.91689 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_20\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"697.284603\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(694.83779 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_21\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"722.635628\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(720.188815 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_14\"/>\n",
       "   <g id=\"patch_135\">\n",
       "    <path d=\"M 653.369891 121.604125 \n",
       "L 657.760582 121.604125 \n",
       "L 657.760582 52.741856 \n",
       "L 653.369891 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_136\">\n",
       "    <path d=\"M 657.760582 121.604125 \n",
       "L 662.151273 121.604125 \n",
       "L 662.151273 52.741856 \n",
       "L 657.760582 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_137\">\n",
       "    <path d=\"M 662.151273 121.604125 \n",
       "L 666.541964 121.604125 \n",
       "L 666.541964 52.741856 \n",
       "L 662.151273 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_138\">\n",
       "    <path d=\"M 666.541964 121.604125 \n",
       "L 670.932655 121.604125 \n",
       "L 670.932655 52.741856 \n",
       "L 666.541964 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_139\">\n",
       "    <path d=\"M 670.932655 121.604125 \n",
       "L 675.323345 121.604125 \n",
       "L 675.323345 52.741856 \n",
       "L 670.932655 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_140\">\n",
       "    <path d=\"M 675.323345 121.604125 \n",
       "L 679.714036 121.604125 \n",
       "L 679.714036 53.017306 \n",
       "L 675.323345 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_141\">\n",
       "    <path d=\"M 679.714036 121.604125 \n",
       "L 684.104727 121.604125 \n",
       "L 684.104727 52.604132 \n",
       "L 679.714036 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_142\">\n",
       "    <path d=\"M 684.104727 121.604125 \n",
       "L 688.495418 121.604125 \n",
       "L 688.495418 52.604132 \n",
       "L 684.104727 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_143\">\n",
       "    <path d=\"M 688.495418 121.604125 \n",
       "L 692.886109 121.604125 \n",
       "L 692.886109 52.741856 \n",
       "L 688.495418 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_144\">\n",
       "    <path d=\"M 692.886109 121.604125 \n",
       "L 697.2768 121.604125 \n",
       "L 697.2768 52.741856 \n",
       "L 692.886109 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_145\">\n",
       "    <path d=\"M 697.2768 121.604125 \n",
       "L 701.667491 121.604125 \n",
       "L 701.667491 52.879581 \n",
       "L 697.2768 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_146\">\n",
       "    <path d=\"M 701.667491 121.604125 \n",
       "L 706.058182 121.604125 \n",
       "L 706.058182 52.741856 \n",
       "L 701.667491 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_147\">\n",
       "    <path d=\"M 706.058182 121.604125 \n",
       "L 710.448873 121.604125 \n",
       "L 710.448873 52.604132 \n",
       "L 706.058182 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_148\">\n",
       "    <path d=\"M 710.448873 121.604125 \n",
       "L 714.839564 121.604125 \n",
       "L 714.839564 52.741856 \n",
       "L 710.448873 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_149\">\n",
       "    <path d=\"M 714.839564 121.604125 \n",
       "L 719.230255 121.604125 \n",
       "L 719.230255 52.741856 \n",
       "L 714.839564 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_150\">\n",
       "    <path d=\"M 719.230255 121.604125 \n",
       "L 723.620945 121.604125 \n",
       "L 723.620945 52.741856 \n",
       "L 719.230255 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_151\">\n",
       "    <path d=\"M 723.620945 121.604125 \n",
       "L 728.011636 121.604125 \n",
       "L 728.011636 52.879581 \n",
       "L 723.620945 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_152\">\n",
       "    <path d=\"M 728.011636 121.604125 \n",
       "L 732.402327 121.604125 \n",
       "L 732.402327 52.604132 \n",
       "L 728.011636 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_153\">\n",
       "    <path d=\"M 732.402327 121.604125 \n",
       "L 736.793018 121.604125 \n",
       "L 736.793018 52.879581 \n",
       "L 732.402327 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_154\">\n",
       "    <path d=\"M 736.793018 121.604125 \n",
       "L 741.183709 121.604125 \n",
       "L 741.183709 52.604132 \n",
       "L 736.793018 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p34eb12ed71)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_155\">\n",
       "    <path d=\"M 671.933578 121.604125 \n",
       "L 722.635628 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_28\">\n",
       "    <!-- spring_constant_N_per_mm -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(636.98355 42.7203) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-73\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "     <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"327.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"377.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"433.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"489.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.992188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"622.607422\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"678.222656\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"706.005859\"/>\n",
       "     <use xlink:href=\"#ArialMT-4e\" x=\"761.621094\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"833.837891\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"889.453125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"945.068359\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1000.683594\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1033.984375\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1089.599609\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1172.900391\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_8\">\n",
       "   <g id=\"patch_156\">\n",
       "    <path d=\"M 755.9424 121.604125 \n",
       "L 852.5376 121.604125 \n",
       "L 852.5376 48.7203 \n",
       "L 755.9424 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_15\">\n",
       "    <g id=\"xtick_22\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"778.88043\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(773.863742 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_23\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"804.236215\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(801.789403 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_24\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"829.592\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(827.145188 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_16\"/>\n",
       "   <g id=\"patch_157\">\n",
       "    <path d=\"M 760.333091 121.604125 \n",
       "L 764.723782 121.604125 \n",
       "L 764.723782 52.741856 \n",
       "L 760.333091 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_158\">\n",
       "    <path d=\"M 764.723782 121.604125 \n",
       "L 769.114473 121.604125 \n",
       "L 769.114473 52.328683 \n",
       "L 764.723782 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_159\">\n",
       "    <path d=\"M 769.114473 121.604125 \n",
       "L 773.505164 121.604125 \n",
       "L 773.505164 53.15503 \n",
       "L 769.114473 53.15503 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_160\">\n",
       "    <path d=\"M 773.505164 121.604125 \n",
       "L 777.895855 121.604125 \n",
       "L 777.895855 52.604132 \n",
       "L 773.505164 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_161\">\n",
       "    <path d=\"M 777.895855 121.604125 \n",
       "L 782.286545 121.604125 \n",
       "L 782.286545 52.741856 \n",
       "L 777.895855 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_162\">\n",
       "    <path d=\"M 782.286545 121.604125 \n",
       "L 786.677236 121.604125 \n",
       "L 786.677236 52.879581 \n",
       "L 782.286545 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_163\">\n",
       "    <path d=\"M 786.677236 121.604125 \n",
       "L 791.067927 121.604125 \n",
       "L 791.067927 52.741856 \n",
       "L 786.677236 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_164\">\n",
       "    <path d=\"M 791.067927 121.604125 \n",
       "L 795.458618 121.604125 \n",
       "L 795.458618 52.741856 \n",
       "L 791.067927 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_165\">\n",
       "    <path d=\"M 795.458618 121.604125 \n",
       "L 799.849309 121.604125 \n",
       "L 799.849309 52.741856 \n",
       "L 795.458618 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_166\">\n",
       "    <path d=\"M 799.849309 121.604125 \n",
       "L 804.24 121.604125 \n",
       "L 804.24 52.741856 \n",
       "L 799.849309 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_167\">\n",
       "    <path d=\"M 804.24 121.604125 \n",
       "L 808.630691 121.604125 \n",
       "L 808.630691 52.741856 \n",
       "L 804.24 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_168\">\n",
       "    <path d=\"M 808.630691 121.604125 \n",
       "L 813.021382 121.604125 \n",
       "L 813.021382 52.741856 \n",
       "L 808.630691 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_169\">\n",
       "    <path d=\"M 813.021382 121.604125 \n",
       "L 817.412073 121.604125 \n",
       "L 817.412073 52.741856 \n",
       "L 813.021382 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_170\">\n",
       "    <path d=\"M 817.412073 121.604125 \n",
       "L 821.802764 121.604125 \n",
       "L 821.802764 52.741856 \n",
       "L 817.412073 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_171\">\n",
       "    <path d=\"M 821.802764 121.604125 \n",
       "L 826.193455 121.604125 \n",
       "L 826.193455 52.741856 \n",
       "L 821.802764 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_172\">\n",
       "    <path d=\"M 826.193455 121.604125 \n",
       "L 830.584145 121.604125 \n",
       "L 830.584145 52.741856 \n",
       "L 826.193455 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_173\">\n",
       "    <path d=\"M 830.584145 121.604125 \n",
       "L 834.974836 121.604125 \n",
       "L 834.974836 52.741856 \n",
       "L 830.584145 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_174\">\n",
       "    <path d=\"M 834.974836 121.604125 \n",
       "L 839.365527 121.604125 \n",
       "L 839.365527 53.017306 \n",
       "L 834.974836 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_175\">\n",
       "    <path d=\"M 839.365527 121.604125 \n",
       "L 843.756218 121.604125 \n",
       "L 843.756218 52.741856 \n",
       "L 839.365527 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_176\">\n",
       "    <path d=\"M 843.756218 121.604125 \n",
       "L 848.146909 121.604125 \n",
       "L 848.146909 52.466407 \n",
       "L 843.756218 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#pc76cdcdc22)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_177\">\n",
       "    <path d=\"M 778.88043 121.604125 \n",
       "L 829.592 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_32\">\n",
       "    <!-- kappa5 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(788.49375 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6b\" d=\"M 425 0 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 1969 \n",
       "L 2319 3319 \n",
       "L 3047 3319 \n",
       "L 1778 2088 \n",
       "L 3175 0 \n",
       "L 2481 0 \n",
       "L 1384 1697 \n",
       "L 988 1316 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6b\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-35\" x=\"272.460938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_9\">\n",
       "   <g id=\"patch_178\">\n",
       "    <path d=\"M 862.9056 121.604125 \n",
       "L 959.5008 121.604125 \n",
       "L 959.5008 48.7203 \n",
       "L 862.9056 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_17\">\n",
       "    <g id=\"xtick_25\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"885.847539\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(880.830851 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_26\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"911.202202\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(908.755389 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_27\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"936.556864\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(934.110052 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_18\"/>\n",
       "   <g id=\"patch_179\">\n",
       "    <path d=\"M 867.296291 121.604125 \n",
       "L 871.686982 121.604125 \n",
       "L 871.686982 52.604132 \n",
       "L 867.296291 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_180\">\n",
       "    <path d=\"M 871.686982 121.604125 \n",
       "L 876.077673 121.604125 \n",
       "L 876.077673 52.879581 \n",
       "L 871.686982 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_181\">\n",
       "    <path d=\"M 876.077673 121.604125 \n",
       "L 880.468364 121.604125 \n",
       "L 880.468364 52.604132 \n",
       "L 876.077673 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_182\">\n",
       "    <path d=\"M 880.468364 121.604125 \n",
       "L 884.859055 121.604125 \n",
       "L 884.859055 52.741856 \n",
       "L 880.468364 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_183\">\n",
       "    <path d=\"M 884.859055 121.604125 \n",
       "L 889.249745 121.604125 \n",
       "L 889.249745 52.879581 \n",
       "L 884.859055 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_184\">\n",
       "    <path d=\"M 889.249745 121.604125 \n",
       "L 893.640436 121.604125 \n",
       "L 893.640436 52.741856 \n",
       "L 889.249745 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_185\">\n",
       "    <path d=\"M 893.640436 121.604125 \n",
       "L 898.031127 121.604125 \n",
       "L 898.031127 52.741856 \n",
       "L 893.640436 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_186\">\n",
       "    <path d=\"M 898.031127 121.604125 \n",
       "L 902.421818 121.604125 \n",
       "L 902.421818 52.466407 \n",
       "L 898.031127 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_187\">\n",
       "    <path d=\"M 902.421818 121.604125 \n",
       "L 906.812509 121.604125 \n",
       "L 906.812509 53.017306 \n",
       "L 902.421818 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_188\">\n",
       "    <path d=\"M 906.812509 121.604125 \n",
       "L 911.2032 121.604125 \n",
       "L 911.2032 52.741856 \n",
       "L 906.812509 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_189\">\n",
       "    <path d=\"M 911.2032 121.604125 \n",
       "L 915.593891 121.604125 \n",
       "L 915.593891 52.604132 \n",
       "L 911.2032 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_190\">\n",
       "    <path d=\"M 915.593891 121.604125 \n",
       "L 919.984582 121.604125 \n",
       "L 919.984582 52.879581 \n",
       "L 915.593891 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_191\">\n",
       "    <path d=\"M 919.984582 121.604125 \n",
       "L 924.375273 121.604125 \n",
       "L 924.375273 52.741856 \n",
       "L 919.984582 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_192\">\n",
       "    <path d=\"M 924.375273 121.604125 \n",
       "L 928.765964 121.604125 \n",
       "L 928.765964 52.741856 \n",
       "L 924.375273 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_193\">\n",
       "    <path d=\"M 928.765964 121.604125 \n",
       "L 933.156655 121.604125 \n",
       "L 933.156655 52.741856 \n",
       "L 928.765964 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_194\">\n",
       "    <path d=\"M 933.156655 121.604125 \n",
       "L 937.547345 121.604125 \n",
       "L 937.547345 52.879581 \n",
       "L 933.156655 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_195\">\n",
       "    <path d=\"M 937.547345 121.604125 \n",
       "L 941.938036 121.604125 \n",
       "L 941.938036 52.741856 \n",
       "L 937.547345 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_196\">\n",
       "    <path d=\"M 941.938036 121.604125 \n",
       "L 946.328727 121.604125 \n",
       "L 946.328727 53.017306 \n",
       "L 941.938036 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_197\">\n",
       "    <path d=\"M 946.328727 121.604125 \n",
       "L 950.719418 121.604125 \n",
       "L 950.719418 52.466407 \n",
       "L 946.328727 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_198\">\n",
       "    <path d=\"M 950.719418 121.604125 \n",
       "L 955.110109 121.604125 \n",
       "L 955.110109 52.604132 \n",
       "L 950.719418 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#p6e1ff7a3fb)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_199\">\n",
       "    <path d=\"M 885.847539 121.604125 \n",
       "L 936.556864 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_36\">\n",
       "    <!-- kappa6 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(895.45695 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6b\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-36\" x=\"272.460938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_10\">\n",
       "   <g id=\"patch_200\">\n",
       "    <path d=\"M 969.8688 121.604125 \n",
       "L 1066.464 121.604125 \n",
       "L 1066.464 48.7203 \n",
       "L 969.8688 48.7203 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_19\">\n",
       "    <g id=\"xtick_28\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"992.801777\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_37\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(987.785089 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_29\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"1018.163236\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_38\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(1015.716424 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_30\">\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m00fd23b375\" x=\"1043.524696\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(1041.077883 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_20\"/>\n",
       "   <g id=\"patch_201\">\n",
       "    <path d=\"M 974.259491 121.604125 \n",
       "L 978.650182 121.604125 \n",
       "L 978.650182 52.466407 \n",
       "L 974.259491 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_202\">\n",
       "    <path d=\"M 978.650182 121.604125 \n",
       "L 983.040873 121.604125 \n",
       "L 983.040873 52.604132 \n",
       "L 978.650182 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_203\">\n",
       "    <path d=\"M 983.040873 121.604125 \n",
       "L 987.431564 121.604125 \n",
       "L 987.431564 52.604132 \n",
       "L 983.040873 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_204\">\n",
       "    <path d=\"M 987.431564 121.604125 \n",
       "L 991.822255 121.604125 \n",
       "L 991.822255 53.15503 \n",
       "L 987.431564 53.15503 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_205\">\n",
       "    <path d=\"M 991.822255 121.604125 \n",
       "L 996.212945 121.604125 \n",
       "L 996.212945 52.328683 \n",
       "L 991.822255 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_206\">\n",
       "    <path d=\"M 996.212945 121.604125 \n",
       "L 1000.603636 121.604125 \n",
       "L 1000.603636 53.292755 \n",
       "L 996.212945 53.292755 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_207\">\n",
       "    <path d=\"M 1000.603636 121.604125 \n",
       "L 1004.994327 121.604125 \n",
       "L 1004.994327 52.741856 \n",
       "L 1000.603636 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_208\">\n",
       "    <path d=\"M 1004.994327 121.604125 \n",
       "L 1009.385018 121.604125 \n",
       "L 1009.385018 52.466407 \n",
       "L 1004.994327 52.466407 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_209\">\n",
       "    <path d=\"M 1009.385018 121.604125 \n",
       "L 1013.775709 121.604125 \n",
       "L 1013.775709 53.017306 \n",
       "L 1009.385018 53.017306 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_210\">\n",
       "    <path d=\"M 1013.775709 121.604125 \n",
       "L 1018.1664 121.604125 \n",
       "L 1018.1664 52.741856 \n",
       "L 1013.775709 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_211\">\n",
       "    <path d=\"M 1018.1664 121.604125 \n",
       "L 1022.557091 121.604125 \n",
       "L 1022.557091 52.741856 \n",
       "L 1018.1664 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_212\">\n",
       "    <path d=\"M 1022.557091 121.604125 \n",
       "L 1026.947782 121.604125 \n",
       "L 1026.947782 52.741856 \n",
       "L 1022.557091 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_213\">\n",
       "    <path d=\"M 1026.947782 121.604125 \n",
       "L 1031.338473 121.604125 \n",
       "L 1031.338473 52.741856 \n",
       "L 1026.947782 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_214\">\n",
       "    <path d=\"M 1031.338473 121.604125 \n",
       "L 1035.729164 121.604125 \n",
       "L 1035.729164 52.741856 \n",
       "L 1031.338473 52.741856 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_215\">\n",
       "    <path d=\"M 1035.729164 121.604125 \n",
       "L 1040.119855 121.604125 \n",
       "L 1040.119855 52.879581 \n",
       "L 1035.729164 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_216\">\n",
       "    <path d=\"M 1040.119855 121.604125 \n",
       "L 1044.510545 121.604125 \n",
       "L 1044.510545 52.879581 \n",
       "L 1040.119855 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_217\">\n",
       "    <path d=\"M 1044.510545 121.604125 \n",
       "L 1048.901236 121.604125 \n",
       "L 1048.901236 52.879581 \n",
       "L 1044.510545 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_218\">\n",
       "    <path d=\"M 1048.901236 121.604125 \n",
       "L 1053.291927 121.604125 \n",
       "L 1053.291927 52.328683 \n",
       "L 1048.901236 52.328683 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_219\">\n",
       "    <path d=\"M 1053.291927 121.604125 \n",
       "L 1057.682618 121.604125 \n",
       "L 1057.682618 52.879581 \n",
       "L 1053.291927 52.879581 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_220\">\n",
       "    <path d=\"M 1057.682618 121.604125 \n",
       "L 1062.073309 121.604125 \n",
       "L 1062.073309 52.604132 \n",
       "L 1057.682618 52.604132 \n",
       "z\n",
       "\" clip-path=\"url(#paddb65490c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_221\">\n",
       "    <path d=\"M 992.801777 121.604125 \n",
       "L 1043.524696 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_40\">\n",
       "    <!-- kappa7 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(1002.42015 42.7203) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6b\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-37\" x=\"272.460938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_41\">\n",
       "   <!-- Transformed input data -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(477.5013 15.5862) scale(0.1152 -0.1152)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-54\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"90.634766\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"146.25\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"201.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-66\" x=\"251.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"279.648438\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"335.263672\"/>\n",
       "    <use xlink:href=\"#ArialMT-6d\" x=\"368.564453\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"451.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"507.480469\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"563.095703\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"590.878906\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"613.095703\"/>\n",
       "    <use xlink:href=\"#ArialMT-70\" x=\"668.710938\"/>\n",
       "    <use xlink:href=\"#ArialMT-75\" x=\"724.326172\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"779.941406\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"807.724609\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"835.507812\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"891.123047\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"946.738281\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"974.521484\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p3c675d26bb\">\n",
       "   <rect x=\"7.2\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p012b5edbad\">\n",
       "   <rect x=\"114.1632\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p7e48deb2fc\">\n",
       "   <rect x=\"221.1264\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pb7cbb96aef\">\n",
       "   <rect x=\"328.0896\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p5b5421daa0\">\n",
       "   <rect x=\"435.0528\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pe4b05cf494\">\n",
       "   <rect x=\"542.016\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p34eb12ed71\">\n",
       "   <rect x=\"648.9792\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pc76cdcdc22\">\n",
       "   <rect x=\"755.9424\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p6e1ff7a3fb\">\n",
       "   <rect x=\"862.9056\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"paddb65490c\">\n",
       "   <rect x=\"969.8688\" y=\"48.7203\" width=\"96.5952\" height=\"72.883825\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1500x200 with 10 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"569.664pt\" height=\"145.152pt\" viewBox=\"0 0 569.664 145.152\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:39:41.515034</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 145.152 \n",
       "L 569.664 145.152 \n",
       "L 569.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 7.2 121.604125 \n",
       "L 138.24 121.604125 \n",
       "L 138.24 48.6318 \n",
       "L 7.2 48.6318 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m90ebd5ed34\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"42.189791\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(37.173103 136.203) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"84.965795\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(82.518982 136.203) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"127.741799\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(125.294986 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 13.156364 121.604125 \n",
       "L 19.112727 121.604125 \n",
       "L 19.112727 112.585165 \n",
       "L 13.156364 112.585165 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 19.112727 121.604125 \n",
       "L 25.069091 121.604125 \n",
       "L 25.069091 103.214113 \n",
       "L 19.112727 103.214113 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 25.069091 121.604125 \n",
       "L 31.025455 121.604125 \n",
       "L 31.025455 102.64535 \n",
       "L 25.069091 102.64535 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 31.025455 121.604125 \n",
       "L 36.981818 121.604125 \n",
       "L 36.981818 105.51625 \n",
       "L 31.025455 105.51625 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 36.981818 121.604125 \n",
       "L 42.938182 121.604125 \n",
       "L 42.938182 108.79341 \n",
       "L 36.981818 108.79341 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 42.938182 121.604125 \n",
       "L 48.894545 121.604125 \n",
       "L 48.894545 110.418448 \n",
       "L 42.938182 110.418448 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 48.894545 121.604125 \n",
       "L 54.850909 121.604125 \n",
       "L 54.850909 112.341409 \n",
       "L 48.894545 112.341409 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 54.850909 121.604125 \n",
       "L 60.807273 121.604125 \n",
       "L 60.807273 113.803943 \n",
       "L 54.850909 113.803943 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 60.807273 121.604125 \n",
       "L 66.763636 121.604125 \n",
       "L 66.763636 115.672737 \n",
       "L 60.807273 115.672737 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 66.763636 121.604125 \n",
       "L 72.72 121.604125 \n",
       "L 72.72 116.837347 \n",
       "L 66.763636 116.837347 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 72.72 121.604125 \n",
       "L 78.676364 121.604125 \n",
       "L 78.676364 117.054019 \n",
       "L 72.72 117.054019 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 78.676364 121.604125 \n",
       "L 84.632727 121.604125 \n",
       "L 84.632727 118.08321 \n",
       "L 78.676364 118.08321 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 84.632727 121.604125 \n",
       "L 90.589091 121.604125 \n",
       "L 90.589091 117.568614 \n",
       "L 84.632727 117.568614 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 90.589091 121.604125 \n",
       "L 96.545455 121.604125 \n",
       "L 96.545455 117.758202 \n",
       "L 90.589091 117.758202 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 96.545455 121.604125 \n",
       "L 102.501818 121.604125 \n",
       "L 102.501818 118.354049 \n",
       "L 96.545455 118.354049 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path d=\"M 102.501818 121.604125 \n",
       "L 108.458182 121.604125 \n",
       "L 108.458182 118.706141 \n",
       "L 102.501818 118.706141 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path d=\"M 108.458182 121.604125 \n",
       "L 114.414545 121.604125 \n",
       "L 114.414545 117.649866 \n",
       "L 108.458182 117.649866 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_20\">\n",
       "    <path d=\"M 114.414545 121.604125 \n",
       "L 120.370909 121.604125 \n",
       "L 120.370909 107.22254 \n",
       "L 114.414545 107.22254 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_21\">\n",
       "    <path d=\"M 120.370909 121.604125 \n",
       "L 126.327273 121.604125 \n",
       "L 126.327273 52.106673 \n",
       "L 120.370909 52.106673 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_22\">\n",
       "    <path d=\"M 126.327273 121.604125 \n",
       "L 132.283636 121.604125 \n",
       "L 132.283636 74.911371 \n",
       "L 126.327273 74.911371 \n",
       "z\n",
       "\" clip-path=\"url(#pf19467ec2b)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_23\">\n",
       "    <path d=\"M 42.189791 121.604125 \n",
       "L 127.741799 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_4\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(20.69025 42.6318) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_24\">\n",
       "    <path d=\"M 148.608 121.604125 \n",
       "L 279.648 121.604125 \n",
       "L 279.648 48.6318 \n",
       "L 148.608 48.6318 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"171.994515\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −2.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(163.30864 136.203) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"218.947546\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(212.831546 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"265.900577\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 2.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(259.784577 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\"/>\n",
       "   <g id=\"patch_25\">\n",
       "    <path d=\"M 154.564364 121.604125 \n",
       "L 160.520727 121.604125 \n",
       "L 160.520727 121.468705 \n",
       "L 154.564364 121.468705 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_26\">\n",
       "    <path d=\"M 160.520727 121.604125 \n",
       "L 166.477091 121.604125 \n",
       "L 166.477091 121.279117 \n",
       "L 160.520727 121.279117 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_27\">\n",
       "    <path d=\"M 166.477091 121.604125 \n",
       "L 172.433455 121.604125 \n",
       "L 172.433455 120.872858 \n",
       "L 166.477091 120.872858 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_28\">\n",
       "    <path d=\"M 172.433455 121.604125 \n",
       "L 178.389818 121.604125 \n",
       "L 178.389818 119.843667 \n",
       "L 172.433455 119.843667 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_29\">\n",
       "    <path d=\"M 178.389818 121.604125 \n",
       "L 184.346182 121.604125 \n",
       "L 184.346182 117.351943 \n",
       "L 178.389818 117.351943 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_30\">\n",
       "    <path d=\"M 184.346182 121.604125 \n",
       "L 190.302545 121.604125 \n",
       "L 190.302545 111.691394 \n",
       "L 184.346182 111.691394 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_31\">\n",
       "    <path d=\"M 190.302545 121.604125 \n",
       "L 196.258909 121.604125 \n",
       "L 196.258909 105.624586 \n",
       "L 190.302545 105.624586 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_32\">\n",
       "    <path d=\"M 196.258909 121.604125 \n",
       "L 202.215273 121.604125 \n",
       "L 202.215273 100.397381 \n",
       "L 196.258909 100.397381 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_33\">\n",
       "    <path d=\"M 202.215273 121.604125 \n",
       "L 208.171636 121.604125 \n",
       "L 208.171636 96.009779 \n",
       "L 202.215273 96.009779 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_34\">\n",
       "    <path d=\"M 208.171636 121.604125 \n",
       "L 214.128 121.604125 \n",
       "L 214.128 91.107581 \n",
       "L 208.171636 91.107581 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_35\">\n",
       "    <path d=\"M 214.128 121.604125 \n",
       "L 220.084364 121.604125 \n",
       "L 220.084364 89.401291 \n",
       "L 214.128 89.401291 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_36\">\n",
       "    <path d=\"M 220.084364 121.604125 \n",
       "L 226.040727 121.604125 \n",
       "L 226.040727 90.701322 \n",
       "L 220.084364 90.701322 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_37\">\n",
       "    <path d=\"M 226.040727 121.604125 \n",
       "L 231.997091 121.604125 \n",
       "L 231.997091 93.599306 \n",
       "L 226.040727 93.599306 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_38\">\n",
       "    <path d=\"M 231.997091 121.604125 \n",
       "L 237.953455 121.604125 \n",
       "L 237.953455 98.636923 \n",
       "L 231.997091 98.636923 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_39\">\n",
       "    <path d=\"M 237.953455 121.604125 \n",
       "L 243.909818 121.604125 \n",
       "L 243.909818 102.266174 \n",
       "L 237.953455 102.266174 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_40\">\n",
       "    <path d=\"M 243.909818 121.604125 \n",
       "L 249.866182 121.604125 \n",
       "L 249.866182 107.845471 \n",
       "L 243.909818 107.845471 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_41\">\n",
       "    <path d=\"M 249.866182 121.604125 \n",
       "L 255.822545 121.604125 \n",
       "L 255.822545 114.237287 \n",
       "L 249.866182 114.237287 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_42\">\n",
       "    <path d=\"M 255.822545 121.604125 \n",
       "L 261.778909 121.604125 \n",
       "L 261.778909 117.568614 \n",
       "L 255.822545 117.568614 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_43\">\n",
       "    <path d=\"M 261.778909 121.604125 \n",
       "L 267.735273 121.604125 \n",
       "L 267.735273 120.060339 \n",
       "L 261.778909 120.060339 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_44\">\n",
       "    <path d=\"M 267.735273 121.604125 \n",
       "L 273.691636 121.604125 \n",
       "L 273.691636 121.279117 \n",
       "L 267.735273 121.279117 \n",
       "z\n",
       "\" clip-path=\"url(#pf6f4eb365a)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_45\">\n",
       "    <path d=\"M 171.994515 121.604125 \n",
       "L 265.900577 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_8\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(179.712 42.6318) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_46\">\n",
       "    <path d=\"M 290.016 121.604125 \n",
       "L 421.056 121.604125 \n",
       "L 421.056 48.6318 \n",
       "L 290.016 48.6318 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"310.681053\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(305.664366 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"358.233761\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(355.786949 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"405.786469\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(403.339657 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\"/>\n",
       "   <g id=\"patch_47\">\n",
       "    <path d=\"M 295.972364 121.604125 \n",
       "L 301.928727 121.604125 \n",
       "L 301.928727 120.574934 \n",
       "L 295.972364 120.574934 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_48\">\n",
       "    <path d=\"M 301.928727 121.604125 \n",
       "L 307.885091 121.604125 \n",
       "L 307.885091 118.733225 \n",
       "L 301.928727 118.733225 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_49\">\n",
       "    <path d=\"M 307.885091 121.604125 \n",
       "L 313.841455 121.604125 \n",
       "L 313.841455 115.862325 \n",
       "L 307.885091 115.862325 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_50\">\n",
       "    <path d=\"M 313.841455 121.604125 \n",
       "L 319.797818 121.604125 \n",
       "L 319.797818 110.960127 \n",
       "L 313.841455 110.960127 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_51\">\n",
       "    <path d=\"M 319.797818 121.604125 \n",
       "L 325.754182 121.604125 \n",
       "L 325.754182 108.143395 \n",
       "L 319.797818 108.143395 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_52\">\n",
       "    <path d=\"M 325.754182 121.604125 \n",
       "L 331.710545 121.604125 \n",
       "L 331.710545 108.251731 \n",
       "L 325.754182 108.251731 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_53\">\n",
       "    <path d=\"M 331.710545 121.604125 \n",
       "L 337.666909 121.604125 \n",
       "L 337.666909 108.766326 \n",
       "L 331.710545 108.766326 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_54\">\n",
       "    <path d=\"M 337.666909 121.604125 \n",
       "L 343.623273 121.604125 \n",
       "L 343.623273 106.897532 \n",
       "L 337.666909 106.897532 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_55\">\n",
       "    <path d=\"M 343.623273 121.604125 \n",
       "L 349.579636 121.604125 \n",
       "L 349.579636 104.541227 \n",
       "L 343.623273 104.541227 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_56\">\n",
       "    <path d=\"M 349.579636 121.604125 \n",
       "L 355.536 121.604125 \n",
       "L 355.536 101.886999 \n",
       "L 349.579636 101.886999 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_57\">\n",
       "    <path d=\"M 355.536 121.604125 \n",
       "L 361.492364 121.604125 \n",
       "L 361.492364 97.120221 \n",
       "L 355.536 97.120221 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_58\">\n",
       "    <path d=\"M 361.492364 121.604125 \n",
       "L 367.448727 121.604125 \n",
       "L 367.448727 95.359764 \n",
       "L 361.492364 95.359764 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_59\">\n",
       "    <path d=\"M 367.448727 121.604125 \n",
       "L 373.405091 121.604125 \n",
       "L 373.405091 94.330573 \n",
       "L 367.448727 94.330573 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_60\">\n",
       "    <path d=\"M 373.405091 121.604125 \n",
       "L 379.361455 121.604125 \n",
       "L 379.361455 96.49729 \n",
       "L 373.405091 96.49729 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_61\">\n",
       "    <path d=\"M 379.361455 121.604125 \n",
       "L 385.317818 121.604125 \n",
       "L 385.317818 98.582755 \n",
       "L 379.361455 98.582755 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_62\">\n",
       "    <path d=\"M 385.317818 121.604125 \n",
       "L 391.274182 121.604125 \n",
       "L 391.274182 106.003762 \n",
       "L 385.317818 106.003762 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_63\">\n",
       "    <path d=\"M 391.274182 121.604125 \n",
       "L 397.230545 121.604125 \n",
       "L 397.230545 110.878875 \n",
       "L 391.274182 110.878875 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_64\">\n",
       "    <path d=\"M 397.230545 121.604125 \n",
       "L 403.186909 121.604125 \n",
       "L 403.186909 116.485256 \n",
       "L 397.230545 116.485256 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_65\">\n",
       "    <path d=\"M 403.186909 121.604125 \n",
       "L 409.143273 121.604125 \n",
       "L 409.143273 119.924919 \n",
       "L 403.186909 119.924919 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_66\">\n",
       "    <path d=\"M 409.143273 121.604125 \n",
       "L 415.099636 121.604125 \n",
       "L 415.099636 121.441621 \n",
       "L 409.143273 121.441621 \n",
       "z\n",
       "\" clip-path=\"url(#p77aa994560)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_67\">\n",
       "    <path d=\"M 310.681053 121.604125 \n",
       "L 405.786469 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_12\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(293.907 42.6318) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_68\">\n",
       "    <path d=\"M 431.424 121.604125 \n",
       "L 562.464 121.604125 \n",
       "L 562.464 48.6318 \n",
       "L 431.424 48.6318 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"441.833073\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(436.816385 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"497.114363\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(494.667551 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m90ebd5ed34\" x=\"552.395654\" y=\"121.604125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(549.948842 136.203) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\"/>\n",
       "   <g id=\"patch_69\">\n",
       "    <path d=\"M 437.380364 121.604125 \n",
       "L 443.336727 121.604125 \n",
       "L 443.336727 120.114507 \n",
       "L 437.380364 120.114507 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_70\">\n",
       "    <path d=\"M 443.336727 121.604125 \n",
       "L 449.293091 121.604125 \n",
       "L 449.293091 113.560188 \n",
       "L 443.336727 113.560188 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_71\">\n",
       "    <path d=\"M 449.293091 121.604125 \n",
       "L 455.249455 121.604125 \n",
       "L 455.249455 108.278815 \n",
       "L 449.293091 108.278815 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_72\">\n",
       "    <path d=\"M 455.249455 121.604125 \n",
       "L 461.205818 121.604125 \n",
       "L 461.205818 108.116311 \n",
       "L 455.249455 108.116311 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_73\">\n",
       "    <path d=\"M 461.205818 121.604125 \n",
       "L 467.162182 121.604125 \n",
       "L 467.162182 108.332982 \n",
       "L 461.205818 108.332982 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_74\">\n",
       "    <path d=\"M 467.162182 121.604125 \n",
       "L 473.118545 121.604125 \n",
       "L 473.118545 107.060036 \n",
       "L 467.162182 107.060036 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_75\">\n",
       "    <path d=\"M 473.118545 121.604125 \n",
       "L 479.074909 121.604125 \n",
       "L 479.074909 106.843364 \n",
       "L 473.118545 106.843364 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_76\">\n",
       "    <path d=\"M 479.074909 121.604125 \n",
       "L 485.031273 121.604125 \n",
       "L 485.031273 104.812067 \n",
       "L 479.074909 104.812067 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_77\">\n",
       "    <path d=\"M 485.031273 121.604125 \n",
       "L 490.987636 121.604125 \n",
       "L 490.987636 105.164159 \n",
       "L 485.031273 105.164159 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_78\">\n",
       "    <path d=\"M 490.987636 121.604125 \n",
       "L 496.944 121.604125 \n",
       "L 496.944 105.353746 \n",
       "L 490.987636 105.353746 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_79\">\n",
       "    <path d=\"M 496.944 121.604125 \n",
       "L 502.900364 121.604125 \n",
       "L 502.900364 102.78077 \n",
       "L 496.944 102.78077 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_80\">\n",
       "    <path d=\"M 502.900364 121.604125 \n",
       "L 508.856727 121.604125 \n",
       "L 508.856727 103.647457 \n",
       "L 502.900364 103.647457 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_81\">\n",
       "    <path d=\"M 508.856727 121.604125 \n",
       "L 514.813091 121.604125 \n",
       "L 514.813091 101.859915 \n",
       "L 508.856727 101.859915 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_82\">\n",
       "    <path d=\"M 514.813091 121.604125 \n",
       "L 520.769455 121.604125 \n",
       "L 520.769455 101.48074 \n",
       "L 514.813091 101.48074 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_83\">\n",
       "    <path d=\"M 520.769455 121.604125 \n",
       "L 526.725818 121.604125 \n",
       "L 526.725818 101.968251 \n",
       "L 520.769455 101.968251 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_84\">\n",
       "    <path d=\"M 526.725818 121.604125 \n",
       "L 532.682182 121.604125 \n",
       "L 532.682182 103.024525 \n",
       "L 526.725818 103.024525 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_85\">\n",
       "    <path d=\"M 532.682182 121.604125 \n",
       "L 538.638545 121.604125 \n",
       "L 538.638545 106.9517 \n",
       "L 532.682182 106.9517 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_86\">\n",
       "    <path d=\"M 538.638545 121.604125 \n",
       "L 544.594909 121.604125 \n",
       "L 544.594909 112.774753 \n",
       "L 538.638545 112.774753 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_87\">\n",
       "    <path d=\"M 544.594909 121.604125 \n",
       "L 550.551273 121.604125 \n",
       "L 550.551273 117.81237 \n",
       "L 544.594909 117.81237 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_88\">\n",
       "    <path d=\"M 550.551273 121.604125 \n",
       "L 556.507636 121.604125 \n",
       "L 556.507636 121.306201 \n",
       "L 550.551273 121.306201 \n",
       "z\n",
       "\" clip-path=\"url(#pbbbac67699)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_89\">\n",
       "    <path d=\"M 441.833073 121.604125 \n",
       "L 552.395654 121.604125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(435.04575 42.6318) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_17\">\n",
       "   <!-- Transformed output data -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(221.9778 15.5862) scale(0.1152 -0.1152)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-54\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"90.634766\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"146.25\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"201.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-66\" x=\"251.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"279.648438\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"335.263672\"/>\n",
       "    <use xlink:href=\"#ArialMT-6d\" x=\"368.564453\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"451.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"507.480469\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"563.095703\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"590.878906\"/>\n",
       "    <use xlink:href=\"#ArialMT-75\" x=\"646.494141\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"702.109375\"/>\n",
       "    <use xlink:href=\"#ArialMT-70\" x=\"729.892578\"/>\n",
       "    <use xlink:href=\"#ArialMT-75\" x=\"785.507812\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"841.123047\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"868.90625\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"896.689453\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"952.304688\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1007.919922\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"1035.703125\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pf19467ec2b\">\n",
       "   <rect x=\"7.2\" y=\"48.6318\" width=\"131.04\" height=\"72.972325\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pf6f4eb365a\">\n",
       "   <rect x=\"148.608\" y=\"48.6318\" width=\"131.04\" height=\"72.972325\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p77aa994560\">\n",
       "   <rect x=\"290.016\" y=\"48.6318\" width=\"131.04\" height=\"72.972325\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pbbbac67699\">\n",
       "   <rect x=\"431.424\" y=\"48.6318\" width=\"131.04\" height=\"72.972325\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 800x200 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(1, X_train_scaled.shape[1], figsize=(15, 2), tight_layout=True, sharey=True)\n",
    "fig.suptitle(\"Transformed input data\")\n",
    "for i, i_name in enumerate(INPUT_NAMES):\n",
    "    ax[i].hist(X_train_scaled[:, i], bins=20)\n",
    "    ax[i].set_title(i_name)\n",
    "    ax[i].set_yticks([])\n",
    "    sns.despine(trim=True, ax=ax[i], left=True)\n",
    "\n",
    "fig, ax = plt.subplots(1, y_train_scaled.shape[1], figsize=(8, 2), tight_layout=True, sharey=True)\n",
    "fig.suptitle(\"Transformed output data\")\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].hist(y_train_scaled[:, i], bins=20)\n",
    "    ax[i].set_title(o_name)\n",
    "    ax[i].set_yticks([])\n",
    "    sns.despine(trim=True, ax=ax[i], left=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Nice! The input/output data are all more-or-less evenly distributed and standarized. Now on to building the Gaussian process surrogate."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Gaussian process regression\n",
    "\n",
    "We will use `GPJax` to construct 4 different GP surrogates, one for each output. We'll write the math down for one of the outputs, but the same applies to the other outputs.\n",
    "\n",
    "### Prior\n",
    "\n",
    "First, let's create the GP prior with zero mean, i.e., \n",
    "\n",
    "$$\n",
    "m(x) = 0\n",
    "$$\n",
    "\n",
    "and a radial basis function (RBF) as the covariance kernel, i.e.,\n",
    "\n",
    "$$\n",
    "k(x, x') = \\sigma^2 \\exp\\left(-\\frac{1}{2} \\sum_{i=1}^d \\left(\\frac{x_i - x'_i}{\\ell_i}\\right)^2\\right)\n",
    "$$\n",
    "\n",
    "where $\\sigma^2$ is the variance and $\\ell_i$ is the length scale for input dimension $i$. We write the prior as\n",
    "\n",
    "$$\n",
    "f \\sim \\operatorname{GP}(m, k).\n",
    "$$\n",
    "\n",
    "Here is how to do it in `GPJax`:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Zero mean\n",
    "mean = gpx.mean_functions.Zero()\n",
    "\n",
    "# Set the lengthscale/variance to decent values - they will be optimized later.\n",
    "kernel = gpx.kernels.RBF(lengthscale=jnp.ones(X_train_scaled.shape[1]), variance=1.0)\n",
    "\n",
    "# GP prior\n",
    "prior = gpx.gps.Prior(mean_function=mean, kernel=kernel)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Likelihood\n",
    "\n",
    "We'll use a Gaussian likelihood. For training data $\\mathcal{D}\\equiv\\{x_i, y_i = f(x_i)\\}_{i=1}^n$, we have that\n",
    "\n",
    "<!-- $$\n",
    "\\mathbf{X} \\equiv \\begin{bmatrix} \\mathbf{x}_1 \\\\ \\vdots \\\\ \\mathbf{x}_N \\end{bmatrix} \\in \\mathbb{R}^{N \\times d}\n",
    "$$ \n",
    "\n",
    "and output data \n",
    "\n",
    "$$\n",
    "\\mathbf{y} \\equiv \\begin{bmatrix} y_1 \\\\ \\vdots \\\\ y_N \\end{bmatrix} \\in \\mathbb{R}^N\n",
    "$$ -->\n",
    "\n",
    "\n",
    "\n",
    "$$\n",
    "y_i|f, x_i \\sim \\mathcal{N}(f(x_i), \\sigma_n^2) \\quad \\text{independently for } i = 1, \\ldots, N,\n",
    "$$\n",
    "\n",
    "where $f$ is the physical model and $\\sigma_n^2$ is the measurement noise variance. \n",
    "\n",
    "Note that for surrogates of computer simulations, $\\sigma_n^2$ will typically be small. This is because, for most deterministic computer programs, running the program several times with the exact same inputs will yield identical results (up to machine precision). \n",
    "\n",
    "Coding this in `GPJax` is straightworward:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "likelihood = gpx.likelihoods.Gaussian(\n",
    "    num_datapoints=y_train.shape[0],\n",
    "    obs_stddev=0.001\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Posterior\n",
    "\n",
    "We can now construct the GP posterior\n",
    "\n",
    "$$\n",
    "f | \\mathcal{D} \\sim \\operatorname{GP}(m_{\\text{post}}, k_{\\text{post}})\n",
    "$$"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "posterior = prior * likelihood"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Optimizing hyperparameters\n",
    "\n",
    "For each GP posterior, the hyperparameters are the RBF kernel variance $\\sigma^2$, lengthscales $\\mathbf{\\ell}=(\\ell_1, \\dots, \\ell_d)$, and measurement noise variance $\\sigma_n^2$. \n",
    "\n",
    "Let's denote the hyperparameters as $\\psi=(\\sigma^2, \\mathbf{\\ell}, \\sigma_n^2)$.\n",
    "We'll pick optimal $\\psi$ by maximizing the marginal log likelihood, i.e.,\n",
    "\n",
    "$$\n",
    "\\psi^* = \\arg\\max_{\\psi} ~ \\log p(\\mathbf{y} | \\mathbf{X}, \\psi).\n",
    "$$\n",
    "\n",
    "`GPJax` provides the functions `conjugate_mll` and `fit` to do this. (Note that we do everything in a loop so each output gets its own GP surrogate.)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "# Loss function: negative marginal log likelihood\n",
    "negative_mll = nnx.jit(lambda p, d: -gpx.objectives.conjugate_mll(p, d))\n",
    "\n",
    "def optimize_gps(posterior, datasets, num_iters=1000, batch_size=128, learning_rate=1e-2, verbose=True, *, key):\n",
    "    \"\"\"Optimizes the hyperparameters in the GP model (separately for each output).\"\"\"\n",
    "    posteriors = {}\n",
    "    loss_histories = {}\n",
    "    \n",
    "    # Do this in a loop to construct a GP for each output.\n",
    "    for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "        key, subkey = jrandom.split(key)\n",
    "        posteriors[o_name], loss_histories[o_name] = gpx.fit(\n",
    "            model=posterior,\n",
    "            objective=negative_mll,\n",
    "            train_data=datasets[o_name],\n",
    "            optim=optax.adam(learning_rate),  # Adam optimizer\n",
    "            num_iters=num_iters,\n",
    "            batch_size=batch_size,\n",
    "            key=subkey,\n",
    "            verbose=verbose\n",
    "        )\n",
    "\n",
    "    return posteriors, loss_histories\n",
    "\n",
    "def create_datasets(size=None, X=X_train_scaled, y=y_train_scaled, output_names=OUTPUT_NAMES):\n",
    "    \"\"\"Creates a GPJax datasets (one for each output) out of a subset of the training data.\"\"\"\n",
    "    if size is None:\n",
    "        size = X.shape[0]\n",
    "    datasets = {}\n",
    "    for i, o_name in enumerate(output_names):\n",
    "        datasets[o_name] = gpx.Dataset(X[:size], y[:size, i:i+1])\n",
    "    return datasets"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a6e3a29e6cab494f94f7743f7eca31de",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/1000 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "cf9790d44c8b44b4ad1b49ff9fddf897",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/1000 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "caa474e753904baaba310ebf303b03e4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/1000 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "573414da8df04c748026897e5e92efdc",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "  0%|          | 0/1000 [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# Create a separate dataset for each output (and put it all in a single dictionary)\n",
    "datasets = create_datasets(size=200)\n",
    "\n",
    "# Optimize the hyperparameters\n",
    "key, subkey = jrandom.split(key)\n",
    "posteriors, loss_histories = optimize_gps(posterior, datasets, key=subkey)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We now have an optimized GP for each output!"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Predictive distribution: How to evaluate the GP?\n",
    "\n",
    "The question now is **how do we use our GPs to make predictions?** The predictive distribution for a new input $\\mathbf{x}^*$ is given by\n",
    "\n",
    "$$\n",
    "p\\big( f(\\mathbf{x}^*) \\big | \\mathcal{D})\n",
    "= \\int \\underbrace{p\\big( f(\\mathbf{x}^*) \\big | f(\\mathbf{x}) \\big)}_{\\substack{\\text{conditional probability} \\\\ \\text{of output at } \\mathbf{x}^*}} \\underbrace{p\\big(f(\\mathbf{x}) \\big| \\mathcal{D}\\big)}_{\\substack{\\text{posterior GP} \\\\ \\text{evaluated at } \\mathbf{x}}} df(\\mathbf{x})\n",
    "$$\n",
    "\n",
    "GPJax provides the function `predict` which can be used to give the mean and variance of the predictive distribution $p\\big( f(\\mathbf{x}^*) \\big| \\mathcal{D} \\big)$. Or, we can sample from the predictive distribution using the function `sample`.\n",
    "\n",
    "To facilitate making new predictions, let's wrap `predict` and `sample` with the following helper class, which represents the surrogate:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "class Surrogate(eqx.Module):\n",
    "    models: dict[str, gpx.gps.AbstractPosterior]\n",
    "    train_data: dict[str, gpx.Dataset]\n",
    "    input_transform: StandardScaler = input_transform\n",
    "    output_transform: StandardScaler = output_transform\n",
    "    IN_NAMES: list[str] = eqx.field(default_factory=lambda: INPUT_NAMES)\n",
    "    OUT_NAMES: list[str] = eqx.field(default_factory=lambda: OUTPUT_NAMES)\n",
    "    \n",
    "    def __call__(self, X):\n",
    "        \"\"\"\n",
    "        Evaluate the model at X.\n",
    "        \"\"\"\n",
    "        Z = vmap(self.input_transform.forward)(X)\n",
    "        y = self.get_scaled_predictive_mean_stdev(Z)[0]  # Just the mean\n",
    "        return vmap(self.output_transform.inverse)(y)\n",
    "\n",
    "    def sample(self, X, num_samples, *, key):\n",
    "        \"\"\"Sample the output. Contains both aleatoric and epistemic uncertainty.\"\"\"\n",
    "        Z = vmap(self.input_transform.forward)(X)\n",
    "        y = self.sample_scaled_predictive(Z, num_samples, key=key)\n",
    "        return vmap(self.output_transform.inverse)(y)\n",
    "    \n",
    "    def sample_scaled_predictive(self, X, num_samples, *, key):\n",
    "        \"\"\"Sample the scaled output. Contains both aleatoric and epistemic uncertainty.\"\"\"\n",
    "        predictive_dists = self._get_predictive_dists(X)\n",
    "        y = []\n",
    "        for o_name in self.OUT_NAMES:\n",
    "            samples = predictive_dists[o_name].sample(seed=key, sample_shape=(num_samples,))\n",
    "            y.append(samples)\n",
    "        y = jnp.concatenate(y, axis=1)\n",
    "        return y\n",
    "    \n",
    "    def sample_latent(self, X, num_samples, *, key):\n",
    "        \"\"\"Sample the latent space of the model (i.e., a GP sample before passing through the likelihood). Contains only epistemic uncertainty.\"\"\"\n",
    "        latent_dists = self._get_latent_dists(X)\n",
    "        f = []\n",
    "        for o_name in self.OUT_NAMES:\n",
    "            samples = latent_dists[o_name].sample(seed=key, sample_shape=(num_samples,))\n",
    "            f.append(samples)\n",
    "        f = jnp.concatenate(f, axis=1)\n",
    "        return f\n",
    "    \n",
    "    def get_scaled_predictive_mean_stdev(self, X):\n",
    "        \"\"\"Get the mean and standard deviation of the scaled output. Contains both aleatoric and epistemic uncertainty.\"\"\"\n",
    "        predictive_dists = self._get_predictive_dists(X)\n",
    "        y_mean = []\n",
    "        y_stdev = []\n",
    "        for o_name in self.OUT_NAMES:\n",
    "            y_mean.append(predictive_dists[o_name].mean())\n",
    "            y_stdev.append(predictive_dists[o_name].stddev())\n",
    "        return jnp.stack(y_mean, axis=1), jnp.stack(y_stdev, axis=1)\n",
    "    \n",
    "    def get_latent_mean_stdev(self, X):\n",
    "        \"\"\"Get the mean and standard deviation of the latent distribution. Contains only epistemic uncertainty.\"\"\"\n",
    "        latent_dists = self._get_latent_dists(X)\n",
    "        f_mean = []\n",
    "        f_stdev = []\n",
    "        for o_name in self.OUT_NAMES:\n",
    "            f_mean.append(latent_dists[o_name].mean())\n",
    "            f_stdev.append(latent_dists[o_name].stddev())\n",
    "        return jnp.stack(f_mean, axis=1), jnp.stack(f_stdev, axis=1)\n",
    "    \n",
    "    def _get_latent_dists(self, X):\n",
    "        latent_dists = {}\n",
    "        for o_name in self.OUT_NAMES:\n",
    "            latent_dists[o_name] = self.models[o_name].predict(X, self.train_data[o_name])\n",
    "        return latent_dists\n",
    "    \n",
    "    def _get_predictive_dists(self, X):\n",
    "        latent_dists = self._get_latent_dists(X)\n",
    "        predictive_dists = {}\n",
    "        for o_name in self.OUT_NAMES:\n",
    "            predictive_dists[o_name] = self.models[o_name].likelihood(latent_dists[o_name])\n",
    "        return predictive_dists"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [],
   "source": [
    "surrogate_ = Surrogate(\n",
    "    models=posteriors,\n",
    "    train_data=datasets,\n",
    "    input_transform=input_transform,\n",
    "    output_transform=output_transform\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now let's make a prediction at a new input location. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "The scaled predictions are:\n",
      "\tneedle_displacement_m    :  -1.38 +/- 0.32\n",
      "\tinjection_time_s         :  -1.78 +/- 0.03\n",
      "\tmax_acceleration_m_per_s2:  1.49 +/- 0.09\n",
      "\tmax_deceleration_m_per_s2:  0.68 +/- 0.04\n"
     ]
    }
   ],
   "source": [
    "# Select a random test point\n",
    "x = X_test.values[0:1]\n",
    "x_scaled = input_transform.forward(x)\n",
    "\n",
    "# Get the mean and standard deviation of the scaled output\n",
    "y_scaled_mean, y_scaled_stdev = surrogate_.get_scaled_predictive_mean_stdev(x_scaled)\n",
    "\n",
    "print('The scaled predictions are:')\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    print(f\"\\t{o_name:<25}:  {y_scaled_mean[0, i]:.2f} +/- {y_scaled_stdev[0, i]:.2f}\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This is one advantage of GP surrogates&mdash;they provide uncertainty estimates!\n",
    "\n",
    "Let's visualize the (unscaled) output probability distributions. We can do this by sampling from the GP posterior:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [],
   "source": [
    "# This samples the unscaled output.\n",
    "y_latent_samples = surrogate_.sample(x, num_samples=1000, key=key)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"713.519688pt\" height=\"137.664pt\" viewBox=\"0 0 713.519688 137.664\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:39:52.480992</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 137.664 \n",
       "L 713.519688 137.664 \n",
       "L 713.519688 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 13.317409 114.116125 \n",
       "L 175.550931 114.116125 \n",
       "L 175.550931 20.1 \n",
       "L 13.317409 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mc3c023df4e\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"23.226313\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −0.0025 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 128.715) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"253.027344\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"308.642578\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"70.911169\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.0000 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(57.454732 128.715) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"118.596026\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.0025 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(105.139589 128.715) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"166.280883\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.0050 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(152.824445 128.715) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 20.69166 114.116125 \n",
       "L 29.909474 114.116125 \n",
       "L 29.909474 113.586307 \n",
       "L 20.69166 113.586307 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 29.909474 114.116125 \n",
       "L 39.127288 114.116125 \n",
       "L 39.127288 111.996855 \n",
       "L 29.909474 111.996855 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 39.127288 114.116125 \n",
       "L 48.345101 114.116125 \n",
       "L 48.345101 109.877585 \n",
       "L 39.127288 109.877585 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 48.345101 114.116125 \n",
       "L 57.562915 114.116125 \n",
       "L 57.562915 106.168862 \n",
       "L 48.345101 106.168862 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 57.562915 114.116125 \n",
       "L 66.780729 114.116125 \n",
       "L 66.780729 95.042693 \n",
       "L 57.562915 95.042693 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 66.780729 114.116125 \n",
       "L 75.998543 114.116125 \n",
       "L 75.998543 73.849991 \n",
       "L 66.780729 73.849991 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 75.998543 114.116125 \n",
       "L 85.216356 114.116125 \n",
       "L 85.216356 61.13437 \n",
       "L 75.998543 61.13437 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 85.216356 114.116125 \n",
       "L 94.43417 114.116125 \n",
       "L 94.43417 36.762762 \n",
       "L 85.216356 36.762762 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 94.43417 114.116125 \n",
       "L 103.651984 114.116125 \n",
       "L 103.651984 24.576958 \n",
       "L 94.43417 24.576958 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 103.651984 114.116125 \n",
       "L 112.869797 114.116125 \n",
       "L 112.869797 27.755864 \n",
       "L 103.651984 27.755864 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 112.869797 114.116125 \n",
       "L 122.087611 114.116125 \n",
       "L 122.087611 52.657289 \n",
       "L 112.869797 52.657289 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 122.087611 114.116125 \n",
       "L 131.305425 114.116125 \n",
       "L 131.305425 71.200903 \n",
       "L 122.087611 71.200903 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 131.305425 114.116125 \n",
       "L 140.523239 114.116125 \n",
       "L 140.523239 85.505977 \n",
       "L 131.305425 85.505977 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 140.523239 114.116125 \n",
       "L 149.741052 114.116125 \n",
       "L 149.741052 101.400504 \n",
       "L 140.523239 101.400504 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 149.741052 114.116125 \n",
       "L 158.958866 114.116125 \n",
       "L 158.958866 112.526672 \n",
       "L 149.741052 112.526672 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path d=\"M 158.958866 114.116125 \n",
       "L 168.17668 114.116125 \n",
       "L 168.17668 111.996855 \n",
       "L 158.958866 111.996855 \n",
       "z\n",
       "\" clip-path=\"url(#pb6bc756e0c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path d=\"M 23.226313 114.116125 \n",
       "L 166.280883 114.116125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_5\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(42.40442 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_20\">\n",
       "    <path d=\"M 190.240328 114.116125 \n",
       "L 352.47385 114.116125 \n",
       "L 352.47385 20.1 \n",
       "L 190.240328 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"223.894424\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 2.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(217.778424 128.715) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"301.477167\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 2.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(295.361167 128.715) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\"/>\n",
       "   <g id=\"patch_21\">\n",
       "    <path d=\"M 197.614579 114.116125 \n",
       "L 206.832393 114.116125 \n",
       "L 206.832393 113.601532 \n",
       "L 197.614579 113.601532 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_22\">\n",
       "    <path d=\"M 206.832393 114.116125 \n",
       "L 216.050207 114.116125 \n",
       "L 216.050207 111.028568 \n",
       "L 206.832393 111.028568 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_23\">\n",
       "    <path d=\"M 216.050207 114.116125 \n",
       "L 225.268021 114.116125 \n",
       "L 225.268021 108.970196 \n",
       "L 216.050207 108.970196 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_24\">\n",
       "    <path d=\"M 225.268021 114.116125 \n",
       "L 234.485834 114.116125 \n",
       "L 234.485834 105.882638 \n",
       "L 225.268021 105.882638 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_25\">\n",
       "    <path d=\"M 234.485834 114.116125 \n",
       "L 243.703648 114.116125 \n",
       "L 243.703648 84.784329 \n",
       "L 234.485834 84.784329 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_26\">\n",
       "    <path d=\"M 243.703648 114.116125 \n",
       "L 252.921462 114.116125 \n",
       "L 252.921462 74.492471 \n",
       "L 243.703648 74.492471 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_27\">\n",
       "    <path d=\"M 252.921462 114.116125 \n",
       "L 262.139275 114.116125 \n",
       "L 262.139275 46.704454 \n",
       "L 252.921462 46.704454 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_28\">\n",
       "    <path d=\"M 262.139275 114.116125 \n",
       "L 271.357089 114.116125 \n",
       "L 271.357089 42.58771 \n",
       "L 262.139275 42.58771 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_29\">\n",
       "    <path d=\"M 271.357089 114.116125 \n",
       "L 280.574903 114.116125 \n",
       "L 280.574903 24.576958 \n",
       "L 271.357089 24.576958 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_30\">\n",
       "    <path d=\"M 280.574903 114.116125 \n",
       "L 289.792716 114.116125 \n",
       "L 289.792716 34.868817 \n",
       "L 280.574903 34.868817 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_31\">\n",
       "    <path d=\"M 289.792716 114.116125 \n",
       "L 299.01053 114.116125 \n",
       "L 299.01053 64.715205 \n",
       "L 289.792716 64.715205 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_32\">\n",
       "    <path d=\"M 299.01053 114.116125 \n",
       "L 308.228344 114.116125 \n",
       "L 308.228344 78.094621 \n",
       "L 299.01053 78.094621 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_33\">\n",
       "    <path d=\"M 308.228344 114.116125 \n",
       "L 317.446158 114.116125 \n",
       "L 317.446158 91.98863 \n",
       "L 308.228344 91.98863 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_34\">\n",
       "    <path d=\"M 317.446158 114.116125 \n",
       "L 326.663971 114.116125 \n",
       "L 326.663971 103.824267 \n",
       "L 317.446158 103.824267 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_35\">\n",
       "    <path d=\"M 326.663971 114.116125 \n",
       "L 335.881785 114.116125 \n",
       "L 335.881785 113.086939 \n",
       "L 326.663971 113.086939 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_36\">\n",
       "    <path d=\"M 335.881785 114.116125 \n",
       "L 345.099599 114.116125 \n",
       "L 345.099599 112.057753 \n",
       "L 335.881785 112.057753 \n",
       "z\n",
       "\" clip-path=\"url(#p66e8868fe2)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_37\">\n",
       "    <path d=\"M 223.894424 114.116125 \n",
       "L 301.477167 114.116125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_8\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(236.941089 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_38\">\n",
       "    <path d=\"M 367.163247 114.116125 \n",
       "L 529.396769 114.116125 \n",
       "L 529.396769 20.1 \n",
       "L 367.163247 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"383.807743\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 80000 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(371.57368 128.715) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-38\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"222.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"458.511918\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 100000 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(443.831043 128.715) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"278.076172\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\"/>\n",
       "   <g id=\"patch_39\">\n",
       "    <path d=\"M 374.537498 114.116125 \n",
       "L 383.755312 114.116125 \n",
       "L 383.755312 113.586307 \n",
       "L 374.537498 113.586307 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_40\">\n",
       "    <path d=\"M 383.755312 114.116125 \n",
       "L 392.973126 114.116125 \n",
       "L 392.973126 110.407402 \n",
       "L 383.755312 110.407402 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_41\">\n",
       "    <path d=\"M 392.973126 114.116125 \n",
       "L 402.19094 114.116125 \n",
       "L 402.19094 106.698679 \n",
       "L 392.973126 106.698679 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_42\">\n",
       "    <path d=\"M 402.19094 114.116125 \n",
       "L 411.408753 114.116125 \n",
       "L 411.408753 100.870686 \n",
       "L 402.19094 100.870686 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_43\">\n",
       "    <path d=\"M 411.408753 114.116125 \n",
       "L 420.626567 114.116125 \n",
       "L 420.626567 74.379808 \n",
       "L 411.408753 74.379808 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_44\">\n",
       "    <path d=\"M 420.626567 114.116125 \n",
       "L 429.844381 114.116125 \n",
       "L 429.844381 67.49218 \n",
       "L 420.626567 67.49218 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_45\">\n",
       "    <path d=\"M 429.844381 114.116125 \n",
       "L 439.062194 114.116125 \n",
       "L 439.062194 34.643492 \n",
       "L 429.844381 34.643492 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_46\">\n",
       "    <path d=\"M 439.062194 114.116125 \n",
       "L 448.280008 114.116125 \n",
       "L 448.280008 24.576958 \n",
       "L 439.062194 24.576958 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_47\">\n",
       "    <path d=\"M 448.280008 114.116125 \n",
       "L 457.497822 114.116125 \n",
       "L 457.497822 33.054039 \n",
       "L 448.280008 33.054039 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_48\">\n",
       "    <path d=\"M 457.497822 114.116125 \n",
       "L 466.715636 114.116125 \n",
       "L 466.715636 43.120573 \n",
       "L 457.497822 43.120573 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_49\">\n",
       "    <path d=\"M 466.715636 114.116125 \n",
       "L 475.933449 114.116125 \n",
       "L 475.933449 75.439444 \n",
       "L 466.715636 75.439444 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_50\">\n",
       "    <path d=\"M 475.933449 114.116125 \n",
       "L 485.151263 114.116125 \n",
       "L 485.151263 78.618349 \n",
       "L 475.933449 78.618349 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_51\">\n",
       "    <path d=\"M 485.151263 114.116125 \n",
       "L 494.369077 114.116125 \n",
       "L 494.369077 102.989956 \n",
       "L 485.151263 102.989956 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_52\">\n",
       "    <path d=\"M 494.369077 114.116125 \n",
       "L 503.58689 114.116125 \n",
       "L 503.58689 104.579409 \n",
       "L 494.369077 104.579409 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_53\">\n",
       "    <path d=\"M 503.58689 114.116125 \n",
       "L 512.804704 114.116125 \n",
       "L 512.804704 113.586307 \n",
       "L 503.58689 113.586307 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_54\">\n",
       "    <path d=\"M 512.804704 114.116125 \n",
       "L 522.022518 114.116125 \n",
       "L 522.022518 111.996855 \n",
       "L 512.804704 111.996855 \n",
       "z\n",
       "\" clip-path=\"url(#p5e23663c50)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_55\">\n",
       "    <path d=\"M 383.807743 114.116125 \n",
       "L 458.511918 114.116125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_11\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(386.651008 14.1) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_56\">\n",
       "    <path d=\"M 544.086166 114.116125 \n",
       "L 706.319688 114.116125 \n",
       "L 706.319688 20.1 \n",
       "L 544.086166 20.1 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"588.822882\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 42000 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(576.58882 128.715) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"222.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc3c023df4e\" x=\"648.406513\" y=\"114.116125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 42500 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(636.17245 128.715) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"222.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\"/>\n",
       "   <g id=\"patch_57\">\n",
       "    <path d=\"M 551.460417 114.116125 \n",
       "L 560.678231 114.116125 \n",
       "L 560.678231 113.586307 \n",
       "L 551.460417 113.586307 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_58\">\n",
       "    <path d=\"M 560.678231 114.116125 \n",
       "L 569.896045 114.116125 \n",
       "L 569.896045 111.996855 \n",
       "L 560.678231 111.996855 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_59\">\n",
       "    <path d=\"M 569.896045 114.116125 \n",
       "L 579.113859 114.116125 \n",
       "L 579.113859 109.877585 \n",
       "L 569.896045 109.877585 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_60\">\n",
       "    <path d=\"M 579.113859 114.116125 \n",
       "L 588.331672 114.116125 \n",
       "L 588.331672 106.168862 \n",
       "L 579.113859 106.168862 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_61\">\n",
       "    <path d=\"M 588.331672 114.116125 \n",
       "L 597.549486 114.116125 \n",
       "L 597.549486 95.042693 \n",
       "L 588.331672 95.042693 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_62\">\n",
       "    <path d=\"M 597.549486 114.116125 \n",
       "L 606.7673 114.116125 \n",
       "L 606.7673 73.849991 \n",
       "L 597.549486 73.849991 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_63\">\n",
       "    <path d=\"M 606.7673 114.116125 \n",
       "L 615.985113 114.116125 \n",
       "L 615.985113 61.13437 \n",
       "L 606.7673 61.13437 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_64\">\n",
       "    <path d=\"M 615.985113 114.116125 \n",
       "L 625.202927 114.116125 \n",
       "L 625.202927 36.762762 \n",
       "L 615.985113 36.762762 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_65\">\n",
       "    <path d=\"M 625.202927 114.116125 \n",
       "L 634.420741 114.116125 \n",
       "L 634.420741 24.576958 \n",
       "L 625.202927 24.576958 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_66\">\n",
       "    <path d=\"M 634.420741 114.116125 \n",
       "L 643.638555 114.116125 \n",
       "L 643.638555 27.755864 \n",
       "L 634.420741 27.755864 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_67\">\n",
       "    <path d=\"M 643.638555 114.116125 \n",
       "L 652.856368 114.116125 \n",
       "L 652.856368 52.657289 \n",
       "L 643.638555 52.657289 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_68\">\n",
       "    <path d=\"M 652.856368 114.116125 \n",
       "L 662.074182 114.116125 \n",
       "L 662.074182 71.200903 \n",
       "L 652.856368 71.200903 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_69\">\n",
       "    <path d=\"M 662.074182 114.116125 \n",
       "L 671.291996 114.116125 \n",
       "L 671.291996 85.505977 \n",
       "L 662.074182 85.505977 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_70\">\n",
       "    <path d=\"M 671.291996 114.116125 \n",
       "L 680.509809 114.116125 \n",
       "L 680.509809 101.400504 \n",
       "L 671.291996 101.400504 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_71\">\n",
       "    <path d=\"M 680.509809 114.116125 \n",
       "L 689.727623 114.116125 \n",
       "L 689.727623 112.526672 \n",
       "L 680.509809 112.526672 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_72\">\n",
       "    <path d=\"M 689.727623 114.116125 \n",
       "L 698.945437 114.116125 \n",
       "L 698.945437 111.996855 \n",
       "L 689.727623 111.996855 \n",
       "z\n",
       "\" clip-path=\"url(#p7231a796a1)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_73\">\n",
       "    <path d=\"M 588.822882 114.116125 \n",
       "L 648.406513 114.116125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_14\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(563.304677 14.1) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pb6bc756e0c\">\n",
       "   <rect x=\"13.317409\" y=\"20.1\" width=\"162.233521\" height=\"94.016125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p66e8868fe2\">\n",
       "   <rect x=\"190.240328\" y=\"20.1\" width=\"162.233521\" height=\"94.016125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p5e23663c50\">\n",
       "   <rect x=\"367.163247\" y=\"20.1\" width=\"162.233521\" height=\"94.016125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p7231a796a1\">\n",
       "   <rect x=\"544.086166\" y=\"20.1\" width=\"162.233521\" height=\"94.016125\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1000x200 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(10, 2), tight_layout=True)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].hist(y_latent_samples[:,i], bins=16, density=True)\n",
    "    ax[i].set_title(o_name)\n",
    "    ax[i].set_yticks([])\n",
    "    sns.despine(trim=True, ax=ax[i], left=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The uncertainty you see here is the *epistemic uncertainty* (or \"lack-of-data\" uncertainty). It should go down as we add more data points. We'll look at this next."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Convergence: How much data do we need?\n",
    "\n",
    "Ideally, we want to use enough data so that the epistemic uncertainty is low.\n",
    "Let's test how much data we need for this problem.\n",
    "We'll create training datasets of sizes $N=50, 500, 1000, 1500, 2000$ and observe the convergence of the trained GP."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Now training GP with dataset of size 50  ... done.\n",
      "Now training GP with dataset of size 500 ... done.\n",
      "Now training GP with dataset of size 1000 ... done.\n",
      "Now training GP with dataset of size 1500 ... done.\n",
      "Now training GP with dataset of size 2000 ... done.\n"
     ]
    }
   ],
   "source": [
    "dataset_sizes = [50, 500, 1000, 1500, 2000]\n",
    "datasets_N = {size: create_datasets(size) for size in dataset_sizes}\n",
    "\n",
    "surrogates_N = {}\n",
    "posteriors_N = {}\n",
    "loss_histories_N = {}\n",
    "\n",
    "for N in dataset_sizes:\n",
    "    print(f'Now training GP with dataset of size {N:<3} ... ', end='')\n",
    "\n",
    "    key, subkey = jrandom.split(key)\n",
    "    posteriors_N[N], loss_histories_N[N] = optimize_gps(posterior, datasets_N[N], verbose=False, key=subkey)\n",
    "\n",
    "    surrogates_N[N] = Surrogate(\n",
    "        models=posteriors_N[N],\n",
    "        train_data=datasets_N[N],\n",
    "        input_transform=input_transform,\n",
    "        output_transform=output_transform\n",
    "    )\n",
    "\n",
    "    print('done.')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We now have trained GPs for each dataset size, stored in `surrogates_N`. \n",
    "Note how the epistemic uncertainty decreases as we add more data:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {},
   "outputs": [],
   "source": [
    "y_latent_samples_N = {}\n",
    "for i, N in enumerate(dataset_sizes):\n",
    "    y_latent_samples_N[N] = surrogates_N[N].sample_latent(x_scaled, num_samples=1000, key=key)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"281.658114pt\" height=\"286.272pt\" viewBox=\"0 0 281.658114 286.272\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:31.704945</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 286.272 \n",
       "L 281.658114 286.272 \n",
       "L 281.658114 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 7.2 66.799865 \n",
       "L 268.881232 66.799865 \n",
       "L 268.881232 45.8583 \n",
       "L 7.2 45.8583 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m849e4291da\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"51.277199\" y=\"66.799865\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"104.900959\" y=\"66.799865\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"158.524719\" y=\"66.799865\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"212.148479\" y=\"66.799865\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"265.772239\" y=\"66.799865\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\"/>\n",
       "   <g id=\"line2d_6\">\n",
       "    <path d=\"M 19.094601 66.79846 \n",
       "L 33.439849 66.687634 \n",
       "L 43.003348 66.348759 \n",
       "L 51.37141 65.863646 \n",
       "L 58.544034 65.249142 \n",
       "L 64.52122 64.551937 \n",
       "L 69.30297 63.768583 \n",
       "L 74.084719 62.73993 \n",
       "L 81.257343 60.928901 \n",
       "L 87.23453 59.209811 \n",
       "L 90.820842 57.968452 \n",
       "L 94.407154 56.50575 \n",
       "L 97.993466 54.815891 \n",
       "L 108.752402 49.403051 \n",
       "L 111.143276 48.520365 \n",
       "L 113.534151 47.861742 \n",
       "L 115.925026 47.419749 \n",
       "L 119.511338 47.073271 \n",
       "L 124.293087 46.920239 \n",
       "L 132.661148 46.878714 \n",
       "L 136.24746 47.075811 \n",
       "L 138.638335 47.385546 \n",
       "L 141.02921 47.884915 \n",
       "L 143.420084 48.58679 \n",
       "L 147.006396 49.951577 \n",
       "L 154.17902 52.86457 \n",
       "L 157.765332 54.040357 \n",
       "L 164.937956 56.282788 \n",
       "L 178.087767 60.857071 \n",
       "L 182.869516 62.117711 \n",
       "L 187.651266 63.12637 \n",
       "L 192.433015 63.917932 \n",
       "L 200.801076 65.017034 \n",
       "L 211.560012 66.248754 \n",
       "L 216.341762 66.568401 \n",
       "L 222.318948 66.697087 \n",
       "L 256.986631 66.798545 \n",
       "L 256.986631 66.798545 \n",
       "\" clip-path=\"url(#pe58f764c6e)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 51.277199 66.799865 \n",
       "L 265.772239 66.799865 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_1\">\n",
       "    <!-- N=50 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(126.432116 39.8583) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-35\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"186.230469\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 7.2 115.78093 \n",
       "L 268.881232 115.78093 \n",
       "L 268.881232 94.839365 \n",
       "L 7.2 94.839365 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"51.277199\" y=\"115.78093\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"104.900959\" y=\"115.78093\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"158.524719\" y=\"115.78093\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"212.148479\" y=\"115.78093\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"265.772239\" y=\"115.78093\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\"/>\n",
       "   <g id=\"line2d_12\">\n",
       "    <path d=\"M 103.476588 115.779525 \n",
       "L 105.374656 115.668699 \n",
       "L 106.640035 115.329824 \n",
       "L 107.905414 114.755895 \n",
       "L 109.01262 113.978302 \n",
       "L 109.803482 113.17267 \n",
       "L 110.594344 111.997824 \n",
       "L 111.859722 109.588653 \n",
       "L 112.808756 107.386311 \n",
       "L 113.599618 104.947609 \n",
       "L 114.864997 100.052922 \n",
       "L 115.655859 97.50143 \n",
       "L 116.130376 96.596575 \n",
       "L 116.604893 96.136673 \n",
       "L 117.237582 95.924153 \n",
       "L 118.344788 95.841116 \n",
       "L 118.819305 95.961542 \n",
       "L 119.293822 96.366611 \n",
       "L 119.768339 97.192226 \n",
       "L 120.401029 98.932642 \n",
       "L 121.666408 102.649799 \n",
       "L 123.406303 107.001634 \n",
       "L 124.51351 109.838136 \n",
       "L 125.462544 111.633001 \n",
       "L 126.411578 112.898997 \n",
       "L 127.835129 114.29489 \n",
       "L 129.100508 115.329195 \n",
       "L 129.733197 115.596861 \n",
       "L 130.524059 115.678095 \n",
       "L 133.054816 115.703596 \n",
       "L 134.952884 115.77961 \n",
       "L 134.952884 115.77961 \n",
       "\" clip-path=\"url(#p2ac7372cc6)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 51.277199 115.78093 \n",
       "L 265.772239 115.78093 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_2\">\n",
       "    <!-- N=500 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(123.762866 88.839365) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-35\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"241.845703\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 7.2 164.761995 \n",
       "L 268.881232 164.761995 \n",
       "L 268.881232 143.82043 \n",
       "L 7.2 143.82043 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"51.277199\" y=\"164.761995\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"104.900959\" y=\"164.761995\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_13\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"158.524719\" y=\"164.761995\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_14\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"212.148479\" y=\"164.761995\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_15\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"265.772239\" y=\"164.761995\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\"/>\n",
       "   <g id=\"line2d_18\">\n",
       "    <path d=\"M 105.241719 164.76059 \n",
       "L 105.775575 164.649764 \n",
       "L 106.131478 164.310889 \n",
       "L 106.53187 163.642664 \n",
       "L 106.932261 162.514067 \n",
       "L 107.288165 160.70206 \n",
       "L 107.866508 156.367376 \n",
       "L 108.311387 150.916508 \n",
       "L 108.756267 145.823872 \n",
       "L 108.978706 145.035401 \n",
       "L 109.245634 144.847258 \n",
       "L 109.512562 144.878991 \n",
       "L 109.646025 145.171117 \n",
       "L 109.823977 146.173291 \n",
       "L 110.313345 151.240746 \n",
       "L 111.559007 161.304653 \n",
       "L 112.092862 163.275955 \n",
       "L 112.58223 164.530531 \n",
       "L 112.849157 164.65916 \n",
       "L 113.560964 164.684661 \n",
       "L 114.09482 164.760675 \n",
       "L 114.09482 164.760675 \n",
       "\" clip-path=\"url(#p4dbef13b82)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 51.277199 164.761995 \n",
       "L 265.772239 164.761995 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_3\">\n",
       "    <!-- N=1000 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(121.093616 137.82043) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"241.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"297.460938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 7.2 213.74306 \n",
       "L 268.881232 213.74306 \n",
       "L 268.881232 192.801495 \n",
       "L 7.2 192.801495 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_16\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"51.277199\" y=\"213.74306\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_17\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"104.900959\" y=\"213.74306\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_18\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"158.524719\" y=\"213.74306\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_19\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"212.148479\" y=\"213.74306\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_20\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"265.772239\" y=\"213.74306\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\"/>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 124.49556 213.741655 \n",
       "L 124.828813 213.630829 \n",
       "L 125.078752 213.234636 \n",
       "L 125.384234 212.308479 \n",
       "L 125.661945 210.711778 \n",
       "L 126.05074 206.524882 \n",
       "L 126.356222 201.152437 \n",
       "L 126.772788 194.211898 \n",
       "L 126.967186 193.844659 \n",
       "L 127.133812 193.821909 \n",
       "L 127.244897 194.152182 \n",
       "L 127.383752 195.529985 \n",
       "L 128.494595 210.680288 \n",
       "L 128.994475 213.291325 \n",
       "L 129.216643 213.640282 \n",
       "L 130.022005 213.74174 \n",
       "L 130.022005 213.74174 \n",
       "\" clip-path=\"url(#p310f52307b)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 51.277199 213.74306 \n",
       "L 265.772239 213.74306 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_4\">\n",
       "    <!-- N=1500 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(121.093616 186.801495) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-35\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"241.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"297.460938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_5\">\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 7.2 262.724125 \n",
       "L 268.881232 262.724125 \n",
       "L 268.881232 241.78256 \n",
       "L 7.2 241.78256 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_9\">\n",
       "    <g id=\"xtick_21\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"51.277199\" y=\"262.724125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −2.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(42.591324 277.323) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_22\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"104.900959\" y=\"262.724125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- −1.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(96.215084 277.323) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_23\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"158.524719\" y=\"262.724125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- −1.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(149.838844 277.323) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_24\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"212.148479\" y=\"262.724125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −1.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(203.462604 277.323) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_25\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m849e4291da\" x=\"265.772239\" y=\"262.724125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −1.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(257.086364 277.323) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_10\"/>\n",
       "   <g id=\"line2d_30\">\n",
       "    <path d=\"M 123.144983 262.72272 \n",
       "L 123.412026 262.611894 \n",
       "L 123.634561 262.155076 \n",
       "L 123.901603 261.051025 \n",
       "L 124.124138 259.205939 \n",
       "L 124.502448 253.430981 \n",
       "L 125.081039 242.867348 \n",
       "L 125.259067 242.802974 \n",
       "L 125.348081 243.133247 \n",
       "L 125.481603 244.931489 \n",
       "L 126.260476 258.820654 \n",
       "L 126.661039 261.810044 \n",
       "L 126.905827 262.614723 \n",
       "L 127.106109 262.56086 \n",
       "L 127.306391 262.646791 \n",
       "L 127.573433 262.722805 \n",
       "L 127.573433 262.722805 \n",
       "\" clip-path=\"url(#pa0686b1f53)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 51.277199 262.724125 \n",
       "L 265.772239 262.724125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_10\">\n",
       "    <!-- N=2000 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(121.093616 235.78256) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"241.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"297.460938\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_11\">\n",
       "   <!-- Epsitemic uncertainty for injection_time_s (scaled) -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(12.7863 15.5862) scale(0.1152 -0.1152)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-45\" d=\"M 506 0 \n",
       "L 506 4581 \n",
       "L 3819 4581 \n",
       "L 3819 4041 \n",
       "L 1113 4041 \n",
       "L 1113 2638 \n",
       "L 3647 2638 \n",
       "L 3647 2100 \n",
       "L 1113 2100 \n",
       "L 1113 541 \n",
       "L 3925 541 \n",
       "L 3925 0 \n",
       "L 506 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-79\" d=\"M 397 -1278 \n",
       "L 334 -750 \n",
       "Q 519 -800 656 -800 \n",
       "Q 844 -800 956 -737 \n",
       "Q 1069 -675 1141 -563 \n",
       "Q 1194 -478 1313 -144 \n",
       "Q 1328 -97 1363 -6 \n",
       "L 103 3319 \n",
       "L 709 3319 \n",
       "L 1400 1397 \n",
       "Q 1534 1031 1641 628 \n",
       "Q 1738 1016 1872 1384 \n",
       "L 2581 3319 \n",
       "L 3144 3319 \n",
       "L 1881 -56 \n",
       "Q 1678 -603 1566 -809 \n",
       "Q 1416 -1088 1222 -1217 \n",
       "Q 1028 -1347 759 -1347 \n",
       "Q 597 -1347 397 -1278 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-28\" d=\"M 1497 -1347 \n",
       "Q 1031 -759 709 28 \n",
       "Q 388 816 388 1659 \n",
       "Q 388 2403 628 3084 \n",
       "Q 909 3875 1497 4659 \n",
       "L 1900 4659 \n",
       "Q 1522 4009 1400 3731 \n",
       "Q 1209 3300 1100 2831 \n",
       "Q 966 2247 966 1656 \n",
       "Q 966 153 1900 -1347 \n",
       "L 1497 -1347 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-29\" d=\"M 791 -1347 \n",
       "L 388 -1347 \n",
       "Q 1322 153 1322 1656 \n",
       "Q 1322 2244 1188 2822 \n",
       "Q 1081 3291 891 3722 \n",
       "Q 769 4003 388 4659 \n",
       "L 791 4659 \n",
       "Q 1378 3875 1659 3084 \n",
       "Q 1900 2403 1900 1659 \n",
       "Q 1900 816 1576 28 \n",
       "Q 1253 -759 791 -1347 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-45\"/>\n",
       "    <use xlink:href=\"#ArialMT-70\" x=\"66.699219\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"122.314453\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"172.314453\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"194.53125\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"222.314453\"/>\n",
       "    <use xlink:href=\"#ArialMT-6d\" x=\"277.929688\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"361.230469\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"383.447266\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"433.447266\"/>\n",
       "    <use xlink:href=\"#ArialMT-75\" x=\"461.230469\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"516.845703\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"572.460938\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"622.460938\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"678.076172\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"711.376953\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"739.160156\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"794.775391\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"816.992188\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"872.607422\"/>\n",
       "    <use xlink:href=\"#ArialMT-79\" x=\"900.390625\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"950.390625\"/>\n",
       "    <use xlink:href=\"#ArialMT-66\" x=\"978.173828\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"1005.957031\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"1061.572266\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"1094.873047\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"1122.65625\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"1144.873047\"/>\n",
       "    <use xlink:href=\"#ArialMT-6a\" x=\"1200.488281\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"1222.705078\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"1278.320312\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1328.320312\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"1356.103516\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"1378.320312\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"1433.935547\"/>\n",
       "    <use xlink:href=\"#ArialMT-5f\" x=\"1489.550781\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1545.166016\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"1572.949219\"/>\n",
       "    <use xlink:href=\"#ArialMT-6d\" x=\"1595.166016\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"1678.466797\"/>\n",
       "    <use xlink:href=\"#ArialMT-5f\" x=\"1734.082031\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"1789.697266\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"1839.697266\"/>\n",
       "    <use xlink:href=\"#ArialMT-28\" x=\"1867.480469\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"1900.78125\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"1950.78125\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"2000.78125\"/>\n",
       "    <use xlink:href=\"#ArialMT-6c\" x=\"2056.396484\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"2078.613281\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"2134.228516\"/>\n",
       "    <use xlink:href=\"#ArialMT-29\" x=\"2189.84375\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pe58f764c6e\">\n",
       "   <rect x=\"7.2\" y=\"45.8583\" width=\"261.681232\" height=\"20.941565\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p2ac7372cc6\">\n",
       "   <rect x=\"7.2\" y=\"94.839365\" width=\"261.681232\" height=\"20.941565\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p4dbef13b82\">\n",
       "   <rect x=\"7.2\" y=\"143.82043\" width=\"261.681232\" height=\"20.941565\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p310f52307b\">\n",
       "   <rect x=\"7.2\" y=\"192.801495\" width=\"261.681232\" height=\"20.941565\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pa0686b1f53\">\n",
       "   <rect x=\"7.2\" y=\"241.78256\" width=\"261.681232\" height=\"20.941565\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 400x400 with 5 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "output_index = 1  # Select an output\n",
    "\n",
    "fig, ax = plt.subplots(len(dataset_sizes), 1, figsize=(4, 4), tight_layout=True, sharex=True, sharey=False)\n",
    "for i, N in enumerate(dataset_sizes):\n",
    "    fig.suptitle(f'Epsitemic uncertainty for {OUTPUT_NAMES[output_index]} (scaled)')\n",
    "    sns.kdeplot(y_latent_samples_N[N][:,output_index], ax=ax[i], lw=2)\n",
    "    ax[i].set_title(f'N={N}')\n",
    "    ax[i].set_yticks([])\n",
    "    ax[i].set_xlabel('')\n",
    "    ax[i].set_ylabel('')\n",
    "    sns.despine(trim=True, ax=ax[i], left=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's visualize the convergence for each (scaled) output. Below, we plot the epistemic uncertainty as a vertical bar:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {},
   "outputs": [],
   "source": [
    "means_N = {}\n",
    "stdevs_N = {}\n",
    "for i, N in enumerate(dataset_sizes):\n",
    "    means_N[N], stdevs_N[N] = surrogates_N[N].get_latent_mean_stdev(x_scaled)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"281.664pt\" height=\"286.272pt\" viewBox=\"0 0 281.664 286.272\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:35.761797</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 286.272 \n",
       "L 281.664 286.272 \n",
       "L 281.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 32.87175 79.273182 \n",
       "L 274.464 79.273182 \n",
       "L 274.464 45.8583 \n",
       "L 32.87175 45.8583 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\"/>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m45d53dabe4\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"71.068667\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(14.538375 74.218104) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"48.064003\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(14.538375 51.213441) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_1\">\n",
       "    <path d=\"M 43.853216 77.754324 \n",
       "L 43.853216 61.645528 \n",
       "\" clip-path=\"url(#pe869b4a82f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 3\"/>\n",
       "    <path d=\"M 94.536905 58.516166 \n",
       "L 94.536905 49.728833 \n",
       "\" clip-path=\"url(#pe869b4a82f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 3\"/>\n",
       "    <path d=\"M 150.852115 51.146818 \n",
       "L 150.852115 47.377158 \n",
       "\" clip-path=\"url(#pe869b4a82f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 3\"/>\n",
       "    <path d=\"M 207.167324 54.019906 \n",
       "L 207.167324 50.966944 \n",
       "\" clip-path=\"url(#pe869b4a82f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 3\"/>\n",
       "    <path d=\"M 263.482534 52.004159 \n",
       "L 263.482534 49.583432 \n",
       "\" clip-path=\"url(#pe869b4a82f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 3\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_3\">\n",
       "    <path d=\"M 43.853216 69.699926 \n",
       "L 94.536905 54.122499 \n",
       "L 150.852115 49.261988 \n",
       "L 207.167324 52.493425 \n",
       "L 263.482534 50.793796 \n",
       "\" clip-path=\"url(#pe869b4a82f)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 32.87175 71.068667 \n",
       "L 32.87175 48.064003 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_3\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #1f77b4\" transform=\"translate(101.638125 39.8583) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 32.87175 136.163663 \n",
       "L 274.464 136.163663 \n",
       "L 274.464 102.748781 \n",
       "L 32.87175 102.748781 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\"/>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"131.545086\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- −1.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 134.694524) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"105.7723\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −1.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 108.921738) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_2\">\n",
       "    <path d=\"M 43.853216 134.644805 \n",
       "L 43.853216 104.267639 \n",
       "\" clip-path=\"url(#pabdd0b0865)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 3\"/>\n",
       "    <path d=\"M 94.536905 127.18314 \n",
       "L 94.536905 123.163835 \n",
       "\" clip-path=\"url(#pabdd0b0865)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 3\"/>\n",
       "    <path d=\"M 150.852115 129.961909 \n",
       "L 150.852115 128.83143 \n",
       "\" clip-path=\"url(#pabdd0b0865)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 3\"/>\n",
       "    <path d=\"M 207.167324 121.241436 \n",
       "L 207.167324 120.535747 \n",
       "\" clip-path=\"url(#pabdd0b0865)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 3\"/>\n",
       "    <path d=\"M 263.482534 122.066593 \n",
       "L 263.482534 121.501111 \n",
       "\" clip-path=\"url(#pabdd0b0865)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 3\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_6\">\n",
       "    <path d=\"M 43.853216 119.456222 \n",
       "L 94.536905 125.173487 \n",
       "L 150.852115 129.39667 \n",
       "L 207.167324 120.888592 \n",
       "L 263.482534 121.783852 \n",
       "\" clip-path=\"url(#pabdd0b0865)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 32.87175 131.545086 \n",
       "L 32.87175 105.7723 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_6\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #ff7f0e\" transform=\"translate(119.251875 96.748781) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 32.87175 193.054144 \n",
       "L 274.464 193.054144 \n",
       "L 274.464 159.639262 \n",
       "L 32.87175 159.639262 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\"/>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"183.403227\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 1.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(12.33975 186.552664) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"163.650618\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 1.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(12.33975 166.800056) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_3\">\n",
       "    <path d=\"M 43.853216 191.535286 \n",
       "L 43.853216 161.15812 \n",
       "\" clip-path=\"url(#p729f1d043d)\" style=\"fill: none; stroke: #2ca02c; stroke-width: 3\"/>\n",
       "    <path d=\"M 94.536905 190.005901 \n",
       "L 94.536905 178.655936 \n",
       "\" clip-path=\"url(#p729f1d043d)\" style=\"fill: none; stroke: #2ca02c; stroke-width: 3\"/>\n",
       "    <path d=\"M 150.852115 184.485959 \n",
       "L 150.852115 181.275339 \n",
       "\" clip-path=\"url(#p729f1d043d)\" style=\"fill: none; stroke: #2ca02c; stroke-width: 3\"/>\n",
       "    <path d=\"M 207.167324 183.848686 \n",
       "L 207.167324 181.350991 \n",
       "\" clip-path=\"url(#p729f1d043d)\" style=\"fill: none; stroke: #2ca02c; stroke-width: 3\"/>\n",
       "    <path d=\"M 263.482534 186.197586 \n",
       "L 263.482534 184.433555 \n",
       "\" clip-path=\"url(#p729f1d043d)\" style=\"fill: none; stroke: #2ca02c; stroke-width: 3\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_9\">\n",
       "    <path d=\"M 43.853216 176.346703 \n",
       "L 94.536905 184.330918 \n",
       "L 150.852115 182.880649 \n",
       "L 207.167324 182.599839 \n",
       "L 263.482534 185.315571 \n",
       "\" clip-path=\"url(#p729f1d043d)\" style=\"fill: none; stroke: #2ca02c; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 32.87175 183.403227 \n",
       "L 32.87175 163.650618 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_9\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #2ca02c\" transform=\"translate(92.038875 153.639262) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 32.87175 249.944625 \n",
       "L 274.464 249.944625 \n",
       "L 274.464 216.529743 \n",
       "L 32.87175 216.529743 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <defs>\n",
       "       <path id=\"mbc389c25da\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbc389c25da\" x=\"38.221695\" y=\"249.944625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(35.774882 264.5435) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbc389c25da\" x=\"94.536905\" y=\"249.944625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 500 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(87.196467 264.5435) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-35\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbc389c25da\" x=\"150.852115\" y=\"249.944625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 1000 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(141.064865 264.5435) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbc389c25da\" x=\"207.167324\" y=\"249.944625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1500 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(197.380074 264.5435) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbc389c25da\" x=\"263.482534\" y=\"249.944625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 2000 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(253.695284 264.5435) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"166.845703\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- Dataset size -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(127.257375 277.164) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-44\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2072 4581 \n",
       "Q 2606 4581 2888 4516 \n",
       "Q 3281 4425 3559 4188 \n",
       "Q 3922 3881 4101 3404 \n",
       "Q 4281 2928 4281 2316 \n",
       "Q 4281 1794 4159 1391 \n",
       "Q 4038 988 3847 723 \n",
       "Q 3656 459 3429 307 \n",
       "Q 3203 156 2883 78 \n",
       "Q 2563 0 2147 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 541 \n",
       "L 2078 541 \n",
       "Q 2531 541 2789 625 \n",
       "Q 3047 709 3200 863 \n",
       "Q 3416 1078 3536 1442 \n",
       "Q 3656 1806 3656 2325 \n",
       "Q 3656 3044 3420 3430 \n",
       "Q 3184 3816 2847 3947 \n",
       "Q 2603 4041 2063 4041 \n",
       "L 1100 4041 \n",
       "L 1100 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-7a\" d=\"M 125 0 \n",
       "L 125 456 \n",
       "L 2238 2881 \n",
       "Q 1878 2863 1603 2863 \n",
       "L 250 2863 \n",
       "L 250 3319 \n",
       "L 2963 3319 \n",
       "L 2963 2947 \n",
       "L 1166 841 \n",
       "L 819 456 \n",
       "Q 1197 484 1528 484 \n",
       "L 3063 484 \n",
       "L 3063 0 \n",
       "L 125 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-44\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"72.216797\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"127.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"155.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"211.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"261.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"316.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"344.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"372.412109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"422.412109\"/>\n",
       "      <use xlink:href=\"#ArialMT-7a\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"494.628906\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"248.43295\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 0.50 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.446125 251.582388) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m45d53dabe4\" x=\"32.87175\" y=\"228.4991\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- 0.75 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.446125 231.648538) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_4\">\n",
       "    <path d=\"M 43.853216 231.685613 \n",
       "L 43.853216 218.048601 \n",
       "\" clip-path=\"url(#pea2f75d0d8)\" style=\"fill: none; stroke: #d62728; stroke-width: 3\"/>\n",
       "    <path d=\"M 94.536905 247.900255 \n",
       "L 94.536905 245.257081 \n",
       "\" clip-path=\"url(#pea2f75d0d8)\" style=\"fill: none; stroke: #d62728; stroke-width: 3\"/>\n",
       "    <path d=\"M 150.852115 248.425767 \n",
       "L 150.852115 247.564693 \n",
       "\" clip-path=\"url(#pea2f75d0d8)\" style=\"fill: none; stroke: #d62728; stroke-width: 3\"/>\n",
       "    <path d=\"M 207.167324 246.368051 \n",
       "L 207.167324 245.766579 \n",
       "\" clip-path=\"url(#pea2f75d0d8)\" style=\"fill: none; stroke: #d62728; stroke-width: 3\"/>\n",
       "    <path d=\"M 263.482534 245.061879 \n",
       "L 263.482534 244.60806 \n",
       "\" clip-path=\"url(#pea2f75d0d8)\" style=\"fill: none; stroke: #d62728; stroke-width: 3\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 43.853216 224.867107 \n",
       "L 94.536905 246.578668 \n",
       "L 150.852115 247.99523 \n",
       "L 207.167324 246.067315 \n",
       "L 263.482534 244.834969 \n",
       "\" clip-path=\"url(#pea2f75d0d8)\" style=\"fill: none; stroke: #d62728; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 32.87175 248.43295 \n",
       "L 32.87175 228.4991 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.221695 249.944625 \n",
       "L 263.482534 249.944625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_18\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #d62728\" transform=\"translate(91.769625 210.529743) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_19\">\n",
       "   <!-- Convergence of epistemic uncertainty to zero -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(25.2603 15.5862) scale(0.1152 -0.1152)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-43\" d=\"M 3763 1606 \n",
       "L 4369 1453 \n",
       "Q 4178 706 3683 314 \n",
       "Q 3188 -78 2472 -78 \n",
       "Q 1731 -78 1267 223 \n",
       "Q 803 525 561 1097 \n",
       "Q 319 1669 319 2325 \n",
       "Q 319 3041 592 3573 \n",
       "Q 866 4106 1370 4382 \n",
       "Q 1875 4659 2481 4659 \n",
       "Q 3169 4659 3637 4309 \n",
       "Q 4106 3959 4291 3325 \n",
       "L 3694 3184 \n",
       "Q 3534 3684 3231 3912 \n",
       "Q 2928 4141 2469 4141 \n",
       "Q 1941 4141 1586 3887 \n",
       "Q 1231 3634 1087 3207 \n",
       "Q 944 2781 944 2328 \n",
       "Q 944 1744 1114 1308 \n",
       "Q 1284 872 1643 656 \n",
       "Q 2003 441 2422 441 \n",
       "Q 2931 441 3284 734 \n",
       "Q 3638 1028 3763 1606 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-67\" d=\"M 319 -275 \n",
       "L 866 -356 \n",
       "Q 900 -609 1056 -725 \n",
       "Q 1266 -881 1628 -881 \n",
       "Q 2019 -881 2231 -725 \n",
       "Q 2444 -569 2519 -288 \n",
       "Q 2563 -116 2559 434 \n",
       "Q 2191 0 1641 0 \n",
       "Q 956 0 581 494 \n",
       "Q 206 988 206 1678 \n",
       "Q 206 2153 378 2554 \n",
       "Q 550 2956 876 3175 \n",
       "Q 1203 3394 1644 3394 \n",
       "Q 2231 3394 2613 2919 \n",
       "L 2613 3319 \n",
       "L 3131 3319 \n",
       "L 3131 450 \n",
       "Q 3131 -325 2973 -648 \n",
       "Q 2816 -972 2473 -1159 \n",
       "Q 2131 -1347 1631 -1347 \n",
       "Q 1038 -1347 672 -1080 \n",
       "Q 306 -813 319 -275 \n",
       "z\n",
       "M 784 1719 \n",
       "Q 784 1066 1043 766 \n",
       "Q 1303 466 1694 466 \n",
       "Q 2081 466 2343 764 \n",
       "Q 2606 1063 2606 1700 \n",
       "Q 2606 2309 2336 2618 \n",
       "Q 2066 2928 1684 2928 \n",
       "Q 1309 2928 1046 2623 \n",
       "Q 784 2319 784 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-79\" d=\"M 397 -1278 \n",
       "L 334 -750 \n",
       "Q 519 -800 656 -800 \n",
       "Q 844 -800 956 -737 \n",
       "Q 1069 -675 1141 -563 \n",
       "Q 1194 -478 1313 -144 \n",
       "Q 1328 -97 1363 -6 \n",
       "L 103 3319 \n",
       "L 709 3319 \n",
       "L 1400 1397 \n",
       "Q 1534 1031 1641 628 \n",
       "Q 1738 1016 1872 1384 \n",
       "L 2581 3319 \n",
       "L 3144 3319 \n",
       "L 1881 -56 \n",
       "Q 1678 -603 1566 -809 \n",
       "Q 1416 -1088 1222 -1217 \n",
       "Q 1028 -1347 759 -1347 \n",
       "Q 597 -1347 397 -1278 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-43\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"72.216797\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"127.832031\"/>\n",
       "    <use xlink:href=\"#ArialMT-76\" x=\"183.447266\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"233.447266\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"289.0625\"/>\n",
       "    <use xlink:href=\"#ArialMT-67\" x=\"322.363281\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"377.978516\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"433.59375\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"489.208984\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"539.208984\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"594.824219\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"622.607422\"/>\n",
       "    <use xlink:href=\"#ArialMT-66\" x=\"678.222656\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"706.005859\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"733.789062\"/>\n",
       "    <use xlink:href=\"#ArialMT-70\" x=\"789.404297\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"845.019531\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"867.236328\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"917.236328\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"945.019531\"/>\n",
       "    <use xlink:href=\"#ArialMT-6d\" x=\"1000.634766\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"1083.935547\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"1106.152344\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"1156.152344\"/>\n",
       "    <use xlink:href=\"#ArialMT-75\" x=\"1183.935547\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"1239.550781\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"1295.166016\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"1345.166016\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"1400.78125\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1434.082031\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"1461.865234\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"1517.480469\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"1539.697266\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1595.3125\"/>\n",
       "    <use xlink:href=\"#ArialMT-79\" x=\"1623.095703\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"1673.095703\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1700.878906\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"1728.662109\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"1784.277344\"/>\n",
       "    <use xlink:href=\"#ArialMT-7a\" x=\"1812.060547\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"1862.060547\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"1917.675781\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"1950.976562\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pe869b4a82f\">\n",
       "   <rect x=\"32.87175\" y=\"45.8583\" width=\"241.59225\" height=\"33.414882\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pabdd0b0865\">\n",
       "   <rect x=\"32.87175\" y=\"102.748781\" width=\"241.59225\" height=\"33.414882\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p729f1d043d\">\n",
       "   <rect x=\"32.87175\" y=\"159.639262\" width=\"241.59225\" height=\"33.414882\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pea2f75d0d8\">\n",
       "   <rect x=\"32.87175\" y=\"216.529743\" width=\"241.59225\" height=\"33.414882\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 400x400 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(len(OUTPUT_NAMES), 1, figsize=(4, 4), tight_layout=True, sharey=False)\n",
    "fig.suptitle('Convergence of epistemic uncertainty to zero')\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].errorbar(dataset_sizes, [means_N[N][0, i] for N in dataset_sizes], yerr=[stdevs_N[N][0, i] for N in dataset_sizes], ls='-', lw=0.5, elinewidth=3, label=f'{o_name} (scaled)', color=f'C{i}')\n",
    "    ax[i].set_title(o_name, color=f'C{i}')\n",
    "    # ax[i].set_yticks([])\n",
    "    if i == len(OUTPUT_NAMES) - 1:\n",
    "        sns.despine(trim=True, ax=ax[i])\n",
    "    else:\n",
    "        sns.despine(trim=True, ax=ax[i], bottom=True)\n",
    "        ax[i].set_xticks([])\n",
    "ax[-1].set_xlabel('Dataset size');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "For $N>1000$ the epistemic uncertainty is low for all outputs. We'll use the GP trained with 1000 points for subsequent analysis."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {},
   "outputs": [],
   "source": [
    "surrogate = surrogates_N[1000]"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Diagnostics: How good is the surrogate?\n",
    "\n",
    "The next question is: **How accurate is our surrogate?** We will use our test dataset to find out.\n",
    "\n",
    "### Parity plot\n",
    "\n",
    "Let's plot the predicted output against the true output (for the test dataset):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "metadata": {},
   "outputs": [],
   "source": [
    "means_train, stdevs_train = surrogate.get_scaled_predictive_mean_stdev(X_train_scaled[:1000])\n",
    "means_test, stdevs_test = surrogate.get_scaled_predictive_mean_stdev(X_test_scaled)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"713.664pt\" height=\"215.712pt\" viewBox=\"0 0 713.664 215.712\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:38.454964</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 215.712 \n",
       "L 713.664 215.712 \n",
       "L 713.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 45.65125 179.384625 \n",
       "L 189.328406 179.384625 \n",
       "L 189.328406 51.531 \n",
       "L 45.65125 51.531 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"me850bab295\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"83.974282\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(78.957595 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"130.894999\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(128.448186 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"177.815715\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(175.368902 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_4\">\n",
       "     <!-- True -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(107.801328 206.604) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <defs>\n",
       "       <path id=\"mbcbf912d53\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"45.65125\" y=\"166.05573\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −1.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 169.205167) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"45.65125\" y=\"145.22158\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- −1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 148.371018) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"45.65125\" y=\"124.38743\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- −0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 127.536868) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"45.65125\" y=\"103.553281\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 106.702718) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"45.65125\" y=\"82.719131\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 85.868568) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"45.65125\" y=\"61.884981\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 65.034418) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_11\">\n",
       "     <!-- Predicted -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(14.0715 135.734812) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"100\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"155.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"211.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"233.447266\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"283.447266\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"366.845703\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_1\">\n",
       "    <path d=\"M 172.804765 66.453722 \n",
       "L 172.804765 66.217105 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.088179 63.53762 \n",
       "L 176.088179 63.301003 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.176208 61.683266 \n",
       "L 178.176208 61.446649 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 152.333221 84.635996 \n",
       "L 152.333221 84.399382 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 110.367359 121.901564 \n",
       "L 110.367359 121.664948 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.468677 65.863888 \n",
       "L 173.468677 65.62727 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.950801 143.584138 \n",
       "L 85.950801 143.34752 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.809238 154.365272 \n",
       "L 73.809238 154.128659 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.944133 64.553199 \n",
       "L 174.944133 64.31658 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.523078 155.508783 \n",
       "L 72.523078 155.272169 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.008633 61.832061 \n",
       "L 178.008633 61.595444 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.906948 63.698172 \n",
       "L 175.906948 63.461554 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 98.273161 132.640153 \n",
       "L 98.273161 132.403554 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.304914 142.38181 \n",
       "L 87.304914 142.145194 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.526171 63.148505 \n",
       "L 176.526171 62.911898 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.705037 155.347749 \n",
       "L 72.705037 155.111131 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.340215 161.887535 \n",
       "L 65.340215 161.650917 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.756565 76.264856 \n",
       "L 161.756565 76.028243 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.362057 73.063162 \n",
       "L 165.362057 72.826543 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.0432 62.687885 \n",
       "L 177.0432 62.451276 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.966434 65.421736 \n",
       "L 173.966434 65.185119 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.634546 140.310265 \n",
       "L 89.634546 140.073651 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.471681 62.308772 \n",
       "L 177.471681 62.072158 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.283376 65.141026 \n",
       "L 174.283376 64.904415 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.355092 62.412836 \n",
       "L 177.355092 62.176219 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 116.246542 116.678791 \n",
       "L 116.246542 116.442179 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.649419 66.591132 \n",
       "L 172.649419 66.354514 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.046025 63.576306 \n",
       "L 176.046025 63.339699 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 130.958885 103.612714 \n",
       "L 130.958885 103.376112 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.54539 147.497048 \n",
       "L 81.54539 147.260433 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.777748 62.92503 \n",
       "L 176.777748 62.688413 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.901197 73.472546 \n",
       "L 164.901197 73.235927 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 100.972691 130.243863 \n",
       "L 100.972691 130.007247 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 148.405734 88.12237 \n",
       "L 148.405734 87.885753 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.150964 159.39318 \n",
       "L 68.150964 159.156564 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.630084 146.533533 \n",
       "L 82.630084 146.296913 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.191137 59.892585 \n",
       "L 180.191137 59.655972 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.928254 167.582349 \n",
       "L 58.928254 167.345731 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 105.63667 126.102229 \n",
       "L 105.63667 125.865613 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.404424 171.598998 \n",
       "L 54.404424 171.362381 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.636362 63.04919 \n",
       "L 176.636362 62.812586 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.003627 171.955565 \n",
       "L 54.003627 171.718946 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.108019 136.335324 \n",
       "L 94.108019 136.098734 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.61121 142.999062 \n",
       "L 86.61121 142.76245 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 146.039069 90.222188 \n",
       "L 146.039069 89.985569 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.439149 65.891164 \n",
       "L 173.439149 65.654548 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.761467 59.387483 \n",
       "L 180.761467 59.150866 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.845768 162.327084 \n",
       "L 64.845768 162.090468 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.54746 69.34556 \n",
       "L 169.54746 69.108942 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.650011 68.366618 \n",
       "L 170.650011 68.130001 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.923211 69.01302 \n",
       "L 169.923211 68.776402 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 144.678935 91.429346 \n",
       "L 144.678935 91.192731 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 123.735929 110.027952 \n",
       "L 123.735929 109.791334 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.480753 64.965158 \n",
       "L 174.480753 64.728539 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.522667 122.652348 \n",
       "L 109.522667 122.41573 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 120.086225 113.267428 \n",
       "L 120.086225 113.030825 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.489193 59.629234 \n",
       "L 180.489193 59.392616 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 125.816981 108.181466 \n",
       "L 125.816981 107.944854 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.64614 66.594436 \n",
       "L 172.64614 66.357816 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.475833 59.640784 \n",
       "L 180.475833 59.404165 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.907353 69.9142 \n",
       "L 168.907353 69.67758 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.07739 138.143877 \n",
       "L 92.07739 137.90726 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 128.754942 105.571101 \n",
       "L 128.754942 105.334483 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.420456 168.03272 \n",
       "L 58.420456 167.796101 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.60885 154.545346 \n",
       "L 73.60885 154.308738 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 98.990324 132.005027 \n",
       "L 98.990324 131.768411 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.722317 146.451876 \n",
       "L 82.722317 146.215258 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.497094 75.607545 \n",
       "L 162.497094 75.370929 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.777057 115.321195 \n",
       "L 117.777057 115.084576 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.511554 160.847078 \n",
       "L 66.511554 160.610472 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.542515 59.581792 \n",
       "L 180.542515 59.345176 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.153024 155.837078 \n",
       "L 72.153024 155.600471 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 112.739792 119.793691 \n",
       "L 112.739792 119.557078 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.251628 63.3914 \n",
       "L 176.251628 63.154785 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.039198 69.796856 \n",
       "L 169.039198 69.560238 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.572368 153.689385 \n",
       "L 74.572368 153.452767 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.786836 64.692981 \n",
       "L 174.786836 64.456365 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.888338 65.491252 \n",
       "L 173.888338 65.254636 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.250806 59.840477 \n",
       "L 180.250806 59.603859 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.268563 166.392357 \n",
       "L 60.268563 166.155738 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.281048 69.583877 \n",
       "L 169.281048 69.347258 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.879844 152.525935 \n",
       "L 75.879844 152.289322 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 79.252638 149.532877 \n",
       "L 79.252638 149.29626 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.659366 67.471043 \n",
       "L 171.659366 67.234424 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 132.428675 102.310216 \n",
       "L 132.428675 102.073601 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.856532 65.519362 \n",
       "L 173.856532 65.282744 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.680395 68.340641 \n",
       "L 170.680395 68.104023 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.730335 75.399814 \n",
       "L 162.730335 75.163196 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 135.320377 99.741931 \n",
       "L 135.320377 99.505317 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.636264 63.938592 \n",
       "L 175.636264 63.701982 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 143.857509 92.161094 \n",
       "L 143.857509 91.924481 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.001153 161.300755 \n",
       "L 66.001153 161.064137 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 155.414408 81.897126 \n",
       "L 155.414408 81.660507 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 137.310849 97.973895 \n",
       "L 137.310849 97.737281 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 110.18294 122.064324 \n",
       "L 110.18294 121.827712 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.887817 63.714415 \n",
       "L 175.887817 63.477807 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.597793 142.122325 \n",
       "L 87.597793 141.885708 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.417038 152.051129 \n",
       "L 76.417038 151.814519 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.129365 66.166773 \n",
       "L 173.129365 65.930162 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.845524 62.864727 \n",
       "L 176.845524 62.62811 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.35222 159.212681 \n",
       "L 68.35222 158.976065 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.53795 169.70511 \n",
       "L 56.53795 169.468491 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.518135 60.491086 \n",
       "L 179.518135 60.254467 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.309004 62.455671 \n",
       "L 177.309004 62.219063 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 95.562534 135.048768 \n",
       "L 95.562534 134.812151 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.283607 70.468815 \n",
       "L 168.283607 70.232196 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.745824 66.506132 \n",
       "L 172.745824 66.269514 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.681912 63.010686 \n",
       "L 176.681912 62.774067 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 55.655758 170.488373 \n",
       "L 55.655758 170.251754 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 104.89951 126.755821 \n",
       "L 104.89951 126.519208 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.792636 63.799132 \n",
       "L 175.792636 63.562518 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.689012 154.474375 \n",
       "L 73.689012 154.237764 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.432686 63.231531 \n",
       "L 176.432686 62.994914 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.923171 65.458369 \n",
       "L 173.923171 65.221759 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.227719 144.225639 \n",
       "L 85.227719 143.989019 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.289263 146.835709 \n",
       "L 82.289263 146.599095 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.800685 160.591025 \n",
       "L 66.800685 160.354409 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.835532 139.247078 \n",
       "L 90.835532 139.01046 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.642583 64.821159 \n",
       "L 174.642583 64.584545 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.199745 168.229926 \n",
       "L 58.199745 167.993308 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.064555 158.580523 \n",
       "L 69.064555 158.343905 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.466713 140.462009 \n",
       "L 89.466713 140.22539 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.029617 148.84361 \n",
       "L 80.029617 148.606993 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.450063 58.775455 \n",
       "L 181.450063 58.538838 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 151.714428 85.183166 \n",
       "L 151.714428 84.946552 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.826414 60.217893 \n",
       "L 179.826414 59.981281 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.342754 161.886443 \n",
       "L 65.342754 161.649827 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.891768 65.487736 \n",
       "L 173.891768 65.251119 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.60939 134.118171 \n",
       "L 96.60939 133.881554 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.415571 59.69496 \n",
       "L 180.415571 59.458347 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.240347 66.954503 \n",
       "L 172.240347 66.717886 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.008771 74.264339 \n",
       "L 164.008771 74.027722 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.965595 153.340268 \n",
       "L 74.965595 153.103657 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 135.148727 99.892851 \n",
       "L 135.148727 99.656233 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 95.831537 134.809663 \n",
       "L 95.831537 134.573046 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.438525 62.336935 \n",
       "L 177.438525 62.100321 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 116.049464 116.854854 \n",
       "L 116.049464 116.618236 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.552528 64.011771 \n",
       "L 175.552528 63.775155 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.49709 147.540875 \n",
       "L 81.49709 147.30426 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.911123 168.485507 \n",
       "L 57.911123 168.248888 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.179013 65.232813 \n",
       "L 174.179013 64.996193 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.404647 63.255584 \n",
       "L 176.404647 63.018968 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.933105 76.995439 \n",
       "L 160.933105 76.758821 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.628562 65.722237 \n",
       "L 173.628562 65.485618 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.496147 66.727737 \n",
       "L 172.496147 66.49112 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.931129 147.150683 \n",
       "L 81.931129 146.914074 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.17713 60.793258 \n",
       "L 179.17713 60.556643 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.713561 59.430269 \n",
       "L 180.713561 59.193655 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.113327 155.873204 \n",
       "L 72.113327 155.636587 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 137.145806 98.119666 \n",
       "L 137.145806 97.883051 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.828851 77.089021 \n",
       "L 160.828851 76.852401 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 135.268408 99.787394 \n",
       "L 135.268408 99.550775 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.919553 162.262841 \n",
       "L 64.919553 162.026225 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.491271 168.858624 \n",
       "L 57.491271 168.622007 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.53221 64.032123 \n",
       "L 175.53221 63.795506 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 118.996265 114.2383 \n",
       "L 118.996265 114.001682 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.235759 65.184204 \n",
       "L 174.235759 64.947593 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.503341 60.504624 \n",
       "L 179.503341 60.268006 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.783024 62.91966 \n",
       "L 176.783024 62.683047 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.158959 164.712774 \n",
       "L 62.158959 164.476159 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 108.023445 123.982487 \n",
       "L 108.023445 123.745892 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.861021 61.961885 \n",
       "L 177.861021 61.725275 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.232647 70.514163 \n",
       "L 168.232647 70.277545 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.759802 64.71978 \n",
       "L 174.759802 64.48317 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.495059 131.556429 \n",
       "L 99.495059 131.31981 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.641698 63.045546 \n",
       "L 176.641698 62.808929 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.350465 64.195487 \n",
       "L 175.350465 63.958869 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.876075 70.83133 \n",
       "L 167.876075 70.594714 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.429965 59.681774 \n",
       "L 180.429965 59.445155 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.970788 58.313215 \n",
       "L 181.970788 58.076597 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.122627 65.282665 \n",
       "L 174.122627 65.04605 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.99873 64.505754 \n",
       "L 174.99873 64.269139 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.41983 139.615306 \n",
       "L 90.41983 139.37869 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.659876 61.252865 \n",
       "L 178.659876 61.016251 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.901416 161.39011 \n",
       "L 65.901416 161.153495 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.702762 158.902665 \n",
       "L 68.702762 158.666049 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.5121 62.272393 \n",
       "L 177.5121 62.035775 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.793404 65.575029 \n",
       "L 173.793404 65.338409 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.776516 168.604573 \n",
       "L 57.776516 168.367955 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.781579 62.032316 \n",
       "L 177.781579 61.795702 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.592491 69.30631 \n",
       "L 169.592491 69.069691 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.803729 62.01463 \n",
       "L 177.803729 61.778025 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.033303 69.806989 \n",
       "L 169.033303 69.570377 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 126.54829 107.531531 \n",
       "L 126.54829 107.294913 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.694502 63.886815 \n",
       "L 175.694502 63.650197 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 124.431119 109.410254 \n",
       "L 124.431119 109.173649 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.301836 68.674341 \n",
       "L 170.301836 68.437724 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.292361 64.245436 \n",
       "L 175.292361 64.00882 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.45176 143.138998 \n",
       "L 86.45176 142.90238 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.96314 150.678857 \n",
       "L 77.96314 150.442238 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.595432 63.975414 \n",
       "L 175.595432 63.738795 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.804428 61.125816 \n",
       "L 178.804428 60.889199 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.648177 72.808461 \n",
       "L 165.648177 72.571844 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.786924 62.029592 \n",
       "L 177.786924 61.792976 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 106.43142 125.396269 \n",
       "L 106.43142 125.159656 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 138.029074 97.335791 \n",
       "L 138.029074 97.099174 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.161169 64.360144 \n",
       "L 175.161169 64.123527 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.695072 146.476035 \n",
       "L 82.695072 146.239418 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.887543 63.715516 \n",
       "L 175.887543 63.478902 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.496044 164.41461 \n",
       "L 62.496044 164.177992 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.91404 67.244493 \n",
       "L 171.91404 67.007874 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 110.641598 121.657664 \n",
       "L 110.641598 121.421045 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.566457 67.553014 \n",
       "L 171.566457 67.316395 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.801723 64.680279 \n",
       "L 174.801723 64.443661 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.324182 76.648608 \n",
       "L 161.324182 76.411989 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.400686 65.038157 \n",
       "L 174.400686 64.801546 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 138.249965 97.140251 \n",
       "L 138.249965 96.903636 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.59892 148.336744 \n",
       "L 80.59892 148.100128 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.041883 68.907492 \n",
       "L 170.041883 68.670875 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.999618 139.101007 \n",
       "L 90.999618 138.86439 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.199764 118.498167 \n",
       "L 114.199764 118.261548 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 155.551842 81.776223 \n",
       "L 155.551842 81.539611 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.848533 66.416584 \n",
       "L 172.848533 66.179969 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.519679 67.593727 \n",
       "L 171.519679 67.357114 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.971264 148.005256 \n",
       "L 80.971264 147.76864 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.085722 75.973188 \n",
       "L 162.085722 75.73657 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.354886 146.778113 \n",
       "L 82.354886 146.541495 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.625459 67.500646 \n",
       "L 171.625459 67.264027 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.581993 63.983322 \n",
       "L 175.581993 63.746723 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.063967 61.78217 \n",
       "L 178.063967 61.545556 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.853265 67.298782 \n",
       "L 171.853265 67.062166 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.223654 65.193576 \n",
       "L 174.223654 64.956988 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.185255 67.004194 \n",
       "L 172.185255 66.767575 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.398171 63.262086 \n",
       "L 176.398171 63.025472 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.504297 151.086237 \n",
       "L 77.504297 150.84962 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.754861 68.27324 \n",
       "L 170.754861 68.036621 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.590866 61.314354 \n",
       "L 178.590866 61.077736 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.431418 62.344944 \n",
       "L 177.431418 62.108326 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.998129 60.953492 \n",
       "L 178.998129 60.716873 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.194672 60.777899 \n",
       "L 179.194672 60.541281 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.998121 66.282581 \n",
       "L 172.998121 66.045963 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.037412 64.47059 \n",
       "L 175.037412 64.233972 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.079754 117.716593 \n",
       "L 115.079754 117.479977 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.87554 64.614294 \n",
       "L 174.87554 64.377676 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.172401 60.797824 \n",
       "L 179.172401 60.561207 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.220814 159.330367 \n",
       "L 68.220814 159.093749 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.740576 118.017429 \n",
       "L 114.740576 117.780813 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.277884 65.146265 \n",
       "L 174.277884 64.90965 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.78381 168.598236 \n",
       "L 57.78381 168.361617 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.341986 64.199869 \n",
       "L 175.341986 63.963258 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.236114 152.210356 \n",
       "L 76.236114 151.973758 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.746028 148.205236 \n",
       "L 80.746028 147.968617 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.14621 148.739461 \n",
       "L 80.14621 148.502847 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.594081 115.482595 \n",
       "L 117.594081 115.245979 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 108.166376 123.855633 \n",
       "L 108.166376 123.619017 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.241574 73.169889 \n",
       "L 165.241574 72.93327 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.462517 64.094274 \n",
       "L 175.462517 63.857674 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.709067 62.098216 \n",
       "L 177.709067 61.861604 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 104.335481 127.257343 \n",
       "L 104.335481 127.020725 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 108.152793 123.867795 \n",
       "L 108.152793 123.631176 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.519707 165.280729 \n",
       "L 61.519707 165.044113 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.369936 62.399551 \n",
       "L 177.369936 62.162936 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.053665 167.47062 \n",
       "L 59.053665 167.234001 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.159464 61.696301 \n",
       "L 178.159464 61.459683 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.375605 136.102831 \n",
       "L 94.375605 135.866214 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.284171 153.055895 \n",
       "L 75.284171 152.819278 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.449414 64.10435 \n",
       "L 175.449414 63.867734 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.079401 63.544245 \n",
       "L 176.079401 63.30763 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.787898 144.6164 \n",
       "L 84.787898 144.379782 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.052963 150.599151 \n",
       "L 78.052963 150.362537 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.260044 157.518302 \n",
       "L 70.260044 157.281684 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.005345 73.379532 \n",
       "L 165.005345 73.142915 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.846504 115.258563 \n",
       "L 117.846504 115.021947 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.232088 64.297545 \n",
       "L 175.232088 64.060927 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.270227 158.397665 \n",
       "L 69.270227 158.161048 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.299069 137.946396 \n",
       "L 92.299069 137.709778 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.692882 160.687167 \n",
       "L 66.692882 160.450551 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.7042 143.803601 \n",
       "L 85.7042 143.566984 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 121.990399 111.580325 \n",
       "L 121.990399 111.34371 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 139.46667 96.059549 \n",
       "L 139.46667 95.822931 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.039024 67.134785 \n",
       "L 172.039024 66.898171 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.314859 62.449096 \n",
       "L 177.314859 62.212479 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.732538 64.741396 \n",
       "L 174.732538 64.504777 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.218856 63.423736 \n",
       "L 176.218856 63.187121 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.781825 61.145151 \n",
       "L 178.781825 60.908533 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 142.044311 93.769488 \n",
       "L 142.044311 93.532874 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.298823 66.01457 \n",
       "L 173.298823 65.777951 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.455306 151.128199 \n",
       "L 77.455306 150.891581 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 152.008271 84.921841 \n",
       "L 152.008271 84.685233 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.149395 157.616832 \n",
       "L 70.149395 157.380214 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.870597 59.290893 \n",
       "L 180.870597 59.054276 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.630048 60.392078 \n",
       "L 179.630048 60.155459 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.819957 65.552247 \n",
       "L 173.819957 65.315629 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 119.587887 113.713052 \n",
       "L 119.587887 113.476433 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.42907 71.228474 \n",
       "L 167.42907 70.991861 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 97.293392 133.509378 \n",
       "L 97.293392 133.272768 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.239331 66.067829 \n",
       "L 173.239331 65.83121 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 119.273319 113.9924 \n",
       "L 119.273319 113.755783 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.021894 60.931979 \n",
       "L 179.021894 60.695361 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.7521 66.500274 \n",
       "L 172.7521 66.263656 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 148.809457 87.762999 \n",
       "L 148.809457 87.526383 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.069496 61.777881 \n",
       "L 178.069496 61.541268 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 127.255732 106.903378 \n",
       "L 127.255732 106.666762 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.611551 64.848321 \n",
       "L 174.611551 64.611704 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.89672 65.483181 \n",
       "L 173.89672 65.246561 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 142.695876 93.189763 \n",
       "L 142.695876 92.953158 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.39112 103.231136 \n",
       "L 131.39112 102.994517 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.877078 158.747221 \n",
       "L 68.877078 158.510602 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.107998 170.086527 \n",
       "L 56.107998 169.84991 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.392311 67.709006 \n",
       "L 171.392311 67.472389 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.5634 168.794315 \n",
       "L 57.5634 168.557696 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.577009 66.655626 \n",
       "L 172.577009 66.41901 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.607974 61.299662 \n",
       "L 178.607974 61.063045 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 127.741544 106.472363 \n",
       "L 127.741544 106.235747 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.854805 76.1779 \n",
       "L 161.854805 75.941282 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.394391 160.95078 \n",
       "L 66.394391 160.714162 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.004932 151.525226 \n",
       "L 77.004932 151.288615 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.374957 160.968739 \n",
       "L 66.374957 160.732121 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.701634 160.678788 \n",
       "L 66.701634 160.442169 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.890697 65.4893 \n",
       "L 173.890697 65.252682 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 107.322172 124.604338 \n",
       "L 107.322172 124.367724 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.286146 155.719826 \n",
       "L 72.286146 155.483211 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.236083 155.764086 \n",
       "L 72.236083 155.527467 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.446447 63.217186 \n",
       "L 176.446447 62.980577 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 121.03079 112.43082 \n",
       "L 121.03079 112.194205 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.875533 64.613785 \n",
       "L 174.875533 64.377169 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.881664 64.607635 \n",
       "L 174.881664 64.371024 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.781126 153.503857 \n",
       "L 74.781126 153.267239 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.563781 154.585244 \n",
       "L 73.563781 154.348627 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.670228 147.38538 \n",
       "L 81.670228 147.148761 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.967449 136.464819 \n",
       "L 93.967449 136.228208 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.928878 142.716492 \n",
       "L 86.928878 142.479878 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.151304 122.980747 \n",
       "L 109.151304 122.744129 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.67454 117.188001 \n",
       "L 115.67454 116.951387 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.56459 158.137508 \n",
       "L 69.56459 157.9009 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.322055 61.552956 \n",
       "L 178.322055 61.316338 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.098017 141.678498 \n",
       "L 88.098017 141.441883 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.308123 163.692545 \n",
       "L 63.308123 163.455927 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.051634 157.70427 \n",
       "L 70.051634 157.467656 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.835253 135.69418 \n",
       "L 94.835253 135.457564 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.986382 156.874158 \n",
       "L 70.986382 156.637539 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 125.692201 108.291168 \n",
       "L 125.692201 108.054551 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.097909 67.082245 \n",
       "L 172.097909 66.845628 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.940276 69.885463 \n",
       "L 168.940276 69.648849 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.584571 58.656001 \n",
       "L 181.584571 58.419385 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 159.044778 78.672094 \n",
       "L 159.044778 78.435487 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.821263 66.439545 \n",
       "L 172.821263 66.202931 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.671253 63.018982 \n",
       "L 176.671253 62.782365 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.885586 62.828207 \n",
       "L 176.885586 62.591595 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.59851 147.450292 \n",
       "L 81.59851 147.213673 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.917032 63.689449 \n",
       "L 175.917032 63.45283 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.011084 147.084343 \n",
       "L 82.011084 146.847736 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.188252 169.127387 \n",
       "L 57.188252 168.890769 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.634303 166.067836 \n",
       "L 60.634303 165.831219 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.683869 147.373607 \n",
       "L 81.683869 147.136992 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.641422 166.060802 \n",
       "L 60.641422 165.824183 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.923655 143.609615 \n",
       "L 85.923655 143.373007 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.267928 63.37856 \n",
       "L 176.267928 63.14195 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.262343 65.158535 \n",
       "L 174.262343 64.921917 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.496189 65.839668 \n",
       "L 173.496189 65.603051 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.223089 66.971816 \n",
       "L 172.223089 66.735198 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 128.105868 106.148823 \n",
       "L 128.105868 105.912204 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.531637 60.478338 \n",
       "L 179.531637 60.241725 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 91.841381 138.353425 \n",
       "L 91.841381 138.116807 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.135903 162.068935 \n",
       "L 65.135903 161.832319 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.743922 147.317283 \n",
       "L 81.743922 147.080671 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.948829 67.212727 \n",
       "L 171.948829 66.976112 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.987969 65.402161 \n",
       "L 173.987969 65.165544 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.234244 65.183428 \n",
       "L 174.234244 64.946812 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.432574 172.462843 \n",
       "L 53.432574 172.226225 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.898987 64.595129 \n",
       "L 174.898987 64.358518 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.203846 61.659113 \n",
       "L 178.203846 61.422494 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.259857 141.534102 \n",
       "L 88.259857 141.297483 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.884951 145.419289 \n",
       "L 83.884951 145.18267 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.933562 63.674151 \n",
       "L 175.933562 63.437538 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.267623 151.295887 \n",
       "L 77.267623 151.059271 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.584073 59.544794 \n",
       "L 180.584073 59.308177 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.948819 66.32607 \n",
       "L 172.948819 66.089454 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.395054 117.435577 \n",
       "L 115.395054 117.198971 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.886049 164.067826 \n",
       "L 62.886049 163.831208 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.72269 118.033049 \n",
       "L 114.72269 117.796432 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.502282 65.833677 \n",
       "L 173.502282 65.597058 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.597752 65.747262 \n",
       "L 173.597752 65.51065 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.556019 70.2259 \n",
       "L 168.556019 69.989284 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.699929 60.33061 \n",
       "L 179.699929 60.093996 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.29262 71.348288 \n",
       "L 167.29262 71.111669 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.331577 65.097366 \n",
       "L 174.331577 64.860748 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.007044 65.382289 \n",
       "L 174.007044 65.145696 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 132.685864 102.081453 \n",
       "L 132.685864 101.844843 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.675577 64.791709 \n",
       "L 174.675577 64.55509 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 130.042974 104.42762 \n",
       "L 130.042974 104.191004 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 113.022121 119.543989 \n",
       "L 113.022121 119.307372 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.370554 65.950671 \n",
       "L 173.370554 65.714053 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 95.506747 135.099645 \n",
       "L 95.506747 134.863029 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.223253 59.865351 \n",
       "L 180.223253 59.628732 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.582222 69.317953 \n",
       "L 169.582222 69.081338 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.929291 62.789549 \n",
       "L 176.929291 62.552935 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.061557 68.001598 \n",
       "L 171.061557 67.764979 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.668242 151.827955 \n",
       "L 76.668242 151.591341 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.044828 60.023792 \n",
       "L 180.044828 59.787176 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.368712 65.064869 \n",
       "L 174.368712 64.828252 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.607248 63.964548 \n",
       "L 175.607248 63.727931 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.445968 65.88736 \n",
       "L 173.445968 65.650747 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.60659 59.525732 \n",
       "L 180.60659 59.289119 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.175173 163.810843 \n",
       "L 63.175173 163.574224 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.676159 61.239329 \n",
       "L 178.676159 61.002713 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.348658 160.103378 \n",
       "L 67.348658 159.866765 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.790433 160.601095 \n",
       "L 66.790433 160.364477 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.888942 61.938177 \n",
       "L 177.888942 61.701561 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.045962 148.828187 \n",
       "L 80.045962 148.59157 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.787927 157.93773 \n",
       "L 69.787927 157.701115 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.357913 151.215536 \n",
       "L 77.357913 150.978917 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.98045 67.185054 \n",
       "L 171.98045 66.94844 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.489145 64.957279 \n",
       "L 174.489145 64.72066 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.811157 65.563907 \n",
       "L 173.811157 65.327306 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.244948 62.50939 \n",
       "L 177.244948 62.27278 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.698335 66.551749 \n",
       "L 172.698335 66.315135 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.279083 59.815923 \n",
       "L 180.279083 59.579304 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.665754 65.688831 \n",
       "L 173.665754 65.452222 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.025333 62.705178 \n",
       "L 177.025333 62.468562 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.112001 65.292932 \n",
       "L 174.112001 65.056315 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.319471 66.884475 \n",
       "L 172.319471 66.647859 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.989433 167.527815 \n",
       "L 58.989433 167.291196 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.812967 62.006022 \n",
       "L 177.812967 61.769405 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 136.660477 98.552408 \n",
       "L 136.660477 98.315798 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.062625 71.554493 \n",
       "L 167.062625 71.317882 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.967014 64.53332 \n",
       "L 174.967014 64.296705 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.340602 72.194485 \n",
       "L 166.340602 71.957866 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 182.797626 57.579147 \n",
       "L 182.797626 57.342528 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.978154 65.412884 \n",
       "L 173.978154 65.176275 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.041699 144.392103 \n",
       "L 85.041699 144.155483 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.130029 65.276087 \n",
       "L 174.130029 65.039471 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.782917 68.247888 \n",
       "L 170.782917 68.011272 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.935238 135.606676 \n",
       "L 94.935238 135.370063 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.844286 63.75422 \n",
       "L 175.844286 63.517613 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 128.293933 105.981484 \n",
       "L 128.293933 105.744865 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.601678 66.633706 \n",
       "L 172.601678 66.397091 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.561885 159.026909 \n",
       "L 68.561885 158.790289 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.503409 159.969009 \n",
       "L 67.503409 159.732393 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.642028 166.947923 \n",
       "L 59.642028 166.711304 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.616566 69.283913 \n",
       "L 169.616566 69.0473 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 103.782565 127.747545 \n",
       "L 103.782565 127.510928 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.548807 143.942648 \n",
       "L 85.548807 143.706034 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.458006 66.761941 \n",
       "L 172.458006 66.525325 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.512712 67.602324 \n",
       "L 171.512712 67.365713 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.453276 169.779923 \n",
       "L 56.453276 169.543304 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 141.958986 93.844939 \n",
       "L 141.958986 93.608321 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 116.493271 116.4608 \n",
       "L 116.493271 116.224183 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.755901 63.831795 \n",
       "L 175.755901 63.595183 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.671103 65.682516 \n",
       "L 173.671103 65.445902 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.508048 159.073637 \n",
       "L 68.508048 158.83702 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.9675 149.78681 \n",
       "L 78.9675 149.550204 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.940212 64.558617 \n",
       "L 174.940212 64.322003 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.985889 60.964163 \n",
       "L 178.985889 60.727549 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.931644 145.376033 \n",
       "L 83.931644 145.13942 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.807673 76.219606 \n",
       "L 161.807673 75.982988 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.541469 163.485443 \n",
       "L 63.541469 163.248826 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 126.908695 107.210649 \n",
       "L 126.908695 106.974041 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.020285 62.710954 \n",
       "L 177.020285 62.474338 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.179748 64.345089 \n",
       "L 175.179748 64.108479 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.188374 115.843536 \n",
       "L 117.188374 115.606918 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.731181 163.317379 \n",
       "L 63.731181 163.080761 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.217438 154.892893 \n",
       "L 73.217438 154.656275 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.606432 62.189401 \n",
       "L 177.606432 61.952783 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.935382 68.112594 \n",
       "L 170.935382 67.875976 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.265864 63.381648 \n",
       "L 176.265864 63.145035 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.204779 61.657076 \n",
       "L 178.204779 61.42046 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.206639 158.456 \n",
       "L 69.206639 158.219386 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.112737 162.090744 \n",
       "L 65.112737 161.854126 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.538343 164.376276 \n",
       "L 62.538343 164.139657 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 103.374253 128.111455 \n",
       "L 103.374253 127.874836 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 135.688668 99.415322 \n",
       "L 135.688668 99.178707 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 97.536955 133.295342 \n",
       "L 97.536955 133.058724 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.110247 145.219197 \n",
       "L 84.110247 144.982579 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.511837 64.940225 \n",
       "L 174.511837 64.703616 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.824928 64.661238 \n",
       "L 174.824928 64.424625 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.838565 60.206782 \n",
       "L 179.838565 59.970166 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.840614 59.316942 \n",
       "L 180.840614 59.08033 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.646749 157.176254 \n",
       "L 70.646749 156.939641 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.675512 58.575487 \n",
       "L 181.675512 58.338869 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.734993 159.76382 \n",
       "L 67.734993 159.527208 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.132898 73.267524 \n",
       "L 165.132898 73.030906 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.111919 147.88137 \n",
       "L 81.111919 147.644752 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.792897 145.500217 \n",
       "L 83.792897 145.263599 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.778072 64.699267 \n",
       "L 174.778072 64.46265 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.861396 131.230828 \n",
       "L 99.861396 130.99421 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.655523 131.410693 \n",
       "L 99.655523 131.174088 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.031705 62.700044 \n",
       "L 177.031705 62.463434 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.088069 144.349755 \n",
       "L 85.088069 144.113139 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.20287 66.100148 \n",
       "L 173.20287 65.863531 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.928663 152.485183 \n",
       "L 75.928663 152.248568 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.692761 152.69432 \n",
       "L 75.692761 152.457705 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.764746 137.532611 \n",
       "L 92.764746 137.295999 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.501331 64.94652 \n",
       "L 174.501331 64.709904 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.309537 163.691634 \n",
       "L 63.309537 163.455018 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.226659 142.446429 \n",
       "L 87.226659 142.209818 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.728276 76.290891 \n",
       "L 161.728276 76.054273 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.305134 171.687664 \n",
       "L 54.305134 171.451045 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.290976 61.581174 \n",
       "L 178.290976 61.344562 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.066886 63.55788 \n",
       "L 176.066886 63.321267 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.946138 62.775472 \n",
       "L 176.946138 62.538857 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.315792 62.447496 \n",
       "L 177.315792 62.210879 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.824005 159.683764 \n",
       "L 67.824005 159.447146 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.240812 166.416483 \n",
       "L 60.240812 166.179864 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.787655 64.692233 \n",
       "L 174.787655 64.455616 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.292953 156.600878 \n",
       "L 71.292953 156.364265 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.811943 65.560253 \n",
       "L 173.811943 65.323642 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.60541 64.855495 \n",
       "L 174.60541 64.618885 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.605382 63.965432 \n",
       "L 175.605382 63.728816 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.607977 62.188348 \n",
       "L 177.607977 61.951731 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.446227 159.129883 \n",
       "L 68.446227 158.893264 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 137.536312 97.771479 \n",
       "L 137.536312 97.534862 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.595328 142.124357 \n",
       "L 87.595328 141.887751 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.107445 103.482416 \n",
       "L 131.107445 103.245801 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.614084 118.129841 \n",
       "L 114.614084 117.893221 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.555904 154.59255 \n",
       "L 73.555904 154.355933 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.458651 136.916983 \n",
       "L 93.458651 136.680369 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.071175 151.469244 \n",
       "L 77.071175 151.232626 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.233345 65.183914 \n",
       "L 174.233345 64.947305 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 126.7614 107.342257 \n",
       "L 126.7614 107.10564 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.818661 64.665001 \n",
       "L 174.818661 64.428385 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 98.89362 132.078813 \n",
       "L 98.89362 131.842219 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.732984 150.884028 \n",
       "L 77.732984 150.647419 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.250501 136.212499 \n",
       "L 94.250501 135.97588 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 143.609951 92.379363 \n",
       "L 143.609951 92.142746 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 104.431468 127.171838 \n",
       "L 104.431468 126.935219 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.499888 70.276977 \n",
       "L 168.499888 70.040359 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.803015 158.811185 \n",
       "L 68.803015 158.57457 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 100.39538 130.756911 \n",
       "L 100.39538 130.520293 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 138.462257 96.951277 \n",
       "L 138.462257 96.714663 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.5211 62.264518 \n",
       "L 177.5211 62.027902 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.811524 149.926149 \n",
       "L 78.811524 149.689539 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.610939 63.961888 \n",
       "L 175.610939 63.72527 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.100644 168.317168 \n",
       "L 58.100644 168.080549 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.264664 66.045015 \n",
       "L 173.264664 65.808396 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.560483 67.561272 \n",
       "L 171.560483 67.32467 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 122.031091 111.544156 \n",
       "L 122.031091 111.307545 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.916627 61.912932 \n",
       "L 177.916627 61.676337 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.355929 159.209068 \n",
       "L 68.355929 158.972449 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.792358 166.817437 \n",
       "L 59.792358 166.580822 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.901821 159.613318 \n",
       "L 67.901821 159.3767 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.984995 61.853113 \n",
       "L 177.984995 61.616495 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 154.389975 82.807299 \n",
       "L 154.389975 82.570683 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.277649 68.697322 \n",
       "L 170.277649 68.460707 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.056498 62.677763 \n",
       "L 177.056498 62.441145 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.482582 60.522273 \n",
       "L 179.482582 60.285654 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.283644 153.058349 \n",
       "L 75.283644 152.821734 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 105.407113 126.306198 \n",
       "L 105.407113 126.069579 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.567525 60.447652 \n",
       "L 179.567525 60.211033 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.184765 61.675141 \n",
       "L 178.184765 61.438523 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 149.181136 87.431646 \n",
       "L 149.181136 87.195027 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.578934 63.988338 \n",
       "L 175.578934 63.751728 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 139.236208 96.264169 \n",
       "L 139.236208 96.027551 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.497652 58.733985 \n",
       "L 181.497652 58.497371 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 125.230375 108.702146 \n",
       "L 125.230375 108.465531 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.22329 171.760505 \n",
       "L 54.22329 171.523886 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.568953 139.484351 \n",
       "L 90.568953 139.247736 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 118.281096 114.873324 \n",
       "L 118.281096 114.63671 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.051952 68.898117 \n",
       "L 170.051952 68.661498 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.432075 139.605717 \n",
       "L 90.432075 139.369106 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.498944 61.396419 \n",
       "L 178.498944 61.159801 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.758181 151.748038 \n",
       "L 76.758181 151.51142 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 145.979488 90.275877 \n",
       "L 145.979488 90.039258 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.166636 140.727376 \n",
       "L 89.166636 140.49076 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.052878 60.905347 \n",
       "L 179.052878 60.66873 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 107.2235 124.693783 \n",
       "L 107.2235 124.457175 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.963117 68.977575 \n",
       "L 169.963117 68.740958 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.906444 60.14672 \n",
       "L 179.906444 59.910102 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 111.144389 121.211841 \n",
       "L 111.144389 120.975223 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.890649 63.711313 \n",
       "L 175.890649 63.474697 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.392194 64.15484 \n",
       "L 175.392194 63.918223 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.256439 65.16363 \n",
       "L 174.256439 64.927012 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.146075 164.724101 \n",
       "L 62.146075 164.487487 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.901027 68.143885 \n",
       "L 170.901027 67.907267 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.769412 141.971296 \n",
       "L 87.769412 141.734683 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.126496 67.944136 \n",
       "L 171.126496 67.707521 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.654908 67.47286 \n",
       "L 171.654908 67.236244 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.600768 70.186995 \n",
       "L 168.600768 69.950376 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.947434 164.901086 \n",
       "L 61.947434 164.664469 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.576075 63.989791 \n",
       "L 175.576075 63.753178 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.054315 155.925582 \n",
       "L 72.054315 155.688963 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.334833 69.536098 \n",
       "L 169.334833 69.299482 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.031476 66.251919 \n",
       "L 173.031476 66.015303 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.089729 169.213966 \n",
       "L 57.089729 168.977348 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.995272 61.843569 \n",
       "L 177.995272 61.606951 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.966938 166.660995 \n",
       "L 59.966938 166.42438 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.081799 70.648923 \n",
       "L 168.081799 70.412306 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 105.752608 125.999353 \n",
       "L 105.752608 125.762734 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.342821 59.758617 \n",
       "L 180.342821 59.522002 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.626006 173.17907 \n",
       "L 52.626006 172.94245 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.417551 73.01361 \n",
       "L 165.417551 72.776992 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.403741 65.92176 \n",
       "L 173.403741 65.685142 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.142047 171.832883 \n",
       "L 54.142047 171.596267 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.332165 65.982831 \n",
       "L 173.332165 65.746214 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.830544 172.109568 \n",
       "L 53.830544 171.872949 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.718393 139.347802 \n",
       "L 90.718393 139.111186 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.515807 63.159229 \n",
       "L 176.515807 62.922615 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.439623 148.478292 \n",
       "L 80.439623 148.241676 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.895664 67.260892 \n",
       "L 171.895664 67.024274 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.36712 62.401692 \n",
       "L 177.36712 62.165074 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.146871 143.410899 \n",
       "L 86.146871 143.17428 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.234891 61.629237 \n",
       "L 178.234891 61.39263 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.068266 118.615032 \n",
       "L 114.068266 118.378416 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.711149 61.207721 \n",
       "L 178.711149 60.971107 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.377227 64.169092 \n",
       "L 175.377227 63.932474 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.3183 65.99693 \n",
       "L 173.3183 65.760313 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.000908 141.762255 \n",
       "L 88.000908 141.525646 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.480984 160.875144 \n",
       "L 66.480984 160.63853 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.546685 66.682011 \n",
       "L 172.546685 66.445392 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.118544 68.839471 \n",
       "L 170.118544 68.602853 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.072725 161.237312 \n",
       "L 66.072725 161.000696 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.606671 160.765255 \n",
       "L 66.606671 160.528642 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.721181 67.41734 \n",
       "L 171.721181 67.180723 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.659818 162.491753 \n",
       "L 64.659818 162.255136 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.416683 59.692477 \n",
       "L 180.416683 59.45586 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.858238 62.854156 \n",
       "L 176.858238 62.61754 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.96914 71.635828 \n",
       "L 166.96914 71.399209 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.770257 117.991054 \n",
       "L 114.770257 117.75444 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.98841 140.888423 \n",
       "L 88.98841 140.651823 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.217817 74.967867 \n",
       "L 163.217817 74.73125 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.884683 73.487499 \n",
       "L 164.884683 73.250881 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.589221 69.309525 \n",
       "L 169.589221 69.072908 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.252385 137.100234 \n",
       "L 93.252385 136.863619 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.967554 71.638193 \n",
       "L 166.967554 71.401584 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.98261 139.115544 \n",
       "L 90.98261 138.878929 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.833257 69.093679 \n",
       "L 169.833257 68.857062 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.375505 122.782302 \n",
       "L 109.375505 122.545685 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 132.503965 102.241682 \n",
       "L 132.503965 102.005068 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.140114 117.662441 \n",
       "L 115.140114 117.425824 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.834447 65.538651 \n",
       "L 173.834447 65.302036 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.14047 68.818941 \n",
       "L 170.14047 68.58233 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.982563 140.891964 \n",
       "L 88.982563 140.655349 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.415274 73.90494 \n",
       "L 164.415274 73.668325 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.869381 58.403003 \n",
       "L 181.869381 58.166388 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.031846 168.379132 \n",
       "L 58.031846 168.142516 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.325774 157.461356 \n",
       "L 70.325774 157.224739 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.118803 68.839026 \n",
       "L 170.118803 68.602408 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.250423 67.833633 \n",
       "L 171.250423 67.597017 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.234952 66.069814 \n",
       "L 173.234952 65.833198 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.768046 131.311851 \n",
       "L 99.768046 131.075234 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 141.526535 94.229627 \n",
       "L 141.526535 93.993009 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.482 148.439794 \n",
       "L 80.482 148.203179 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.160921 165.602252 \n",
       "L 61.160921 165.365638 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.556518 64.010491 \n",
       "L 175.556518 63.773877 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.525855 115.545211 \n",
       "L 117.525855 115.308599 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.343457 164.549081 \n",
       "L 62.343457 164.312462 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.977305 116.91925 \n",
       "L 115.977305 116.68263 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 152.104325 84.837939 \n",
       "L 152.104325 84.601331 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 101.671452 129.625122 \n",
       "L 101.671452 129.388507 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.979737 141.782993 \n",
       "L 87.979737 141.546376 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.622563 160.751101 \n",
       "L 66.622563 160.514489 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.201619 74.981243 \n",
       "L 163.201619 74.744625 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.416877 151.163554 \n",
       "L 77.416877 150.926936 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 144.166806 91.885372 \n",
       "L 144.166806 91.648753 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 148.75072 87.814984 \n",
       "L 148.75072 87.578366 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.399148 60.596843 \n",
       "L 179.399148 60.360226 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.262445 65.15703 \n",
       "L 174.262445 64.920416 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.045562 62.687558 \n",
       "L 177.045562 62.450941 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.187726 72.33079 \n",
       "L 166.187726 72.094184 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.712807 61.206624 \n",
       "L 178.712807 60.970005 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.992377 65.396917 \n",
       "L 173.992377 65.160305 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 101.940397 129.384959 \n",
       "L 101.940397 129.148339 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 135.902797 99.225012 \n",
       "L 135.902797 98.988403 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.197277 63.441875 \n",
       "L 176.197277 63.205258 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.55734 165.24721 \n",
       "L 61.55734 165.010591 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.674139 61.239922 \n",
       "L 178.674139 61.003311 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.214111 69.641869 \n",
       "L 169.214111 69.405253 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.193205 142.481289 \n",
       "L 87.193205 142.244671 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.8981 69.923761 \n",
       "L 168.8981 69.687148 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.361495 165.422767 \n",
       "L 61.361495 165.186148 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.88905 63.714735 \n",
       "L 175.88905 63.478121 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.899592 136.525346 \n",
       "L 93.899592 136.288732 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.314441 150.365055 \n",
       "L 78.314441 150.128437 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.168364 67.906048 \n",
       "L 171.168364 67.66943 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.437788 163.576096 \n",
       "L 63.437788 163.339481 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 111.819856 120.611094 \n",
       "L 111.819856 120.374475 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.497008 159.973438 \n",
       "L 67.497008 159.73682 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.954856 169.335131 \n",
       "L 56.954856 169.098512 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.769342 71.812857 \n",
       "L 166.769342 71.576237 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.057311 157.695268 \n",
       "L 70.057311 157.45866 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.153102 60.816272 \n",
       "L 179.153102 60.579655 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.997711 58.289586 \n",
       "L 181.997711 58.05297 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.038471 155.054369 \n",
       "L 73.038471 154.817764 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 97.091609 133.691209 \n",
       "L 97.091609 133.454589 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.975671 168.425801 \n",
       "L 57.975671 168.18919 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.83066 65.54305 \n",
       "L 173.83066 65.306433 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.072412 161.237856 \n",
       "L 66.072412 161.001238 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.509759 159.961199 \n",
       "L 67.509759 159.724579 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.840781 168.547639 \n",
       "L 57.840781 168.31102 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.740326 159.756574 \n",
       "L 67.740326 159.519954 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.410346 65.027406 \n",
       "L 174.410346 64.790787 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.228432 69.630417 \n",
       "L 169.228432 69.3938 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.925508 160.480507 \n",
       "L 66.925508 160.243888 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.589469 65.758037 \n",
       "L 173.589469 65.521424 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.142636 69.705886 \n",
       "L 169.142636 69.469268 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.299723 66.901518 \n",
       "L 172.299723 66.664901 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.130894 67.051883 \n",
       "L 172.130894 66.815267 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 151.061597 85.763037 \n",
       "L 151.061597 85.526421 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.953851 152.461137 \n",
       "L 75.953851 152.224521 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.958178 65.428377 \n",
       "L 173.958178 65.191758 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.200235 64.325416 \n",
       "L 175.200235 64.088797 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.40305 58.817103 \n",
       "L 181.40305 58.580489 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.152751 136.300837 \n",
       "L 94.152751 136.06422 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.352985 66.852868 \n",
       "L 172.352985 66.616253 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.34649 148.56155 \n",
       "L 80.34649 148.324932 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.785509 133.963385 \n",
       "L 96.785509 133.726774 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.225511 59.862795 \n",
       "L 180.225511 59.62618 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.771606 164.168801 \n",
       "L 62.771606 163.932185 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.888044 64.603229 \n",
       "L 174.888044 64.36661 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.319472 152.137708 \n",
       "L 76.319472 151.901088 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.255592 145.090807 \n",
       "L 84.255592 144.854191 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.95077 60.9963 \n",
       "L 178.95077 60.759683 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.158133 146.064661 \n",
       "L 83.158133 145.828047 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.854169 160.544069 \n",
       "L 66.854169 160.307453 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.79931 62.016757 \n",
       "L 177.79931 61.78014 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.230546 153.992247 \n",
       "L 74.230546 153.75563 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.864232 164.087005 \n",
       "L 62.864232 163.850388 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 101.1081 130.123859 \n",
       "L 101.1081 129.88724 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.408211 69.470073 \n",
       "L 169.408211 69.233456 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.759514 62.05319 \n",
       "L 177.759514 61.816575 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.047312 60.02182 \n",
       "L 180.047312 59.785201 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.519622 69.373132 \n",
       "L 169.519622 69.136518 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.821436 157.909776 \n",
       "L 69.821436 157.673167 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.779052 67.364261 \n",
       "L 171.779052 67.127646 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.943892 64.553575 \n",
       "L 174.943892 64.316956 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.266425 140.640066 \n",
       "L 89.266425 140.403448 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.97567 65.414005 \n",
       "L 173.97567 65.177388 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.948737 61.884798 \n",
       "L 177.948737 61.648183 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.216678 154.003658 \n",
       "L 74.216678 153.767044 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.976379 140.009087 \n",
       "L 89.976379 139.772473 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.205189 66.986593 \n",
       "L 172.205189 66.749975 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.262961 68.710592 \n",
       "L 170.262961 68.473974 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 119.988713 113.354904 \n",
       "L 119.988713 113.118294 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.637904 165.17599 \n",
       "L 61.637904 164.939371 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.714006 157.115666 \n",
       "L 70.714006 156.879051 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.887418 166.72942 \n",
       "L 59.887418 166.492805 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.560342 66.670249 \n",
       "L 172.560342 66.433629 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.238066 65.180009 \n",
       "L 174.238066 64.943396 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.927769 147.1562 \n",
       "L 81.927769 146.919582 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.419001 157.377702 \n",
       "L 70.419001 157.141083 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.605707 71.069851 \n",
       "L 167.605707 70.833244 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 130.685283 103.858499 \n",
       "L 130.685283 103.621889 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.455029 166.22673 \n",
       "L 60.455029 165.990112 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.188706 164.686753 \n",
       "L 62.188706 164.450136 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.639151 155.406953 \n",
       "L 72.639151 155.170341 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.208124 61.65511 \n",
       "L 178.208124 61.418495 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.107733 146.109737 \n",
       "L 83.107733 145.873118 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.619518 70.170369 \n",
       "L 168.619518 69.933751 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.484018 65.849889 \n",
       "L 173.484018 65.61327 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 155.735202 81.613132 \n",
       "L 155.735202 81.376517 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.505155 143.979394 \n",
       "L 85.505155 143.742785 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 112.115205 120.348185 \n",
       "L 112.115205 120.111572 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.150898 154.950899 \n",
       "L 73.150898 154.714282 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.897315 166.720969 \n",
       "L 59.897315 166.484354 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.711459 142.021208 \n",
       "L 87.711459 141.78459 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.417809 154.71469 \n",
       "L 73.417809 154.478072 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.588143 155.450841 \n",
       "L 72.588143 155.214229 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.777276 62.036817 \n",
       "L 177.777276 61.8002 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.645698 115.437439 \n",
       "L 117.645698 115.200825 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.341999 61.535637 \n",
       "L 178.341999 61.29902 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.511056 151.967823 \n",
       "L 76.511056 151.731205 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.445775 64.109503 \n",
       "L 175.445775 63.872887 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.36146 167.197701 \n",
       "L 59.36146 166.961084 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.555721 66.674083 \n",
       "L 172.555721 66.437465 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.074506 62.660405 \n",
       "L 177.074506 62.423787 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 143.02196 92.90148 \n",
       "L 143.02196 92.664863 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.702492 64.770055 \n",
       "L 174.702492 64.533438 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.643074 71.037195 \n",
       "L 167.643074 70.800576 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.65927 159.828533 \n",
       "L 67.65927 159.591917 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.850966 65.524353 \n",
       "L 173.850966 65.287733 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.245132 64.286839 \n",
       "L 175.245132 64.050222 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.044329 140.837451 \n",
       "L 89.044329 140.600833 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.327974 173.443669 \n",
       "L 52.327974 173.207049 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.395855 65.927556 \n",
       "L 173.395855 65.690938 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.158185 62.586467 \n",
       "L 177.158185 62.349849 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.184277 140.712601 \n",
       "L 89.184277 140.475985 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.471161 64.086707 \n",
       "L 175.471161 63.850094 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.638851 67.490705 \n",
       "L 171.638851 67.254091 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.510961 64.937888 \n",
       "L 174.510961 64.701271 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 123.074769 110.615469 \n",
       "L 123.074769 110.378852 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.390316 65.93273 \n",
       "L 173.390316 65.696111 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.419076 63.241375 \n",
       "L 176.419076 63.004765 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.391799 64.155857 \n",
       "L 175.391799 63.919239 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.576897 63.992782 \n",
       "L 175.576897 63.756167 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.725749 147.337224 \n",
       "L 81.725749 147.100606 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.849032 77.070872 \n",
       "L 160.849032 76.834253 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.676953 59.462878 \n",
       "L 180.676953 59.226262 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.957133 60.101009 \n",
       "L 179.957133 59.864394 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.254601 162.851569 \n",
       "L 64.254601 162.614951 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.30719 67.783102 \n",
       "L 171.30719 67.546486 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.845534 153.446236 \n",
       "L 74.845534 153.209618 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 108.643602 123.430318 \n",
       "L 108.643602 123.193716 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.815039 62.003807 \n",
       "L 177.815039 61.767188 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.588498 164.332422 \n",
       "L 62.588498 164.095805 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.630335 65.719649 \n",
       "L 173.630335 65.483032 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.18203 173.573097 \n",
       "L 52.18203 173.336477 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.105185 147.887787 \n",
       "L 81.105185 147.651173 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.103473 162.986022 \n",
       "L 64.103473 162.749403 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.508273 65.828745 \n",
       "L 173.508273 65.59213 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.119764 65.286561 \n",
       "L 174.119764 65.049947 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.714532 152.675396 \n",
       "L 75.714532 152.438783 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.37336 122.784193 \n",
       "L 109.37336 122.547576 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.361687 169.861458 \n",
       "L 56.361687 169.624839 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.955432 148.019217 \n",
       "L 80.955432 147.782604 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.297741 66.904566 \n",
       "L 172.297741 66.667948 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.8437 151.670969 \n",
       "L 76.8437 151.434355 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 136.222572 98.939403 \n",
       "L 136.222572 98.702783 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.414688 160.045711 \n",
       "L 67.414688 159.809093 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.941964 122.278995 \n",
       "L 109.941964 122.042376 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.945514 66.328025 \n",
       "L 172.945514 66.091409 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.390892 63.268198 \n",
       "L 176.390892 63.031579 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.916234 66.355486 \n",
       "L 172.916234 66.118871 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.442409 154.694025 \n",
       "L 73.442409 154.457411 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.533779 159.939946 \n",
       "L 67.533779 159.703328 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.186909 61.67329 \n",
       "L 178.186909 61.436673 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.618214 70.172007 \n",
       "L 168.618214 69.93539 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.427427 164.478243 \n",
       "L 62.427427 164.241631 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.965144 166.661819 \n",
       "L 59.965144 166.425202 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.749384 65.615256 \n",
       "L 173.749384 65.378648 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.85094 64.635719 \n",
       "L 174.85094 64.399102 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.994493 137.328179 \n",
       "L 92.994493 137.091565 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 102.797924 128.619613 \n",
       "L 102.797924 128.383009 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.883483 64.607251 \n",
       "L 174.883483 64.370632 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 116.848978 116.144905 \n",
       "L 116.848978 115.908291 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.598124 63.085974 \n",
       "L 176.598124 62.849356 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 119.639921 113.66707 \n",
       "L 119.639921 113.430462 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.34964 157.438199 \n",
       "L 70.34964 157.201581 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.696941 59.444572 \n",
       "L 180.696941 59.207953 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.226555 65.191567 \n",
       "L 174.226555 64.954949 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.00397 144.425806 \n",
       "L 85.00397 144.189192 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.986079 63.628228 \n",
       "L 175.986079 63.391621 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.009049 66.274175 \n",
       "L 173.009049 66.037564 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.380316 63.278831 \n",
       "L 176.380316 63.042214 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.097842 154.111489 \n",
       "L 74.097842 153.874874 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 143.784821 92.224369 \n",
       "L 143.784821 91.98775 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 154.733371 82.501898 \n",
       "L 154.733371 82.26528 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 67.573641 159.903741 \n",
       "L 67.573641 159.667123 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.08433 155.899594 \n",
       "L 72.08433 155.662977 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.140525 64.37854 \n",
       "L 175.140525 64.141926 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.434279 62.340449 \n",
       "L 177.434279 62.103831 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.663864 63.914534 \n",
       "L 175.663864 63.67792 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.480101 161.764004 \n",
       "L 65.480101 161.527386 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.920025 131.178136 \n",
       "L 99.920025 130.941518 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.553122 64.01307 \n",
       "L 175.553122 63.776452 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.518125 64.931464 \n",
       "L 174.518125 64.694853 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.806592 157.921258 \n",
       "L 69.806592 157.684641 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.560302 153.701777 \n",
       "L 74.560302 153.465171 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.359279 66.848808 \n",
       "L 172.359279 66.61219 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.144122 62.599892 \n",
       "L 177.144122 62.363272 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.924893 151.600221 \n",
       "L 76.924893 151.363605 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.14438 59.934895 \n",
       "L 180.14438 59.698278 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.520921 143.966132 \n",
       "L 85.520921 143.729516 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.250312 59.84106 \n",
       "L 180.250312 59.604444 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.53979 65.800925 \n",
       "L 173.53979 65.564309 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.149907 64.370939 \n",
       "L 175.149907 64.134321 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.993064 167.524105 \n",
       "L 58.993064 167.287488 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 133.393083 101.452709 \n",
       "L 133.393083 101.2161 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.12878 163.851522 \n",
       "L 63.12878 163.614902 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.010476 60.055597 \n",
       "L 180.010476 59.818981 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.774423 145.516995 \n",
       "L 83.774423 145.280377 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.588871 63.092909 \n",
       "L 176.588871 62.85629 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.358197 64.18639 \n",
       "L 175.358197 63.949778 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.320249 59.779209 \n",
       "L 180.320249 59.542591 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.90926 142.731607 \n",
       "L 86.90926 142.494993 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.536368 144.84183 \n",
       "L 84.536368 144.605224 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 142.932403 92.987279 \n",
       "L 142.932403 92.750742 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.79482 62.022231 \n",
       "L 177.79482 61.785615 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.519963 65.817742 \n",
       "L 173.519963 65.581126 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.596921 169.652547 \n",
       "L 56.596921 169.415929 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.468845 150.226507 \n",
       "L 78.468845 149.989891 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.105118 64.411055 \n",
       "L 175.105118 64.174438 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.493664 66.730144 \n",
       "L 172.493664 66.493525 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.983694 163.092911 \n",
       "L 63.983694 162.856293 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.351092 103.26664 \n",
       "L 131.351092 103.030022 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.051705 131.949784 \n",
       "L 99.051705 131.713166 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.068564 170.121798 \n",
       "L 56.068564 169.885179 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.451587 167.117344 \n",
       "L 59.451587 166.880725 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.173781 63.461031 \n",
       "L 176.173781 63.224413 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.323672 169.895512 \n",
       "L 56.323672 169.658893 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.891838 65.487591 \n",
       "L 173.891838 65.250973 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.888775 142.7515 \n",
       "L 86.888775 142.514881 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 111.408134 120.974444 \n",
       "L 111.408134 120.737838 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.950956 140.920178 \n",
       "L 88.950956 140.68356 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.570633 62.220642 \n",
       "L 177.570633 61.98403 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.131302 71.491951 \n",
       "L 167.131302 71.255332 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.143366 60.824514 \n",
       "L 179.143366 60.587896 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.230357 60.747522 \n",
       "L 179.230357 60.510904 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.044707 70.680393 \n",
       "L 168.044707 70.443775 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.989622 116.908134 \n",
       "L 115.989622 116.671519 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 97.339368 133.470365 \n",
       "L 97.339368 133.233747 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.786929 149.94446 \n",
       "L 78.786929 149.707846 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 154.766809 82.471617 \n",
       "L 154.766809 82.235001 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.520376 140.41463 \n",
       "L 89.520376 140.178011 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.087076 166.552204 \n",
       "L 60.087076 166.315587 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.598942 59.531371 \n",
       "L 180.598942 59.294753 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.635999 58.611469 \n",
       "L 181.635999 58.374852 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.396221 63.26592 \n",
       "L 176.396221 63.029303 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.2612 166.398113 \n",
       "L 60.2612 166.161494 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.433078 74.777315 \n",
       "L 163.433078 74.540698 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.937306 63.671578 \n",
       "L 175.937306 63.434959 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 146.261751 90.025656 \n",
       "L 146.261751 89.789043 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.823498 61.108367 \n",
       "L 178.823498 60.871752 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.243374 65.176064 \n",
       "L 174.243374 64.939446 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.425504 65.01557 \n",
       "L 174.425504 64.778956 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.704465 156.235951 \n",
       "L 71.704465 155.999341 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.289102 76.688122 \n",
       "L 161.289102 76.451527 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.944415 69.882307 \n",
       "L 168.944415 69.645691 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.652649 158.947201 \n",
       "L 68.652649 158.710584 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.147289 151.402243 \n",
       "L 77.147289 151.165632 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.328608 70.428458 \n",
       "L 168.328608 70.19184 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.537066 142.174583 \n",
       "L 87.537066 141.937978 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.99969 158.63812 \n",
       "L 68.99969 158.401502 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.033446 168.376615 \n",
       "L 58.033446 168.139998 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.057899 67.119621 \n",
       "L 172.057899 66.883006 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.750751 61.172342 \n",
       "L 178.750751 60.935725 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.592944 59.536703 \n",
       "L 180.592944 59.300085 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.26705 171.721404 \n",
       "L 54.26705 171.484786 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 129.956073 104.504409 \n",
       "L 129.956073 104.267793 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 127.129296 107.015647 \n",
       "L 127.129296 106.779031 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.866935 166.748465 \n",
       "L 59.866935 166.511847 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.298405 145.050634 \n",
       "L 84.298405 144.814016 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.193027 67.885834 \n",
       "L 171.193027 67.649218 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 124.897415 108.997211 \n",
       "L 124.897415 108.760599 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.904592 63.701458 \n",
       "L 175.904592 63.464841 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.522779 65.815563 \n",
       "L 173.522779 65.578944 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 55.391551 170.722656 \n",
       "L 55.391551 170.486038 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.686727 163.358913 \n",
       "L 63.686727 163.122312 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 108.819928 123.274517 \n",
       "L 108.819928 123.0379 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.007259 60.05772 \n",
       "L 180.007259 59.821103 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.325939 66.878684 \n",
       "L 172.325939 66.642067 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.492612 65.842471 \n",
       "L 173.492612 65.605858 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 137.642626 97.683098 \n",
       "L 137.642626 97.446519 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.147839 64.373335 \n",
       "L 175.147839 64.136718 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.998831 137.325313 \n",
       "L 92.998831 137.088706 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.713794 163.332324 \n",
       "L 63.713794 163.095707 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.479341 60.526029 \n",
       "L 179.479341 60.289411 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.582101 63.987973 \n",
       "L 175.582101 63.751355 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.740392 134.003172 \n",
       "L 96.740392 133.766557 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.049165 154.151122 \n",
       "L 74.049165 153.914507 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.591023 71.97215 \n",
       "L 166.591023 71.735533 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.094219 62.642497 \n",
       "L 177.094219 62.405885 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.817324 64.667392 \n",
       "L 174.817324 64.430775 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.818425 66.440786 \n",
       "L 172.818425 66.20417 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.721856 65.639272 \n",
       "L 173.721856 65.402656 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 105.838372 125.923032 \n",
       "L 105.838372 125.686413 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.136056 61.719074 \n",
       "L 178.136056 61.482463 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.05628 67.120025 \n",
       "L 172.05628 66.883416 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.655823 148.286697 \n",
       "L 80.655823 148.05008 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.689949 163.353216 \n",
       "L 63.689949 163.116598 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.724143 62.082255 \n",
       "L 177.724143 61.845638 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 135.701009 99.403118 \n",
       "L 135.701009 99.166505 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.026567 64.478814 \n",
       "L 175.026567 64.242198 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.299217 168.140398 \n",
       "L 58.299217 167.90378 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 130.284229 104.213949 \n",
       "L 130.284229 103.977331 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.908174 71.68933 \n",
       "L 166.908174 71.452711 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.988445 66.292079 \n",
       "L 172.988445 66.055468 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.061292 64.449977 \n",
       "L 175.061292 64.213373 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.880893 62.832991 \n",
       "L 176.880893 62.596375 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 55.022202 171.050825 \n",
       "L 55.022202 170.814206 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.871825 70.834067 \n",
       "L 167.871825 70.597448 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.433345 65.004137 \n",
       "L 174.433345 64.767525 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.773053 160.615897 \n",
       "L 66.773053 160.379282 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.423926 66.79144 \n",
       "L 172.423926 66.554822 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 75.032324 153.28053 \n",
       "L 75.032324 153.043912 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.891179 167.615506 \n",
       "L 58.891179 167.378889 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.932883 61.898362 \n",
       "L 177.932883 61.661754 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 101.221313 130.021943 \n",
       "L 101.221313 129.785325 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 172.554146 66.675874 \n",
       "L 172.554146 66.439255 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.043037 66.240777 \n",
       "L 173.043037 66.004161 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 180.211127 59.874651 \n",
       "L 180.211127 59.638034 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.513922 60.495172 \n",
       "L 179.513922 60.258553 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.895872 71.701366 \n",
       "L 166.895872 71.46475 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.866665 156.979562 \n",
       "L 70.866665 156.742951 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.472098 68.524935 \n",
       "L 170.472098 68.288327 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 175.793678 63.799584 \n",
       "L 175.793678 63.562968 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.039793 68.90945 \n",
       "L 170.039793 68.672832 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 129.508445 104.902338 \n",
       "L 129.508445 104.665719 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.955145 67.207641 \n",
       "L 171.955145 66.971025 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 179.595707 60.423397 \n",
       "L 179.595707 60.186781 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.826155 161.456152 \n",
       "L 65.826155 161.219535 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 129.417366 104.984763 \n",
       "L 129.417366 104.748149 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.511839 145.751196 \n",
       "L 83.511839 145.514581 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 157.72395 79.847165 \n",
       "L 157.72395 79.610549 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.032856 63.586843 \n",
       "L 176.032856 63.350224 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.418957 58.803752 \n",
       "L 181.418957 58.567134 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 173.331524 65.98523 \n",
       "L 173.331524 65.748614 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 176.804045 62.903213 \n",
       "L 176.804045 62.666603 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 181.169531 59.025216 \n",
       "L 181.169531 58.788597 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.355014 61.524034 \n",
       "L 178.355014 61.287417 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 107.121295 124.785285 \n",
       "L 107.121295 124.548667 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.398243 161.837697 \n",
       "L 65.398243 161.601081 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.199521 146.027984 \n",
       "L 83.199521 145.791365 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 82.480724 146.66563 \n",
       "L 82.480724 146.429016 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.523616 122.650309 \n",
       "L 109.523616 122.413692 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 127.465694 106.717044 \n",
       "L 127.465694 106.480425 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.420626 155.600065 \n",
       "L 72.420626 155.363447 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.365013 144.992709 \n",
       "L 84.365013 144.756091 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.174091 61.68544 \n",
       "L 178.174091 61.448824 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 178.231062 61.634176 \n",
       "L 178.231062 61.397557 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 174.888142 64.602323 \n",
       "L 174.888142 64.365708 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 147.346036 89.064447 \n",
       "L 147.346036 88.82783 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.201192 134.482039 \n",
       "L 96.201192 134.245423 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 177.158077 62.585666 \n",
       "L 177.158077 62.349054 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.999692 157.750153 \n",
       "L 69.999692 157.51354 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.218205 158.444396 \n",
       "L 69.218205 158.207779 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.305381 150.373834 \n",
       "L 78.305381 150.137215 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.472743 144.00799 \n",
       "L 85.472743 143.771374 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.082577 117.713961 \n",
       "L 115.082577 117.477341 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.224657 153.998345 \n",
       "L 74.224657 153.761729 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.731094 70.073718 \n",
       "L 168.731094 69.837103 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_10\">\n",
       "    <defs>\n",
       "     <path id=\"m6c2c26cb29\" d=\"M 0 1 \n",
       "C 0.265203 1 0.51958 0.894634 0.707107 0.707107 \n",
       "C 0.894634 0.51958 1 0.265203 1 0 \n",
       "C 1 -0.265203 0.894634 -0.51958 0.707107 -0.707107 \n",
       "C 0.51958 -0.894634 0.265203 -1 0 -1 \n",
       "C -0.265203 -1 -0.51958 -0.894634 -0.707107 -0.707107 \n",
       "C -0.894634 -0.51958 -1 -0.265203 -1 0 \n",
       "C -1 0.265203 -0.894634 0.51958 -0.707107 0.707107 \n",
       "C -0.51958 0.894634 -0.265203 1 0 1 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf2d8b3ac00)\">\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.804765\" y=\"66.335413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.088179\" y=\"63.419312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.176208\" y=\"61.564958\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"152.333221\" y=\"84.517689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"110.367359\" y=\"121.783256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.468677\" y=\"65.745579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.950801\" y=\"143.465829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.809238\" y=\"154.246966\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.944133\" y=\"64.434889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.523078\" y=\"155.390476\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.008633\" y=\"61.713753\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.906948\" y=\"63.579863\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"98.273161\" y=\"132.521854\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.304914\" y=\"142.263502\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.526171\" y=\"63.030201\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.705037\" y=\"155.22944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.340215\" y=\"161.769226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"161.756565\" y=\"76.146549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"165.362057\" y=\"72.944852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.0432\" y=\"62.569581\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.966434\" y=\"65.303428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.634546\" y=\"140.191958\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.471681\" y=\"62.190465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.283376\" y=\"65.022721\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.355092\" y=\"62.294527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"116.246542\" y=\"116.560485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.649419\" y=\"66.472823\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.046025\" y=\"63.458003\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"130.958885\" y=\"103.494413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.54539\" y=\"147.378741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.777748\" y=\"62.806721\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"164.901197\" y=\"73.354236\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"100.972691\" y=\"130.125555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"148.405734\" y=\"88.004062\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.150964\" y=\"159.274872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.630084\" y=\"146.415223\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.191137\" y=\"59.774279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.928254\" y=\"167.46404\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"105.63667\" y=\"125.983921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"54.404424\" y=\"171.48069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.636362\" y=\"62.930888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"54.003627\" y=\"171.837255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"94.108019\" y=\"136.217029\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"86.61121\" y=\"142.880756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"146.039069\" y=\"90.103878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.439149\" y=\"65.772856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.761467\" y=\"59.269175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"64.845768\" y=\"162.208776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.54746\" y=\"69.227251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.650011\" y=\"68.24831\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.923211\" y=\"68.894711\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"144.678935\" y=\"91.311039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"123.735929\" y=\"109.909643\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.480753\" y=\"64.846849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"109.522667\" y=\"122.534039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"120.086225\" y=\"113.149126\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.489193\" y=\"59.510925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"125.816981\" y=\"108.06316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.64614\" y=\"66.476126\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.475833\" y=\"59.522474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.907353\" y=\"69.79589\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"92.07739\" y=\"138.025568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"128.754942\" y=\"105.452792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.420456\" y=\"167.914411\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.60885\" y=\"154.427042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"98.990324\" y=\"131.886719\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.722317\" y=\"146.333567\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"162.497094\" y=\"75.489237\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"117.777057\" y=\"115.202886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.511554\" y=\"160.728775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.542515\" y=\"59.463484\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.153024\" y=\"155.718775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"112.739792\" y=\"119.675385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.251628\" y=\"63.273093\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.039198\" y=\"69.678547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.572368\" y=\"153.571076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.786836\" y=\"64.574673\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.888338\" y=\"65.372944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.250806\" y=\"59.722168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.268563\" y=\"166.274048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.281048\" y=\"69.465568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.879844\" y=\"152.407628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"79.252638\" y=\"149.414569\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.659366\" y=\"67.352734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"132.428675\" y=\"102.191909\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.856532\" y=\"65.401053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.680395\" y=\"68.222332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"162.730335\" y=\"75.281505\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"135.320377\" y=\"99.623624\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.636264\" y=\"63.820287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"143.857509\" y=\"92.042788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.001153\" y=\"161.182446\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"155.414408\" y=\"81.778817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"137.310849\" y=\"97.855588\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"110.18294\" y=\"121.946018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.887817\" y=\"63.596111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.597793\" y=\"142.004017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.417038\" y=\"151.932824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.129365\" y=\"66.048467\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.845524\" y=\"62.746418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.35222\" y=\"159.094373\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.53795\" y=\"169.5868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.518135\" y=\"60.372776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.309004\" y=\"62.337367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"95.562534\" y=\"134.93046\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.283607\" y=\"70.350505\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.745824\" y=\"66.387823\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.681912\" y=\"62.892376\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"55.655758\" y=\"170.370064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"104.89951\" y=\"126.637515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.792636\" y=\"63.680825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.689012\" y=\"154.356069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.432686\" y=\"63.113222\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.923171\" y=\"65.340064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.227719\" y=\"144.107329\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.289263\" y=\"146.717402\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.800685\" y=\"160.472717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.835532\" y=\"139.128769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.642583\" y=\"64.702852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.199745\" y=\"168.111617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.064555\" y=\"158.462214\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.466713\" y=\"140.3437\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.029617\" y=\"148.725301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.450063\" y=\"58.657146\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"151.714428\" y=\"85.064859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.826414\" y=\"60.099587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.342754\" y=\"161.768135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.891768\" y=\"65.369427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"96.60939\" y=\"133.999862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.415571\" y=\"59.576654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.240347\" y=\"66.836195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"164.008771\" y=\"74.14603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.965595\" y=\"153.221962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"135.148727\" y=\"99.774542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"95.831537\" y=\"134.691354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.438525\" y=\"62.218628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"116.049464\" y=\"116.736545\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.552528\" y=\"63.893463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.49709\" y=\"147.422567\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.911123\" y=\"168.367197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.179013\" y=\"65.114503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.404647\" y=\"63.137276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"160.933105\" y=\"76.87713\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.628562\" y=\"65.603928\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.496147\" y=\"66.609428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.931129\" y=\"147.032378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.17713\" y=\"60.674951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.713561\" y=\"59.311962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.113327\" y=\"155.754895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"137.145806\" y=\"98.001358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"160.828851\" y=\"76.970711\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"135.268408\" y=\"99.669085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"64.919553\" y=\"162.144533\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.491271\" y=\"168.740316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.53221\" y=\"63.913815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"118.996265\" y=\"114.119991\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.235759\" y=\"65.065898\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.503341\" y=\"60.386315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.783024\" y=\"62.801354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.158959\" y=\"164.594466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"108.023445\" y=\"123.864189\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.861021\" y=\"61.84358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.232647\" y=\"70.395854\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.759802\" y=\"64.601475\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"99.495059\" y=\"131.43812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.641698\" y=\"62.927238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.350465\" y=\"64.077178\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.876075\" y=\"70.713022\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.429965\" y=\"59.563465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.970788\" y=\"58.194906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.122627\" y=\"65.164358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.99873\" y=\"64.387447\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.41983\" y=\"139.496998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.659876\" y=\"61.134558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.901416\" y=\"161.271803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.702762\" y=\"158.784357\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.5121\" y=\"62.154084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.793404\" y=\"65.456719\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.776516\" y=\"168.486264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.781579\" y=\"61.914009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.592491\" y=\"69.188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.803729\" y=\"61.896327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.033303\" y=\"69.688683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"126.54829\" y=\"107.413222\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.694502\" y=\"63.768506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"124.431119\" y=\"109.291951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.301836\" y=\"68.556033\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.292361\" y=\"64.127128\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"86.45176\" y=\"143.020689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.96314\" y=\"150.560547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.595432\" y=\"63.857105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.804428\" y=\"61.007507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"165.648177\" y=\"72.690152\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.786924\" y=\"61.911284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"106.43142\" y=\"125.277963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"138.029074\" y=\"97.217483\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.161169\" y=\"64.241835\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.695072\" y=\"146.357726\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.887543\" y=\"63.597209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.496044\" y=\"164.296301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.91404\" y=\"67.126184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"110.641598\" y=\"121.539354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.566457\" y=\"67.434705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.801723\" y=\"64.56197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"161.324182\" y=\"76.530299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.400686\" y=\"64.919851\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"138.249965\" y=\"97.021943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.59892\" y=\"148.218436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.041883\" y=\"68.789184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.999618\" y=\"138.982698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"114.199764\" y=\"118.379857\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"155.551842\" y=\"81.657917\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.848533\" y=\"66.298276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.519679\" y=\"67.475421\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.971264\" y=\"147.886948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"162.085722\" y=\"75.854879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.354886\" y=\"146.659804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.625459\" y=\"67.382336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.581993\" y=\"63.865022\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.063967\" y=\"61.663863\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.853265\" y=\"67.180474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.223654\" y=\"65.075282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.185255\" y=\"66.885885\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.398171\" y=\"63.143779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.504297\" y=\"150.967929\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.754861\" y=\"68.154931\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.590866\" y=\"61.196045\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.431418\" y=\"62.226635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.998129\" y=\"60.835182\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.194672\" y=\"60.65959\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.998121\" y=\"66.164272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.037412\" y=\"64.352281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.079754\" y=\"117.598285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.87554\" y=\"64.495985\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.172401\" y=\"60.679516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.220814\" y=\"159.212058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"114.740576\" y=\"117.899121\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.277884\" y=\"65.027957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.78381\" y=\"168.479926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.341986\" y=\"64.081563\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.236114\" y=\"152.092057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.746028\" y=\"148.086926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.14621\" y=\"148.621154\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"117.594081\" y=\"115.364287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"108.166376\" y=\"123.737325\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"165.241574\" y=\"73.051579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.462517\" y=\"63.975974\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.709067\" y=\"61.97991\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"104.335481\" y=\"127.139034\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"108.152793\" y=\"123.749486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"61.519707\" y=\"165.162421\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.369936\" y=\"62.281243\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.053665\" y=\"167.35231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.159464\" y=\"61.577992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"94.375605\" y=\"135.984522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.284171\" y=\"152.937586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.449414\" y=\"63.986042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.079401\" y=\"63.425938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"84.787898\" y=\"144.498091\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.052963\" y=\"150.480844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.260044\" y=\"157.399993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"165.005345\" y=\"73.261223\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"117.846504\" y=\"115.140255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.232088\" y=\"64.179236\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.270227\" y=\"158.279357\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"92.299069\" y=\"137.828087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.692882\" y=\"160.568859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.7042\" y=\"143.685292\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"121.990399\" y=\"111.462018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"139.46667\" y=\"95.94124\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.039024\" y=\"67.016478\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.314859\" y=\"62.330787\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.732538\" y=\"64.623087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.218856\" y=\"63.305428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.781825\" y=\"61.026842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"142.044311\" y=\"93.651181\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.298823\" y=\"65.896261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.455306\" y=\"151.00989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"152.008271\" y=\"84.803537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.149395\" y=\"157.498523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.870597\" y=\"59.172585\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.630048\" y=\"60.273768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.819957\" y=\"65.433938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"119.587887\" y=\"113.594743\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.42907\" y=\"71.110168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"97.293392\" y=\"133.391073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.239331\" y=\"65.94952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"119.273319\" y=\"113.874091\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.021894\" y=\"60.81367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.7521\" y=\"66.381965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"148.809457\" y=\"87.644691\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.069496\" y=\"61.659575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"127.255732\" y=\"106.78507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.611551\" y=\"64.730013\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.89672\" y=\"65.364871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"142.695876\" y=\"93.071461\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"131.39112\" y=\"103.112827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.877078\" y=\"158.628911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.107998\" y=\"169.968218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.392311\" y=\"67.590697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.5634\" y=\"168.676006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.577009\" y=\"66.537318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.607974\" y=\"61.181353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"127.741544\" y=\"106.354055\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"161.854805\" y=\"76.059591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.394391\" y=\"160.832471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.004932\" y=\"151.406921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.374957\" y=\"160.85043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.701634\" y=\"160.560478\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.890697\" y=\"65.370991\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"107.322172\" y=\"124.486031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.286146\" y=\"155.601519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.236083\" y=\"155.645776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.446447\" y=\"63.098882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"121.03079\" y=\"112.312513\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.875533\" y=\"64.495477\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.881664\" y=\"64.48933\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.781126\" y=\"153.385548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.563781\" y=\"154.466935\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.670228\" y=\"147.267071\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"93.967449\" y=\"136.346513\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"86.928878\" y=\"142.598185\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"109.151304\" y=\"122.862438\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.67454\" y=\"117.069694\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.56459\" y=\"158.019204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.322055\" y=\"61.434647\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"88.098017\" y=\"141.560191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.308123\" y=\"163.574236\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.051634\" y=\"157.585963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"94.835253\" y=\"135.575872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.986382\" y=\"156.755849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"125.692201\" y=\"108.172859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.097909\" y=\"66.963937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.940276\" y=\"69.767156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.584571\" y=\"58.537693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"159.044778\" y=\"78.553791\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.821263\" y=\"66.321238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.671253\" y=\"62.900674\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.885586\" y=\"62.709901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.59851\" y=\"147.331983\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.917032\" y=\"63.571139\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.011084\" y=\"146.966039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.188252\" y=\"169.009078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.634303\" y=\"165.949527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.683869\" y=\"147.2553\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.641422\" y=\"165.942493\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.923655\" y=\"143.491311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.267928\" y=\"63.260255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.262343\" y=\"65.040226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.496189\" y=\"65.72136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.223089\" y=\"66.853507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"128.105868\" y=\"106.030514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.531637\" y=\"60.360032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"91.841381\" y=\"138.235116\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.135903\" y=\"161.950627\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.743922\" y=\"147.198977\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.948829\" y=\"67.094419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.987969\" y=\"65.283852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.234244\" y=\"65.06512\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"53.432574\" y=\"172.344534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.898987\" y=\"64.476824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.203846\" y=\"61.540803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"88.259857\" y=\"141.415793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.884951\" y=\"145.30098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.933562\" y=\"63.555845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.267623\" y=\"151.177579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.584073\" y=\"59.426486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.948819\" y=\"66.207762\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.395054\" y=\"117.317274\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.886049\" y=\"163.949517\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"114.72269\" y=\"117.91474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.502282\" y=\"65.715367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.597752\" y=\"65.628956\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.556019\" y=\"70.107592\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.699929\" y=\"60.212303\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.29262\" y=\"71.229979\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.331577\" y=\"64.979057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.007044\" y=\"65.263993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"132.685864\" y=\"101.963148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.675577\" y=\"64.6734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"130.042974\" y=\"104.309312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"113.022121\" y=\"119.425681\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.370554\" y=\"65.832362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"95.506747\" y=\"134.981337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.223253\" y=\"59.747042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.582222\" y=\"69.199646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.929291\" y=\"62.671242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.061557\" y=\"67.883288\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.668242\" y=\"151.709648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.044828\" y=\"59.905484\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.368712\" y=\"64.946561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.607248\" y=\"63.84624\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.445968\" y=\"65.769053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.60659\" y=\"59.407425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.175173\" y=\"163.692533\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.676159\" y=\"61.121021\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.348658\" y=\"159.985072\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.790433\" y=\"160.482786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.888942\" y=\"61.819869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.045962\" y=\"148.709879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.787927\" y=\"157.819422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.357913\" y=\"151.097226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.98045\" y=\"67.066747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.489145\" y=\"64.838969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.811157\" y=\"65.445607\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.244948\" y=\"62.391085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.698335\" y=\"66.433442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.279083\" y=\"59.697613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.665754\" y=\"65.570526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.025333\" y=\"62.58687\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.112001\" y=\"65.174623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.319471\" y=\"66.766167\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.989433\" y=\"167.409506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.812967\" y=\"61.887714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"136.660477\" y=\"98.434103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.062625\" y=\"71.436188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.967014\" y=\"64.415013\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.340602\" y=\"72.076176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"182.797626\" y=\"57.460838\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.978154\" y=\"65.294579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.041699\" y=\"144.273793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.130029\" y=\"65.157779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.782917\" y=\"68.12958\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"94.935238\" y=\"135.488369\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.844286\" y=\"63.635917\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"128.293933\" y=\"105.863174\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.601678\" y=\"66.515399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.561885\" y=\"158.908599\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.503409\" y=\"159.850701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.642028\" y=\"166.829613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.616566\" y=\"69.165606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"103.782565\" y=\"127.629236\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.548807\" y=\"143.824341\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.458006\" y=\"66.643633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.512712\" y=\"67.484019\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.453276\" y=\"169.661614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"141.958986\" y=\"93.72663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"116.493271\" y=\"116.342492\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.755901\" y=\"63.713489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.671103\" y=\"65.564209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.508048\" y=\"158.955328\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.9675\" y=\"149.668507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.940212\" y=\"64.44031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.985889\" y=\"60.845856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.931644\" y=\"145.257727\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"161.807673\" y=\"76.101297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.541469\" y=\"163.367135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"126.908695\" y=\"107.092345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.020285\" y=\"62.592646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.179748\" y=\"64.226784\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"117.188374\" y=\"115.725227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.731181\" y=\"163.19907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.217438\" y=\"154.774584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.606432\" y=\"62.071092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.935382\" y=\"67.994285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.265864\" y=\"63.263342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.204779\" y=\"61.538768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.206639\" y=\"158.337693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.112737\" y=\"161.972435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.538343\" y=\"164.257966\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"103.374253\" y=\"127.993145\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"135.688668\" y=\"99.297015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"97.536955\" y=\"133.177033\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"84.110247\" y=\"145.100888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.511837\" y=\"64.82192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.824928\" y=\"64.542932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.838565\" y=\"60.088474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.840614\" y=\"59.198636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.646749\" y=\"157.057947\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.675512\" y=\"58.457178\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.734993\" y=\"159.645514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"165.132898\" y=\"73.149215\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.111919\" y=\"147.763061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.792897\" y=\"145.381908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.778072\" y=\"64.580959\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"99.861396\" y=\"131.112519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"99.655523\" y=\"131.292391\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.031705\" y=\"62.581739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.088069\" y=\"144.231447\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.20287\" y=\"65.981839\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.928663\" y=\"152.366876\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.692761\" y=\"152.576012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"92.764746\" y=\"137.414305\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.501331\" y=\"64.828212\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.309537\" y=\"163.573326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.226659\" y=\"142.328123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"161.728276\" y=\"76.172582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"54.305134\" y=\"171.569354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.290976\" y=\"61.462868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.066886\" y=\"63.439573\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.946138\" y=\"62.657165\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.315792\" y=\"62.329187\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.824005\" y=\"159.565455\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.240812\" y=\"166.298174\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.787655\" y=\"64.573924\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"71.292953\" y=\"156.482572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.811943\" y=\"65.441948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.60541\" y=\"64.73719\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.605382\" y=\"63.847124\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.607977\" y=\"62.07004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.446227\" y=\"159.011574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"137.536312\" y=\"97.65317\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.595328\" y=\"142.006054\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"131.107445\" y=\"103.364109\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"114.614084\" y=\"118.011531\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.555904\" y=\"154.474241\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"93.458651\" y=\"136.798676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.071175\" y=\"151.350935\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.233345\" y=\"65.065609\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"126.7614\" y=\"107.223949\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.818661\" y=\"64.546693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"98.89362\" y=\"131.960516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.732984\" y=\"150.765723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"94.250501\" y=\"136.094189\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"143.609951\" y=\"92.261054\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"104.431468\" y=\"127.053529\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.499888\" y=\"70.158668\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.803015\" y=\"158.692878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"100.39538\" y=\"130.638602\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"138.462257\" y=\"96.83297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.5211\" y=\"62.14621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.811524\" y=\"149.807844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.610939\" y=\"63.843579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.100644\" y=\"168.198858\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.264664\" y=\"65.926706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.560483\" y=\"67.442971\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"122.031091\" y=\"111.425851\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.916627\" y=\"61.794635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.355929\" y=\"159.090758\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.792358\" y=\"166.699129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.901821\" y=\"159.495009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.984995\" y=\"61.734804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"154.389975\" y=\"82.688991\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.277649\" y=\"68.579014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.056498\" y=\"62.559454\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.482582\" y=\"60.403964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.283644\" y=\"152.940042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"105.407113\" y=\"126.187888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.567525\" y=\"60.329342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.184765\" y=\"61.556832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"149.181136\" y=\"87.313337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.578934\" y=\"63.870033\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"139.236208\" y=\"96.14586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.497652\" y=\"58.615678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"125.230375\" y=\"108.583838\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"54.22329\" y=\"171.642196\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.568953\" y=\"139.366043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"118.281096\" y=\"114.755017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.051952\" y=\"68.779807\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.432075\" y=\"139.487412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.498944\" y=\"61.27811\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.758181\" y=\"151.629729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"145.979488\" y=\"90.157568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.166636\" y=\"140.609068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.052878\" y=\"60.787038\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"107.2235\" y=\"124.575479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.963117\" y=\"68.859267\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.906444\" y=\"60.028411\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"111.144389\" y=\"121.093532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.890649\" y=\"63.593005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.392194\" y=\"64.036532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.256439\" y=\"65.045321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.146075\" y=\"164.605794\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.901027\" y=\"68.025576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.769412\" y=\"141.85299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.126496\" y=\"67.825828\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.654908\" y=\"67.354552\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.600768\" y=\"70.068686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"61.947434\" y=\"164.782777\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.576075\" y=\"63.871485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.054315\" y=\"155.807273\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.334833\" y=\"69.41779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.031476\" y=\"66.133611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.089729\" y=\"169.095657\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.995272\" y=\"61.72526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.966938\" y=\"166.542687\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.081799\" y=\"70.530614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"105.752608\" y=\"125.881043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.342821\" y=\"59.64031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"52.626006\" y=\"173.06076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"165.417551\" y=\"72.895301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.403741\" y=\"65.803451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"54.142047\" y=\"171.714575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.332165\" y=\"65.864523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"53.830544\" y=\"171.991259\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.718393\" y=\"139.229494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.515807\" y=\"63.040922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.439623\" y=\"148.359984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.895664\" y=\"67.142583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.36712\" y=\"62.283383\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"86.146871\" y=\"143.29259\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.234891\" y=\"61.510934\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"114.068266\" y=\"118.496724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.711149\" y=\"61.089414\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.377227\" y=\"64.050783\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.3183\" y=\"65.878621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"88.000908\" y=\"141.64395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.480984\" y=\"160.756837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.546685\" y=\"66.563701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.118544\" y=\"68.721162\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.072725\" y=\"161.119004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.606671\" y=\"160.646948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.721181\" y=\"67.299032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"64.659818\" y=\"162.373444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.416683\" y=\"59.574168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.858238\" y=\"62.735848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.96914\" y=\"71.517519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"114.770257\" y=\"117.872747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"88.98841\" y=\"140.770123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"163.217817\" y=\"74.849558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"164.884683\" y=\"73.36919\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.589221\" y=\"69.191216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"93.252385\" y=\"136.981927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.967554\" y=\"71.519888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"90.98261\" y=\"138.997237\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.833257\" y=\"68.97537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"109.375505\" y=\"122.663993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"132.503965\" y=\"102.123375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.140114\" y=\"117.544133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.834447\" y=\"65.420343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.14047\" y=\"68.700636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"88.982563\" y=\"140.773657\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"164.415274\" y=\"73.786633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.869381\" y=\"58.284696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.031846\" y=\"168.260824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.325774\" y=\"157.343047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.118803\" y=\"68.720717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.250423\" y=\"67.715325\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.234952\" y=\"65.951506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"99.768046\" y=\"131.193542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"141.526535\" y=\"94.111318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.482\" y=\"148.321487\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"61.160921\" y=\"165.483945\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.556518\" y=\"63.892184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"117.525855\" y=\"115.426905\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.343457\" y=\"164.430771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.977305\" y=\"116.80094\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"152.104325\" y=\"84.719635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"101.671452\" y=\"129.506814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.979737\" y=\"141.664684\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.622563\" y=\"160.632795\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"163.201619\" y=\"74.862934\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.416877\" y=\"151.045245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"144.166806\" y=\"91.767062\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"148.75072\" y=\"87.696675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.399148\" y=\"60.478534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.262445\" y=\"65.038723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.045562\" y=\"62.569249\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.187726\" y=\"72.212487\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.712807\" y=\"61.088314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.992377\" y=\"65.278611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"101.940397\" y=\"129.266649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"135.902797\" y=\"99.106708\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.197277\" y=\"63.323566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"61.55734\" y=\"165.1289\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.674139\" y=\"61.121616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.214111\" y=\"69.523561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.193205\" y=\"142.36298\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.8981\" y=\"69.805454\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"61.361495\" y=\"165.304458\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.88905\" y=\"63.596428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"93.899592\" y=\"136.407039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.314441\" y=\"150.246746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.168364\" y=\"67.787739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.437788\" y=\"163.457788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"111.819856\" y=\"120.492785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.497008\" y=\"159.855129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.954856\" y=\"169.216821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.769342\" y=\"71.694547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.057311\" y=\"157.576964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.153102\" y=\"60.697963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.997711\" y=\"58.171278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.038471\" y=\"154.936066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"97.091609\" y=\"133.572899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.975671\" y=\"168.307495\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.83066\" y=\"65.424742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.072412\" y=\"161.119547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.509759\" y=\"159.842889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"57.840781\" y=\"168.429329\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.740326\" y=\"159.638264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.410346\" y=\"64.909096\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.228432\" y=\"69.512109\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.925508\" y=\"160.362197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.589469\" y=\"65.639731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.142636\" y=\"69.587577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.299723\" y=\"66.78321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.130894\" y=\"66.933575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"151.061597\" y=\"85.644729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.953851\" y=\"152.342829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.958178\" y=\"65.310068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.200235\" y=\"64.207107\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.40305\" y=\"58.698796\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"94.152751\" y=\"136.182528\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.352985\" y=\"66.734561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.34649\" y=\"148.443241\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"96.785509\" y=\"133.845079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.225511\" y=\"59.744487\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.771606\" y=\"164.050493\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.888044\" y=\"64.48492\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.319472\" y=\"152.019398\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"84.255592\" y=\"144.972499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.95077\" y=\"60.877991\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.158133\" y=\"145.946354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.854169\" y=\"160.425761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.79931\" y=\"61.898449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.230546\" y=\"153.873939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.864232\" y=\"163.968696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"101.1081\" y=\"130.00555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.408211\" y=\"69.351764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.759514\" y=\"61.934882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.047312\" y=\"59.90351\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"169.519622\" y=\"69.254825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.821436\" y=\"157.791472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.779052\" y=\"67.245953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.943892\" y=\"64.435265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.266425\" y=\"140.521757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.97567\" y=\"65.295697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.948737\" y=\"61.766491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.216678\" y=\"153.885351\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.976379\" y=\"139.89078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.205189\" y=\"66.868284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.262961\" y=\"68.592283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"119.988713\" y=\"113.236599\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"61.637904\" y=\"165.057681\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.714006\" y=\"156.997358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.887418\" y=\"166.611113\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.560342\" y=\"66.551939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.238066\" y=\"65.061702\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.927769\" y=\"147.037891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.419001\" y=\"157.259392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.605707\" y=\"70.951547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"130.685283\" y=\"103.740194\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.455029\" y=\"166.108421\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.188706\" y=\"164.568444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.639151\" y=\"155.288647\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.208124\" y=\"61.536802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.107733\" y=\"145.991428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.619518\" y=\"70.05206\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.484018\" y=\"65.731579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"155.735202\" y=\"81.494825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.505155\" y=\"143.86109\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"112.115205\" y=\"120.229878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.150898\" y=\"154.832591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.897315\" y=\"166.602662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.711459\" y=\"141.902899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.417809\" y=\"154.596381\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.588143\" y=\"155.332535\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.777276\" y=\"61.918508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"117.645698\" y=\"115.319132\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.341999\" y=\"61.417329\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.511056\" y=\"151.849514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.445775\" y=\"63.991195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.36146\" y=\"167.079393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.555721\" y=\"66.555774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.074506\" y=\"62.542096\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"143.02196\" y=\"92.783172\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.702492\" y=\"64.651746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.643074\" y=\"70.918886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.65927\" y=\"159.710225\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.850966\" y=\"65.406043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.245132\" y=\"64.168531\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.044329\" y=\"140.719142\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"52.327974\" y=\"173.325359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.395855\" y=\"65.809247\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.158185\" y=\"62.468158\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.184277\" y=\"140.594293\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.471161\" y=\"63.9684\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.638851\" y=\"67.372398\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.510961\" y=\"64.819579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"123.074769\" y=\"110.497161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.390316\" y=\"65.81442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.419076\" y=\"63.12307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.391799\" y=\"64.037548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.576897\" y=\"63.874474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.725749\" y=\"147.218915\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"160.849032\" y=\"76.952563\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.676953\" y=\"59.34457\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.957133\" y=\"59.982701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"64.254601\" y=\"162.73326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.30719\" y=\"67.664794\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.845534\" y=\"153.327927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"108.643602\" y=\"123.312017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.815039\" y=\"61.885497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.588498\" y=\"164.214113\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.630335\" y=\"65.60134\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"52.18203\" y=\"173.454787\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"81.105185\" y=\"147.76948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"64.103473\" y=\"162.867712\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.508273\" y=\"65.710437\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.119764\" y=\"65.168254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.714532\" y=\"152.557089\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"109.37336\" y=\"122.665884\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.361687\" y=\"169.743148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.955432\" y=\"147.900911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.297741\" y=\"66.786257\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.8437\" y=\"151.552662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"136.222572\" y=\"98.821093\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.414688\" y=\"159.927402\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"109.941964\" y=\"122.160686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.945514\" y=\"66.209717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.390892\" y=\"63.149889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.916234\" y=\"66.237179\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"73.442409\" y=\"154.575718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.533779\" y=\"159.821637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.186909\" y=\"61.554982\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.618214\" y=\"70.053699\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"62.427427\" y=\"164.359937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.965144\" y=\"166.543511\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.749384\" y=\"65.496952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.85094\" y=\"64.51741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"92.994493\" y=\"137.209872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"102.797924\" y=\"128.501311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.883483\" y=\"64.488941\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"116.848978\" y=\"116.026598\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.598124\" y=\"62.967665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"119.639921\" y=\"113.548766\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.34964\" y=\"157.31989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.696941\" y=\"59.326262\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.226555\" y=\"65.073258\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.00397\" y=\"144.307499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.986079\" y=\"63.509925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.009049\" y=\"66.15587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.380316\" y=\"63.160522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.097842\" y=\"153.993182\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"143.784821\" y=\"92.10606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"154.733371\" y=\"82.383589\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"67.573641\" y=\"159.785432\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.08433\" y=\"155.781286\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.140525\" y=\"64.260233\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.434279\" y=\"62.22214\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.663864\" y=\"63.796227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.480101\" y=\"161.645695\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"99.920025\" y=\"131.059827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.553122\" y=\"63.894761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.518125\" y=\"64.813159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.806592\" y=\"157.80295\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.560302\" y=\"153.583474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.359279\" y=\"66.730499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.144122\" y=\"62.481582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"76.924893\" y=\"151.481913\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.14438\" y=\"59.816586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.520921\" y=\"143.847824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.250312\" y=\"59.722752\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.53979\" y=\"65.682617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.149907\" y=\"64.25263\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.993064\" y=\"167.405796\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"133.393083\" y=\"101.334405\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.12878\" y=\"163.733212\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.010476\" y=\"59.937289\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.774423\" y=\"145.398686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.588871\" y=\"62.9746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.358197\" y=\"64.068084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.320249\" y=\"59.6609\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"86.90926\" y=\"142.6133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"84.536368\" y=\"144.723527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"142.932403\" y=\"92.869011\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.79482\" y=\"61.903923\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.519963\" y=\"65.699434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.596921\" y=\"169.534238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.468845\" y=\"150.108199\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.105118\" y=\"64.292747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.493664\" y=\"66.611834\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.983694\" y=\"162.974602\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"131.351092\" y=\"103.148331\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"99.051705\" y=\"131.831475\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.068564\" y=\"170.003488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.451587\" y=\"166.999034\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.173781\" y=\"63.342722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"56.323672\" y=\"169.777203\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.891838\" y=\"65.369282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"86.888775\" y=\"142.633191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"111.408134\" y=\"120.856141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"88.950956\" y=\"140.801869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.570633\" y=\"62.102336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.131302\" y=\"71.373641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.143366\" y=\"60.706205\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.230357\" y=\"60.629213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.044707\" y=\"70.562084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.989622\" y=\"116.789826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"97.339368\" y=\"133.352056\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.786929\" y=\"149.826153\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"154.766809\" y=\"82.353309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"89.520376\" y=\"140.29632\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.087076\" y=\"166.433896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.598942\" y=\"59.413062\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.635999\" y=\"58.49316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.396221\" y=\"63.147612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"60.2612\" y=\"166.279804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"163.433078\" y=\"74.659006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.937306\" y=\"63.553269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"146.261751\" y=\"89.907349\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.823498\" y=\"60.99006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.243374\" y=\"65.057755\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.425504\" y=\"64.897263\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"71.704465\" y=\"156.117646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"161.289102\" y=\"76.569825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.944415\" y=\"69.763999\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.652649\" y=\"158.828892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"77.147289\" y=\"151.283937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.328608\" y=\"70.310149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"87.537066\" y=\"142.05628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"68.99969\" y=\"158.519811\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.033446\" y=\"168.258307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.057899\" y=\"67.001314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.750751\" y=\"61.054034\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.592944\" y=\"59.418394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"54.26705\" y=\"171.603095\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"129.956073\" y=\"104.386101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"127.129296\" y=\"106.897339\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"59.866935\" y=\"166.630156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"84.298405\" y=\"144.932325\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.193027\" y=\"67.767526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"124.897415\" y=\"108.878905\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.904592\" y=\"63.58315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.522779\" y=\"65.697254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"55.391551\" y=\"170.604347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.686727\" y=\"163.240612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"108.819928\" y=\"123.156209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.007259\" y=\"59.939412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.325939\" y=\"66.760375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.492612\" y=\"65.724165\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"137.642626\" y=\"97.564809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.147839\" y=\"64.255027\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"92.998831\" y=\"137.207009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.713794\" y=\"163.214015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.479341\" y=\"60.40772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.582101\" y=\"63.869664\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"96.740392\" y=\"133.884865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.049165\" y=\"154.032815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.591023\" y=\"71.853841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.094219\" y=\"62.524191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.817324\" y=\"64.549084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.818425\" y=\"66.322478\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.721856\" y=\"65.520964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"105.838372\" y=\"125.804722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.136056\" y=\"61.600768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.05628\" y=\"67.001721\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"80.655823\" y=\"148.168389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"63.689949\" y=\"163.234907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.724143\" y=\"61.963946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"135.701009\" y=\"99.284812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.026567\" y=\"64.360506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.299217\" y=\"168.022089\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"130.284229\" y=\"104.09564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.908174\" y=\"71.57102\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.988445\" y=\"66.173773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.061292\" y=\"64.331675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.880893\" y=\"62.714683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"55.022202\" y=\"170.932515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"167.871825\" y=\"70.715758\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.433345\" y=\"64.885831\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"66.773053\" y=\"160.49759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.423926\" y=\"66.673131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"75.032324\" y=\"153.162221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"58.891179\" y=\"167.497198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.932883\" y=\"61.780058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"101.221313\" y=\"129.903634\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"172.554146\" y=\"66.557564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.043037\" y=\"66.122469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"180.211127\" y=\"59.756343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.513922\" y=\"60.376863\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"166.895872\" y=\"71.583058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"70.866665\" y=\"156.861256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.472098\" y=\"68.406631\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"175.793678\" y=\"63.681276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"170.039793\" y=\"68.791141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"129.508445\" y=\"104.784028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"171.955145\" y=\"67.089333\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"179.595707\" y=\"60.305089\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.826155\" y=\"161.337844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"129.417366\" y=\"104.866456\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.511839\" y=\"145.632889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"157.72395\" y=\"79.728857\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.032856\" y=\"63.468533\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.418957\" y=\"58.685443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"173.331524\" y=\"65.866922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"176.804045\" y=\"62.784908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"181.169531\" y=\"58.906906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.355014\" y=\"61.405725\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"107.121295\" y=\"124.666976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"65.398243\" y=\"161.719389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"83.199521\" y=\"145.909674\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"82.480724\" y=\"146.547323\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"109.523616\" y=\"122.532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"127.465694\" y=\"106.598734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"72.420626\" y=\"155.481756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"84.365013\" y=\"144.8744\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.174091\" y=\"61.567132\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"178.231062\" y=\"61.515867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"174.888142\" y=\"64.484015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"147.346036\" y=\"88.946138\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"96.201192\" y=\"134.363731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"177.158077\" y=\"62.46736\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.999692\" y=\"157.631847\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"69.218205\" y=\"158.326087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"78.305381\" y=\"150.255525\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"85.472743\" y=\"143.889682\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"115.082577\" y=\"117.595651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"74.224657\" y=\"153.880037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"168.731094\" y=\"69.95541\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 45.65125 166.05573 \n",
       "L 45.65125 61.884981 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 83.974282 179.384625 \n",
       "L 177.815715 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_12\">\n",
       "    <!-- RMSE: 0.000 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(52.835108 64.316362) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-52\" d=\"M 503 0 \n",
       "L 503 4581 \n",
       "L 2534 4581 \n",
       "Q 3147 4581 3465 4457 \n",
       "Q 3784 4334 3975 4021 \n",
       "Q 4166 3709 4166 3331 \n",
       "Q 4166 2844 3850 2509 \n",
       "Q 3534 2175 2875 2084 \n",
       "Q 3116 1969 3241 1856 \n",
       "Q 3506 1613 3744 1247 \n",
       "L 4541 0 \n",
       "L 3778 0 \n",
       "L 3172 953 \n",
       "Q 2906 1366 2734 1584 \n",
       "Q 2563 1803 2427 1890 \n",
       "Q 2291 1978 2150 2013 \n",
       "Q 2047 2034 1813 2034 \n",
       "L 1109 2034 \n",
       "L 1109 0 \n",
       "L 503 0 \n",
       "z\n",
       "M 1109 2559 \n",
       "L 2413 2559 \n",
       "Q 2828 2559 3062 2645 \n",
       "Q 3297 2731 3419 2920 \n",
       "Q 3541 3109 3541 3331 \n",
       "Q 3541 3656 3305 3865 \n",
       "Q 3069 4075 2559 4075 \n",
       "L 1109 4075 \n",
       "L 1109 2559 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-53\" d=\"M 288 1472 \n",
       "L 859 1522 \n",
       "Q 900 1178 1048 958 \n",
       "Q 1197 738 1509 602 \n",
       "Q 1822 466 2213 466 \n",
       "Q 2559 466 2825 569 \n",
       "Q 3091 672 3220 851 \n",
       "Q 3350 1031 3350 1244 \n",
       "Q 3350 1459 3225 1620 \n",
       "Q 3100 1781 2813 1891 \n",
       "Q 2628 1963 1997 2114 \n",
       "Q 1366 2266 1113 2400 \n",
       "Q 784 2572 623 2826 \n",
       "Q 463 3081 463 3397 \n",
       "Q 463 3744 659 4045 \n",
       "Q 856 4347 1234 4503 \n",
       "Q 1613 4659 2075 4659 \n",
       "Q 2584 4659 2973 4495 \n",
       "Q 3363 4331 3572 4012 \n",
       "Q 3781 3694 3797 3291 \n",
       "L 3216 3247 \n",
       "Q 3169 3681 2898 3903 \n",
       "Q 2628 4125 2100 4125 \n",
       "Q 1550 4125 1298 3923 \n",
       "Q 1047 3722 1047 3438 \n",
       "Q 1047 3191 1225 3031 \n",
       "Q 1400 2872 2139 2705 \n",
       "Q 2878 2538 3153 2413 \n",
       "Q 3553 2228 3743 1945 \n",
       "Q 3934 1663 3934 1294 \n",
       "Q 3934 928 3725 604 \n",
       "Q 3516 281 3123 101 \n",
       "Q 2731 -78 2241 -78 \n",
       "Q 1619 -78 1198 103 \n",
       "Q 778 284 539 648 \n",
       "Q 300 1013 288 1472 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-45\" d=\"M 506 0 \n",
       "L 506 4581 \n",
       "L 3819 4581 \n",
       "L 3819 4041 \n",
       "L 1113 4041 \n",
       "L 1113 2638 \n",
       "L 3647 2638 \n",
       "L 3647 2100 \n",
       "L 1113 2100 \n",
       "L 1113 541 \n",
       "L 3925 541 \n",
       "L 3925 0 \n",
       "L 506 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3a\" d=\"M 578 2678 \n",
       "L 578 3319 \n",
       "L 1219 3319 \n",
       "L 1219 2678 \n",
       "L 578 2678 \n",
       "z\n",
       "M 578 0 \n",
       "L 578 641 \n",
       "L 1219 641 \n",
       "L 1219 0 \n",
       "L 578 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_13\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(65.460078 45.531) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_11\">\n",
       "    <path d=\"M 172.804765 66.334993 \n",
       "L 181.970788 58.195037 \n",
       "L 54.003627 171.837248 \n",
       "L 62.496044 164.295494 \n",
       "\" clip-path=\"url(#pf2d8b3ac00)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 218.029781 179.384625 \n",
       "L 361.706937 179.384625 \n",
       "L 361.706937 51.531 \n",
       "L 218.029781 51.531 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"248.634114\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.617426 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"294.591812\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(292.144999 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"340.54951\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(338.102697 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"218.029781\" y=\"172.541674\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(199.696406 175.691111) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"218.029781\" y=\"152.114141\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(199.696406 155.263578) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"218.029781\" y=\"131.686608\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(199.696406 134.836046) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"218.029781\" y=\"111.259076\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(204.836156 114.408513) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"218.029781\" y=\"90.831543\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(204.836156 93.980981) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"218.029781\" y=\"70.40401\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(204.836156 73.553448) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_2\">\n",
       "    <path d=\"M 319.094076 89.540474 \n",
       "L 319.094076 89.425181 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 332.337333 77.763973 \n",
       "L 332.337333 77.648403 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.522127 101.605326 \n",
       "L 305.522127 101.48993 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.875725 116.403545 \n",
       "L 288.875725 116.288276 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.289636 125.821821 \n",
       "L 278.289636 125.706525 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.576444 84.65534 \n",
       "L 324.576444 84.539674 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.449248 136.339352 \n",
       "L 266.449248 136.223712 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.924309 107.506893 \n",
       "L 298.924309 107.392404 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.428145 84.796562 \n",
       "L 324.428145 84.680823 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.710677 141.394357 \n",
       "L 260.710677 141.279253 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.160803 103.694642 \n",
       "L 303.160803 103.579955 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.931842 87.899085 \n",
       "L 320.931842 87.783673 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.207028 132.973087 \n",
       "L 270.207028 132.861269 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.285058 128.486632 \n",
       "L 275.285058 128.371516 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.575899 98.004136 \n",
       "L 309.575899 97.890679 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.769257 120.069261 \n",
       "L 284.769257 119.953515 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.412817 119.475291 \n",
       "L 285.412817 119.359524 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.664138 110.342909 \n",
       "L 295.664138 110.22873 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.450965 119.429046 \n",
       "L 285.450965 119.313267 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.161923 85.91193 \n",
       "L 323.161923 85.798006 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.865958 83.51485 \n",
       "L 325.865958 83.399154 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.567723 121.121863 \n",
       "L 283.567723 121.006862 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.845619 107.51806 \n",
       "L 298.845619 107.403703 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.17361 94.795076 \n",
       "L 313.17361 94.681007 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 332.560718 77.566618 \n",
       "L 332.560718 77.451082 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.645249 137.080253 \n",
       "L 265.645249 136.965871 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.809799 83.552986 \n",
       "L 325.809799 83.43723 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.068459 100.227022 \n",
       "L 307.068459 100.113486 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.947892 106.553217 \n",
       "L 299.947892 106.441487 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 254.578053 146.857972 \n",
       "L 254.578053 146.742942 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.66233 84.582641 \n",
       "L 324.66233 84.46689 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 351.880509 60.392563 \n",
       "L 351.880509 60.276679 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.00387 117.168859 \n",
       "L 288.00387 117.053803 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.316586 97.336414 \n",
       "L 310.316586 97.220629 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.564204 127.36565 \n",
       "L 276.564204 127.250465 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.273927 124.037061 \n",
       "L 280.273927 123.921213 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.476135 109.620883 \n",
       "L 296.476135 109.506462 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 251.311349 149.775489 \n",
       "L 251.311349 149.659636 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.49737 132.683565 \n",
       "L 270.49737 132.568599 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.948238 128.805556 \n",
       "L 274.948238 128.690451 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.911982 95.92877 \n",
       "L 311.911982 95.815632 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.47721 138.990109 \n",
       "L 263.47721 138.87435 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.273265 116.927873 \n",
       "L 288.273265 116.817655 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.804811 115.551585 \n",
       "L 289.804811 115.436317 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.957799 78.09823 \n",
       "L 331.957799 77.982475 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.857094 89.749494 \n",
       "L 318.857094 89.634033 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.873243 87.95789 \n",
       "L 320.873243 87.842561 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.784748 114.711772 \n",
       "L 290.784748 114.596683 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.395349 90.156688 \n",
       "L 318.395349 90.04097 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.725517 100.539241 \n",
       "L 306.725517 100.423984 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.144264 85.931394 \n",
       "L 323.144264 85.815692 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.262896 116.038895 \n",
       "L 289.262896 115.924073 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.497212 123.850042 \n",
       "L 280.497212 123.73427 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.238759 102.741173 \n",
       "L 304.238759 102.625367 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.623198 114.8488 \n",
       "L 290.623198 114.733133 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.984528 117.197748 \n",
       "L 287.984528 117.085715 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.754547 95.168548 \n",
       "L 312.754547 95.052837 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.952472 105.645954 \n",
       "L 300.952472 105.531964 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 342.642546 68.606402 \n",
       "L 342.642546 68.490543 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.805637 122.683338 \n",
       "L 281.805637 122.567543 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 337.533316 73.136609 \n",
       "L 337.533316 73.020751 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.672464 114.802195 \n",
       "L 290.672464 114.686657 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.406352 126.580483 \n",
       "L 277.406352 126.464876 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.595182 144.187042 \n",
       "L 257.595182 144.071304 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.921379 112.819914 \n",
       "L 292.921379 112.705975 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.22441 132.084437 \n",
       "L 271.22441 131.969236 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.567013 146.039082 \n",
       "L 255.567013 145.923487 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.93144 114.579211 \n",
       "L 290.93144 114.463917 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.55495 106.011007 \n",
       "L 300.55495 105.895123 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.450182 113.219653 \n",
       "L 292.450182 113.106314 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.711845 98.75386 \n",
       "L 308.711845 98.638489 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.41318 109.754283 \n",
       "L 296.41318 109.64073 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.965548 116.325022 \n",
       "L 288.965548 116.210991 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.633791 87.278206 \n",
       "L 321.633791 87.163402 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 343.912871 67.473338 \n",
       "L 343.912871 67.357542 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 245.703593 154.75168 \n",
       "L 245.703593 154.636034 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.559523 117.55965 \n",
       "L 287.559523 117.444759 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.720105 108.529316 \n",
       "L 297.720105 108.413981 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.253814 101.837009 \n",
       "L 305.253814 101.721373 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.354061 108.841364 \n",
       "L 297.354061 108.725689 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.288445 92.029842 \n",
       "L 316.288445 91.914037 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.453613 108.768955 \n",
       "L 297.453613 108.654189 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.136835 123.266863 \n",
       "L 281.136835 123.15143 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.021734 99.375818 \n",
       "L 308.021734 99.260093 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.698516 95.214881 \n",
       "L 312.698516 95.099553 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.897813 98.604127 \n",
       "L 308.897813 98.488438 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.482189 78.523805 \n",
       "L 331.482189 78.40843 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 350.761381 61.390787 \n",
       "L 350.761381 61.275132 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.978726 104.754745 \n",
       "L 301.978726 104.639986 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.065385 101.091213 \n",
       "L 306.065385 100.97756 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.403039 115.948315 \n",
       "L 289.403039 115.833942 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.507129 130.069148 \n",
       "L 273.507129 129.953516 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.618258 123.739008 \n",
       "L 280.618258 123.623198 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.520055 122.04286 \n",
       "L 282.520055 121.928188 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.950597 116.309784 \n",
       "L 288.950597 116.196167 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.251594 98.278453 \n",
       "L 309.251594 98.164889 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.041021 100.250664 \n",
       "L 307.041021 100.135273 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.456747 123.850496 \n",
       "L 280.456747 123.73677 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.308068 99.116488 \n",
       "L 308.308068 99.002013 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.590944 95.308603 \n",
       "L 312.590944 95.193225 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.520513 115.832341 \n",
       "L 289.520513 115.717813 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.306927 108.897803 \n",
       "L 297.306927 108.782111 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.963801 98.537764 \n",
       "L 308.963801 98.421915 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.787813 104.924573 \n",
       "L 301.787813 104.810904 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.749581 143.159585 \n",
       "L 258.749581 143.043972 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.003871 83.39215 \n",
       "L 326.003871 83.276287 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.148832 108.152672 \n",
       "L 298.148832 108.037344 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.953015 93.219135 \n",
       "L 314.953015 93.103288 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.520128 133.621706 \n",
       "L 269.520128 133.505809 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.320237 103.552565 \n",
       "L 303.320237 103.437896 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.872283 92.389688 \n",
       "L 315.872283 92.274717 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.343128 137.290987 \n",
       "L 265.343128 137.176531 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.825505 110.222749 \n",
       "L 295.825505 110.107301 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.750706 86.290562 \n",
       "L 322.750706 86.176719 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.309317 107.124041 \n",
       "L 299.309317 107.008146 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.084828 113.565035 \n",
       "L 292.084828 113.449988 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.604445 118.410377 \n",
       "L 286.604445 118.295159 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.677752 130.785776 \n",
       "L 272.677752 130.670165 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.521208 102.465167 \n",
       "L 304.521208 102.350485 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.349487 120.416943 \n",
       "L 284.349487 120.301344 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.675662 137.903673 \n",
       "L 264.675662 137.78798 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.31401 148.007231 \n",
       "L 253.31401 147.891381 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.798298 107.573868 \n",
       "L 298.798298 107.458117 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.231286 87.641218 \n",
       "L 321.231286 87.525686 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.50205 107.850829 \n",
       "L 298.50205 107.735458 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.479727 95.432874 \n",
       "L 312.479727 95.318503 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.522473 123.801383 \n",
       "L 280.522473 123.686023 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.964652 105.661774 \n",
       "L 300.964652 105.546443 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.098159 125.086917 \n",
       "L 279.098159 124.972301 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.317438 93.789292 \n",
       "L 314.317438 93.674419 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.005927 102.942119 \n",
       "L 304.005927 102.826435 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 334.345013 75.974955 \n",
       "L 334.345013 75.859316 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.585141 112.199669 \n",
       "L 293.585141 112.08522 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 340.010077 70.94608 \n",
       "L 340.010077 70.830656 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.520778 120.265437 \n",
       "L 284.520778 120.149747 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.330475 112.444775 \n",
       "L 293.330475 112.33032 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.429469 131.017371 \n",
       "L 272.429469 130.901868 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.747492 83.618462 \n",
       "L 325.747492 83.503305 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.18718 124.131702 \n",
       "L 280.18718 124.016746 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.239936 130.298377 \n",
       "L 273.239936 130.182522 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.588894 82.87352 \n",
       "L 326.588894 82.757632 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.314507 95.556633 \n",
       "L 312.314507 95.441641 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 339.801834 71.131348 \n",
       "L 339.801834 71.015907 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.598746 103.310292 \n",
       "L 303.598746 103.194458 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 330.600982 79.311602 \n",
       "L 330.600982 79.196323 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.778658 110.265428 \n",
       "L 295.778658 110.151305 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.836758 79.985067 \n",
       "L 329.836758 79.869701 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.99737 96.737626 \n",
       "L 310.99737 96.622075 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.739341 120.97048 \n",
       "L 283.739341 120.854766 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.981707 126.060489 \n",
       "L 277.981707 125.945464 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 355.011584 57.606245 \n",
       "L 355.011584 57.490349 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.219591 117.876171 \n",
       "L 287.219591 117.760523 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.853177 144.869041 \n",
       "L 256.853177 144.753442 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.215523 140.092276 \n",
       "L 262.215523 139.976583 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.409234 105.281633 \n",
       "L 301.409234 105.166514 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.64918 141.512767 \n",
       "L 260.64918 141.397095 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.836923 102.213447 \n",
       "L 304.836923 102.099618 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.627553 103.270571 \n",
       "L 303.627553 103.155379 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.334134 106.218451 \n",
       "L 300.334134 106.103679 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.097241 131.317779 \n",
       "L 272.097241 131.202801 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.42919 130.16604 \n",
       "L 273.42919 130.054362 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.775134 96.938244 \n",
       "L 310.775134 96.824842 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.883536 118.16475 \n",
       "L 286.883536 118.048983 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.943427 108.345733 \n",
       "L 297.943427 108.231959 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.587713 122.882787 \n",
       "L 281.587713 122.766925 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.147221 115.275458 \n",
       "L 290.147221 115.160077 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.685909 102.334075 \n",
       "L 304.685909 102.218561 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.813322 88.002276 \n",
       "L 320.813322 87.887036 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.643886 97.941644 \n",
       "L 309.643886 97.825792 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.063698 96.680922 \n",
       "L 311.063698 96.565249 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.708881 94.315678 \n",
       "L 313.708881 94.20064 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.87184 101.285205 \n",
       "L 305.87184 101.169946 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.974203 131.39537 \n",
       "L 271.974203 131.280026 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.863526 89.735529 \n",
       "L 318.863526 89.620246 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.96458 138.530236 \n",
       "L 263.96458 138.414792 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.861989 133.295112 \n",
       "L 269.861989 133.180116 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.609778 94.413199 \n",
       "L 313.609778 94.297847 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.748493 91.623178 \n",
       "L 316.748493 91.507318 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.761415 125.387259 \n",
       "L 278.761415 125.271861 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.682288 107.685566 \n",
       "L 298.682288 107.570521 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.41624 87.473013 \n",
       "L 321.41624 87.357186 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.205448 95.658587 \n",
       "L 312.205448 95.544244 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.208252 113.438199 \n",
       "L 292.208252 113.323192 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.321558 128.450374 \n",
       "L 275.321558 128.334679 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.78989 93.354724 \n",
       "L 314.78989 93.239139 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.896984 113.728774 \n",
       "L 291.896984 113.615526 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.769065 92.501777 \n",
       "L 315.769065 92.386283 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.346229 97.324579 \n",
       "L 310.346229 97.209409 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.69111 130.782847 \n",
       "L 272.69111 130.667208 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.966553 124.316742 \n",
       "L 279.966553 124.200947 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.014897 97.60651 \n",
       "L 310.014897 97.490665 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.74766 96.950044 \n",
       "L 310.74766 96.834334 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 334.193575 76.115187 \n",
       "L 334.193575 75.999756 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.80977 125.336222 \n",
       "L 278.80977 125.220812 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.169159 128.606425 \n",
       "L 275.169159 128.491594 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.773347 103.151699 \n",
       "L 303.773347 103.036173 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.784076 112.035794 \n",
       "L 293.784076 111.920101 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.322211 115.110215 \n",
       "L 290.322211 114.994746 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.773373 92.494403 \n",
       "L 315.773373 92.379484 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.557387 129.121033 \n",
       "L 274.557387 129.005593 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.742694 114.74137 \n",
       "L 290.742694 114.62558 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.012023 136.722265 \n",
       "L 266.012023 136.606379 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.732478 101.418512 \n",
       "L 305.732478 101.302877 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.892307 98.605657 \n",
       "L 308.892307 98.490012 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 352.124211 60.172944 \n",
       "L 352.124211 60.05717 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.394472 93.705334 \n",
       "L 314.394472 93.591422 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.493841 124.726983 \n",
       "L 279.493841 124.61235 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.036943 126.036529 \n",
       "L 278.036943 125.921204 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.256773 118.724809 \n",
       "L 286.256773 118.609384 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.001238 140.306645 \n",
       "L 262.001238 140.191134 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.552494 130.018408 \n",
       "L 273.552494 129.902525 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.151262 109.922702 \n",
       "L 296.151262 109.808668 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.081431 108.204235 \n",
       "L 298.081431 108.089736 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.976405 91.427212 \n",
       "L 316.976405 91.312302 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.876512 127.030287 \n",
       "L 276.876512 126.914787 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.003209 130.521994 \n",
       "L 273.003209 130.406815 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.879415 142.165715 \n",
       "L 259.879415 142.050019 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.72015 96.087986 \n",
       "L 311.72015 95.972112 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.527643 102.436325 \n",
       "L 304.527643 102.326196 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.226703 92.968462 \n",
       "L 315.226703 92.853321 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.094528 101.98138 \n",
       "L 305.094528 101.865777 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.42321 96.356352 \n",
       "L 311.42321 96.248001 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 342.131309 69.055762 \n",
       "L 342.131309 68.939955 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.416448 100.810114 \n",
       "L 306.416448 100.695175 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.626025 129.053281 \n",
       "L 274.626025 128.937606 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 334.883222 75.503825 \n",
       "L 334.883222 75.387985 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.578516 98.876394 \n",
       "L 308.578516 98.760748 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.458478 104.332692 \n",
       "L 302.458478 104.217098 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.592247 118.427926 \n",
       "L 286.592247 118.312097 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.403759 83.035494 \n",
       "L 326.403759 82.919947 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.017019 86.044108 \n",
       "L 323.017019 85.928447 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.450822 115.894392 \n",
       "L 289.450822 115.778799 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.189417 136.558393 \n",
       "L 266.189417 136.442716 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.69852 91.663625 \n",
       "L 316.69852 91.547936 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.15122 101.938997 \n",
       "L 305.15122 101.823413 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.591412 139.771372 \n",
       "L 262.591412 139.655635 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.301113 131.139096 \n",
       "L 272.301113 131.023806 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.522503 86.484041 \n",
       "L 322.522503 86.36931 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.195392 127.668898 \n",
       "L 276.195392 127.553071 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.818666 112.033494 \n",
       "L 293.818666 111.919464 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.907027 117.267162 \n",
       "L 287.907027 117.157076 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.09573 93.972299 \n",
       "L 314.09573 93.857015 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.750912 145.881802 \n",
       "L 255.750912 145.766851 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.725861 110.311046 \n",
       "L 295.725861 110.195587 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.15369 118.808427 \n",
       "L 286.15369 118.693264 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.631131 95.277677 \n",
       "L 312.631131 95.162061 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.90304 103.062052 \n",
       "L 303.90304 102.950416 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.225861 120.528365 \n",
       "L 284.225861 120.413569 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.224841 127.643015 \n",
       "L 276.224841 127.527464 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.45759 136.331963 \n",
       "L 266.45759 136.21612 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.625236 138.818505 \n",
       "L 263.625236 138.703182 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.631089 113.044291 \n",
       "L 292.631089 112.929468 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.261773 116.947696 \n",
       "L 288.261773 116.831875 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.935809 118.131301 \n",
       "L 286.935809 118.015741 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.49088 126.499133 \n",
       "L 277.49088 126.383455 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.884092 130.626971 \n",
       "L 272.884092 130.511374 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.284305 105.366332 \n",
       "L 301.284305 105.251177 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.621536 109.513513 \n",
       "L 296.621536 109.398934 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.747476 117.429806 \n",
       "L 287.747476 117.31401 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.580044 118.447271 \n",
       "L 286.580044 118.332187 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.75412 138.722863 \n",
       "L 263.75412 138.607215 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.420632 83.910774 \n",
       "L 325.420632 83.795156 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.612988 121.055483 \n",
       "L 283.612988 120.940143 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.73505 109.412346 \n",
       "L 296.73505 109.296841 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.700958 108.557207 \n",
       "L 297.700958 108.441831 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.446395 111.44119 \n",
       "L 294.446395 111.32554 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.979963 118.068206 \n",
       "L 286.979963 117.95288 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.782285 136.909795 \n",
       "L 265.782285 136.794434 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.929024 101.235843 \n",
       "L 305.929024 101.120526 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.697507 135.220753 \n",
       "L 267.697507 135.105118 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.748493 91.605477 \n",
       "L 316.748493 91.490709 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.976854 124.306813 \n",
       "L 279.976854 124.191396 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.734621 91.634387 \n",
       "L 316.734621 91.518573 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.859247 98.618826 \n",
       "L 308.859247 98.503529 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.214806 124.984527 \n",
       "L 279.214806 124.86908 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.764937 124.490949 \n",
       "L 279.764937 124.376162 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.97054 108.3125 \n",
       "L 297.97054 108.196596 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.528075 117.596857 \n",
       "L 287.528075 117.481099 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.337762 113.305626 \n",
       "L 292.337762 113.192101 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.90983 138.585308 \n",
       "L 263.90983 138.469511 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.249823 82.281421 \n",
       "L 327.249823 82.166029 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.867644 94.178215 \n",
       "L 313.867644 94.062397 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.207661 92.994558 \n",
       "L 315.207661 92.878854 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.629486 144.183934 \n",
       "L 257.629486 144.068117 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.808863 99.570135 \n",
       "L 307.808863 99.455197 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.763356 109.390823 \n",
       "L 296.763356 109.276116 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.185564 103.677753 \n",
       "L 303.185564 103.562005 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.469975 113.210124 \n",
       "L 292.469975 113.094646 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.732033 89.858088 \n",
       "L 318.732033 89.742377 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.327793 99.994867 \n",
       "L 307.327793 99.879458 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.307767 111.56739 \n",
       "L 294.307767 111.451877 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.364164 102.628465 \n",
       "L 304.364164 102.514676 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.110575 120.619098 \n",
       "L 284.110575 120.503688 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 334.203994 76.101529 \n",
       "L 334.203994 75.986154 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.89894 115.483442 \n",
       "L 289.89894 115.36758 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.067583 123.30734 \n",
       "L 281.067583 123.194123 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.676707 140.577757 \n",
       "L 261.676707 140.461887 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 252.612155 148.602994 \n",
       "L 252.612155 148.48722 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.443621 138.138021 \n",
       "L 264.443621 138.022329 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.632737 95.278488 \n",
       "L 312.632737 95.162748 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.531501 115.831046 \n",
       "L 289.531501 115.715223 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.812603 90.673902 \n",
       "L 317.812603 90.558518 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.313888 89.342441 \n",
       "L 319.313888 89.226695 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.833202 117.325613 \n",
       "L 287.833202 117.210099 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.628553 81.057951 \n",
       "L 328.628553 80.942152 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.938224 109.225981 \n",
       "L 296.938224 109.110267 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.298478 112.4734 \n",
       "L 293.298478 112.359055 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 248.227112 152.528625 \n",
       "L 248.227112 152.412925 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 254.475932 146.969674 \n",
       "L 254.475932 146.853939 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.29682 99.135724 \n",
       "L 308.29682 99.019924 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.29119 108.054904 \n",
       "L 298.29119 107.940437 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.25017 142.710209 \n",
       "L 259.25017 142.594942 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.17272 143.695497 \n",
       "L 258.17272 143.57961 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.866677 113.742096 \n",
       "L 291.866677 113.630481 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.675905 110.316055 \n",
       "L 295.675905 110.201628 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.876864 94.179968 \n",
       "L 313.876864 94.064711 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.797437 96.915933 \n",
       "L 310.797437 96.80185 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.638917 141.491886 \n",
       "L 260.638917 141.376185 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.513245 147.880476 \n",
       "L 253.513245 147.765354 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.361089 96.411873 \n",
       "L 311.361089 96.29612 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.788023 112.922418 \n",
       "L 292.788023 112.807635 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.989403 129.628787 \n",
       "L 273.989403 129.514156 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.297487 134.689535 \n",
       "L 268.297487 134.573881 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.657932 112.142672 \n",
       "L 293.657932 112.027634 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.289679 118.66004 \n",
       "L 286.289679 118.547219 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.780717 104.927956 \n",
       "L 301.780717 104.812307 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.750912 145.859166 \n",
       "L 255.750912 145.743999 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.714003 115.653143 \n",
       "L 289.714003 115.537471 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.678073 131.694609 \n",
       "L 271.678073 131.579313 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.740279 103.186681 \n",
       "L 303.740279 103.071365 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.946018 134.129317 \n",
       "L 268.946018 134.013438 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.762672 119.178992 \n",
       "L 285.762672 119.063567 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.195618 83.215901 \n",
       "L 326.195618 83.100257 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 340.398127 70.603692 \n",
       "L 340.398127 70.489189 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.099727 102.868776 \n",
       "L 304.099727 102.753685 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.855535 115.552626 \n",
       "L 289.855535 115.438205 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.831355 110.229546 \n",
       "L 295.831355 110.11477 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.088587 105.540726 \n",
       "L 301.088587 105.425112 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.520915 98.940755 \n",
       "L 308.520915 98.825803 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.041354 119.794005 \n",
       "L 285.041354 119.678281 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 336.641816 73.936542 \n",
       "L 336.641816 73.820904 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.644629 121.098007 \n",
       "L 283.644629 120.984907 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.230218 128.527456 \n",
       "L 275.230218 128.411917 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.418369 114.143902 \n",
       "L 291.418369 114.028352 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.374618 119.507522 \n",
       "L 285.374618 119.392487 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.367829 124.845826 \n",
       "L 279.367829 124.730051 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.498588 111.417653 \n",
       "L 294.498588 111.303945 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.036719 78.905615 \n",
       "L 331.036719 78.791281 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.994999 84.291456 \n",
       "L 324.994999 84.175992 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.123147 94.852123 \n",
       "L 313.123147 94.737006 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.138059 108.167156 \n",
       "L 298.138059 108.051406 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.840772 135.094478 \n",
       "L 267.840772 134.978694 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.161706 101.905451 \n",
       "L 305.161706 101.790943 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 254.894805 146.635019 \n",
       "L 254.894805 146.519353 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.11309 139.330895 \n",
       "L 263.11309 139.215814 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.192561 116.111864 \n",
       "L 289.192561 115.997976 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.55775 90.89268 \n",
       "L 317.55775 90.777521 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.259967 84.933537 \n",
       "L 324.259967 84.817954 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.586936 89.988417 \n",
       "L 318.586936 89.873116 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 228.051663 170.456412 \n",
       "L 228.051663 170.340554 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.09244 109.084214 \n",
       "L 297.09244 108.970997 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.107181 116.196365 \n",
       "L 289.107181 116.080613 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.221161 111.643514 \n",
       "L 294.221161 111.5279 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.823087 143.992245 \n",
       "L 257.823087 143.876579 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.138926 94.84077 \n",
       "L 313.138926 94.726483 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.478178 140.771754 \n",
       "L 261.478178 140.656231 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.123399 89.508511 \n",
       "L 319.123399 89.392878 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 337.392886 73.253002 \n",
       "L 337.392886 73.137446 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.092846 125.135339 \n",
       "L 279.092846 125.024142 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.53453 114.036406 \n",
       "L 291.53453 113.92068 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.912317 121.700321 \n",
       "L 282.912317 121.584935 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.534575 104.258657 \n",
       "L 302.534575 104.142861 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.266087 98.267385 \n",
       "L 309.266087 98.15269 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 335.730896 74.738309 \n",
       "L 335.730896 74.622952 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.489242 84.719763 \n",
       "L 324.489242 84.604932 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 333.021626 77.153624 \n",
       "L 333.021626 77.037798 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.174916 97.460888 \n",
       "L 310.174916 97.345182 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.180048 90.367482 \n",
       "L 318.180048 90.257418 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.189415 112.549347 \n",
       "L 293.189415 112.434826 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.417146 81.242468 \n",
       "L 328.417146 81.126816 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.391366 106.161632 \n",
       "L 300.391366 106.046314 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.879511 118.167809 \n",
       "L 286.879511 118.052397 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.107472 90.428718 \n",
       "L 318.107472 90.313445 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.830419 135.977735 \n",
       "L 266.830419 135.862518 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.763082 117.386103 \n",
       "L 287.763082 117.270237 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.70023 96.132058 \n",
       "L 311.70023 96.017283 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.861188 93.299954 \n",
       "L 314.861188 93.184846 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 339.041464 71.806394 \n",
       "L 339.041464 71.690593 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.920209 132.36177 \n",
       "L 270.920209 132.247208 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.002223 98.511568 \n",
       "L 309.002223 98.39635 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 332.554405 77.566618 \n",
       "L 332.554405 77.451211 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.060878 102.0067 \n",
       "L 305.060878 101.891034 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.561973 95.358419 \n",
       "L 312.561973 95.244077 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.397964 90.161091 \n",
       "L 318.397964 90.045902 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.016184 142.050412 \n",
       "L 260.016184 141.934619 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.055782 89.566308 \n",
       "L 319.055782 89.450916 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.797747 130.687692 \n",
       "L 272.797747 130.572636 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.628322 123.733147 \n",
       "L 280.628322 123.617548 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.286713 105.347892 \n",
       "L 301.286713 105.232797 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.264911 137.37602 \n",
       "L 265.264911 137.260459 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.556327 125.571855 \n",
       "L 278.556327 125.457616 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.56769 140.663305 \n",
       "L 261.56769 140.547508 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.046338 99.354112 \n",
       "L 308.046338 99.239247 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.07281 99.335285 \n",
       "L 308.07281 99.219621 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.794551 111.140869 \n",
       "L 294.794551 111.029248 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.939457 92.345322 \n",
       "L 315.939457 92.230669 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.908902 119.034546 \n",
       "L 285.908902 118.919551 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.465512 87.42434 \n",
       "L 321.465512 87.308467 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.64719 95.270279 \n",
       "L 312.64719 95.156683 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.349004 91.981619 \n",
       "L 316.349004 91.866702 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.572568 90.880299 \n",
       "L 317.572568 90.764676 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 333.664592 76.582212 \n",
       "L 333.664592 76.466754 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.192432 133.00971 \n",
       "L 270.192432 132.89394 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.687571 107.678286 \n",
       "L 298.687571 107.562656 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.428917 126.528025 \n",
       "L 277.428917 126.413819 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.091766 101.105248 \n",
       "L 306.091766 100.990936 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.305645 94.685487 \n",
       "L 313.305645 94.570642 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 355.176158 57.458325 \n",
       "L 355.176158 57.342528 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.757063 104.062501 \n",
       "L 302.757063 103.946763 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.54543 98.00916 \n",
       "L 309.54543 97.895342 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.196058 123.216549 \n",
       "L 281.196058 123.100662 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.152883 119.731559 \n",
       "L 285.152883 119.616484 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.4664 82.101186 \n",
       "L 327.4664 81.985847 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.384108 113.272275 \n",
       "L 292.384108 113.157035 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.592314 107.756154 \n",
       "L 298.592314 107.642528 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.415134 125.711467 \n",
       "L 278.415134 125.595707 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.289263 106.240632 \n",
       "L 300.289263 106.125454 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.098819 144.639456 \n",
       "L 257.098819 144.523583 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.348471 131.093156 \n",
       "L 272.348471 130.97758 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.832397 100.439369 \n",
       "L 306.832397 100.323667 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 332.326992 77.751094 \n",
       "L 332.326992 77.636466 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.476576 131.873758 \n",
       "L 271.476576 131.758144 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.260075 123.134211 \n",
       "L 281.260075 123.01898 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.711557 92.528518 \n",
       "L 315.711557 92.413243 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.45717 114.993674 \n",
       "L 290.45717 114.879757 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 251.482626 149.649068 \n",
       "L 251.482626 149.533247 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.460313 116.765948 \n",
       "L 288.460313 116.650386 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.211439 134.769255 \n",
       "L 268.211439 134.653797 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.537808 95.351504 \n",
       "L 312.537808 95.236738 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.640786 94.376482 \n",
       "L 313.640786 94.261231 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 242.246239 157.822301 \n",
       "L 242.246239 157.706781 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.155596 122.359226 \n",
       "L 282.155596 122.246373 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.207306 110.765178 \n",
       "L 295.207306 110.650898 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.171497 109.922017 \n",
       "L 296.171497 109.80711 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.169884 122.361999 \n",
       "L 282.169884 122.246854 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.574219 116.664268 \n",
       "L 288.574219 116.548613 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.562676 139.788892 \n",
       "L 262.562676 139.67317 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.463567 122.098527 \n",
       "L 282.463567 121.985275 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.301679 112.440588 \n",
       "L 293.301679 112.325508 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.624333 88.193404 \n",
       "L 320.624333 88.079158 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.174264 106.358191 \n",
       "L 300.174264 106.242413 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.362849 138.18327 \n",
       "L 264.362849 138.067571 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.279829 133.814975 \n",
       "L 269.279829 133.699441 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.333857 94.638351 \n",
       "L 313.333857 94.522895 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.594364 99.766764 \n",
       "L 307.594364 99.651219 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.609266 105.967625 \n",
       "L 300.609266 105.852624 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.575167 111.336586 \n",
       "L 294.575167 111.221029 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.923585 123.458913 \n",
       "L 280.923585 123.343439 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.42919 130.122353 \n",
       "L 273.42919 130.00689 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 227.320057 171.101715 \n",
       "L 227.320057 170.985827 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.382425 136.398764 \n",
       "L 266.382425 136.282979 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.836857 131.551348 \n",
       "L 271.836857 131.436086 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.295104 125.812124 \n",
       "L 278.295104 125.696377 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.664387 130.804867 \n",
       "L 272.664387 130.689287 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.159131 97.466487 \n",
       "L 310.159131 97.352336 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.038683 102.922018 \n",
       "L 304.038683 102.807435 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.67572 81.014719 \n",
       "L 328.67572 80.899201 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.099348 96.640669 \n",
       "L 311.099348 96.52565 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.522473 123.815226 \n",
       "L 280.522473 123.700962 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.416017 98.136977 \n",
       "L 309.416017 98.021141 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.527105 119.367867 \n",
       "L 285.527105 119.253482 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 353.074194 59.328293 \n",
       "L 353.074194 59.212584 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.855099 135.969508 \n",
       "L 266.855099 135.853834 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.222932 124.096772 \n",
       "L 280.222932 123.98118 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.424735 78.578804 \n",
       "L 331.424735 78.463333 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.26679 128.485667 \n",
       "L 275.26679 128.37007 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.791283 112.913358 \n",
       "L 292.791283 112.799692 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.828051 85.323609 \n",
       "L 323.828051 85.208918 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.675838 128.994427 \n",
       "L 274.675838 128.879008 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.208012 108.122614 \n",
       "L 298.208012 108.007025 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.025022 112.674799 \n",
       "L 293.025022 112.559619 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.97541 134.950577 \n",
       "L 267.97541 134.835296 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.651905 103.247152 \n",
       "L 303.651905 103.132111 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.522775 94.488117 \n",
       "L 313.522775 94.372614 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.670239 122.808515 \n",
       "L 281.670239 122.693515 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.778679 117.379507 \n",
       "L 287.778679 117.266552 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.287583 126.714259 \n",
       "L 277.287583 126.598779 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.360345 135.542009 \n",
       "L 267.360345 135.42619 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.957345 105.669876 \n",
       "L 300.957345 105.555423 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.894769 85.266089 \n",
       "L 323.894769 85.151216 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.044064 110.034458 \n",
       "L 296.044064 109.919242 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.585674 85.533819 \n",
       "L 323.585674 85.418711 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.491249 125.628145 \n",
       "L 278.491249 125.512552 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.667183 113.918573 \n",
       "L 291.667183 113.802821 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.73999 112.078754 \n",
       "L 293.73999 111.963346 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.155714 136.561425 \n",
       "L 266.155714 136.446337 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.552478 106.018793 \n",
       "L 300.552478 105.904618 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.932966 100.354778 \n",
       "L 306.932966 100.240783 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.843744 103.978087 \n",
       "L 302.843744 103.862523 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.386805 104.399839 \n",
       "L 302.386805 104.284112 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.563686 128.232348 \n",
       "L 275.563686 128.11661 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 351.19818 60.989866 \n",
       "L 351.19818 60.874286 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.843459 141.312601 \n",
       "L 260.843459 141.19843 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.586183 119.32546 \n",
       "L 285.586183 119.209925 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.948514 126.110188 \n",
       "L 277.948514 125.994296 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.830988 130.664604 \n",
       "L 272.830988 130.548987 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.287665 131.995279 \n",
       "L 271.287665 131.880208 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.848813 123.518537 \n",
       "L 280.848813 123.403237 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.581994 90.902751 \n",
       "L 317.581994 90.789378 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.581709 107.76076 \n",
       "L 298.581709 107.645026 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.323057 99.097577 \n",
       "L 308.323057 98.982432 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.717051 110.298263 \n",
       "L 295.717051 110.189227 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.096039 117.975663 \n",
       "L 287.096039 117.861517 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.711588 103.215517 \n",
       "L 303.711588 103.099759 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 345.864187 65.735806 \n",
       "L 345.864187 65.620071 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.064762 113.558349 \n",
       "L 292.064762 113.442578 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.675245 125.467091 \n",
       "L 278.675245 125.351476 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.823844 123.534849 \n",
       "L 280.823844 123.420333 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.568805 137.995893 \n",
       "L 264.568805 137.88013 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.737931 128.046002 \n",
       "L 275.737931 127.931269 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 324.286477 84.915431 \n",
       "L 324.286477 84.799955 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.466301 110.542806 \n",
       "L 295.466301 110.429265 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.891493 105.725398 \n",
       "L 300.891493 105.609608 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 254.322049 147.079668 \n",
       "L 254.322049 146.963937 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.946104 79.904627 \n",
       "L 329.946104 79.788759 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.580028 101.550898 \n",
       "L 305.580028 101.438649 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.169159 128.579895 \n",
       "L 275.169159 128.465612 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.951509 95.898868 \n",
       "L 311.951509 95.786773 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.950597 116.331092 \n",
       "L 288.950597 116.215328 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.581762 128.213859 \n",
       "L 275.581762 128.099787 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.834434 144.011292 \n",
       "L 257.834434 143.895609 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.203611 101.875479 \n",
       "L 305.203611 101.759816 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.081889 104.659709 \n",
       "L 302.081889 104.544262 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.007036 86.058351 \n",
       "L 323.007036 85.94319 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.272092 89.377501 \n",
       "L 319.272092 89.261675 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.036877 99.367761 \n",
       "L 308.036877 99.251943 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.151543 137.486831 \n",
       "L 265.151543 137.371793 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 244.923391 155.44691 \n",
       "L 244.923391 155.331143 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.686031 89.012098 \n",
       "L 319.686031 88.896266 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.833999 109.3217 \n",
       "L 296.833999 109.205975 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 340.661755 70.3589 \n",
       "L 340.661755 70.243264 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.87553 108.397997 \n",
       "L 297.87553 108.284268 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 351.320873 60.895974 \n",
       "L 351.320873 60.780215 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.325951 90.213876 \n",
       "L 318.325951 90.099003 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.249579 129.392135 \n",
       "L 274.249579 129.276981 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.997581 110.075628 \n",
       "L 295.997581 109.959867 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.598283 132.646568 \n",
       "L 270.598283 132.531275 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.647186 104.154421 \n",
       "L 302.647186 104.039394 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.274605 82.263609 \n",
       "L 327.274605 82.147837 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.943425 139.481521 \n",
       "L 262.943425 139.366926 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.159414 110.808658 \n",
       "L 295.159414 110.692979 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 242.872246 157.246469 \n",
       "L 242.872246 157.130818 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.490203 133.626598 \n",
       "L 269.490203 133.510727 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.487118 122.06888 \n",
       "L 282.487118 121.953739 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.999022 97.62565 \n",
       "L 309.999022 97.510006 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.309215 106.231839 \n",
       "L 300.309215 106.117279 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.241249 124.951501 \n",
       "L 279.241249 124.836343 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.900798 89.700442 \n",
       "L 318.900798 89.584705 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.997257 97.628447 \n",
       "L 309.997257 97.512769 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.240605 90.30451 \n",
       "L 318.240605 90.189084 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.311544 87.569602 \n",
       "L 321.311544 87.454268 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.975265 85.193733 \n",
       "L 323.975265 85.077996 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.941929 117.280471 \n",
       "L 287.941929 117.165478 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.409431 102.591411 \n",
       "L 304.409431 102.475548 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.117035 126.840427 \n",
       "L 277.117035 126.725545 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.361909 97.302753 \n",
       "L 310.361909 97.187556 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.986033 91.399528 \n",
       "L 316.986033 91.284158 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 339.361466 71.520636 \n",
       "L 339.361466 71.404819 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.766575 118.273462 \n",
       "L 286.766575 118.15809 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.09755 102.843159 \n",
       "L 304.09755 102.7296 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.1866 115.233959 \n",
       "L 290.1866 115.118094 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.861852 128.848794 \n",
       "L 274.861852 128.733483 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 336.073358 74.441438 \n",
       "L 336.073358 74.326036 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.311846 135.578549 \n",
       "L 267.311846 135.462961 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.920098 106.578441 \n",
       "L 299.920098 106.462756 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.210334 132.12769 \n",
       "L 271.210334 132.012463 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.032763 105.592106 \n",
       "L 301.032763 105.477075 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.638753 120.170222 \n",
       "L 284.638753 120.05441 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.03772 102.040401 \n",
       "L 305.03772 101.925174 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 224.560561 173.573097 \n",
       "L 224.560561 173.45718 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.495174 98.062164 \n",
       "L 309.495174 97.946534 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.648532 94.372525 \n",
       "L 313.648532 94.256818 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 240.173391 159.634602 \n",
       "L 240.173391 159.519118 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.570971 94.442797 \n",
       "L 313.570971 94.328148 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 239.916605 159.925461 \n",
       "L 239.916605 159.809666 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.856567 109.305237 \n",
       "L 296.856567 109.190033 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.347212 109.748585 \n",
       "L 296.347212 109.633318 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.448516 110.546084 \n",
       "L 295.448516 110.430714 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 330.860386 79.073851 \n",
       "L 330.860386 78.958105 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.072063 118.002895 \n",
       "L 287.072063 117.887376 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.166999 148.14433 \n",
       "L 253.166999 148.02843 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.006079 97.60497 \n",
       "L 310.006079 97.491214 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.157164 119.729467 \n",
       "L 285.157164 119.61429 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.240317 100.055803 \n",
       "L 307.240317 99.940815 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.513186 115.850055 \n",
       "L 289.513186 115.734587 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.892307 98.602955 \n",
       "L 308.892307 98.487674 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.985888 120.762256 \n",
       "L 283.985888 120.648524 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.008483 126.996038 \n",
       "L 277.008483 126.881444 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.748437 90.732553 \n",
       "L 317.748437 90.616711 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.427654 85.685654 \n",
       "L 323.427654 85.57003 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.765149 100.48033 \n",
       "L 306.765149 100.365299 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.185035 117.007854 \n",
       "L 288.185035 116.893895 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.686675 120.122505 \n",
       "L 284.686675 120.006924 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.4976 102.514598 \n",
       "L 304.4976 102.3991 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.92055 90.561971 \n",
       "L 317.92055 90.446581 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.469179 115.868537 \n",
       "L 289.469179 115.753149 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.773638 83.598684 \n",
       "L 325.773638 83.48279 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.088925 130.411416 \n",
       "L 273.088925 130.296295 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.766342 120.938138 \n",
       "L 283.766342 120.826745 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.146264 124.163233 \n",
       "L 280.146264 124.047654 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.258135 113.355051 \n",
       "L 292.258135 113.239592 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.18598 99.241808 \n",
       "L 308.18598 99.126105 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.549597 121.1293 \n",
       "L 283.549597 121.014197 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.594891 121.137258 \n",
       "L 283.594891 121.023947 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.002359 125.155547 \n",
       "L 279.002359 125.040042 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.059282 103.779819 \n",
       "L 303.059282 103.664364 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.622285 137.985529 \n",
       "L 264.622285 137.869751 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.367104 120.449042 \n",
       "L 284.367104 120.335535 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.958863 118.998526 \n",
       "L 285.958863 118.883108 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.848794 129.740466 \n",
       "L 273.848794 129.626388 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.672478 85.450546 \n",
       "L 323.672478 85.335789 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.453266 134.567823 \n",
       "L 268.453266 134.452883 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.837479 124.459857 \n",
       "L 279.837479 124.344694 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.0593 86.904674 \n",
       "L 322.0593 86.789329 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.370183 133.734303 \n",
       "L 269.370183 133.61879 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.533911 120.252606 \n",
       "L 284.533911 120.137149 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.243262 129.409239 \n",
       "L 274.243262 129.293609 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.498899 83.830041 \n",
       "L 325.498899 83.714773 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.805904 98.68124 \n",
       "L 308.805904 98.566043 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.988398 117.20979 \n",
       "L 287.988398 117.09449 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.147917 117.93126 \n",
       "L 287.147917 117.815494 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.870551 121.739148 \n",
       "L 282.870551 121.623591 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.599077 127.317822 \n",
       "L 276.599077 127.202771 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.369837 92.837716 \n",
       "L 315.369837 92.722805 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.015554 119.835151 \n",
       "L 285.015554 119.720736 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.794372 144.926827 \n",
       "L 256.794372 144.810975 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.691516 98.774606 \n",
       "L 308.691516 98.658761 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.580307 108.660038 \n",
       "L 297.580307 108.54593 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.514693 122.926371 \n",
       "L 281.514693 122.811243 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.413327 129.252196 \n",
       "L 274.413327 129.136571 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.136171 133.945675 \n",
       "L 269.136171 133.831011 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 353.619577 58.846259 \n",
       "L 353.619577 58.730403 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.520098 130.044208 \n",
       "L 273.520098 129.928535 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 343.811647 67.561996 \n",
       "L 343.811647 67.446234 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 350.087662 61.979363 \n",
       "L 350.087662 61.863602 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.100304 92.214483 \n",
       "L 316.100304 92.099066 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.819589 87.112701 \n",
       "L 321.819589 86.997678 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.557812 99.795026 \n",
       "L 307.557812 99.679503 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.865766 111.955034 \n",
       "L 293.865766 111.840967 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.5997 91.752631 \n",
       "L 316.5997 91.636804 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.062837 119.75155 \n",
       "L 285.062837 119.636646 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.197836 136.548321 \n",
       "L 266.197836 136.432586 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.66007 98.812469 \n",
       "L 308.66007 98.698115 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.357938 80.407137 \n",
       "L 329.357938 80.29184 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.842155 104.868106 \n",
       "L 301.842155 104.752382 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.889747 106.621556 \n",
       "L 299.889747 106.50775 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 334.660833 75.70043 \n",
       "L 334.660833 75.585215 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.217517 143.645403 \n",
       "L 258.217517 143.529681 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 346.240601 65.406901 \n",
       "L 346.240601 65.292015 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.58131 121.099079 \n",
       "L 283.58131 120.983425 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.291408 101.7903 \n",
       "L 305.291408 101.675537 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.603156 123.742766 \n",
       "L 280.603156 123.627693 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.156543 125.048239 \n",
       "L 279.156543 124.932537 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 335.560564 74.893298 \n",
       "L 335.560564 74.777586 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.399766 131.907657 \n",
       "L 271.399766 131.79273 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.620204 106.859885 \n",
       "L 299.620204 106.744053 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.69158 133.459992 \n",
       "L 269.69158 133.344553 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.790827 136.889104 \n",
       "L 265.790827 136.773277 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 335.472519 74.974611 \n",
       "L 335.472519 74.858756 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.040912 108.252262 \n",
       "L 298.040912 108.138932 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 333.479661 76.760417 \n",
       "L 333.479661 76.644874 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.658219 98.799819 \n",
       "L 308.658219 98.685093 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.019614 132.232408 \n",
       "L 271.019614 132.119373 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.074797 113.564235 \n",
       "L 292.074797 113.448382 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.463876 141.777563 \n",
       "L 260.463876 141.662842 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.988857 110.099129 \n",
       "L 295.988857 109.98362 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.877246 115.508643 \n",
       "L 289.877246 115.392795 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.420735 131.923092 \n",
       "L 271.420735 131.807158 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 249.308724 151.567846 \n",
       "L 249.308724 151.452023 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.29141 114.243892 \n",
       "L 291.29141 114.127981 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.386394 106.164918 \n",
       "L 300.386394 106.049197 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.526996 96.264592 \n",
       "L 311.526996 96.149482 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 248.874828 151.974469 \n",
       "L 248.874828 151.858733 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.575413 113.996712 \n",
       "L 291.575413 113.882228 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.856489 108.402484 \n",
       "L 297.856489 108.287057 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 337.940015 72.783153 \n",
       "L 337.940015 72.667616 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.890111 88.832069 \n",
       "L 319.890111 88.717025 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.848899 110.190823 \n",
       "L 295.848899 110.07563 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.481846 96.297507 \n",
       "L 311.481846 96.182458 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 336.200451 74.327516 \n",
       "L 336.200451 74.211725 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.998816 93.175233 \n",
       "L 314.998816 93.059419 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.921323 91.453323 \n",
       "L 316.921323 91.338326 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.005687 142.045101 \n",
       "L 260.005687 141.929529 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.693917 103.227948 \n",
       "L 303.693917 103.11297 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.631196 126.388274 \n",
       "L 277.631196 126.272483 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.741971 108.530298 \n",
       "L 297.741971 108.416122 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.889904 102.149957 \n",
       "L 304.889904 102.034819 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.686597 140.544499 \n",
       "L 261.686597 140.429398 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.413062 99.92448 \n",
       "L 307.413062 99.808698 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.634368 113.060859 \n",
       "L 292.634368 112.944942 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.407745 133.691829 \n",
       "L 269.407745 133.576384 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.157509 85.915915 \n",
       "L 323.157509 85.800378 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.833501 136.881577 \n",
       "L 265.833501 136.766555 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.034938 120.701444 \n",
       "L 284.034938 120.586335 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.076165 92.214959 \n",
       "L 316.076165 92.099424 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.617165 133.514102 \n",
       "L 269.617165 133.398457 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.650942 129.025435 \n",
       "L 274.650942 128.909855 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.112174 112.638503 \n",
       "L 293.112174 112.522809 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.862695 80.844297 \n",
       "L 328.862695 80.728917 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.540284 110.471773 \n",
       "L 295.540284 110.35744 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.234322 106.299589 \n",
       "L 300.234322 106.184091 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.376355 98.168285 \n",
       "L 309.376355 98.05355 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.772484 138.682624 \n",
       "L 263.772484 138.568221 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.643993 101.487476 \n",
       "L 305.643993 101.372237 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.933036 87.901922 \n",
       "L 320.933036 87.786119 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.128398 130.399258 \n",
       "L 273.128398 130.28365 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.588435 97.992024 \n",
       "L 309.588435 97.877437 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.373926 103.510435 \n",
       "L 303.373926 103.395358 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.359601 108.853164 \n",
       "L 297.359601 108.738764 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.643411 123.716587 \n",
       "L 280.643411 123.601304 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.353962 81.304893 \n",
       "L 328.353962 81.189444 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.018348 125.182639 \n",
       "L 279.018348 125.067018 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.43528 122.094844 \n",
       "L 282.43528 121.981023 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 246.716813 153.876828 \n",
       "L 246.716813 153.760977 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.703965 119.216504 \n",
       "L 285.703965 119.101727 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.315732 132.039752 \n",
       "L 271.315732 131.92444 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.141075 102.822829 \n",
       "L 304.141075 102.706919 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.469129 89.193013 \n",
       "L 319.469129 89.078403 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.649124 118.381786 \n",
       "L 286.649124 118.265948 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.39752 122.150434 \n",
       "L 282.39752 122.03453 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 336.647272 73.925063 \n",
       "L 336.647272 73.811439 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.843083 113.791657 \n",
       "L 291.843083 113.677019 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.501748 119.39459 \n",
       "L 285.501748 119.278975 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.199731 132.996696 \n",
       "L 270.199731 132.881084 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.605028 108.630356 \n",
       "L 297.605028 108.516236 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.025476 97.578432 \n",
       "L 310.025476 97.463248 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.443621 138.096723 \n",
       "L 264.443621 137.980983 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 342.905622 68.359282 \n",
       "L 342.905622 68.243636 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.984923 83.413655 \n",
       "L 325.984923 83.297786 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 349.48161 62.512687 \n",
       "L 349.48161 62.397482 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.66078 121.939396 \n",
       "L 282.66078 121.825357 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.170523 133.029916 \n",
       "L 270.170523 132.91473 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.007687 94.935198 \n",
       "L 313.007687 94.820068 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.836662 138.697715 \n",
       "L 263.836662 138.582136 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.094217 126.884049 \n",
       "L 277.094217 126.768361 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.047651 142.048483 \n",
       "L 260.047651 141.932767 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.497488 131.885143 \n",
       "L 271.497488 131.770979 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.192812 107.227721 \n",
       "L 299.192812 107.112181 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.660581 113.028624 \n",
       "L 292.660581 112.913638 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.305376 84.023493 \n",
       "L 325.305376 83.907935 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.912131 135.04804 \n",
       "L 267.912131 134.932238 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.703965 119.216103 \n",
       "L 285.703965 119.100505 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.92358 144.840829 \n",
       "L 256.92358 144.725175 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 330.488221 79.408137 \n",
       "L 330.488221 79.292322 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.267363 78.716416 \n",
       "L 331.267363 78.600659 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.153421 110.812286 \n",
       "L 295.153421 110.696983 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.654879 114.817266 \n",
       "L 290.654879 114.701649 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.909244 82.588935 \n",
       "L 326.909244 82.473058 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.779414 115.580349 \n",
       "L 289.779414 115.464861 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.314561 113.342633 \n",
       "L 292.314561 113.226724 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.295048 117.821309 \n",
       "L 287.295048 117.705868 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.483548 131.882499 \n",
       "L 271.483548 131.766942 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 241.706948 158.340939 \n",
       "L 241.706948 158.225045 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.670786 82.801323 \n",
       "L 326.670786 82.685575 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.936839 111.009298 \n",
       "L 294.936839 110.893557 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.578803 112.213742 \n",
       "L 293.578803 112.098459 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.704962 103.223408 \n",
       "L 303.704962 103.108826 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.214965 111.644824 \n",
       "L 294.214965 111.529893 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.740775 87.181286 \n",
       "L 321.740775 87.065824 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.808852 123.563905 \n",
       "L 280.808852 123.448534 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 333.300418 76.907682 \n",
       "L 333.300418 76.79181 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.877954 90.64105 \n",
       "L 317.877954 90.526902 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.598784 117.536205 \n",
       "L 287.598784 117.420535 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.000631 81.642298 \n",
       "L 328.000631 81.527637 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.914697 141.295071 \n",
       "L 260.914697 141.179285 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 353.223716 59.195387 \n",
       "L 353.223716 59.079487 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.533502 82.031683 \n",
       "L 327.533502 81.916097 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.833631 112.86836 \n",
       "L 292.833631 112.754077 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.287173 132.927783 \n",
       "L 270.287173 132.812028 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.47842 114.972379 \n",
       "L 290.47842 114.857173 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.264742 133.830399 \n",
       "L 269.264742 133.715009 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.483131 116.733874 \n",
       "L 288.483131 116.621507 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.202318 105.440598 \n",
       "L 301.202318 105.324838 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.590768 130.868387 \n",
       "L 272.590768 130.752993 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.318441 118.668672 \n",
       "L 286.318441 118.553079 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.384875 143.49997 \n",
       "L 258.384875 143.384136 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.836662 138.670578 \n",
       "L 263.836662 138.555118 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.048029 113.56666 \n",
       "L 292.048029 113.450917 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.975404 86.976681 \n",
       "L 321.975404 86.861375 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.709936 118.315698 \n",
       "L 286.709936 118.20101 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.668694 127.244083 \n",
       "L 276.668694 127.129169 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.700724 134.342467 \n",
       "L 268.700724 134.227114 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.524686 109.602828 \n",
       "L 296.524686 109.48693 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.153507 114.367958 \n",
       "L 291.153507 114.253653 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.918005 83.472577 \n",
       "L 325.918005 83.356878 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.580307 108.67008 \n",
       "L 297.580307 108.555073 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 349.933553 62.118359 \n",
       "L 349.933553 62.002499 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.842028 136.907534 \n",
       "L 265.842028 136.791742 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.122133 115.290485 \n",
       "L 290.122133 115.174635 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.288514 85.802478 \n",
       "L 323.288514 85.687049 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.616158 107.735008 \n",
       "L 298.616158 107.619238 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.069542 121.564243 \n",
       "L 283.069542 121.449697 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.71314 129.028661 \n",
       "L 274.71314 128.914522 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.148113 130.395548 \n",
       "L 273.148113 130.279941 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.014581 101.162884 \n",
       "L 306.014581 101.047416 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.274742 113.367456 \n",
       "L 292.274742 113.252006 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.167845 117.898412 \n",
       "L 287.167845 117.784406 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.4493 117.652594 \n",
       "L 287.4493 117.537168 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.327793 99.991357 \n",
       "L 307.327793 99.878198 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.824819 85.325494 \n",
       "L 323.824819 85.210006 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.032757 119.812162 \n",
       "L 285.032757 119.696855 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.815284 122.671268 \n",
       "L 281.815284 122.558651 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.714856 86.318322 \n",
       "L 322.714856 86.202456 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.823872 106.653989 \n",
       "L 299.823872 106.538857 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.06719 102.015054 \n",
       "L 305.06719 101.899429 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.355825 109.761622 \n",
       "L 296.355825 109.647261 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.562154 113.124021 \n",
       "L 292.562154 113.00832 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.335126 90.206698 \n",
       "L 318.335126 90.090927 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.322745 84.015756 \n",
       "L 325.322745 83.900603 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.928092 138.569303 \n",
       "L 263.928092 138.453964 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.375835 89.278059 \n",
       "L 319.375835 89.165341 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.858424 99.513684 \n",
       "L 307.858424 99.399162 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 332.454 77.651305 \n",
       "L 332.454 77.535952 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.63799 117.50549 \n",
       "L 287.63799 117.390162 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.570019 127.344072 \n",
       "L 276.570019 127.228251 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.403338 132.832471 \n",
       "L 270.403338 132.716985 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.243363 101.848179 \n",
       "L 305.243363 101.732542 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.35778 131.933428 \n",
       "L 271.35778 131.817775 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.26195 89.380901 \n",
       "L 319.26195 89.265947 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.901296 95.029914 \n",
       "L 312.901296 94.914444 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.084828 113.571298 \n",
       "L 292.084828 113.456385 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.486458 142.524527 \n",
       "L 259.486458 142.408764 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.926422 117.24142 \n",
       "L 287.926422 117.125804 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.910531 114.587846 \n",
       "L 290.910531 114.472083 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.253814 101.81225 \n",
       "L 305.253814 101.698283 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.763303 138.76153 \n",
       "L 263.763303 138.645946 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.610865 130.923229 \n",
       "L 272.610865 130.811261 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.558541 94.450007 \n",
       "L 313.558541 94.334376 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.279164 108.927782 \n",
       "L 297.279164 108.811836 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.806962 118.244477 \n",
       "L 286.806962 118.129258 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.432025 85.678997 \n",
       "L 323.432025 85.563233 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.621855 102.398007 \n",
       "L 304.621855 102.282483 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.943302 101.228449 \n",
       "L 305.943302 101.113314 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.4647 109.660918 \n",
       "L 296.4647 109.545444 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.976068 110.967724 \n",
       "L 294.976068 110.852287 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.565806 136.231096 \n",
       "L 266.565806 136.115622 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.504466 117.62896 \n",
       "L 287.504466 117.515578 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.557911 145.117221 \n",
       "L 256.557911 145.001395 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.090193 93.096768 \n",
       "L 315.090193 92.981169 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.016184 142.066676 \n",
       "L 260.016184 141.951193 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.016038 118.040356 \n",
       "L 287.016038 117.9247 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.879316 102.188866 \n",
       "L 304.879316 102.074219 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.058518 118.904812 \n",
       "L 286.058518 118.789203 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.146594 114.385537 \n",
       "L 291.146594 114.270464 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.150815 128.623967 \n",
       "L 275.150815 128.510334 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.265604 116.927331 \n",
       "L 288.265604 116.823144 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.7732 96.047761 \n",
       "L 311.7732 95.932422 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.953154 95.89603 \n",
       "L 311.953154 95.780527 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.538435 111.34851 \n",
       "L 294.538435 111.232837 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.513527 116.741365 \n",
       "L 288.513527 116.62624 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.547708 103.354757 \n",
       "L 303.547708 103.2392 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.978726 104.755092 \n",
       "L 301.978726 104.639282 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.959571 119.869476 \n",
       "L 284.959571 119.753896 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.01684 109.157701 \n",
       "L 297.01684 109.042142 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.968731 103.87008 \n",
       "L 302.968731 103.754523 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.887212 129.711576 \n",
       "L 273.887212 129.595818 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 238.050061 161.586898 \n",
       "L 238.050061 161.470987 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.673562 85.461219 \n",
       "L 323.673562 85.34568 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.473008 137.197939 \n",
       "L 265.473008 137.082155 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.71905 99.649448 \n",
       "L 307.71905 99.533803 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 243.294658 156.896751 \n",
       "L 243.294658 156.780907 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.332888 126.65846 \n",
       "L 277.332888 126.546453 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.884823 125.267659 \n",
       "L 278.884823 125.151925 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.590477 80.191908 \n",
       "L 329.590477 80.077871 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 336.118567 74.400565 \n",
       "L 336.118567 74.284704 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.572147 89.114984 \n",
       "L 319.572147 88.99932 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.800113 109.353398 \n",
       "L 296.800113 109.237622 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 330.193587 79.655197 \n",
       "L 330.193587 79.539946 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.021405 100.274872 \n",
       "L 307.021405 100.159683 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.14821 127.715298 \n",
       "L 276.14821 127.599598 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.33285 109.763891 \n",
       "L 296.33285 109.649032 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 337.741339 72.958145 \n",
       "L 337.741339 72.842649 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.958682 127.876395 \n",
       "L 275.958682 127.760525 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.580979 131.781906 \n",
       "L 271.580979 131.666277 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.547708 103.370489 \n",
       "L 303.547708 103.254974 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.046762 104.687306 \n",
       "L 302.046762 104.571886 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.204067 108.984975 \n",
       "L 297.204067 108.869662 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.213732 130.312303 \n",
       "L 273.213732 130.196421 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.600264 107.753535 \n",
       "L 298.600264 107.637909 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.785428 93.362546 \n",
       "L 314.785428 93.246686 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.233417 94.744905 \n",
       "L 313.233417 94.630042 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.288872 112.478311 \n",
       "L 293.288872 112.363321 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.58829 101.53741 \n",
       "L 305.58829 101.421686 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.847963 81.752316 \n",
       "L 327.847963 81.637094 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.034719 112.705167 \n",
       "L 293.034719 112.590857 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.959756 110.158658 \n",
       "L 295.959756 110.049406 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 344.504931 66.948434 \n",
       "L 344.504931 66.833372 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.56013 131.800723 \n",
       "L 271.56013 131.68525 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.594847 129.087146 \n",
       "L 274.594847 128.973359 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.821191 96.001173 \n",
       "L 311.821191 95.885392 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.806092 112.00309 \n",
       "L 293.806092 111.891077 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.568805 138.029283 \n",
       "L 264.568805 137.913663 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 239.417759 160.361104 \n",
       "L 239.417759 160.24537 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.217954 81.429261 \n",
       "L 328.217954 81.314844 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.353581 116.858066 \n",
       "L 288.353581 116.742519 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.099792 81.530517 \n",
       "L 328.099792 81.414738 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.091222 129.545324 \n",
       "L 274.091222 129.429863 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.836347 100.435177 \n",
       "L 306.836347 100.319737 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.80619 107.568877 \n",
       "L 298.80619 107.453913 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.752572 142.277878 \n",
       "L 259.752572 142.162115 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.513377 126.497169 \n",
       "L 277.513377 126.381701 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.891749 95.05082 \n",
       "L 312.891749 94.935296 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.777936 120.005545 \n",
       "L 284.777936 119.890551 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.563357 98.016973 \n",
       "L 309.563357 97.901417 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.917331 85.250059 \n",
       "L 323.917331 85.134214 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.543502 139.805392 \n",
       "L 262.543502 139.689738 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.29939 123.892632 \n",
       "L 280.29939 123.780453 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.729276 112.959952 \n",
       "L 292.729276 112.844398 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.423222 98.136998 \n",
       "L 309.423222 98.021863 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.492239 97.176809 \n",
       "L 310.492239 97.06121 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.659827 83.690659 \n",
       "L 325.659827 83.576591 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.875485 118.149702 \n",
       "L 286.875485 118.041673 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.635393 96.168129 \n",
       "L 311.635393 96.052763 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.69428 121.003717 \n",
       "L 283.69428 120.890719 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.640637 106.831243 \n",
       "L 299.640637 106.715736 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.022899 96.70876 \n",
       "L 311.022899 96.592927 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.9073 110.14521 \n",
       "L 295.9073 110.02964 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.28454 144.526165 \n",
       "L 257.28454 144.410889 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.545715 113.127936 \n",
       "L 292.545715 113.012802 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.244494 80.51171 \n",
       "L 329.244494 80.396107 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.559796 102.478552 \n",
       "L 304.559796 102.36413 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.261088 110.721977 \n",
       "L 295.261088 110.606524 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.232528 100.084356 \n",
       "L 307.232528 99.968977 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.54543 98.022044 \n",
       "L 309.54543 97.906448 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.31708 137.328641 \n",
       "L 265.31708 137.212756 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.277344 118.705538 \n",
       "L 286.277344 118.590973 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.1428 100.172423 \n",
       "L 307.1428 100.059256 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.756641 136.990103 \n",
       "L 265.756641 136.874386 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 250.922106 150.152136 \n",
       "L 250.922106 150.036508 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.781852 116.479094 \n",
       "L 288.781852 116.36359 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.616867 122.879726 \n",
       "L 281.616867 122.765255 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.711333 104.103975 \n",
       "L 302.711333 103.988751 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.961795 135.87749 \n",
       "L 266.961795 135.761837 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.467559 109.677386 \n",
       "L 296.467559 109.561749 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.22502 93.862479 \n",
       "L 314.22502 93.746652 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.144384 112.603998 \n",
       "L 293.144384 112.491023 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.693877 97.854558 \n",
       "L 309.693877 97.742175 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.598656 82.866085 \n",
       "L 326.598656 82.750759 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.461032 134.527011 \n",
       "L 268.461032 134.411455 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.077248 117.113148 \n",
       "L 288.077248 116.997293 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.203282 88.530251 \n",
       "L 320.203282 88.416451 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.990657 139.482994 \n",
       "L 262.990657 139.368036 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.36228 101.743656 \n",
       "L 305.36228 101.627915 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.461691 130.111287 \n",
       "L 273.461691 129.995554 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.682026 111.233264 \n",
       "L 294.682026 111.117981 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.058279 95.772835 \n",
       "L 312.058279 95.658664 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.026071 106.493084 \n",
       "L 300.026071 106.377416 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.947192 80.775309 \n",
       "L 328.947192 80.659475 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.223011 87.645357 \n",
       "L 321.223011 87.530683 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.751569 99.618446 \n",
       "L 307.751569 99.503089 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.048029 113.574946 \n",
       "L 292.048029 113.459115 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.745607 112.973202 \n",
       "L 292.745607 112.858244 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.666161 119.262297 \n",
       "L 285.666161 119.149182 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.318564 98.237366 \n",
       "L 309.318564 98.123361 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.069795 91.333204 \n",
       "L 317.069795 91.217825 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.163575 125.930194 \n",
       "L 278.163575 125.814399 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 338.673393 72.132701 \n",
       "L 338.673393 72.016857 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.410612 98.13841 \n",
       "L 309.410612 98.0232 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.687242 101.443031 \n",
       "L 305.687242 101.327683 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.265658 120.496635 \n",
       "L 284.265658 120.381399 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.314609 115.999489 \n",
       "L 289.314609 115.884741 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.619652 116.63046 \n",
       "L 288.619652 116.515289 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.006592 111.843594 \n",
       "L 294.006592 111.728612 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.180479 80.565162 \n",
       "L 329.180479 80.449428 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.852632 90.642939 \n",
       "L 317.852632 90.52711 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.016573 108.287958 \n",
       "L 298.016573 108.172769 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.734618 89.842005 \n",
       "L 318.734618 89.727763 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.997849 100.287454 \n",
       "L 306.997849 100.171686 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.442686 99.008787 \n",
       "L 308.442686 98.893203 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.544888 101.575473 \n",
       "L 305.544888 101.460062 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.406757 131.920584 \n",
       "L 271.406757 131.805453 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.145365 144.612029 \n",
       "L 257.145365 144.496145 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.935412 109.220143 \n",
       "L 296.935412 109.105182 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.742484 103.186575 \n",
       "L 303.742484 103.070947 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.393119 109.72032 \n",
       "L 296.393119 109.604431 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.723643 144.973811 \n",
       "L 256.723643 144.858047 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.884188 141.279045 \n",
       "L 260.884188 141.163409 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.127976 117.945738 \n",
       "L 287.127976 117.830636 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.043306 96.692148 \n",
       "L 311.043306 96.576277 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.100865 90.411179 \n",
       "L 318.100865 90.296269 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.868786 103.936382 \n",
       "L 302.868786 103.821163 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.210302 103.651375 \n",
       "L 303.210302 103.535856 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.530632 106.921217 \n",
       "L 299.530632 106.80657 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.916431 119.926038 \n",
       "L 284.916431 119.810924 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.898746 131.469045 \n",
       "L 271.898746 131.353645 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.210334 132.085564 \n",
       "L 271.210334 131.96974 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.963881 119.877272 \n",
       "L 284.963881 119.761596 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.705485 135.215349 \n",
       "L 267.705485 135.099542 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.703437 127.215541 \n",
       "L 276.703437 127.100199 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.188829 109.890687 \n",
       "L 296.188829 109.776011 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_21\">\n",
       "    <g clip-path=\"url(#p9688c5624f)\">\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.094076\" y=\"89.482827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"332.337333\" y=\"77.706188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.522127\" y=\"101.547628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.875725\" y=\"116.34591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.289636\" y=\"125.764173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.576444\" y=\"84.597507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.449248\" y=\"136.281532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.924309\" y=\"107.449649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.428145\" y=\"84.738693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.710677\" y=\"141.336805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.160803\" y=\"103.637299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"320.931842\" y=\"87.841379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.207028\" y=\"132.917178\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.285058\" y=\"128.429074\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.575899\" y=\"97.947407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.769257\" y=\"120.011388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.412817\" y=\"119.417408\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.664138\" y=\"110.285819\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.450965\" y=\"119.371156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.161923\" y=\"85.854968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.865958\" y=\"83.457002\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.567723\" y=\"121.064363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.845619\" y=\"107.460882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.17361\" y=\"94.738042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"332.560718\" y=\"77.50885\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.645249\" y=\"137.023062\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.809799\" y=\"83.495108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.068459\" y=\"100.170254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.947892\" y=\"106.497352\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"254.578053\" y=\"146.800457\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.66233\" y=\"84.524766\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"351.880509\" y=\"60.334621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.00387\" y=\"117.111331\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.316586\" y=\"97.278521\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.564204\" y=\"127.308058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.273927\" y=\"123.979137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.476135\" y=\"109.563673\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"251.311349\" y=\"149.717562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.49737\" y=\"132.626082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.948238\" y=\"128.748004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.911982\" y=\"95.872201\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.47721\" y=\"138.93223\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.273265\" y=\"116.872764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.804811\" y=\"115.493951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"331.957799\" y=\"78.040353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.857094\" y=\"89.691764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"320.873243\" y=\"87.900225\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.784748\" y=\"114.654228\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.395349\" y=\"90.098829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.725517\" y=\"100.481612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.144264\" y=\"85.873543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.262896\" y=\"115.981484\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.497212\" y=\"123.792156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.238759\" y=\"102.68327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.623198\" y=\"114.790967\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.984528\" y=\"117.141732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.754547\" y=\"95.110693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.952472\" y=\"105.588959\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"342.642546\" y=\"68.548472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.805637\" y=\"122.62544\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"337.533316\" y=\"73.07868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.672464\" y=\"114.744426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.406352\" y=\"126.522679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.595182\" y=\"144.129173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.921379\" y=\"112.762944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.22441\" y=\"132.026837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"255.567013\" y=\"145.981285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.93144\" y=\"114.521564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.55495\" y=\"105.953065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.450182\" y=\"113.162984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.711845\" y=\"98.696175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.41318\" y=\"109.697507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.965548\" y=\"116.268006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.633791\" y=\"87.220804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"343.912871\" y=\"67.41544\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"245.703593\" y=\"154.693857\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.559523\" y=\"117.502204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.720105\" y=\"108.471649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.253814\" y=\"101.779191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.354061\" y=\"108.783527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.288445\" y=\"91.971939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.453613\" y=\"108.711572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.136835\" y=\"123.209146\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.021734\" y=\"99.317955\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.698516\" y=\"95.157217\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.897813\" y=\"98.546283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"331.482189\" y=\"78.466118\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"350.761381\" y=\"61.33296\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.978726\" y=\"104.697366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.065385\" y=\"101.034387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.403039\" y=\"115.891129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.507129\" y=\"130.011332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.618258\" y=\"123.681103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.520055\" y=\"121.985524\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.950597\" y=\"116.252975\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.251594\" y=\"98.221671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.041021\" y=\"100.192969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.456747\" y=\"123.793633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.308068\" y=\"99.05925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.590944\" y=\"95.250914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.520513\" y=\"115.775077\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.306927\" y=\"108.839957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.963801\" y=\"98.47984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.787813\" y=\"104.867739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"258.749581\" y=\"143.101778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.003871\" y=\"83.334219\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.148832\" y=\"108.095008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.953015\" y=\"93.161211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.520128\" y=\"133.563757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.320237\" y=\"103.495231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.872283\" y=\"92.332203\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.343128\" y=\"137.233759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.825505\" y=\"110.165025\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"322.750706\" y=\"86.233641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.309317\" y=\"107.066093\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.084828\" y=\"113.507512\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.604445\" y=\"118.352768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.677752\" y=\"130.72797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.521208\" y=\"102.407826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.349487\" y=\"120.359143\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.675662\" y=\"137.845827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"253.31401\" y=\"147.949306\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.798298\" y=\"107.515993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.231286\" y=\"87.583452\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.50205\" y=\"107.793143\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.479727\" y=\"95.375689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.522473\" y=\"123.743703\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.964652\" y=\"105.604109\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.098159\" y=\"125.029609\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.317438\" y=\"93.731855\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.005927\" y=\"102.884277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"334.345013\" y=\"75.917136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.585141\" y=\"112.142444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"340.010077\" y=\"70.888368\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.520778\" y=\"120.207592\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.330475\" y=\"112.387548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.429469\" y=\"130.95962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.747492\" y=\"83.560883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.18718\" y=\"124.074224\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.239936\" y=\"130.240449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.588894\" y=\"82.815576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.314507\" y=\"95.499137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"339.801834\" y=\"71.073627\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.598746\" y=\"103.252375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"330.600982\" y=\"79.253962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.778658\" y=\"110.208367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"329.836758\" y=\"79.927384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.99737\" y=\"96.679851\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.739341\" y=\"120.912623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.981707\" y=\"126.002976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"355.011584\" y=\"57.548297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.219591\" y=\"117.818347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"256.853177\" y=\"144.811241\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.215523\" y=\"140.034429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.409234\" y=\"105.224073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.64918\" y=\"141.454931\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.836923\" y=\"102.156532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.627553\" y=\"103.212975\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.334134\" y=\"106.161065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.097241\" y=\"131.26029\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.42919\" y=\"130.110201\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.775134\" y=\"96.881543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.883536\" y=\"118.106866\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.943427\" y=\"108.288846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.587713\" y=\"122.824856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.147221\" y=\"115.217767\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.685909\" y=\"102.276318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"320.813322\" y=\"87.944656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.643886\" y=\"97.883718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.063698\" y=\"96.623086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.708881\" y=\"94.258159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.87184\" y=\"101.227576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.974203\" y=\"131.337698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.863526\" y=\"89.677888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.96458\" y=\"138.472514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.861989\" y=\"133.237614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.609778\" y=\"94.355523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.748493\" y=\"91.565248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.761415\" y=\"125.32956\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.682288\" y=\"107.628043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.41624\" y=\"87.415099\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.205448\" y=\"95.601416\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.208252\" y=\"113.380696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.321558\" y=\"128.392527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.78989\" y=\"93.296932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.896984\" y=\"113.67215\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.769065\" y=\"92.44403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.346229\" y=\"97.266994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.69111\" y=\"130.725028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.966553\" y=\"124.258845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.014897\" y=\"97.548588\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.74766\" y=\"96.892189\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"334.193575\" y=\"76.057471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.80977\" y=\"125.278517\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.169159\" y=\"128.549009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.773347\" y=\"103.093936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.784076\" y=\"111.977947\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.322211\" y=\"115.05248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.773373\" y=\"92.436944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.557387\" y=\"129.063313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.742694\" y=\"114.683475\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.012023\" y=\"136.664322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.732478\" y=\"101.360694\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.892307\" y=\"98.547834\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"352.124211\" y=\"60.115057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.394472\" y=\"93.648378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.493841\" y=\"124.669667\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.036943\" y=\"125.978866\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.256773\" y=\"118.667097\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.001238\" y=\"140.248889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.552494\" y=\"129.960466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.151262\" y=\"109.865685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.081431\" y=\"108.146986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.976405\" y=\"91.369757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.876512\" y=\"126.972537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.003209\" y=\"130.464405\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"259.879415\" y=\"142.107867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.72015\" y=\"96.030049\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.527643\" y=\"102.381261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.226703\" y=\"92.910891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.094528\" y=\"101.923578\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.42321\" y=\"96.302176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"342.131309\" y=\"68.997859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.416448\" y=\"100.752644\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.626025\" y=\"128.995443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"334.883222\" y=\"75.445905\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.578516\" y=\"98.818571\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.458478\" y=\"104.274895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.592247\" y=\"118.370012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.403759\" y=\"82.97772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.017019\" y=\"85.986277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.450822\" y=\"115.836596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.189417\" y=\"136.500555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.69852\" y=\"91.605781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.15122\" y=\"101.881205\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.591412\" y=\"139.713503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.301113\" y=\"131.081451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"322.522503\" y=\"86.426676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.195392\" y=\"127.610984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.818666\" y=\"111.976479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.907027\" y=\"117.212119\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.09573\" y=\"93.914657\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"255.750912\" y=\"145.824327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.725861\" y=\"110.253316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.15369\" y=\"118.750845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.631131\" y=\"95.219869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.90304\" y=\"103.006234\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.225861\" y=\"120.470967\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.224841\" y=\"127.585239\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.45759\" y=\"136.274042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.625236\" y=\"138.760843\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.631089\" y=\"112.98688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.261773\" y=\"116.889785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.935809\" y=\"118.073521\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.49088\" y=\"126.441294\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.884092\" y=\"130.569173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.284305\" y=\"105.308754\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.621536\" y=\"109.456224\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.747476\" y=\"117.371908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.580044\" y=\"118.389729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.75412\" y=\"138.665039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.420632\" y=\"83.852965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.612988\" y=\"120.997813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.73505\" y=\"109.354593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.700958\" y=\"108.499519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.446395\" y=\"111.383365\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.979963\" y=\"118.010543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.782285\" y=\"136.852115\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.929024\" y=\"101.178184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.697507\" y=\"135.162936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.748493\" y=\"91.548093\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.976854\" y=\"124.249104\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.734621\" y=\"91.57648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.859247\" y=\"98.561177\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.214806\" y=\"124.926803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.764937\" y=\"124.433556\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.97054\" y=\"108.254548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.528075\" y=\"117.538978\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.337762\" y=\"113.248864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.90983\" y=\"138.52741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"327.249823\" y=\"82.223725\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.867644\" y=\"94.120306\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.207661\" y=\"92.936706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.629486\" y=\"144.126026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.808863\" y=\"99.512666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.763356\" y=\"109.333469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.185564\" y=\"103.619879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.469975\" y=\"113.152385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.732033\" y=\"89.800232\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.327793\" y=\"99.937163\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.307767\" y=\"111.509633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.364164\" y=\"102.57157\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.110575\" y=\"120.561393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"334.203994\" y=\"76.043841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.89894\" y=\"115.425511\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.067583\" y=\"123.250732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"261.676707\" y=\"140.519822\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"252.612155\" y=\"148.545107\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.443621\" y=\"138.080175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.632737\" y=\"95.220618\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.531501\" y=\"115.773135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.812603\" y=\"90.61621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.313888\" y=\"89.284568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.833202\" y=\"117.267856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.628553\" y=\"81.000051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.938224\" y=\"109.168124\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.298478\" y=\"112.416228\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"248.227112\" y=\"152.470775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"254.475932\" y=\"146.911806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.29682\" y=\"99.077824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.29119\" y=\"107.997671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"259.25017\" y=\"142.652575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"258.17272\" y=\"143.637554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.866677\" y=\"113.686288\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.675905\" y=\"110.258841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.876864\" y=\"94.12234\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.797437\" y=\"96.858892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.638917\" y=\"141.434036\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"253.513245\" y=\"147.822915\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.361089\" y=\"96.353996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.788023\" y=\"112.865026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.989403\" y=\"129.571472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"268.297487\" y=\"134.631708\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.657932\" y=\"112.085153\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.289679\" y=\"118.603629\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.780717\" y=\"104.870132\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"255.750912\" y=\"145.801583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.714003\" y=\"115.595307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.678073\" y=\"131.636961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.740279\" y=\"103.129023\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"268.946018\" y=\"134.071378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.762672\" y=\"119.121279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.195618\" y=\"83.158079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"340.398127\" y=\"70.546441\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.099727\" y=\"102.81123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.855535\" y=\"115.495416\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.831355\" y=\"110.172158\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.088587\" y=\"105.482919\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.520915\" y=\"98.883279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.041354\" y=\"119.736143\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"336.641816\" y=\"73.878723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.644629\" y=\"121.041457\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.230218\" y=\"128.469686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.418369\" y=\"114.086127\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.374618\" y=\"119.450004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.367829\" y=\"124.787939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.498588\" y=\"111.360799\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"331.036719\" y=\"78.848448\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.994999\" y=\"84.233724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.123147\" y=\"94.794564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.138059\" y=\"108.109281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.840772\" y=\"135.036586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.161706\" y=\"101.848197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"254.894805\" y=\"146.577186\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.11309\" y=\"139.273354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.192561\" y=\"116.05492\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.55775\" y=\"90.835101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.259967\" y=\"84.875746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.586936\" y=\"89.930766\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"228.051663\" y=\"170.398483\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.09244\" y=\"109.027606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.107181\" y=\"116.138489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.221161\" y=\"111.585707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.823087\" y=\"143.934412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.138926\" y=\"94.783626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"261.478178\" y=\"140.713992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.123399\" y=\"89.450694\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"337.392886\" y=\"73.195224\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.092846\" y=\"125.07974\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.53453\" y=\"113.978543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.912317\" y=\"121.642628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.534575\" y=\"104.200759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.266087\" y=\"98.210037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"335.730896\" y=\"74.68063\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.489242\" y=\"84.662347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"333.021626\" y=\"77.095711\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.174916\" y=\"97.403035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.180048\" y=\"90.31245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.189415\" y=\"112.492087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.417146\" y=\"81.184642\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.391366\" y=\"106.103973\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.879511\" y=\"118.110103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.107472\" y=\"90.371081\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.830419\" y=\"135.920127\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.763082\" y=\"117.32817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.70023\" y=\"96.07467\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.861188\" y=\"93.2424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"339.041464\" y=\"71.748494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.920209\" y=\"132.304489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.002223\" y=\"98.453959\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"332.554405\" y=\"77.508914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.060878\" y=\"101.948867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.561973\" y=\"95.301248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.397964\" y=\"90.103497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.016184\" y=\"141.992515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.055782\" y=\"89.508612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.797747\" y=\"130.630164\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.628322\" y=\"123.675347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.286713\" y=\"105.290344\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.264911\" y=\"137.318239\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.556327\" y=\"125.514735\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"261.56769\" y=\"140.605407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.046338\" y=\"99.296679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.07281\" y=\"99.277453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.794551\" y=\"111.085059\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.939457\" y=\"92.287995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.908902\" y=\"118.977049\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.465512\" y=\"87.366404\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.64719\" y=\"95.213481\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.349004\" y=\"91.924161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.572568\" y=\"90.822488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"333.664592\" y=\"76.524483\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.192432\" y=\"132.951825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.687571\" y=\"107.620471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.428917\" y=\"126.470922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.091766\" y=\"101.048092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.305645\" y=\"94.628065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"355.176158\" y=\"57.400427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.757063\" y=\"104.004632\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.54543\" y=\"97.952251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.196058\" y=\"123.158606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.152883\" y=\"119.674022\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"327.4664\" y=\"82.043516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.384108\" y=\"113.214655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.592314\" y=\"107.699341\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.415134\" y=\"125.653587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.289263\" y=\"106.183043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.098819\" y=\"144.58152\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.348471\" y=\"131.035368\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.832397\" y=\"100.381518\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"332.326992\" y=\"77.69378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.476576\" y=\"131.815951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.260075\" y=\"123.076595\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.711557\" y=\"92.470881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.45717\" y=\"114.936715\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"251.482626\" y=\"149.591157\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.460313\" y=\"116.708167\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"268.211439\" y=\"134.711526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.537808\" y=\"95.294121\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.640786\" y=\"94.318856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"242.246239\" y=\"157.764541\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.155596\" y=\"122.3028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.207306\" y=\"110.708038\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.171497\" y=\"109.864563\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.169884\" y=\"122.304426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.574219\" y=\"116.60644\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.562676\" y=\"139.731031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.463567\" y=\"122.041901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.301679\" y=\"112.383048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"320.624333\" y=\"88.136281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.174264\" y=\"106.300302\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.362849\" y=\"138.12542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.279829\" y=\"133.757208\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.333857\" y=\"94.580623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.594364\" y=\"99.708992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.609266\" y=\"105.910125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.575167\" y=\"111.278808\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.923585\" y=\"123.401176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.42919\" y=\"130.064621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"227.320057\" y=\"171.043771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.382425\" y=\"136.340872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.836857\" y=\"131.493717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.295104\" y=\"125.754251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.664387\" y=\"130.747077\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.159131\" y=\"97.409411\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.038683\" y=\"102.864726\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.67572\" y=\"80.95696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.099348\" y=\"96.583159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.522473\" y=\"123.758094\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.416017\" y=\"98.079059\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.527105\" y=\"119.310675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"353.074194\" y=\"59.270439\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.855099\" y=\"135.911671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.222932\" y=\"124.038976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"331.424735\" y=\"78.521068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.26679\" y=\"128.427868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.791283\" y=\"112.856525\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.828051\" y=\"85.266264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.675838\" y=\"128.936718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.208012\" y=\"108.06482\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.025022\" y=\"112.617209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.97541\" y=\"134.892936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.651905\" y=\"103.189631\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.522775\" y=\"94.430366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.670239\" y=\"122.751015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.778679\" y=\"117.323029\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.287583\" y=\"126.656519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.360345\" y=\"135.484099\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.957345\" y=\"105.612649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.894769\" y=\"85.208652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.044064\" y=\"109.97685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.585674\" y=\"85.476265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.491249\" y=\"125.570348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.667183\" y=\"113.860697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.73999\" y=\"112.02105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.155714\" y=\"136.503881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.552478\" y=\"105.961705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.932966\" y=\"100.297781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.843744\" y=\"103.920305\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.386805\" y=\"104.341975\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.563686\" y=\"128.174479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"351.19818\" y=\"60.932076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.843459\" y=\"141.255516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.586183\" y=\"119.267693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.948514\" y=\"126.052242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.830988\" y=\"130.606796\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.287665\" y=\"131.937744\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.848813\" y=\"123.460887\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.581994\" y=\"90.846064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.581709\" y=\"107.702893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.323057\" y=\"99.040005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.717051\" y=\"110.243745\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.096039\" y=\"117.91859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.711588\" y=\"103.157638\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"345.864187\" y=\"65.677939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.064762\" y=\"113.500463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.675245\" y=\"125.409284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.823844\" y=\"123.477591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.568805\" y=\"137.938012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.737931\" y=\"127.988636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"324.286477\" y=\"84.857693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.466301\" y=\"110.486036\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.891493\" y=\"105.667503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"254.322049\" y=\"147.021803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"329.946104\" y=\"79.846693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.580028\" y=\"101.494773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.169159\" y=\"128.522754\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.951509\" y=\"95.842821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.950597\" y=\"116.27321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.581762\" y=\"128.156823\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.834434\" y=\"143.953451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.203611\" y=\"101.817648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.081889\" y=\"104.601985\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.007036\" y=\"86.000771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.272092\" y=\"89.319588\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.036877\" y=\"99.309852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.151543\" y=\"137.429312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"244.923391\" y=\"155.389026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.686031\" y=\"88.954182\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.833999\" y=\"109.263837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"340.661755\" y=\"70.301082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.87553\" y=\"108.341133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"351.320873\" y=\"60.838094\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.325951\" y=\"90.15644\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.249579\" y=\"129.334558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.997581\" y=\"110.017747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.598283\" y=\"132.588922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.647186\" y=\"104.096908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"327.274605\" y=\"82.205723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.943425\" y=\"139.424224\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.159414\" y=\"110.750818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"242.872246\" y=\"157.188643\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.490203\" y=\"133.568663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.487118\" y=\"122.011309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.999022\" y=\"97.567828\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.309215\" y=\"106.174559\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.241249\" y=\"124.893922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.900798\" y=\"89.642574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.997257\" y=\"97.570608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.240605\" y=\"90.246797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.311544\" y=\"87.511935\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.975265\" y=\"85.135865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.941929\" y=\"117.222974\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.409431\" y=\"102.533479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.117035\" y=\"126.782986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.361909\" y=\"97.245155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.986033\" y=\"91.341843\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"339.361466\" y=\"71.462728\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.766575\" y=\"118.215776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.09755\" y=\"102.786379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.1866\" y=\"115.176027\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.861852\" y=\"128.791139\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"336.073358\" y=\"74.383737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.311846\" y=\"135.520755\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.920098\" y=\"106.520598\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.210334\" y=\"132.070077\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.032763\" y=\"105.534591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.638753\" y=\"120.112316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.03772\" y=\"101.982788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"224.560561\" y=\"173.515138\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.495174\" y=\"98.004349\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.648532\" y=\"94.314671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"240.173391\" y=\"159.57686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.570971\" y=\"94.385472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"239.916605\" y=\"159.867563\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.856567\" y=\"109.247635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.347212\" y=\"109.690951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.448516\" y=\"110.488399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"330.860386\" y=\"79.015978\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.072063\" y=\"117.945135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"253.166999\" y=\"148.08638\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.006079\" y=\"97.548092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.157164\" y=\"119.671879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.240317\" y=\"99.998309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.513186\" y=\"115.792321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.892307\" y=\"98.545314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.985888\" y=\"120.70539\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.008483\" y=\"126.938741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.748437\" y=\"90.674632\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.427654\" y=\"85.627842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.765149\" y=\"100.422815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.185035\" y=\"116.950874\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.686675\" y=\"120.064714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.4976\" y=\"102.456849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.92055\" y=\"90.504276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.469179\" y=\"115.810843\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.773638\" y=\"83.540737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.088925\" y=\"130.353855\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.766342\" y=\"120.882441\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.146264\" y=\"124.105443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.258135\" y=\"113.297321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.18598\" y=\"99.183957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.549597\" y=\"121.071748\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.594891\" y=\"121.080603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.002359\" y=\"125.097795\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.059282\" y=\"103.722091\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.622285\" y=\"137.92764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.367104\" y=\"120.392288\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.958863\" y=\"118.940817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.848794\" y=\"129.683427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.672478\" y=\"85.393168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"268.453266\" y=\"134.510353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.837479\" y=\"124.402276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"322.0593\" y=\"86.847002\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.370183\" y=\"133.676546\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.533911\" y=\"120.194878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.243262\" y=\"129.351424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.498899\" y=\"83.772407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.805904\" y=\"98.623641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.988398\" y=\"117.15214\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.147917\" y=\"117.873377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.870551\" y=\"121.681369\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.599077\" y=\"127.260296\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.369837\" y=\"92.780261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.015554\" y=\"119.777943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"256.794372\" y=\"144.868901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.691516\" y=\"98.716683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.580307\" y=\"108.602984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.514693\" y=\"122.868807\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.413327\" y=\"129.194383\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.136171\" y=\"133.888343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"353.619577\" y=\"58.788331\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.520098\" y=\"129.986372\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"343.811647\" y=\"67.504115\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"350.087662\" y=\"61.921483\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.100304\" y=\"92.156774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.819589\" y=\"87.05519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.557812\" y=\"99.737265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.865766\" y=\"111.898001\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.5997\" y=\"91.694717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.062837\" y=\"119.694098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.197836\" y=\"136.490453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.66007\" y=\"98.755292\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"329.357938\" y=\"80.349488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.842155\" y=\"104.810244\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.889747\" y=\"106.564653\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"334.660833\" y=\"75.642823\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"258.217517\" y=\"143.587542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"346.240601\" y=\"65.349458\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.58131\" y=\"121.041252\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.291408\" y=\"101.732918\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.603156\" y=\"123.68523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.156543\" y=\"124.990388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"335.560564\" y=\"74.835442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.399766\" y=\"131.850194\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.620204\" y=\"106.801969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.69158\" y=\"133.402273\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.790827\" y=\"136.83119\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"335.472519\" y=\"74.916683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.040912\" y=\"108.195597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"333.479661\" y=\"76.702646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.658219\" y=\"98.742456\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.019614\" y=\"132.175891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.074797\" y=\"113.506309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.463876\" y=\"141.720202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.988857\" y=\"110.041375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.877246\" y=\"115.450719\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.420735\" y=\"131.865125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"249.308724\" y=\"151.509935\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.29141\" y=\"114.185937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.386394\" y=\"106.107058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.526996\" y=\"96.207037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"248.874828\" y=\"151.916601\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.575413\" y=\"113.93947\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.856489\" y=\"108.34477\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"337.940015\" y=\"72.725385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.890111\" y=\"88.774547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.848899\" y=\"110.133227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.481846\" y=\"96.239982\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"336.200451\" y=\"74.26962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.998816\" y=\"93.117326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.921323\" y=\"91.395825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.005687\" y=\"141.987315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.693917\" y=\"103.170459\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.631196\" y=\"126.330378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.741971\" y=\"108.47321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.889904\" y=\"102.092388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"261.686597\" y=\"140.486949\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.413062\" y=\"99.866589\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.634368\" y=\"113.002901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.407745\" y=\"133.634106\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.157509\" y=\"85.858147\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.833501\" y=\"136.824066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.034938\" y=\"120.643889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"316.076165\" y=\"92.157192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.617165\" y=\"133.456279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.650942\" y=\"128.967645\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.112174\" y=\"112.580656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.862695\" y=\"80.786607\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.540284\" y=\"110.414606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.234322\" y=\"106.24184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.376355\" y=\"98.110917\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.772484\" y=\"138.625422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.643993\" y=\"101.429856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"320.933036\" y=\"87.844021\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.128398\" y=\"130.341454\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.588435\" y=\"97.93473\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.373926\" y=\"103.452896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.359601\" y=\"108.795964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.643411\" y=\"123.658945\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.353962\" y=\"81.247169\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"279.018348\" y=\"125.124828\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.43528\" y=\"122.037933\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"246.716813\" y=\"153.818902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.703965\" y=\"119.159115\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.315732\" y=\"131.982096\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.141075\" y=\"102.764874\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.469129\" y=\"89.135708\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.649124\" y=\"118.323867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.39752\" y=\"122.092482\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"336.647272\" y=\"73.868251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.843083\" y=\"113.734338\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.501748\" y=\"119.336782\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.199731\" y=\"132.93889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.605028\" y=\"108.573296\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.025476\" y=\"97.52084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.443621\" y=\"138.038853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"342.905622\" y=\"68.301459\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.984923\" y=\"83.35572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"349.48161\" y=\"62.455085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"282.66078\" y=\"121.882376\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.170523\" y=\"132.972323\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.007687\" y=\"94.877633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.836662\" y=\"138.639926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.094217\" y=\"126.826205\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.047651\" y=\"141.990625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.497488\" y=\"131.828061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.192812\" y=\"107.169951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.660581\" y=\"112.971131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.305376\" y=\"83.965714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.912131\" y=\"134.990139\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.703965\" y=\"119.158304\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"256.92358\" y=\"144.783002\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"330.488221\" y=\"79.35023\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"331.267363\" y=\"78.658537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.153421\" y=\"110.754635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.654879\" y=\"114.759458\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.909244\" y=\"82.530996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.779414\" y=\"115.522605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.314561\" y=\"113.284679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.295048\" y=\"117.763588\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.483548\" y=\"131.82472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"241.706948\" y=\"158.282992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.670786\" y=\"82.743449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.936839\" y=\"110.951428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.578803\" y=\"112.1561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.704962\" y=\"103.166117\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.214965\" y=\"111.587359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.740775\" y=\"87.123555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.808852\" y=\"123.50622\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"333.300418\" y=\"76.849746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.877954\" y=\"90.583976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.598784\" y=\"117.47837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.000631\" y=\"81.584968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.914697\" y=\"141.237178\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"353.223716\" y=\"59.137437\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"327.533502\" y=\"81.97389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.833631\" y=\"112.811219\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.287173\" y=\"132.869906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.47842\" y=\"114.914776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"269.264742\" y=\"133.772704\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.483131\" y=\"116.677691\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.202318\" y=\"105.382718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.590768\" y=\"130.81069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.318441\" y=\"118.610876\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"258.384875\" y=\"143.442053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.836662\" y=\"138.612848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.048029\" y=\"113.508788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.975404\" y=\"86.919028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.709936\" y=\"118.258354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.668694\" y=\"127.186626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"268.700724\" y=\"134.28479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.524686\" y=\"109.544879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.153507\" y=\"114.310806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.918005\" y=\"83.414728\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.580307\" y=\"108.612576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"349.933553\" y=\"62.060429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.842028\" y=\"136.849638\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.122133\" y=\"115.23256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.288514\" y=\"85.744763\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.616158\" y=\"107.677123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.069542\" y=\"121.50697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.71314\" y=\"128.971591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.148113\" y=\"130.337744\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.014581\" y=\"101.10515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.274742\" y=\"113.309731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.167845\" y=\"117.841409\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.4493\" y=\"117.594881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.327793\" y=\"99.934778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.824819\" y=\"85.26775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.032757\" y=\"119.754508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.815284\" y=\"122.614959\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"322.714856\" y=\"86.260389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.823872\" y=\"106.596423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.06719\" y=\"101.957242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.355825\" y=\"109.704442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.562154\" y=\"113.066171\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.335126\" y=\"90.148812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.322745\" y=\"83.958179\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.928092\" y=\"138.511634\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.375835\" y=\"89.2217\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.858424\" y=\"99.456423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"332.454\" y=\"77.593628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.63799\" y=\"117.447826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.570019\" y=\"127.286162\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"270.403338\" y=\"132.774728\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.243363\" y=\"101.79036\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.35778\" y=\"131.875602\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.26195\" y=\"89.323424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.901296\" y=\"94.972179\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.084828\" y=\"113.513842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"259.486458\" y=\"142.466645\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.926422\" y=\"117.183612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"290.910531\" y=\"114.529964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.253814\" y=\"101.755266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"263.763303\" y=\"138.703738\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"272.610865\" y=\"130.867245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.558541\" y=\"94.392191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.279164\" y=\"108.869809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.806962\" y=\"118.186868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.432025\" y=\"85.621115\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.621855\" y=\"102.340245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.943302\" y=\"101.170882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.4647\" y=\"109.603181\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.976068\" y=\"110.910005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.565806\" y=\"136.173359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.504466\" y=\"117.572269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"256.557911\" y=\"145.059308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"315.090193\" y=\"93.038969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.016184\" y=\"142.008935\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.016038\" y=\"117.982528\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.879316\" y=\"102.131543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.058518\" y=\"118.847007\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"291.146594\" y=\"114.328\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.150815\" y=\"128.567151\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.265604\" y=\"116.875238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.7732\" y=\"95.990092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.953154\" y=\"95.838278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.538435\" y=\"111.290674\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.513527\" y=\"116.683803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.547708\" y=\"103.296979\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"301.978726\" y=\"104.697187\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.959571\" y=\"119.811686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.01684\" y=\"109.099922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.968731\" y=\"103.812301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.887212\" y=\"129.653697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"238.050061\" y=\"161.528943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.673562\" y=\"85.403449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.473008\" y=\"137.140047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.71905\" y=\"99.591625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"243.294658\" y=\"156.838829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.332888\" y=\"126.602456\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.884823\" y=\"125.209792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"329.590477\" y=\"80.134889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"336.118567\" y=\"74.342635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"319.572147\" y=\"89.057152\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.800113\" y=\"109.29551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"330.193587\" y=\"79.597571\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.021405\" y=\"100.217277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.14821\" y=\"127.657448\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.33285\" y=\"109.706461\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"337.741339\" y=\"72.900397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"275.958682\" y=\"127.81846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.580979\" y=\"131.724092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.547708\" y=\"103.312731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.046762\" y=\"104.629596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"297.204067\" y=\"108.927318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.213732\" y=\"130.254362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.600264\" y=\"107.695722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.785428\" y=\"93.304616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"313.233417\" y=\"94.687474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.288872\" y=\"112.420816\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.58829\" y=\"101.479548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"327.847963\" y=\"81.694705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.034719\" y=\"112.648012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.959756\" y=\"110.104032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"344.504931\" y=\"66.890903\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.56013\" y=\"131.742986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.594847\" y=\"129.030252\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.821191\" y=\"95.943283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.806092\" y=\"111.947083\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"264.568805\" y=\"137.971473\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"239.417759\" y=\"160.303237\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.217954\" y=\"81.372052\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.353581\" y=\"116.800292\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.099792\" y=\"81.472628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"274.091222\" y=\"129.487594\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.836347\" y=\"100.377457\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.80619\" y=\"107.511395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"259.752572\" y=\"142.219997\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"277.513377\" y=\"126.439435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.891749\" y=\"94.993058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.777936\" y=\"119.948048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.563357\" y=\"97.959195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"323.917331\" y=\"85.192137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.543502\" y=\"139.747565\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"280.29939\" y=\"123.836542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.729276\" y=\"112.902175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.423222\" y=\"98.07943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"310.492239\" y=\"97.11901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"325.659827\" y=\"83.633625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.875485\" y=\"118.095688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.635393\" y=\"96.110446\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"283.69428\" y=\"120.947218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.640637\" y=\"106.773489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.022899\" y=\"96.650843\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.9073\" y=\"110.087425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.28454\" y=\"144.468527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.545715\" y=\"113.070369\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"329.244494\" y=\"80.453909\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"304.559796\" y=\"102.421341\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"295.261088\" y=\"110.66425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.232528\" y=\"100.026666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.54543\" y=\"97.964246\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.31708\" y=\"137.270698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"286.277344\" y=\"118.648256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.1428\" y=\"100.11584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"265.756641\" y=\"136.932245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"250.922106\" y=\"150.094322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.781852\" y=\"116.421342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"281.616867\" y=\"122.82249\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.711333\" y=\"104.046363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"266.961795\" y=\"135.819663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.467559\" y=\"109.619567\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"314.22502\" y=\"93.804565\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"293.144384\" y=\"112.54751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.693877\" y=\"97.798366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"326.598656\" y=\"82.808422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"268.461032\" y=\"134.469233\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.077248\" y=\"117.05522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"320.203282\" y=\"88.473351\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"262.990657\" y=\"139.425515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.36228\" y=\"101.685785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"273.461691\" y=\"130.053421\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.682026\" y=\"111.175623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"312.058279\" y=\"95.71575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"300.026071\" y=\"106.43525\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"328.947192\" y=\"80.717392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"321.223011\" y=\"87.58802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"307.751569\" y=\"99.560768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.048029\" y=\"113.517031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"292.745607\" y=\"112.915723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"285.666161\" y=\"119.205739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.318564\" y=\"98.180363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.069795\" y=\"91.275515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"278.163575\" y=\"125.872297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"338.673393\" y=\"72.074779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"309.410612\" y=\"98.080805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.687242\" y=\"101.385357\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.265658\" y=\"120.439017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"289.314609\" y=\"115.942115\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"288.619652\" y=\"116.572875\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"294.006592\" y=\"111.786103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"329.180479\" y=\"80.507295\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"317.852632\" y=\"90.585024\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"298.016573\" y=\"108.230364\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.734618\" y=\"89.784884\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"306.997849\" y=\"100.22957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"308.442686\" y=\"98.950995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"305.544888\" y=\"101.517768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.406757\" y=\"131.863019\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"257.145365\" y=\"144.554087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.935412\" y=\"109.162663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.742484\" y=\"103.128761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.393119\" y=\"109.662376\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"256.723643\" y=\"144.915929\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"260.884188\" y=\"141.221227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"287.127976\" y=\"117.888187\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"311.043306\" y=\"96.634212\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"318.100865\" y=\"90.353724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"302.868786\" y=\"103.878772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"303.210302\" y=\"103.593615\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"299.530632\" y=\"106.863894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.916431\" y=\"119.868481\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.898746\" y=\"131.411345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"271.210334\" y=\"132.027652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"284.963881\" y=\"119.819434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"267.705485\" y=\"135.157446\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"276.703437\" y=\"127.15787\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"296.188829\" y=\"109.833349\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 218.029781 172.541674 \n",
       "L 218.029781 70.40401 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 248.634114 179.384625 \n",
       "L 340.54951 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_23\">\n",
       "    <!-- RMSE: 0.001 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(225.213639 64.316362) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_24\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(255.452359 45.531) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_22\">\n",
       "    <path d=\"M 319.094076 89.477271 \n",
       "L 355.011584 57.547645 \n",
       "L 245.703593 154.719289 \n",
       "L 274.557387 129.0691 \n",
       "\" clip-path=\"url(#p9688c5624f)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 390.408313 179.384625 \n",
       "L 534.085469 179.384625 \n",
       "L 534.085469 51.531 \n",
       "L 390.408313 51.531 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"409.66731\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(404.650622 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"466.910229\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(464.463417 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"524.153149\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(521.706337 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"390.408313\" y=\"162.185075\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074938 165.334512) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"390.408313\" y=\"136.747732\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074938 139.897169) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"390.408313\" y=\"111.310388\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 114.459826) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"390.408313\" y=\"85.873045\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 89.022483) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"390.408313\" y=\"60.435702\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 63.585139) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_3\">\n",
       "    <path d=\"M 484.193407 96.020985 \n",
       "L 484.193407 95.876672 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.45961 109.118839 \n",
       "L 469.45961 108.974446 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.678936 148.921827 \n",
       "L 424.678936 148.777445 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.567321 109.020968 \n",
       "L 469.567321 108.876583 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.628328 135.631584 \n",
       "L 439.628328 135.487185 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.036918 99.717605 \n",
       "L 480.036918 99.573216 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.713046 108.001001 \n",
       "L 470.713046 107.856603 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.831413 68.793067 \n",
       "L 514.831413 68.648676 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 511.040335 72.162151 \n",
       "L 511.040335 72.017743 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.575609 105.463756 \n",
       "L 473.575609 105.319402 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.427434 92.25675 \n",
       "L 488.427434 92.112461 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.013479 83.739782 \n",
       "L 498.013479 83.595405 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.14226 136.06815 \n",
       "L 439.14226 135.924127 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.301868 132.366454 \n",
       "L 443.301868 132.222077 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.315459 130.57554 \n",
       "L 445.315459 130.43119 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.166663 109.376122 \n",
       "L 469.166663 109.231729 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.2494 87.085248 \n",
       "L 494.2494 86.940857 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.472766 141.105642 \n",
       "L 433.472766 140.961345 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.107532 160.08971 \n",
       "L 412.107532 159.945293 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 513.26327 70.179698 \n",
       "L 513.26327 70.03544 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.436864 86.918334 \n",
       "L 494.436864 86.773941 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.138029 77.406153 \n",
       "L 505.138029 77.26179 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 408.211424 163.540214 \n",
       "L 408.211424 163.395888 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.180978 104.032224 \n",
       "L 475.180978 103.887869 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.328338 79.903959 \n",
       "L 502.328338 79.759596 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.401074 131.390777 \n",
       "L 444.401074 131.246471 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.179155 128.029728 \n",
       "L 448.179155 127.885315 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.542235 77.047376 \n",
       "L 505.542235 76.903085 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.698674 94.683351 \n",
       "L 485.698674 94.539158 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.398037 113.617187 \n",
       "L 464.398037 113.472846 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.785786 75.054565 \n",
       "L 507.785786 74.910157 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.428047 128.69807 \n",
       "L 447.428047 128.553661 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.428596 108.255205 \n",
       "L 470.428596 108.110807 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.378634 129.630424 \n",
       "L 446.378634 129.486015 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.752352 92.858375 \n",
       "L 487.752352 92.713992 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.232669 108.431178 \n",
       "L 470.232669 108.286789 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 404.651056 166.717399 \n",
       "L 404.651056 166.573022 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.06699 92.580731 \n",
       "L 488.06699 92.436329 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.745931 146.193067 \n",
       "L 427.745931 146.048708 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 524.315348 60.363763 \n",
       "L 524.315348 60.21937 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.19644 126.242002 \n",
       "L 450.19644 126.097697 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.678486 83.148912 \n",
       "L 498.678486 83.004495 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.712641 119.550505 \n",
       "L 457.712641 119.406287 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.652032 107.169372 \n",
       "L 471.652032 107.024989 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 405.475777 165.977744 \n",
       "L 405.475777 165.833337 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.562386 85.030085 \n",
       "L 496.562386 84.885696 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.638405 93.847131 \n",
       "L 486.638405 93.702741 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.474941 86.884228 \n",
       "L 494.474941 86.739843 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.666178 96.492361 \n",
       "L 483.666178 96.347969 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.270031 147.499881 \n",
       "L 426.270031 147.355496 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.011097 106.849177 \n",
       "L 472.011097 106.704769 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.164352 116.491479 \n",
       "L 461.164352 116.347109 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.21429 104.001087 \n",
       "L 475.21429 103.85669 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.061551 102.36115 \n",
       "L 477.061551 102.216757 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.829002 106.123954 \n",
       "L 472.829002 105.979552 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.839648 110.555423 \n",
       "L 467.839648 110.411173 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.371271 127.856801 \n",
       "L 448.371271 127.712416 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.968413 89.111565 \n",
       "L 491.968413 88.967208 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.233787 159.975456 \n",
       "L 412.233787 159.831042 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.288639 133.26475 \n",
       "L 442.288639 133.120336 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.757708 147.067486 \n",
       "L 426.757708 146.923072 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.027896 135.274631 \n",
       "L 440.027896 135.130228 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.975818 113.101845 \n",
       "L 464.975818 112.957438 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.149569 95.170544 \n",
       "L 485.149569 95.026143 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.643354 84.071117 \n",
       "L 497.643354 83.926797 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.454705 141.116014 \n",
       "L 433.454705 140.971739 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.462866 124.22113 \n",
       "L 452.462866 124.076765 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.646865 149.833447 \n",
       "L 423.646865 149.689049 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.403326 140.271275 \n",
       "L 434.403326 140.126862 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.220186 96.001941 \n",
       "L 484.220186 95.857661 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.295908 149.254875 \n",
       "L 424.295908 149.110483 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.307467 86.142946 \n",
       "L 495.307467 85.998649 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.943108 143.346139 \n",
       "L 430.943108 143.201789 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.91998 85.602584 \n",
       "L 495.91998 85.458263 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.826863 93.681152 \n",
       "L 486.826863 93.536741 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.299619 110.148195 \n",
       "L 468.299619 110.003818 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.277411 150.161576 \n",
       "L 423.277411 150.017196 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.613742 140.084542 \n",
       "L 434.613742 139.940154 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.207943 104.008607 \n",
       "L 475.207943 103.864207 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.528499 82.391922 \n",
       "L 499.528499 82.247513 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.510567 119.73571 \n",
       "L 457.510567 119.591317 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.661022 93.827856 \n",
       "L 486.661022 93.68351 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.520945 119.724765 \n",
       "L 457.520945 119.580394 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.596718 83.221444 \n",
       "L 498.596718 83.077028 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.688453 94.690394 \n",
       "L 485.688453 94.546047 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 435.634207 139.179178 \n",
       "L 435.634207 139.034768 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.707725 96.454459 \n",
       "L 483.707725 96.310061 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.22557 86.217742 \n",
       "L 495.22557 86.073343 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.239678 115.534741 \n",
       "L 462.239678 115.390376 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.925745 156.68481 \n",
       "L 415.925745 156.54046 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.246667 114.636533 \n",
       "L 463.246667 114.492204 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.934685 94.476885 \n",
       "L 485.934685 94.332485 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.724049 96.43911 \n",
       "L 483.724049 96.294693 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.609299 145.426248 \n",
       "L 428.609299 145.281899 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.260574 86.182312 \n",
       "L 495.260574 86.038012 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.211234 151.105732 \n",
       "L 422.211234 150.961431 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.848758 98.10861 \n",
       "L 481.848758 97.964231 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.524811 119.714286 \n",
       "L 457.524811 119.570024 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.05801 102.364442 \n",
       "L 477.05801 102.22009 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.911457 110.494396 \n",
       "L 467.911457 110.35 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.788404 87.493218 \n",
       "L 493.788404 87.348842 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.808467 72.368383 \n",
       "L 510.808467 72.223978 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.44384 113.575463 \n",
       "L 464.44384 113.431044 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.759874 147.965714 \n",
       "L 425.759874 147.821434 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.840364 130.104159 \n",
       "L 445.840364 129.959784 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.230781 156.426624 \n",
       "L 416.230781 156.282216 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.903153 90.058542 \n",
       "L 490.903153 89.914232 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 435.871523 138.967344 \n",
       "L 435.871523 138.822933 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.111059 96.096677 \n",
       "L 484.111059 95.952266 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.48912 119.755329 \n",
       "L 457.48912 119.61095 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.898115 158.49502 \n",
       "L 413.898115 158.350627 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.070002 94.34979 \n",
       "L 486.070002 94.205509 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.899606 116.724808 \n",
       "L 460.899606 116.580424 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.31882 107.462038 \n",
       "L 471.31882 107.317855 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.281495 103.944176 \n",
       "L 475.281495 103.799761 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.936463 112.247579 \n",
       "L 465.936463 112.103233 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.014757 79.29425 \n",
       "L 503.014757 79.149885 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.834955 109.673393 \n",
       "L 468.834955 109.528991 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.31087 153.691267 \n",
       "L 419.31087 153.546889 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 517.034304 66.835747 \n",
       "L 517.034304 66.691351 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.064044 81.031107 \n",
       "L 501.064044 80.886706 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.265762 102.180097 \n",
       "L 477.265762 102.035689 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.70831 97.342365 \n",
       "L 482.70831 97.197965 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.153312 116.499471 \n",
       "L 461.153312 116.355084 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.47884 118.875185 \n",
       "L 458.47884 118.730783 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.828604 119.452989 \n",
       "L 457.828604 119.308694 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.796509 76.822106 \n",
       "L 505.796509 76.677705 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 421.638849 151.622022 \n",
       "L 421.638849 151.477624 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.130589 160.070957 \n",
       "L 412.130589 159.926596 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.899022 121.169809 \n",
       "L 455.899022 121.025433 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.57432 114.347544 \n",
       "L 463.57432 114.203144 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.797568 85.708783 \n",
       "L 495.797568 85.564378 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.507987 74.411401 \n",
       "L 508.507987 74.267087 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.699837 124.89975 \n",
       "L 451.699837 124.755364 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.205151 84.458552 \n",
       "L 497.205151 84.314142 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.340255 133.221024 \n",
       "L 442.340255 133.076683 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 406.320809 165.224568 \n",
       "L 406.320809 165.08018 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.051111 89.035608 \n",
       "L 492.051111 88.891283 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.846141 114.104185 \n",
       "L 463.846141 113.959853 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.372114 102.083137 \n",
       "L 477.372114 101.938726 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.883097 149.623462 \n",
       "L 423.883097 149.479041 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.356022 101.210157 \n",
       "L 478.356022 101.065819 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.783629 101.719289 \n",
       "L 477.783629 101.574917 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.45508 138.450858 \n",
       "L 436.45508 138.306452 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.962603 90.006095 \n",
       "L 490.962603 89.861693 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.356797 87.878412 \n",
       "L 493.356797 87.734023 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.104891 109.433982 \n",
       "L 469.104891 109.289624 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.226234 118.211166 \n",
       "L 459.226234 118.066781 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.590589 93.002252 \n",
       "L 487.590589 92.857849 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.715817 76.001989 \n",
       "L 506.715817 75.857665 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.082439 144.110583 \n",
       "L 430.082439 143.96616 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.397714 135.834733 \n",
       "L 439.397714 135.690346 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.767267 83.072132 \n",
       "L 498.767267 82.927744 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.42919 69.149995 \n",
       "L 514.42919 69.005587 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.249946 135.961508 \n",
       "L 439.249946 135.817128 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.810495 148.799883 \n",
       "L 424.810495 148.655479 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.563837 105.470957 \n",
       "L 473.563837 105.326671 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.101194 119.214856 \n",
       "L 458.101194 119.070474 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.611452 75.210291 \n",
       "L 507.611452 75.065982 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.641263 82.294029 \n",
       "L 499.641263 82.149674 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.281183 146.608416 \n",
       "L 427.281183 146.464275 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.253819 119.958116 \n",
       "L 457.253819 119.813809 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.196925 144.011861 \n",
       "L 430.196925 143.867447 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.82073 75.917459 \n",
       "L 506.82073 75.773179 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.146037 156.504648 \n",
       "L 416.146037 156.360236 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.293133 150.154195 \n",
       "L 423.293133 150.00979 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.244217 75.535709 \n",
       "L 507.244217 75.391321 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.770869 105.285149 \n",
       "L 473.770869 105.140753 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.38169 147.402171 \n",
       "L 426.38169 147.257753 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.790067 113.26611 \n",
       "L 464.790067 113.121698 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.770604 102.622447 \n",
       "L 476.770604 102.47812 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.693073 98.243998 \n",
       "L 481.693073 98.099638 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.443528 126.903874 \n",
       "L 449.443528 126.759519 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.362034 128.758628 \n",
       "L 447.362034 128.614245 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.022178 84.616763 \n",
       "L 497.022178 84.472407 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.566688 106.353896 \n",
       "L 472.566688 106.209524 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 527.554689 57.486939 \n",
       "L 527.554689 57.342528 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.690408 144.462983 \n",
       "L 429.690408 144.318563 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.397644 83.397492 \n",
       "L 498.397644 83.253116 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.895645 106.954182 \n",
       "L 471.895645 106.809809 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.649546 89.395355 \n",
       "L 491.649546 89.250945 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.165063 156.479245 \n",
       "L 416.165063 156.33494 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.277295 103.947515 \n",
       "L 475.277295 103.803127 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.230009 104.876286 \n",
       "L 474.230009 104.73187 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.907517 74.947065 \n",
       "L 507.907517 74.802721 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.195218 136.908626 \n",
       "L 438.195218 136.764398 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.277784 107.504721 \n",
       "L 471.277784 107.36041 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.318209 118.130166 \n",
       "L 459.318209 117.985778 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.518323 98.398475 \n",
       "L 481.518323 98.254078 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.285279 105.71878 \n",
       "L 473.285279 105.574374 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.47028 114.438866 \n",
       "L 463.47028 114.294452 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.574167 102.793426 \n",
       "L 476.574167 102.649014 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.613188 130.308816 \n",
       "L 445.613188 130.164427 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.193551 108.463964 \n",
       "L 470.193551 108.319581 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.567654 119.687857 \n",
       "L 457.567654 119.543524 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.600362 148.983327 \n",
       "L 424.600362 148.83892 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.099229 151.205201 \n",
       "L 422.099229 151.060808 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.078436 103.233826 \n",
       "L 476.078436 103.089419 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.056515 145.909883 \n",
       "L 428.056515 145.76555 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 512.920995 70.491196 \n",
       "L 512.920995 70.346794 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.075001 103.237769 \n",
       "L 476.075001 103.093367 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.277776 154.603008 \n",
       "L 418.277776 154.458591 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.484045 138.421035 \n",
       "L 436.484045 138.276648 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.564749 129.459659 \n",
       "L 446.564749 129.315274 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.921013 103.373286 \n",
       "L 475.921013 103.228882 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.475695 97.552384 \n",
       "L 482.475695 97.408072 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 414.209002 158.215135 \n",
       "L 414.209002 158.070796 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.979105 110.437509 \n",
       "L 467.979105 110.293147 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.84976 144.318287 \n",
       "L 429.84976 144.173881 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.284386 127.936713 \n",
       "L 448.284386 127.792346 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.454781 133.117546 \n",
       "L 442.454781 132.973134 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.082658 97.897559 \n",
       "L 482.082658 97.753219 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.284365 106.602593 \n",
       "L 472.284365 106.458233 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.209845 109.337932 \n",
       "L 469.209845 109.193555 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.654424 99.168722 \n",
       "L 480.654424 99.024332 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 408.097237 163.649321 \n",
       "L 408.097237 163.504937 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.095413 128.990068 \n",
       "L 447.095413 128.845669 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.965472 84.671459 \n",
       "L 496.965472 84.527041 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.219747 151.092307 \n",
       "L 422.219747 150.948225 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.966174 128.220022 \n",
       "L 447.966174 128.07565 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.267651 118.1731 \n",
       "L 459.267651 118.028718 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.572646 84.126354 \n",
       "L 497.572646 83.983013 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.670985 108.039998 \n",
       "L 470.670985 107.8956 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.336034 92.338116 \n",
       "L 488.336034 92.193847 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.83966 105.224122 \n",
       "L 473.83966 105.079718 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.347452 136.768265 \n",
       "L 438.347452 136.623848 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.50787 87.742305 \n",
       "L 493.50787 87.597911 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 406.342683 165.207674 \n",
       "L 406.342683 165.063271 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.24927 120.85796 \n",
       "L 456.24927 120.713562 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.417995 91.378104 \n",
       "L 489.417995 91.23372 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.760918 94.627775 \n",
       "L 485.760918 94.483393 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.289635 79.048873 \n",
       "L 503.289635 78.904462 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.605624 148.091852 \n",
       "L 425.605624 147.94745 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.50164 154.403112 \n",
       "L 418.50164 154.258719 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.858452 90.989283 \n",
       "L 489.858452 90.844881 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.910419 86.498444 \n",
       "L 494.910419 86.354032 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.754366 128.408827 \n",
       "L 447.754366 128.264447 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.481097 142.868974 \n",
       "L 431.481097 142.724587 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.25979 89.741802 \n",
       "L 491.25979 89.597384 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.554637 145.475305 \n",
       "L 428.554637 145.331136 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.265468 81.739862 \n",
       "L 500.265468 81.595827 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.987637 92.64974 \n",
       "L 487.987637 92.505373 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.666637 114.261964 \n",
       "L 463.666637 114.117639 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.955776 111.33966 \n",
       "L 466.955776 111.19528 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.494798 118.860137 \n",
       "L 458.494798 118.715764 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.174197 136.920633 \n",
       "L 438.174197 136.776231 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.412202 110.051869 \n",
       "L 468.412202 109.907812 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.270387 105.728607 \n",
       "L 473.270387 105.584237 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.117231 114.753811 \n",
       "L 463.117231 114.609406 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.124102 141.409226 \n",
       "L 433.124102 141.264814 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.109271 95.207477 \n",
       "L 485.109271 95.063108 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.852935 93.658351 \n",
       "L 486.852935 93.513987 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.746179 94.642222 \n",
       "L 485.746179 94.497805 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.40678 88.722105 \n",
       "L 492.40678 88.577709 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.045287 137.928189 \n",
       "L 437.045287 137.783795 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.90562 91.832466 \n",
       "L 488.90562 91.688089 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.426232 117.144872 \n",
       "L 460.426232 117.000493 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.062565 160.129607 \n",
       "L 412.062565 159.985312 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.359032 94.986445 \n",
       "L 485.359032 94.842039 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.344642 105.66483 \n",
       "L 473.344642 105.520471 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.216467 103.113193 \n",
       "L 476.216467 102.968795 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.163432 113.822098 \n",
       "L 464.163432 113.677707 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.163807 113.823976 \n",
       "L 464.163807 113.679579 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.357947 158.978338 \n",
       "L 413.357947 158.833931 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.886489 86.517676 \n",
       "L 494.886489 86.373276 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.080815 118.341237 \n",
       "L 459.080815 118.196837 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 515.522985 68.178922 \n",
       "L 515.522985 68.034511 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.280397 103.947912 \n",
       "L 475.280397 103.80353 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.880372 74.969916 \n",
       "L 507.880372 74.825522 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.720836 154.20723 \n",
       "L 418.720836 154.06282 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.357825 115.427076 \n",
       "L 462.357825 115.282752 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.503573 101.967675 \n",
       "L 477.503573 101.823287 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.324763 87.017429 \n",
       "L 494.324763 86.873033 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.596959 100.10406 \n",
       "L 479.596959 99.959689 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.134554 147.622005 \n",
       "L 426.134554 147.477622 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.955656 123.783053 \n",
       "L 452.955656 123.638708 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 511.02274 72.178268 \n",
       "L 511.02274 72.033859 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.434261 82.477492 \n",
       "L 499.434261 82.333076 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.335322 127.893747 \n",
       "L 448.335322 127.749433 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.374461 102.081532 \n",
       "L 477.374461 101.937131 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.896055 121.173348 \n",
       "L 455.896055 121.029001 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.512156 141.952821 \n",
       "L 432.512156 141.808408 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.449604 79.798582 \n",
       "L 502.449604 79.654173 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.377588 154.510775 \n",
       "L 418.377588 154.366373 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.650612 106.280993 \n",
       "L 472.650612 106.136636 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.697721 105.353084 \n",
       "L 473.697721 105.208717 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.852131 148.757287 \n",
       "L 424.852131 148.61287 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.841976 127.441141 \n",
       "L 448.841976 127.296731 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.389838 77.184811 \n",
       "L 505.389838 77.040408 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.527804 118.832403 \n",
       "L 458.527804 118.688024 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.716155 96.447099 \n",
       "L 483.716155 96.302711 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 400.855729 170.07808 \n",
       "L 400.855729 169.933702 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.067575 129.018253 \n",
       "L 447.067575 128.873866 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.338203 86.117152 \n",
       "L 495.338203 85.972754 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 421.425548 151.807023 \n",
       "L 421.425548 151.662604 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.59229 162.294836 \n",
       "L 409.59229 162.150613 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.153853 160.045828 \n",
       "L 412.153853 159.901413 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.456749 120.673288 \n",
       "L 456.456749 120.528907 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 518.192751 65.805708 \n",
       "L 518.192751 65.661298 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.149734 94.285318 \n",
       "L 486.149734 94.140914 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.817745 88.357444 \n",
       "L 492.817745 88.213039 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.840686 154.103863 \n",
       "L 418.840686 153.959496 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.873719 119.41499 \n",
       "L 457.873719 119.27058 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.641362 113.398985 \n",
       "L 464.641362 113.254601 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.880546 117.630379 \n",
       "L 459.880546 117.485972 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.67066 100.929664 \n",
       "L 478.67066 100.785252 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.611618 100.096311 \n",
       "L 479.611618 99.952026 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.656102 98.277493 \n",
       "L 481.656102 98.13311 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.508377 125.960403 \n",
       "L 450.508377 125.816017 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.695356 148.901436 \n",
       "L 424.695356 148.757017 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.261311 116.402487 \n",
       "L 461.261311 116.258147 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.321421 113.683975 \n",
       "L 464.321421 113.53962 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.039483 134.374461 \n",
       "L 441.039483 134.230044 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.239881 102.198464 \n",
       "L 477.239881 102.054221 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.837962 125.669201 \n",
       "L 450.837962 125.524924 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.762884 144.395153 \n",
       "L 429.762884 144.250786 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.455369 150.003683 \n",
       "L 423.455369 149.859331 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.46407 125.111237 \n",
       "L 451.46407 124.966841 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.20599 116.452009 \n",
       "L 461.20599 116.307642 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.552677 83.25987 \n",
       "L 498.552677 83.115461 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.403506 112.723855 \n",
       "L 465.403506 112.579483 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.967148 141.553409 \n",
       "L 432.967148 141.409049 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.35309 118.098563 \n",
       "L 459.35309 117.95415 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.101759 122.763404 \n",
       "L 454.101759 122.619014 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.138583 83.629724 \n",
       "L 498.138583 83.485436 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.434158 143.801562 \n",
       "L 430.434158 143.657158 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.78485 121.267959 \n",
       "L 455.78485 121.123594 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.100494 80.995765 \n",
       "L 501.100494 80.851352 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.262879 103.073611 \n",
       "L 476.262879 102.929239 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.850014 116.771513 \n",
       "L 460.850014 116.627157 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.510585 113.513884 \n",
       "L 464.510585 113.36948 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 519.892048 64.292064 \n",
       "L 519.892048 64.147666 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 509.31418 73.695564 \n",
       "L 509.31418 73.551176 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.876276 115.856064 \n",
       "L 461.876276 115.71172 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.857904 122.093047 \n",
       "L 454.857904 121.948638 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.362741 162.508291 \n",
       "L 409.362741 162.364054 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.684053 115.136335 \n",
       "L 462.684053 114.992013 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.210812 87.119788 \n",
       "L 494.210812 86.97538 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.87552 86.528706 \n",
       "L 494.87552 86.384358 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.794125 124.815021 \n",
       "L 451.794125 124.670631 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.642166 79.625337 \n",
       "L 502.642166 79.480935 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.187104 100.468768 \n",
       "L 479.187104 100.32455 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.927101 74.92883 \n",
       "L 507.927101 74.78443 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 509.808548 73.25441 \n",
       "L 509.808548 73.110004 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.591 104.557394 \n",
       "L 474.591 104.41301 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.222419 93.329493 \n",
       "L 487.222419 93.185081 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.189763 124.468979 \n",
       "L 452.189763 124.324697 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.88077 106.078086 \n",
       "L 472.88077 105.933805 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.10293 108.545037 \n",
       "L 470.10293 108.400644 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.515028 137.505543 \n",
       "L 437.515028 137.361203 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.519503 84.178247 \n",
       "L 497.519503 84.033836 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.18796 138.687293 \n",
       "L 436.18796 138.542871 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.189678 105.799429 \n",
       "L 473.189678 105.65508 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.678907 148.028525 \n",
       "L 425.678907 147.884119 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.285538 110.158594 \n",
       "L 468.285538 110.014257 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 520.491771 63.759679 \n",
       "L 520.491771 63.61532 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.837187 127.446354 \n",
       "L 448.837187 127.302028 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.47628 127.766952 \n",
       "L 448.47628 127.622556 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.902164 124.723391 \n",
       "L 451.902164 124.578995 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.218576 84.445178 \n",
       "L 497.218576 84.300781 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.879285 77.640654 \n",
       "L 504.879285 77.496337 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.347056 115.439134 \n",
       "L 462.347056 115.294741 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.635222 124.958004 \n",
       "L 451.635222 124.813604 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.57727 155.229361 \n",
       "L 417.57727 155.084957 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.850387 82.106622 \n",
       "L 499.850387 81.962319 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.126782 96.970696 \n",
       "L 483.126782 96.826305 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.595646 97.44324 \n",
       "L 482.595646 97.298835 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.059643 133.468734 \n",
       "L 442.059643 133.324341 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.045425 149.477904 \n",
       "L 424.045425 149.333641 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.536371 92.162438 \n",
       "L 488.536371 92.018023 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.450893 75.352752 \n",
       "L 507.450893 75.208363 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.319044 121.683514 \n",
       "L 455.319044 121.539101 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.529058 105.498169 \n",
       "L 473.529058 105.353841 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.939599 113.135184 \n",
       "L 464.939599 112.990792 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.263228 133.287735 \n",
       "L 442.263228 133.143386 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 400.972298 169.983057 \n",
       "L 400.972298 169.838647 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.812752 116.801177 \n",
       "L 460.812752 116.656787 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.134312 85.411415 \n",
       "L 496.134312 85.26791 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.260008 135.067564 \n",
       "L 440.260008 134.923178 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.113119 155.641695 \n",
       "L 417.113119 155.497286 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.233243 91.540903 \n",
       "L 489.233243 91.396518 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.104692 123.647683 \n",
       "L 453.104692 123.503293 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.2759 147.494196 \n",
       "L 426.2759 147.3498 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.460849 110.00576 \n",
       "L 468.460849 109.861423 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.492228 117.085925 \n",
       "L 460.492228 116.941505 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.450181 90.46308 \n",
       "L 490.450181 90.318785 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.352277 132.314948 \n",
       "L 443.352277 132.170601 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.514519 140.175131 \n",
       "L 434.514519 140.03072 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.66066 107.158848 \n",
       "L 471.66066 107.014549 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.356879 100.320057 \n",
       "L 479.356879 100.175687 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.908016 123.828766 \n",
       "L 452.908016 123.684398 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.015504 147.725004 \n",
       "L 426.015504 147.580621 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.64867 84.066858 \n",
       "L 497.64867 83.92257 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.304682 117.251557 \n",
       "L 460.304682 117.107201 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.832762 84.788343 \n",
       "L 496.832762 84.643933 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 513.543633 69.935447 \n",
       "L 513.543633 69.791063 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.542236 101.04203 \n",
       "L 478.542236 100.897661 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.630295 76.081068 \n",
       "L 506.630295 75.936663 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.101612 85.435235 \n",
       "L 496.101612 85.290867 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.988438 137.973536 \n",
       "L 436.988438 137.829182 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.310951 97.693018 \n",
       "L 482.310951 97.548687 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.98644 146.867898 \n",
       "L 426.98644 146.723497 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.273129 143.061674 \n",
       "L 431.273129 142.917334 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.805276 141.693196 \n",
       "L 432.805276 141.548793 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.18015 106.695933 \n",
       "L 472.18015 106.551797 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 435.020732 139.730744 \n",
       "L 435.020732 139.58641 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.970053 79.33156 \n",
       "L 502.970053 79.187175 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.060626 84.586059 \n",
       "L 497.060626 84.44164 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.047249 137.04592 \n",
       "L 438.047249 136.90163 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.055689 156.575807 \n",
       "L 416.055689 156.431432 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.681581 100.920594 \n",
       "L 478.681581 100.77619 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 512.403605 70.952115 \n",
       "L 512.403605 70.807762 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.347267 84.331791 \n",
       "L 497.347267 84.18738 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.177764 156.469086 \n",
       "L 416.177764 156.324677 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.682643 140.91961 \n",
       "L 433.682643 140.775274 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.411898 132.269891 \n",
       "L 443.411898 132.125538 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.370628 125.194696 \n",
       "L 451.370628 125.050368 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.03659 144.154089 \n",
       "L 430.03659 144.009676 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.533612 112.608974 \n",
       "L 465.533612 112.464571 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.705071 103.565621 \n",
       "L 475.705071 103.421333 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.220584 104.885613 \n",
       "L 474.220584 104.741207 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 421.432787 151.799024 \n",
       "L 421.432787 151.654647 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.923827 105.150562 \n",
       "L 473.923827 105.00619 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.19141 141.352221 \n",
       "L 433.19141 141.20785 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.280827 116.384934 \n",
       "L 461.280827 116.240629 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.198362 156.453221 \n",
       "L 416.198362 156.308809 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.767853 149.730066 \n",
       "L 423.767853 149.585673 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.918999 90.932645 \n",
       "L 489.918999 90.788238 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.224471 79.997005 \n",
       "L 502.224471 79.852602 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.554051 85.923289 \n",
       "L 495.554051 85.778874 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.652857 101.835677 \n",
       "L 477.652857 101.691344 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.591142 85.003794 \n",
       "L 496.591142 84.859392 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.934799 113.139589 \n",
       "L 464.934799 112.995192 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 414.439747 158.016421 \n",
       "L 414.439747 157.87204 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.717866 101.777444 \n",
       "L 477.717866 101.633146 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.840556 88.337474 \n",
       "L 492.840556 88.193057 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.446135 134.012449 \n",
       "L 441.446135 133.868063 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.247458 140.415522 \n",
       "L 434.247458 140.27113 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.373444 143.854515 \n",
       "L 430.373444 143.71019 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.527312 103.724166 \n",
       "L 475.527312 103.579802 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.277587 90.615427 \n",
       "L 490.277587 90.471082 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.737383 96.430064 \n",
       "L 483.737383 96.285811 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.867901 118.530587 \n",
       "L 458.867901 118.386319 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 397.641871 172.937137 \n",
       "L 397.641871 172.79275 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.184057 87.142846 \n",
       "L 494.184057 86.998464 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.134256 146.732779 \n",
       "L 427.134256 146.588376 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.807254 106.14252 \n",
       "L 472.807254 105.998121 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.502587 137.527994 \n",
       "L 437.502587 137.383772 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.947014 103.352303 \n",
       "L 475.947014 103.207907 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 405.217372 166.21188 \n",
       "L 405.217372 166.067529 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.165852 120.04212 \n",
       "L 457.165852 119.897708 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.486927 92.206657 \n",
       "L 488.486927 92.062257 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.362637 78.986827 \n",
       "L 503.362637 78.842478 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.635292 142.73651 \n",
       "L 431.635292 142.592133 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.055545 119.251941 \n",
       "L 458.055545 119.107542 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 515.102942 68.550775 \n",
       "L 515.102942 68.406388 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.856189 106.987151 \n",
       "L 471.856189 106.842775 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.658776 96.498584 \n",
       "L 483.658776 96.354186 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.23151 103.986836 \n",
       "L 475.23151 103.842466 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.341132 79.892124 \n",
       "L 502.341132 79.747712 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.840542 142.55126 \n",
       "L 431.840542 142.40684 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.367742 137.638662 \n",
       "L 437.367742 137.49429 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 399.838169 170.984764 \n",
       "L 399.838169 170.84036 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.282629 131.495739 \n",
       "L 444.282629 131.351417 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.755985 111.519392 \n",
       "L 466.755985 111.375205 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.497913 101.971797 \n",
       "L 477.497913 101.827442 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.643537 97.395789 \n",
       "L 482.643537 97.251392 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.363187 130.531298 \n",
       "L 445.363187 130.386921 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.690469 111.577463 \n",
       "L 466.690469 111.433181 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.206224 91.567749 \n",
       "L 489.206224 91.423341 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.9099 75.833667 \n",
       "L 506.9099 75.689309 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.541803 149.929498 \n",
       "L 423.541803 149.785096 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.75929 114.183404 \n",
       "L 463.75929 114.039011 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.664963 102.712519 \n",
       "L 476.664963 102.568124 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.860267 125.644686 \n",
       "L 450.860267 125.500291 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.45001 94.901893 \n",
       "L 485.45001 94.757486 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.731625 99.986026 \n",
       "L 479.731625 99.841729 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.788599 111.485221 \n",
       "L 466.788599 111.340879 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.625757 107.189793 \n",
       "L 471.625757 107.04543 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.124962 159.183266 \n",
       "L 413.124962 159.038854 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.020466 100.620776 \n",
       "L 479.020466 100.476415 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.282741 116.386919 \n",
       "L 461.282741 116.242556 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.830667 121.236347 \n",
       "L 455.830667 121.09201 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.391225 108.287952 \n",
       "L 470.391225 108.143561 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.003279 100.634894 \n",
       "L 479.003279 100.490521 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.829877 81.23332 \n",
       "L 500.829877 81.089143 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.013964 145.953651 \n",
       "L 428.013964 145.809233 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.209779 74.67736 \n",
       "L 508.209779 74.532941 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.401929 162.481807 \n",
       "L 409.401929 162.337439 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.531205 93.054367 \n",
       "L 487.531205 92.909999 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 420.050443 153.030273 \n",
       "L 420.050443 152.885873 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.101884 75.666221 \n",
       "L 507.101884 75.521859 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.269078 100.396964 \n",
       "L 479.269078 100.252616 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.725456 82.218592 \n",
       "L 499.725456 82.074183 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.132866 132.51617 \n",
       "L 443.132866 132.371781 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.744481 104.421372 \n",
       "L 474.744481 104.27701 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.156846 85.388341 \n",
       "L 496.156846 85.243986 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.559872 138.362734 \n",
       "L 436.559872 138.218431 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.259601 86.186398 \n",
       "L 495.259601 86.041999 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.37089 115.418444 \n",
       "L 462.37089 115.274032 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.788057 111.491276 \n",
       "L 466.788057 111.346871 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.226369 159.090113 \n",
       "L 413.226369 158.945715 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.991921 136.187805 \n",
       "L 438.991921 136.04373 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.418457 157.151172 \n",
       "L 415.418457 157.006793 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.140015 123.621039 \n",
       "L 453.140015 123.476623 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.161498 99.608762 \n",
       "L 480.161498 99.464365 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.430284 130.476423 \n",
       "L 445.430284 130.332044 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.312564 77.253357 \n",
       "L 505.312564 77.108975 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.841927 103.448127 \n",
       "L 475.841927 103.30384 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.999969 102.415331 \n",
       "L 476.999969 102.270931 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.736966 146.188459 \n",
       "L 427.736966 146.044109 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.243916 101.301827 \n",
       "L 478.243916 101.158189 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.496894 96.6423 \n",
       "L 483.496894 96.49806 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.09131 87.224939 \n",
       "L 494.09131 87.080524 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.777696 96.391404 \n",
       "L 483.777696 96.247 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.111497 112.982354 \n",
       "L 465.111497 112.837941 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.040732 95.274786 \n",
       "L 485.040732 95.130389 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.198305 84.461224 \n",
       "L 497.198305 84.316841 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.063626 153.908902 \n",
       "L 419.063626 153.764489 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.545457 148.143042 \n",
       "L 425.545457 147.998663 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.343445 82.558211 \n",
       "L 499.343445 82.413824 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.366242 101.196658 \n",
       "L 478.366242 101.052388 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.901773 136.274888 \n",
       "L 438.901773 136.13047 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.650898 85.83959 \n",
       "L 495.650898 85.695224 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.557858 135.690945 \n",
       "L 439.557858 135.546527 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.939097 122.021054 \n",
       "L 454.939097 121.876791 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.956394 129.113779 \n",
       "L 446.956394 128.969468 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.564879 141.919022 \n",
       "L 432.564879 141.774792 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.301714 84.372413 \n",
       "L 497.301714 84.228013 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.487591 72.65378 \n",
       "L 510.487591 72.509412 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.906635 82.057201 \n",
       "L 499.906635 81.912811 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.36131 80.764686 \n",
       "L 501.36131 80.620274 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.998326 154.84982 \n",
       "L 417.998326 154.70543 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.328148 96.792548 \n",
       "L 483.328148 96.648156 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.611067 95.651719 \n",
       "L 484.611067 95.507315 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.50645 125.961812 \n",
       "L 450.50645 125.8174 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.294398 103.037382 \n",
       "L 476.294398 102.89302 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.627517 156.072959 \n",
       "L 416.627517 155.928555 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 509.765768 73.295495 \n",
       "L 509.765768 73.151086 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.475622 116.21238 \n",
       "L 461.475622 116.067979 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.538572 96.603578 \n",
       "L 483.538572 96.459168 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.075756 131.669844 \n",
       "L 444.075756 131.525552 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.347605 109.216298 \n",
       "L 469.347605 109.071889 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.134957 113.848499 \n",
       "L 464.134957 113.704126 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.11463 131.639486 \n",
       "L 444.11463 131.495112 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 512.71478 70.673521 \n",
       "L 512.71478 70.529102 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.057783 111.251426 \n",
       "L 467.057783 111.107044 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.422777 86.041221 \n",
       "L 495.422777 85.896845 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 516.202202 67.573912 \n",
       "L 516.202202 67.429499 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.350186 128.770368 \n",
       "L 447.350186 128.626054 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 404.433737 166.906283 \n",
       "L 404.433737 166.761874 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.717604 130.215728 \n",
       "L 445.717604 130.07137 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.988513 147.758566 \n",
       "L 425.988513 147.614153 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.956404 89.125344 \n",
       "L 491.956404 88.980978 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.141259 85.407241 \n",
       "L 496.141259 85.262831 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.926921 143.355674 \n",
       "L 430.926921 143.211332 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.765355 141.730709 \n",
       "L 432.765355 141.586334 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.909732 99.826329 \n",
       "L 479.909732 99.681952 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.87853 88.301982 \n",
       "L 492.87853 88.157575 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.671494 82.266344 \n",
       "L 499.671494 82.121952 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.671415 92.04148 \n",
       "L 488.671415 91.897094 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 521.851949 62.55261 \n",
       "L 521.851949 62.408196 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.78846 92.828165 \n",
       "L 487.78846 92.683814 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.787505 74.163835 \n",
       "L 508.787505 74.019438 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.149196 132.50318 \n",
       "L 443.149196 132.358856 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.189355 128.909043 \n",
       "L 447.189355 128.764663 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.365159 92.316006 \n",
       "L 488.365159 92.17165 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.623249 142.745291 \n",
       "L 431.623249 142.600879 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.752265 89.305936 \n",
       "L 491.752265 89.161531 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.95581 120.232968 \n",
       "L 456.95581 120.088707 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.447774 82.464109 \n",
       "L 499.447774 82.319692 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.226669 157.323817 \n",
       "L 415.226669 157.179429 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.142898 149.396108 \n",
       "L 424.142898 149.251708 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.377235 72.749429 \n",
       "L 510.377235 72.605034 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.675702 93.814063 \n",
       "L 486.675702 93.66968 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.040033 94.381129 \n",
       "L 486.040033 94.236751 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.686692 75.14322 \n",
       "L 507.686692 74.99884 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 403.095868 168.09373 \n",
       "L 403.095868 167.949316 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.465452 117.997179 \n",
       "L 459.465452 117.85279 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.119998 72.981418 \n",
       "L 510.119998 72.837005 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.185625 96.91929 \n",
       "L 483.185625 96.774883 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.555661 117.917949 \n",
       "L 459.555661 117.773541 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.17282 74.712072 \n",
       "L 508.17282 74.567683 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.776362 77.728884 \n",
       "L 504.776362 77.584506 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.962899 74.896148 \n",
       "L 507.962899 74.751738 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.278197 69.282208 \n",
       "L 514.278197 69.137844 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.268996 107.511602 \n",
       "L 471.268996 107.367208 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.730755 94.656378 \n",
       "L 485.730755 94.511973 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 519.660917 64.501212 \n",
       "L 519.660917 64.356798 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.086092 131.665761 \n",
       "L 444.086092 131.52136 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.466838 109.110172 \n",
       "L 469.466838 108.96575 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.306957 104.811454 \n",
       "L 474.306957 104.667091 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.914209 110.491851 \n",
       "L 467.914209 110.347478 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.317477 105.688227 \n",
       "L 473.317477 105.543902 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.116388 150.302904 \n",
       "L 423.116388 150.15851 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.983926 100.651611 \n",
       "L 478.983926 100.507241 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.914528 105.155933 \n",
       "L 473.914528 105.011651 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 515.418781 68.269568 \n",
       "L 515.418781 68.125218 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.208631 83.566138 \n",
       "L 498.208631 83.421721 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.011704 83.740762 \n",
       "L 498.011704 83.59635 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.362245 78.985096 \n",
       "L 503.362245 78.840753 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.321371 86.129609 \n",
       "L 495.321371 85.985317 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.839558 99.887861 \n",
       "L 479.839558 99.743482 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.388608 78.961855 \n",
       "L 503.388608 78.817441 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.543665 123.261386 \n",
       "L 453.543665 123.11701 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.506533 93.077102 \n",
       "L 487.506533 92.932762 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.404619 90.502452 \n",
       "L 490.404619 90.358036 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.314438 135.022903 \n",
       "L 440.314438 134.878534 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.665821 109.826824 \n",
       "L 468.665821 109.682694 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.744475 133.752756 \n",
       "L 441.744475 133.608367 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 407.112034 164.531131 \n",
       "L 407.112034 164.386733 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.652881 153.383483 \n",
       "L 419.652881 153.239066 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.948182 122.015873 \n",
       "L 454.948182 121.871495 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.14 119.177468 \n",
       "L 458.14 119.033148 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.984794 118.426945 \n",
       "L 458.984794 118.28256 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.280174 102.165873 \n",
       "L 477.280174 102.021467 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.769451 149.726373 \n",
       "L 423.769451 149.581962 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 403.560429 167.685827 \n",
       "L 403.560429 167.541462 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.626799 133.854276 \n",
       "L 441.626799 133.709882 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.779485 146.163432 \n",
       "L 427.779485 146.019098 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.002793 94.415415 \n",
       "L 486.002793 94.271051 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.969145 118.437041 \n",
       "L 458.969145 118.29267 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.816678 138.127398 \n",
       "L 436.816678 137.98303 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.341243 110.11073 \n",
       "L 468.341243 109.966325 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 518.939104 65.142358 \n",
       "L 518.939104 64.997961 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.341468 88.781553 \n",
       "L 492.341468 88.637162 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.490029 110.867315 \n",
       "L 467.490029 110.722913 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.090449 120.996207 \n",
       "L 456.090449 120.85182 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.628232 110.744515 \n",
       "L 467.628232 110.60012 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.424686 96.700464 \n",
       "L 483.424686 96.556095 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.403766 111.831981 \n",
       "L 466.403766 111.687568 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.397351 99.393497 \n",
       "L 480.397351 99.249129 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.971238 85.556174 \n",
       "L 495.971238 85.411821 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.286223 83.495564 \n",
       "L 498.286223 83.351221 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.428386 118.029429 \n",
       "L 459.428386 117.885129 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.885834 84.741627 \n",
       "L 496.885834 84.597213 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.222917 153.763631 \n",
       "L 419.222917 153.619215 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.848585 108.773045 \n",
       "L 469.848585 108.628743 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.509108 136.624146 \n",
       "L 438.509108 136.47976 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.729776 117.762099 \n",
       "L 459.729776 117.617714 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.506041 79.750443 \n",
       "L 502.506041 79.6062 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.355473 114.542627 \n",
       "L 463.355473 114.398226 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.181424 121.805124 \n",
       "L 455.181424 121.660722 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.633555 153.403681 \n",
       "L 419.633555 153.259277 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.205602 120.006813 \n",
       "L 457.205602 119.862414 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.315908 129.685456 \n",
       "L 446.315908 129.541054 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.248187 107.528926 \n",
       "L 471.248187 107.384606 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.572563 129.455527 \n",
       "L 446.572563 129.311123 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.55441 127.69158 \n",
       "L 448.55441 127.547277 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.326995 110.123641 \n",
       "L 468.326995 109.979231 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.173241 150.260639 \n",
       "L 423.173241 150.116287 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.542844 122.374543 \n",
       "L 454.542844 122.230142 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.189737 95.13623 \n",
       "L 485.189737 94.991886 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 513.713391 69.788313 \n",
       "L 513.713391 69.643938 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.016472 91.735958 \n",
       "L 489.016472 91.591544 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.455743 92.237022 \n",
       "L 488.455743 92.09274 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.973396 88.222309 \n",
       "L 492.973396 88.077957 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.547332 113.480765 \n",
       "L 464.547332 113.336366 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.126264 126.300697 \n",
       "L 450.126264 126.156342 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.284246 79.943684 \n",
       "L 502.284246 79.799282 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.917817 136.259638 \n",
       "L 438.917817 136.115292 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.351326 105.660023 \n",
       "L 473.351326 105.515698 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.442407 75.359895 \n",
       "L 507.442407 75.215492 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.298267 119.036824 \n",
       "L 458.298267 118.892411 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.908065 91.831238 \n",
       "L 488.908065 91.68689 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.610211 90.318895 \n",
       "L 490.610211 90.174482 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.004779 102.40897 \n",
       "L 477.004779 102.264613 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.027192 78.395675 \n",
       "L 504.027192 78.25126 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.544533 81.490266 \n",
       "L 500.544533 81.345842 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.603885 92.99445 \n",
       "L 487.603885 92.850225 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.018844 114.8414 \n",
       "L 463.018844 114.697068 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.756303 112.405589 \n",
       "L 465.756303 112.261253 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.222566 106.666295 \n",
       "L 472.222566 106.521976 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.856918 114.984978 \n",
       "L 462.856918 114.840556 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.605379 86.763788 \n",
       "L 494.605379 86.61944 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.065813 131.685246 \n",
       "L 444.065813 131.540848 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.842429 86.557979 \n",
       "L 494.842429 86.413562 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.282244 99.498234 \n",
       "L 480.282244 99.35381 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.856016 81.212686 \n",
       "L 500.856016 81.068275 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.332976 75.457469 \n",
       "L 507.332976 75.313052 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.001504 155.738632 \n",
       "L 417.001504 155.594235 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.239428 99.536237 \n",
       "L 480.239428 99.391873 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.654498 116.054213 \n",
       "L 461.654498 115.90981 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.662524 133.829666 \n",
       "L 441.662524 133.685303 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.024468 90.841378 \n",
       "L 490.024468 90.696972 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.309187 87.919471 \n",
       "L 493.309187 87.77511 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.884275 100.738445 \n",
       "L 478.884275 100.594099 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.819604 91.02357 \n",
       "L 489.819604 90.879223 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.311468 76.365632 \n",
       "L 506.311468 76.221291 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.269881 100.39703 \n",
       "L 479.269881 100.252645 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.040702 127.263893 \n",
       "L 449.040702 127.119493 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.578474 98.346004 \n",
       "L 481.578474 98.201634 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.527506 141.053546 \n",
       "L 433.527506 140.909153 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.628353 89.414723 \n",
       "L 491.628353 89.270375 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.660086 114.270187 \n",
       "L 463.660086 114.125772 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.88571 111.403405 \n",
       "L 466.88571 111.259173 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.564415 114.35721 \n",
       "L 463.564415 114.212819 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.31413 95.912166 \n",
       "L 484.31413 95.767806 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 511.477737 71.77055 \n",
       "L 511.477737 71.626166 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.479457 86.881385 \n",
       "L 494.479457 86.736963 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.860231 102.539295 \n",
       "L 476.860231 102.394927 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.983907 103.321182 \n",
       "L 475.983907 103.17679 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.719232 108.887765 \n",
       "L 469.719232 108.74341 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.78454 99.940512 \n",
       "L 479.78454 99.796169 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.26744 102.177741 \n",
       "L 477.26744 102.033367 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.397818 91.39684 \n",
       "L 489.397818 91.252441 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.937196 93.584555 \n",
       "L 486.937196 93.440164 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.983862 156.645654 \n",
       "L 415.983862 156.501257 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.089341 125.443097 \n",
       "L 451.089341 125.298713 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 410.002998 161.952722 \n",
       "L 410.002998 161.808367 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.77821 102.612813 \n",
       "L 476.77821 102.468424 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.449793 94.905944 \n",
       "L 485.449793 94.761597 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.621336 89.425187 \n",
       "L 491.621336 89.280943 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.755302 102.633563 \n",
       "L 476.755302 102.489174 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.158356 125.383172 \n",
       "L 451.158356 125.238764 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.006627 99.743813 \n",
       "L 480.006627 99.599405 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 420.607738 152.530329 \n",
       "L 420.607738 152.385986 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.182783 128.030755 \n",
       "L 448.182783 127.886416 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.043658 75.715657 \n",
       "L 507.043658 75.571307 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.241214 115.533396 \n",
       "L 462.241214 115.389012 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.631641 79.635885 \n",
       "L 502.631641 79.491481 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.216398 148.436587 \n",
       "L 425.216398 148.292191 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.906861 120.271044 \n",
       "L 456.906861 120.126745 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.422564 94.041476 \n",
       "L 486.422564 93.897062 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.825106 106.126112 \n",
       "L 472.825106 105.981776 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 512.118401 71.202728 \n",
       "L 512.118401 71.05839 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 404.663438 166.703061 \n",
       "L 404.663438 166.55864 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.354314 122.542875 \n",
       "L 454.354314 122.398495 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.417904 92.267801 \n",
       "L 488.417904 92.123389 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.290765 108.377711 \n",
       "L 470.290765 108.233295 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.968919 108.662804 \n",
       "L 469.968919 108.518605 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.494307 146.415672 \n",
       "L 427.494307 146.271346 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.680685 93.811924 \n",
       "L 486.680685 93.667522 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.399987 93.170588 \n",
       "L 487.399987 93.026188 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.009608 78.412051 \n",
       "L 504.009608 78.267706 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.84817 149.661545 \n",
       "L 423.84817 149.517187 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.9086 122.938113 \n",
       "L 453.9086 122.793694 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.697338 148.899517 \n",
       "L 424.697338 148.755128 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.226077 81.771527 \n",
       "L 500.226077 81.627113 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.546194 111.707492 \n",
       "L 466.546194 111.56314 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.713209 103.55595 \n",
       "L 475.713209 103.411767 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.367089 143.858904 \n",
       "L 430.367089 143.714515 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.053763 81.923312 \n",
       "L 500.053763 81.778969 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.153798 93.39022 \n",
       "L 487.153798 93.245824 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.481903 127.76047 \n",
       "L 448.481903 127.616066 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.352456 107.434048 \n",
       "L 471.352456 107.289656 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.317283 86.141607 \n",
       "L 495.317283 85.997257 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.045033 113.927703 \n",
       "L 464.045033 113.783305 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.35503 126.984853 \n",
       "L 449.35503 126.840474 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.82859 124.783111 \n",
       "L 451.82859 124.638721 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.474253 116.214195 \n",
       "L 461.474253 116.069786 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.853433 82.995006 \n",
       "L 498.853433 82.850598 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.026292 92.616257 \n",
       "L 488.026292 92.471864 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.964361 112.224327 \n",
       "L 465.964361 112.079932 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.819024 109.687456 \n",
       "L 468.819024 109.543056 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.173123 149.366321 \n",
       "L 424.173123 149.221961 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.55597 103.698962 \n",
       "L 475.55597 103.554561 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.63995 138.28481 \n",
       "L 436.63995 138.140387 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.677726 99.1473 \n",
       "L 480.677726 99.002892 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.363883 150.083836 \n",
       "L 423.363883 149.939412 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.640673 108.068427 \n",
       "L 470.640673 107.924034 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.529331 146.378405 \n",
       "L 427.529331 146.234032 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 523.920028 60.715602 \n",
       "L 523.920028 60.571182 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.10979 162.75247 \n",
       "L 409.10979 162.608061 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.07824 151.224868 \n",
       "L 422.07824 151.080465 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.181779 120.030632 \n",
       "L 457.181779 119.886246 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.199533 93.349473 \n",
       "L 487.199533 93.205098 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.28895 79.943122 \n",
       "L 502.28895 79.798793 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.268388 98.621928 \n",
       "L 481.268388 98.477547 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.38612 112.73351 \n",
       "L 465.38612 112.589113 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.932193 126.471762 \n",
       "L 449.932193 126.327346 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.439537 85.139201 \n",
       "L 496.439537 84.995 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.432095 107.363214 \n",
       "L 471.432095 107.218801 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.298961 154.605063 \n",
       "L 418.298961 154.460705 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.549766 120.588011 \n",
       "L 456.549766 120.44362 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.042723 83.713657 \n",
       "L 498.042723 83.569242 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.622892 90.305523 \n",
       "L 490.622892 90.16113 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.998754 137.080411 \n",
       "L 437.998754 136.936031 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.484592 91.318352 \n",
       "L 489.484592 91.173959 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.845079 143.435745 \n",
       "L 430.845079 143.291344 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.460405 100.230085 \n",
       "L 479.460405 100.085706 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.511672 110.847282 \n",
       "L 467.511672 110.70307 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.355463 126.984267 \n",
       "L 449.355463 126.839869 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.506597 85.079031 \n",
       "L 496.506597 84.934641 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 517.528458 66.396872 \n",
       "L 517.528458 66.252466 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 516.42667 67.375075 \n",
       "L 516.42667 67.230658 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.613136 106.312125 \n",
       "L 472.613136 106.167755 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.654007 105.387514 \n",
       "L 473.654007 105.243113 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.741603 72.427607 \n",
       "L 510.741603 72.283252 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.519709 153.496669 \n",
       "L 419.519709 153.352304 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.393102 99.401203 \n",
       "L 480.393102 99.256846 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.40962 133.160711 \n",
       "L 442.40962 133.016321 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.981672 73.991761 \n",
       "L 508.981672 73.847345 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.337367 87.895451 \n",
       "L 493.337367 87.751119 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.017376 113.064477 \n",
       "L 465.017376 112.920077 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.962902 82.895517 \n",
       "L 498.962902 82.751153 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.61783 156.969036 \n",
       "L 415.61783 156.824615 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.999606 101.526062 \n",
       "L 477.999606 101.381661 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.748854 107.971115 \n",
       "L 470.748854 107.826702 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.09107 101.445031 \n",
       "L 478.09107 101.300632 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 516.303409 67.485563 \n",
       "L 516.303409 67.341159 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.108554 92.541577 \n",
       "L 488.108554 92.397235 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.417142 93.155538 \n",
       "L 487.417142 93.011256 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.621659 109.861817 \n",
       "L 468.621659 109.717423 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 396.939092 173.573097 \n",
       "L 396.939092 173.428688 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.460841 133.113064 \n",
       "L 442.460841 132.968679 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.41205 93.162229 \n",
       "L 487.41205 93.017935 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.853821 83.883 \n",
       "L 497.853821 83.738617 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.172613 96.928431 \n",
       "L 483.172613 96.784163 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.40034 119.831466 \n",
       "L 457.40034 119.687069 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.185671 101.361972 \n",
       "L 478.185671 101.217602 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.192848 103.129181 \n",
       "L 476.192848 102.985021 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.970777 112.218404 \n",
       "L 465.970777 112.073995 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.118455 116.5277 \n",
       "L 461.118455 116.383342 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.597016 89.445795 \n",
       "L 491.597016 89.301398 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.480006 132.206591 \n",
       "L 443.480006 132.062221 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.899966 77.618431 \n",
       "L 504.899966 77.47405 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.715685 155.993194 \n",
       "L 416.715685 155.848775 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.411098 154.486533 \n",
       "L 418.411098 154.342143 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.397944 111.840551 \n",
       "L 466.397944 111.696195 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.063456 117.466723 \n",
       "L 460.063456 117.322475 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.821304 109.684984 \n",
       "L 468.821304 109.54065 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.96236 155.766132 \n",
       "L 416.96236 155.621757 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.130713 98.744835 \n",
       "L 481.130713 98.600474 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.497372 145.526619 \n",
       "L 428.497372 145.382209 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.013659 108.625095 \n",
       "L 470.013659 108.480727 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.847061 89.219462 \n",
       "L 491.847061 89.075059 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.739779 91.094423 \n",
       "L 489.739779 90.950031 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.751272 78.640822 \n",
       "L 503.751272 78.496463 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 401.344143 169.644417 \n",
       "L 401.344143 169.500043 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.554163 128.5874 \n",
       "L 447.554163 128.443032 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.252814 109.299357 \n",
       "L 469.252814 109.154962 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.779715 123.940048 \n",
       "L 452.779715 123.795632 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.239832 79.983233 \n",
       "L 502.239832 79.838821 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.901142 138.061914 \n",
       "L 436.901142 137.917636 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.118644 108.531464 \n",
       "L 470.118644 108.387112 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.065979 105.02613 \n",
       "L 474.065979 104.881979 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.225741 144.877025 \n",
       "L 429.225741 144.732609 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 518.406468 65.6163 \n",
       "L 518.406468 65.471877 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.310027 91.474489 \n",
       "L 489.310027 91.330118 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.729954 103.543385 \n",
       "L 475.729954 103.398986 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 513.156044 70.283087 \n",
       "L 513.156044 70.138687 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 400.570421 170.348305 \n",
       "L 400.570421 170.203915 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.266598 151.066052 \n",
       "L 422.266598 150.921652 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.826103 147.89789 \n",
       "L 425.826103 147.753486 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.649677 78.730525 \n",
       "L 503.649677 78.586139 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.345541 114.547703 \n",
       "L 463.345541 114.403481 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.657008 92.05478 \n",
       "L 488.657008 91.910368 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.508864 81.522513 \n",
       "L 500.508864 81.378123 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.98571 131.75666 \n",
       "L 443.98571 131.61227 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.933688 124.692995 \n",
       "L 451.933688 124.54859 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.549504 105.481295 \n",
       "L 473.549504 105.336934 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.570996 159.676193 \n",
       "L 412.570996 159.53179 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.693213 108.019783 \n",
       "L 470.693213 107.875385 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.609623 112.538311 \n",
       "L 465.609623 112.394098 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.870861 148.778719 \n",
       "L 424.870861 148.635008 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.629511 96.52498 \n",
       "L 483.629511 96.380602 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.98104 128.203039 \n",
       "L 447.98104 128.05865 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.022431 84.620839 \n",
       "L 497.022431 84.476442 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.319561 86.135088 \n",
       "L 495.319561 85.990702 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.262322 140.401911 \n",
       "L 434.262322 140.257521 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.710077 84.897792 \n",
       "L 496.710077 84.753376 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.268523 93.289169 \n",
       "L 487.268523 93.144761 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.865231 122.977337 \n",
       "L 453.865231 122.832947 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.850468 139.874732 \n",
       "L 434.850468 139.730353 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.883417 90.9634 \n",
       "L 489.883417 90.818993 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 524.977021 59.775759 \n",
       "L 524.977021 59.631344 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.630181 124.075609 \n",
       "L 452.630181 123.931212 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.406169 76.280786 \n",
       "L 506.406169 76.136373 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.107251 79.211507 \n",
       "L 503.107251 79.0671 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 435.215383 139.550527 \n",
       "L 435.215383 139.406112 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.467419 134.87693 \n",
       "L 440.467419 134.732704 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.829007 127.454791 \n",
       "L 448.829007 127.310387 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.113986 90.760604 \n",
       "L 490.113986 90.616338 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.637892 140.063566 \n",
       "L 434.637892 139.919156 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.37187 88.752403 \n",
       "L 492.37187 88.607994 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.035821 88.164611 \n",
       "L 493.035821 88.020199 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.247131 81.754241 \n",
       "L 500.247131 81.609831 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.947077 119.348001 \n",
       "L 457.947077 119.203624 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 435.039359 139.709451 \n",
       "L 435.039359 139.565043 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.238839 95.092127 \n",
       "L 485.238839 94.947773 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.285556 97.71657 \n",
       "L 482.285556 97.572178 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.388235 144.733641 \n",
       "L 429.388235 144.589229 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.063344 74.806843 \n",
       "L 508.063344 74.662444 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.353484 104.768045 \n",
       "L 474.353484 104.62365 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 402.693333 168.45627 \n",
       "L 402.693333 168.31186 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.21295 78.227329 \n",
       "L 504.21295 78.082946 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.43788 100.248658 \n",
       "L 479.43788 100.104238 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.453044 105.56771 \n",
       "L 473.453044 105.423306 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.212214 82.674119 \n",
       "L 499.212214 82.529702 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.398822 89.619099 \n",
       "L 491.398822 89.47475 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.396632 120.723129 \n",
       "L 456.396632 120.578759 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.396779 158.950017 \n",
       "L 413.396779 158.805625 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.415994 109.154618 \n",
       "L 469.415994 109.010244 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.331651 82.569669 \n",
       "L 499.331651 82.425351 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.870996 100.759846 \n",
       "L 478.870996 100.616401 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.773995 89.284126 \n",
       "L 491.773995 89.139757 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.353049 110.989976 \n",
       "L 467.353049 110.845604 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.344305 92.336659 \n",
       "L 488.344305 92.192427 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.070665 98.797535 \n",
       "L 481.070665 98.653131 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.104434 107.655724 \n",
       "L 471.104434 107.511461 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.266317 111.953673 \n",
       "L 466.266317 111.80927 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.309379 86.141515 \n",
       "L 495.309379 85.997137 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.120969 98.755239 \n",
       "L 481.120969 98.610992 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.952199 98.011829 \n",
       "L 481.952199 97.867433 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.219905 83.556582 \n",
       "L 498.219905 83.412173 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.025899 83.730468 \n",
       "L 498.025899 83.586061 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.20944 106.672601 \n",
       "L 472.20944 106.528223 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.55309 121.47456 \n",
       "L 455.55309 121.330232 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.296849 85.264959 \n",
       "L 496.296849 85.120552 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.721232 97.330241 \n",
       "L 482.721232 97.18588 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.388448 82.51749 \n",
       "L 499.388448 82.373087 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.767899 120.393312 \n",
       "L 456.767899 120.248953 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.950519 111.345462 \n",
       "L 466.950519 111.201065 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.75244 83.083012 \n",
       "L 498.75244 82.938595 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 519.396776 64.735954 \n",
       "L 519.396776 64.591546 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.852017 79.437936 \n",
       "L 502.852017 79.293799 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.33014 104.788332 \n",
       "L 474.33014 104.643951 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.478469 91.323932 \n",
       "L 489.478469 91.179579 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.246383 69.312087 \n",
       "L 514.246383 69.167677 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.625642 117.854933 \n",
       "L 459.625642 117.710629 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.308166 128.791574 \n",
       "L 447.308166 128.647555 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.768035 131.950238 \n",
       "L 443.768035 131.805859 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.732292 105.313518 \n",
       "L 473.732292 105.1692 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 513.266939 70.183031 \n",
       "L 513.266939 70.038618 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.080152 97.89972 \n",
       "L 482.080152 97.7553 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.671373 124.040178 \n",
       "L 452.671373 123.895794 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.163478 140.481065 \n",
       "L 434.163478 140.336694 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 513.972915 69.557288 \n",
       "L 513.972915 69.412914 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.63357 101.848694 \n",
       "L 477.63357 101.704331 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.871835 82.092481 \n",
       "L 499.871835 81.948213 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.25995 91.518585 \n",
       "L 489.25995 91.374216 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.014338 141.505316 \n",
       "L 433.014338 141.360972 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.721769 96.440842 \n",
       "L 483.721769 96.296464 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.725756 156.872751 \n",
       "L 415.725756 156.728344 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.849463 117.661476 \n",
       "L 459.849463 117.517131 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.699522 119.565743 \n",
       "L 457.699522 119.421435 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.748162 114.195157 \n",
       "L 463.748162 114.050763 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.109121 96.986067 \n",
       "L 483.109121 96.841689 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.178968 96.92081 \n",
       "L 483.178968 96.776415 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.428662 121.588585 \n",
       "L 455.428662 121.444251 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.956794 111.344655 \n",
       "L 466.956794 111.200333 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.881526 78.524909 \n",
       "L 503.881526 78.380504 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.506472 121.519142 \n",
       "L 455.506472 121.374743 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.162926 102.270564 \n",
       "L 477.162926 102.126154 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.651648 96.496549 \n",
       "L 483.651648 96.352323 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.808865 103.470004 \n",
       "L 475.808865 103.325833 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.627297 145.406612 \n",
       "L 428.627297 145.262226 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 526.780627 58.172399 \n",
       "L 526.780627 58.027994 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 404.21258 167.103479 \n",
       "L 404.21258 166.95906 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.956364 113.119132 \n",
       "L 464.956364 112.974912 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.912926 92.717857 \n",
       "L 487.912926 92.573561 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.750151 148.852651 \n",
       "L 424.750151 148.708241 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.567877 83.247158 \n",
       "L 498.567877 83.102745 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 511.879103 71.415924 \n",
       "L 511.879103 71.271533 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.219549 132.435225 \n",
       "L 443.219549 132.290895 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.348096 104.772553 \n",
       "L 474.348096 104.628159 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.582097 137.447984 \n",
       "L 437.582097 137.303572 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.338376 100.339044 \n",
       "L 479.338376 100.194734 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.867571 103.421882 \n",
       "L 475.867571 103.277491 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.706053 116.007831 \n",
       "L 461.706053 115.863425 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 400.508367 170.393344 \n",
       "L 400.508367 170.248965 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.309659 87.921521 \n",
       "L 493.309659 87.777254 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.427505 122.476358 \n",
       "L 454.427505 122.332032 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.573416 120.570566 \n",
       "L 456.573416 120.426158 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.397217 80.733107 \n",
       "L 501.397217 80.58869 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.083594 111.227835 \n",
       "L 467.083594 111.08342 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.932043 144.244464 \n",
       "L 429.932043 144.100107 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 414.135712 158.28783 \n",
       "L 414.135712 158.143424 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.65008 90.283783 \n",
       "L 490.65008 90.139389 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.875433 92.751624 \n",
       "L 487.875433 92.607297 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.866256 90.981313 \n",
       "L 489.866256 90.836938 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.723771 121.324104 \n",
       "L 455.723771 121.179719 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.138479 122.732505 \n",
       "L 454.138479 122.588096 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.76757 106.177201 \n",
       "L 472.76757 106.032786 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.796616 97.262472 \n",
       "L 482.796616 97.118125 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.771208 107.060522 \n",
       "L 471.771208 106.916172 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.956345 103.341969 \n",
       "L 475.956345 103.197558 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.175991 134.256922 \n",
       "L 441.175991 134.112526 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.88646 107.849138 \n",
       "L 470.88646 107.704752 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.38031 88.741923 \n",
       "L 492.38031 88.597562 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.116945 88.091077 \n",
       "L 493.116945 87.946664 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.27051 103.065136 \n",
       "L 476.27051 102.920784 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.368922 86.089566 \n",
       "L 495.368922 85.945152 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.509006 153.510027 \n",
       "L 419.509006 153.365616 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.031276 115.720684 \n",
       "L 462.031276 115.576276 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.53792 149.039789 \n",
       "L 424.53792 148.895392 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.247182 113.746763 \n",
       "L 464.247182 113.602405 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.292806 75.493644 \n",
       "L 507.292806 75.349226 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.845935 98.99696 \n",
       "L 480.845935 98.852594 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.844651 84.775118 \n",
       "L 496.844651 84.630735 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 522.118877 62.31563 \n",
       "L 522.118877 62.171231 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.758035 134.62436 \n",
       "L 440.758035 134.480054 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.083463 97.007973 \n",
       "L 483.083463 96.863603 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 512.746832 70.643771 \n",
       "L 512.746832 70.499432 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.256175 111.074243 \n",
       "L 467.256175 110.929831 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.924476 101.592837 \n",
       "L 477.924476 101.448441 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.366826 159.857818 \n",
       "L 412.366826 159.713401 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.24498 79.091511 \n",
       "L 503.24498 78.947144 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.047472 69.486598 \n",
       "L 514.047472 69.34223 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_31\">\n",
       "    <g clip-path=\"url(#p86e636b471)\">\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"484.193407\" y=\"95.948829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.45961\" y=\"109.046642\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.678936\" y=\"148.849636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.567321\" y=\"108.948776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"439.628328\" y=\"135.559385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.036918\" y=\"99.645411\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.713046\" y=\"107.928802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"514.831413\" y=\"68.720872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"511.040335\" y=\"72.089947\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.575609\" y=\"105.391579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.427434\" y=\"92.184606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.013479\" y=\"83.667594\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"439.14226\" y=\"135.996138\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.301868\" y=\"132.294266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"445.315459\" y=\"130.503365\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.166663\" y=\"109.303926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.2494\" y=\"87.013053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.472766\" y=\"141.033494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.107532\" y=\"160.017501\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"513.26327\" y=\"70.107569\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.436864\" y=\"86.846137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"505.138029\" y=\"77.333972\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"408.211424\" y=\"163.468051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.180978\" y=\"103.960046\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.328338\" y=\"79.831778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"444.401074\" y=\"131.318624\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.179155\" y=\"127.957522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"505.542235\" y=\"76.975231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.698674\" y=\"94.611254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.398037\" y=\"113.545017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.785786\" y=\"74.982361\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.428047\" y=\"128.625866\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.428596\" y=\"108.183006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"446.378634\" y=\"129.55822\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.752352\" y=\"92.786184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.232669\" y=\"108.358984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"404.651056\" y=\"166.645211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.06699\" y=\"92.50853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.745931\" y=\"146.120888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"524.315348\" y=\"60.291566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"450.19644\" y=\"126.169849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.678486\" y=\"83.076704\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.712641\" y=\"119.478396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.652032\" y=\"107.097181\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"405.475777\" y=\"165.905541\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.562386\" y=\"84.957891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.638405\" y=\"93.774936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.474941\" y=\"86.812035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.666178\" y=\"96.420165\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.270031\" y=\"147.427688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.011097\" y=\"106.776973\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.164352\" y=\"116.419294\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.21429\" y=\"103.928888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.061551\" y=\"102.288953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.829002\" y=\"106.051753\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.839648\" y=\"110.483298\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.371271\" y=\"127.784608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.968413\" y=\"89.039387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.233787\" y=\"159.903249\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.288639\" y=\"133.192543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.757708\" y=\"146.995279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"440.027896\" y=\"135.202429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.975818\" y=\"113.029641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.149569\" y=\"95.098343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.643354\" y=\"83.998957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.454705\" y=\"141.043877\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.462866\" y=\"124.148948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.646865\" y=\"149.761248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.403326\" y=\"140.199069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"484.220186\" y=\"95.929801\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.295908\" y=\"149.182679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.307467\" y=\"86.070797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.943108\" y=\"143.273964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.91998\" y=\"85.530424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.826863\" y=\"93.608946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.299619\" y=\"110.076006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.277411\" y=\"150.089386\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.613742\" y=\"140.012348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.207943\" y=\"103.936407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.528499\" y=\"82.319717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.510567\" y=\"119.663514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.661022\" y=\"93.755683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.520945\" y=\"119.652579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.596718\" y=\"83.149236\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.688453\" y=\"94.618221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"435.634207\" y=\"139.106973\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.707725\" y=\"96.38226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.22557\" y=\"86.145542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.239678\" y=\"115.462558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"415.925745\" y=\"156.612635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.246667\" y=\"114.564369\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.934685\" y=\"94.404685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.724049\" y=\"96.366902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"428.609299\" y=\"145.354073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.260574\" y=\"86.110162\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"422.211234\" y=\"151.033582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.848758\" y=\"98.03642\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.524811\" y=\"119.642155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.05801\" y=\"102.292266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.911457\" y=\"110.422198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.788404\" y=\"87.42103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"510.808467\" y=\"72.296181\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.44384\" y=\"113.503253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.759874\" y=\"147.893574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"445.840364\" y=\"130.031971\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.230781\" y=\"156.35442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.903153\" y=\"89.986387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"435.871523\" y=\"138.895139\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"484.111059\" y=\"96.024472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.48912\" y=\"119.683139\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"413.898115\" y=\"158.422824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.070002\" y=\"94.27765\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.899606\" y=\"116.652616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.31882\" y=\"107.389946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.281495\" y=\"103.871968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.936463\" y=\"112.175406\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.014757\" y=\"79.222067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.834955\" y=\"109.601192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.31087\" y=\"153.619078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"517.034304\" y=\"66.763549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"501.064044\" y=\"80.958907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.265762\" y=\"102.107893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.70831\" y=\"97.270165\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.153312\" y=\"116.427278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.47884\" y=\"118.802984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.828604\" y=\"119.380841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"505.796509\" y=\"76.749906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"421.638849\" y=\"151.549823\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.130589\" y=\"159.998776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.899022\" y=\"121.097621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.57432\" y=\"114.275344\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.797568\" y=\"85.63658\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"508.507987\" y=\"74.339244\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.699837\" y=\"124.827557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.205151\" y=\"84.386347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.340255\" y=\"133.148854\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"406.320809\" y=\"165.152374\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.051111\" y=\"88.963445\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.846141\" y=\"114.032019\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.372114\" y=\"102.010932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.883097\" y=\"149.551251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.356022\" y=\"101.137988\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.783629\" y=\"101.647103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.45508\" y=\"138.378655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.962603\" y=\"89.933894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.356797\" y=\"87.806217\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.104891\" y=\"109.361803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.226234\" y=\"118.138973\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.590589\" y=\"92.930051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"506.715817\" y=\"75.929827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.082439\" y=\"144.038372\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"439.397714\" y=\"135.76254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.767267\" y=\"82.999938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"514.42919\" y=\"69.077791\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"439.249946\" y=\"135.889318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.810495\" y=\"148.727681\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.563837\" y=\"105.398814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.101194\" y=\"119.142665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.611452\" y=\"75.138136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.641263\" y=\"82.221852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.281183\" y=\"146.536345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.253819\" y=\"119.885963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.196925\" y=\"143.939654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"506.82073\" y=\"75.845319\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.146037\" y=\"156.432442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.293133\" y=\"150.081992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.244217\" y=\"75.463515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.770869\" y=\"105.212951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.38169\" y=\"147.329962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.790067\" y=\"113.193904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.770604\" y=\"102.550284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.693073\" y=\"98.171818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"449.443528\" y=\"126.831697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.362034\" y=\"128.686437\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.022178\" y=\"84.544585\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.566688\" y=\"106.28171\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"527.554689\" y=\"57.414734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"429.690408\" y=\"144.390773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.397644\" y=\"83.325304\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.895645\" y=\"106.881995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.649546\" y=\"89.32315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.165063\" y=\"156.407092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.277295\" y=\"103.875321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.230009\" y=\"104.804078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.907517\" y=\"74.874893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.195218\" y=\"136.836512\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.277784\" y=\"107.432566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.318209\" y=\"118.057972\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.518323\" y=\"98.326276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.285279\" y=\"105.646577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.47028\" y=\"114.366659\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.574167\" y=\"102.72122\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"445.613188\" y=\"130.236622\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.193551\" y=\"108.391773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.567654\" y=\"119.61569\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.600362\" y=\"148.911123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"422.099229\" y=\"151.133005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.078436\" y=\"103.161623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"428.056515\" y=\"145.837716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"512.920995\" y=\"70.418995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.075001\" y=\"103.165568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.277776\" y=\"154.5308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.484045\" y=\"138.348841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"446.564749\" y=\"129.387466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.921013\" y=\"103.301084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.475695\" y=\"97.480228\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"414.209002\" y=\"158.142966\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.979105\" y=\"110.365328\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"429.84976\" y=\"144.246084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.284386\" y=\"127.86453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.454781\" y=\"133.04534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.082658\" y=\"97.825389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.284365\" y=\"106.530413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.209845\" y=\"109.265743\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.654424\" y=\"99.096527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"408.097237\" y=\"163.577129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.095413\" y=\"128.917869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.965472\" y=\"84.59925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"422.219747\" y=\"151.020266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.966174\" y=\"128.147836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.267651\" y=\"118.100909\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.572646\" y=\"84.054683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.670985\" y=\"107.967799\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.336034\" y=\"92.265982\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.83966\" y=\"105.15192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.347452\" y=\"136.696057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.50787\" y=\"87.670108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"406.342683\" y=\"165.135473\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.24927\" y=\"120.785761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.417995\" y=\"91.305912\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.760918\" y=\"94.555584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.289635\" y=\"78.976667\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.605624\" y=\"148.019651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.50164\" y=\"154.330915\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.858452\" y=\"90.917082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.910419\" y=\"86.426238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.754366\" y=\"128.336637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"431.481097\" y=\"142.796781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.25979\" y=\"89.669593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"428.554637\" y=\"145.40322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.265468\" y=\"81.667844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.987637\" y=\"92.577557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.666637\" y=\"114.189802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.955776\" y=\"111.26747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.494798\" y=\"118.787951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.174197\" y=\"136.848432\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.412202\" y=\"109.97984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.270387\" y=\"105.656422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.117231\" y=\"114.681608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.124102\" y=\"141.33702\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.109271\" y=\"95.135293\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.852935\" y=\"93.586169\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.746179\" y=\"94.570014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.40678\" y=\"88.649907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"437.045287\" y=\"137.855992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.90562\" y=\"91.760277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.426232\" y=\"117.072682\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.062565\" y=\"160.05746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.359032\" y=\"94.914242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.344642\" y=\"105.592651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.216467\" y=\"103.040994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.163432\" y=\"113.749902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.163807\" y=\"113.751777\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"413.357947\" y=\"158.906135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.886489\" y=\"86.445476\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.080815\" y=\"118.269037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"515.522985\" y=\"68.106716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.280397\" y=\"103.875721\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.880372\" y=\"74.897719\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.720836\" y=\"154.135025\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.357825\" y=\"115.354914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.503573\" y=\"101.895481\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.324763\" y=\"86.945231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.596959\" y=\"100.031875\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.134554\" y=\"147.549814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.955656\" y=\"123.71088\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"511.02274\" y=\"72.106064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.434261\" y=\"82.405284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.335322\" y=\"127.82159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.374461\" y=\"102.009332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.896055\" y=\"121.101175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"432.512156\" y=\"141.880614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.449604\" y=\"79.726377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.377588\" y=\"154.438574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.650612\" y=\"106.208815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.697721\" y=\"105.2809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.852131\" y=\"148.685078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.841976\" y=\"127.368936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"505.389838\" y=\"77.11261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.527804\" y=\"118.760214\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.716155\" y=\"96.374905\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"400.855729\" y=\"170.005891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.067575\" y=\"128.94606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.338203\" y=\"86.044953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"421.425548\" y=\"151.734813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"409.59229\" y=\"162.222725\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.153853\" y=\"159.973621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.456749\" y=\"120.601097\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"518.192751\" y=\"65.733503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.149734\" y=\"94.213116\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.817745\" y=\"88.285242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.840686\" y=\"154.031679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.873719\" y=\"119.342785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.641362\" y=\"113.326793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.880546\" y=\"117.558176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.67066\" y=\"100.857458\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.611618\" y=\"100.024169\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.656102\" y=\"98.205302\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"450.508377\" y=\"125.88821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.695356\" y=\"148.829226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.261311\" y=\"116.330317\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.321421\" y=\"113.611797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"441.039483\" y=\"134.302253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.239881\" y=\"102.126343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"450.837962\" y=\"125.597063\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"429.762884\" y=\"144.322969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.455369\" y=\"149.931507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.46407\" y=\"125.039039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.20599\" y=\"116.379826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.552677\" y=\"83.187666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.403506\" y=\"112.651669\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"432.967148\" y=\"141.481229\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.35309\" y=\"118.026357\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.101759\" y=\"122.691209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.138583\" y=\"83.55758\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.434158\" y=\"143.72936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.78485\" y=\"121.195777\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"501.100494\" y=\"80.923558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.262879\" y=\"103.001425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.850014\" y=\"116.699335\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.510585\" y=\"113.441682\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"519.892048\" y=\"64.219865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"509.31418\" y=\"73.62337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.876276\" y=\"115.783892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.857904\" y=\"122.020842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"409.362741\" y=\"162.436173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.684053\" y=\"115.064174\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.210812\" y=\"87.047584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.87552\" y=\"86.456532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.794125\" y=\"124.742826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.642166\" y=\"79.553136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.187104\" y=\"100.396659\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.927101\" y=\"74.85663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"509.808548\" y=\"73.182207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.591\" y=\"104.485202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.222419\" y=\"93.257287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.189763\" y=\"124.396838\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.88077\" y=\"106.005946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.10293\" y=\"108.47284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"437.515028\" y=\"137.433373\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.519503\" y=\"84.106041\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.18796\" y=\"138.615082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.189678\" y=\"105.727255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.678907\" y=\"147.956322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.285538\" y=\"110.086426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"520.491771\" y=\"63.687499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.837187\" y=\"127.374191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.47628\" y=\"127.694754\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.902164\" y=\"124.651193\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.218576\" y=\"84.372979\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"504.879285\" y=\"77.568495\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.347056\" y=\"115.366938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.635222\" y=\"124.885804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"417.57727\" y=\"155.157159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.850387\" y=\"82.03447\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.126782\" y=\"96.8985\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.595646\" y=\"97.371037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.059643\" y=\"133.396538\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.045425\" y=\"149.405773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.536371\" y=\"92.090231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.450893\" y=\"75.280558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.319044\" y=\"121.611308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.529058\" y=\"105.426005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.939599\" y=\"113.062988\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.263228\" y=\"133.21556\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"400.972298\" y=\"169.910852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.812752\" y=\"116.728982\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.134312\" y=\"85.339662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"440.260008\" y=\"134.995371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"417.113119\" y=\"155.56949\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.233243\" y=\"91.468711\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"453.104692\" y=\"123.575488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.2759\" y=\"147.421998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.460849\" y=\"109.933591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.492228\" y=\"117.013715\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.450181\" y=\"90.390933\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.352277\" y=\"132.242774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.514519\" y=\"140.102925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.66066\" y=\"107.086699\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.356879\" y=\"100.247872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.908016\" y=\"123.756582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.015504\" y=\"147.652812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.64867\" y=\"83.994714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.304682\" y=\"117.179379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.832762\" y=\"84.716138\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"513.543633\" y=\"69.863255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.542236\" y=\"100.969845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"506.630295\" y=\"76.008865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.101612\" y=\"85.363051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.988438\" y=\"137.901359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.310951\" y=\"97.620852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"426.98644\" y=\"146.795697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"431.273129\" y=\"142.989504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"432.805276\" y=\"141.620995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.18015\" y=\"106.623865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"435.020732\" y=\"139.658577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.970053\" y=\"79.259368\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.060626\" y=\"84.51385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.047249\" y=\"136.973775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.055689\" y=\"156.50362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.681581\" y=\"100.848392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"512.403605\" y=\"70.879938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.347267\" y=\"84.259585\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.177764\" y=\"156.396882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.682643\" y=\"140.847442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.411898\" y=\"132.197714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.370628\" y=\"125.122532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.03659\" y=\"144.081882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.533612\" y=\"112.536772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.705071\" y=\"103.493477\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.220584\" y=\"104.81341\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"421.432787\" y=\"151.726836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.923827\" y=\"105.078376\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.19141\" y=\"141.280035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.280827\" y=\"116.312782\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.198362\" y=\"156.381015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.767853\" y=\"149.657869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.918999\" y=\"90.860442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.224471\" y=\"79.924804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.554051\" y=\"85.851082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.652857\" y=\"101.763511\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.591142\" y=\"84.931593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.934799\" y=\"113.06739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"414.439747\" y=\"157.94423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.717866\" y=\"101.705295\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.840556\" y=\"88.265266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"441.446135\" y=\"133.940256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.247458\" y=\"140.343326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.373444\" y=\"143.782353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.527312\" y=\"103.651984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.277587\" y=\"90.543254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.737383\" y=\"96.357937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.867901\" y=\"118.458453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"397.641871\" y=\"172.864944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.184057\" y=\"87.070655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.134256\" y=\"146.660577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.807254\" y=\"106.07032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"437.502587\" y=\"137.455883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.947014\" y=\"103.280105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"405.217372\" y=\"166.139704\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.165852\" y=\"119.969914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.486927\" y=\"92.134457\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.362637\" y=\"78.914653\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"431.635292\" y=\"142.664321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.055545\" y=\"119.179742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"515.102942\" y=\"68.478582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.856189\" y=\"106.914963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.658776\" y=\"96.426385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.23151\" y=\"103.914651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.341132\" y=\"79.819918\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"431.840542\" y=\"142.47905\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"437.367742\" y=\"137.566476\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"399.838169\" y=\"170.912562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"444.282629\" y=\"131.423578\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.755985\" y=\"111.447299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.497913\" y=\"101.899619\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.643537\" y=\"97.32359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"445.363187\" y=\"130.45911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.690469\" y=\"111.505322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.206224\" y=\"91.495545\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"506.9099\" y=\"75.761488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.541803\" y=\"149.857297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.75929\" y=\"114.111207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.664963\" y=\"102.640322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"450.860267\" y=\"125.572489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.45001\" y=\"94.82969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.731625\" y=\"99.913878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.788599\" y=\"111.41305\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.625757\" y=\"107.117611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"413.124962\" y=\"159.11106\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.020466\" y=\"100.548596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.282741\" y=\"116.314737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.830667\" y=\"121.164179\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.391225\" y=\"108.215757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.003279\" y=\"100.562707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.829877\" y=\"81.161231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"428.013964\" y=\"145.881442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"508.209779\" y=\"74.60515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"409.401929\" y=\"162.409623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.531205\" y=\"92.982183\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"420.050443\" y=\"152.958073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.101884\" y=\"75.59404\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.269078\" y=\"100.32479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.725456\" y=\"82.146387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.132866\" y=\"132.443976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.744481\" y=\"104.349191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.156846\" y=\"85.316163\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.559872\" y=\"138.290582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.259601\" y=\"86.114199\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.37089\" y=\"115.346238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.788057\" y=\"111.419074\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"413.226369\" y=\"159.017914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.991921\" y=\"136.115767\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"415.418457\" y=\"157.078983\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"453.140015\" y=\"123.548831\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.161498\" y=\"99.536564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"445.430284\" y=\"130.404233\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"505.312564\" y=\"77.181166\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.841927\" y=\"103.375984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.999969\" y=\"102.343131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.736966\" y=\"146.116284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.243916\" y=\"101.230008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.496894\" y=\"96.57018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.09131\" y=\"87.152731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.777696\" y=\"96.319202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.111497\" y=\"112.910148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.040732\" y=\"95.202587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.198305\" y=\"84.389032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.063626\" y=\"153.836695\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.545457\" y=\"148.070853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.343445\" y=\"82.486018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.366242\" y=\"101.124523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.901773\" y=\"136.202679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.650898\" y=\"85.767407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"439.557858\" y=\"135.618736\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.939097\" y=\"121.948922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"446.956394\" y=\"129.041623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"432.564879\" y=\"141.846907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.301714\" y=\"84.300213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"510.487591\" y=\"72.581596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.906635\" y=\"81.985006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"501.36131\" y=\"80.69248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"417.998326\" y=\"154.777625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.328148\" y=\"96.720352\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"484.611067\" y=\"95.579517\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"450.50645\" y=\"125.889606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.294398\" y=\"102.965201\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.627517\" y=\"156.000757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"509.765768\" y=\"73.223291\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.475622\" y=\"116.140179\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.538572\" y=\"96.531373\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"444.075756\" y=\"131.597698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.347605\" y=\"109.144093\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.134957\" y=\"113.776313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"444.11463\" y=\"131.567299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"512.71478\" y=\"70.601312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.057783\" y=\"111.179235\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.422777\" y=\"85.969033\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"516.202202\" y=\"67.501706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.350186\" y=\"128.698211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"404.433737\" y=\"166.834079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"445.717604\" y=\"130.143549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.988513\" y=\"147.68636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.956404\" y=\"89.053161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.141259\" y=\"85.335036\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.926921\" y=\"143.283503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"432.765355\" y=\"141.658522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.909732\" y=\"99.754141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.87853\" y=\"88.229779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.671494\" y=\"82.194148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.671415\" y=\"91.969287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"521.851949\" y=\"62.480403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.78846\" y=\"92.755989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"508.787505\" y=\"74.091637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.149196\" y=\"132.431018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.189355\" y=\"128.836853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.365159\" y=\"92.243828\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"431.623249\" y=\"142.673085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.752265\" y=\"89.233734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.95581\" y=\"120.160837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.447774\" y=\"82.391901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"415.226669\" y=\"157.251623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.142898\" y=\"149.323908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"510.377235\" y=\"72.677232\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.675702\" y=\"93.741871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.040033\" y=\"94.30894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.686692\" y=\"75.07103\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"403.095868\" y=\"168.021523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.465452\" y=\"117.924984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"510.119998\" y=\"72.909211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.185625\" y=\"96.847086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.555661\" y=\"117.845745\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"508.17282\" y=\"74.639878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"504.776362\" y=\"77.656695\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.962899\" y=\"74.823943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"514.278197\" y=\"69.210026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.268996\" y=\"107.439405\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.730755\" y=\"94.584175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"519.660917\" y=\"64.429005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"444.086092\" y=\"131.59356\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.466838\" y=\"109.037961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.306957\" y=\"104.739272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.914209\" y=\"110.419665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.317477\" y=\"105.616064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.116388\" y=\"150.230707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.983926\" y=\"100.579426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.914528\" y=\"105.083792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"515.418781\" y=\"68.197393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.208631\" y=\"83.49393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.011704\" y=\"83.668556\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.362245\" y=\"78.912925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.321371\" y=\"86.057463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.839558\" y=\"99.815672\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.388608\" y=\"78.889648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"453.543665\" y=\"123.189198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.506533\" y=\"93.004932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.404619\" y=\"90.430244\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"440.314438\" y=\"134.950718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.665821\" y=\"109.754759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"441.744475\" y=\"133.680562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"407.112034\" y=\"164.458932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.652881\" y=\"153.311275\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.948182\" y=\"121.943684\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.14\" y=\"119.105308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.984794\" y=\"118.354752\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.280174\" y=\"102.09367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.769451\" y=\"149.654168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"403.560429\" y=\"167.613644\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"441.626799\" y=\"133.782079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.779485\" y=\"146.091265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.002793\" y=\"94.343233\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.969145\" y=\"118.364855\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.816678\" y=\"138.055214\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.341243\" y=\"110.038528\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"518.939104\" y=\"65.070159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.341468\" y=\"88.709357\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.490029\" y=\"110.795114\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.090449\" y=\"120.924013\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.628232\" y=\"110.672318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.424686\" y=\"96.628279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.403766\" y=\"111.759774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.397351\" y=\"99.321313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.971238\" y=\"85.483997\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.286223\" y=\"83.423392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.428386\" y=\"117.957279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.885834\" y=\"84.66942\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.222917\" y=\"153.691423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.848585\" y=\"108.700894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.509108\" y=\"136.551953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.729776\" y=\"117.689906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.506041\" y=\"79.678321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.355473\" y=\"114.470426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.181424\" y=\"121.732923\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.633555\" y=\"153.331479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.205602\" y=\"119.934614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"446.315908\" y=\"129.613255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.248187\" y=\"107.456766\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"446.572563\" y=\"129.383325\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.55441\" y=\"127.619428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.326995\" y=\"110.051436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.173241\" y=\"150.188463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.542844\" y=\"122.302343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.189737\" y=\"95.064058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"513.713391\" y=\"69.716125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.016472\" y=\"91.663751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.455743\" y=\"92.164881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.973396\" y=\"88.150133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.547332\" y=\"113.408565\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"450.126264\" y=\"126.22852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.284246\" y=\"79.871483\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"438.917817\" y=\"136.187465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.351326\" y=\"105.587861\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.442407\" y=\"75.287693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"458.298267\" y=\"118.964617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.908065\" y=\"91.759064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.610211\" y=\"90.246688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.004779\" y=\"102.336792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"504.027192\" y=\"78.323467\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.544533\" y=\"81.418054\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.603885\" y=\"92.922338\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.018844\" y=\"114.769234\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.756303\" y=\"112.333421\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.222566\" y=\"106.594136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.856918\" y=\"114.912767\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.605379\" y=\"86.691614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"444.065813\" y=\"131.613047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.842429\" y=\"86.48577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.282244\" y=\"99.426022\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.856016\" y=\"81.14048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.332976\" y=\"75.38526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"417.001504\" y=\"155.666433\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.239428\" y=\"99.464055\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.654498\" y=\"115.982012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"441.662524\" y=\"133.757484\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.024468\" y=\"90.769175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.309187\" y=\"87.847291\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.884275\" y=\"100.666272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.819604\" y=\"90.951396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"506.311468\" y=\"76.293462\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.269881\" y=\"100.324837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"449.040702\" y=\"127.191693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.578474\" y=\"98.273819\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.527506\" y=\"140.98135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.628353\" y=\"89.342549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.660086\" y=\"114.19798\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.88571\" y=\"111.331289\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.564415\" y=\"114.285015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"484.31413\" y=\"95.839986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"511.477737\" y=\"71.698358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"494.479457\" y=\"86.809174\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.860231\" y=\"102.467111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.983907\" y=\"103.248986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.719232\" y=\"108.815588\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.78454\" y=\"99.86834\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.26744\" y=\"102.105554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.397818\" y=\"91.32464\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.937196\" y=\"93.512359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"415.983862\" y=\"156.573456\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.089341\" y=\"125.370905\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"410.002998\" y=\"161.880544\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.77821\" y=\"102.540618\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.449793\" y=\"94.833771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.621336\" y=\"89.353065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.755302\" y=\"102.561368\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.158356\" y=\"125.310968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.006627\" y=\"99.671609\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"420.607738\" y=\"152.458158\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.182783\" y=\"127.958586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.043658\" y=\"75.643482\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.241214\" y=\"115.461204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.631641\" y=\"79.563683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.216398\" y=\"148.364389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.906861\" y=\"120.198894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.422564\" y=\"93.969269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.825106\" y=\"106.053944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"512.118401\" y=\"71.130559\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"404.663438\" y=\"166.63085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.354314\" y=\"122.470685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.417904\" y=\"92.195595\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.290765\" y=\"108.305503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.968919\" y=\"108.590705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.494307\" y=\"146.343509\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"486.680685\" y=\"93.739723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.399987\" y=\"93.098388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"504.009608\" y=\"78.339878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.84817\" y=\"149.589366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"453.9086\" y=\"122.865903\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.697338\" y=\"148.827323\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.226077\" y=\"81.69932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.546194\" y=\"111.635316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.713209\" y=\"103.483858\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.367089\" y=\"143.786709\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.053763\" y=\"81.85114\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.153798\" y=\"93.318022\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.481903\" y=\"127.688268\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.352456\" y=\"107.361852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.317283\" y=\"86.069432\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.045033\" y=\"113.855504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"449.35503\" y=\"126.912663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.82859\" y=\"124.710916\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.474253\" y=\"116.14199\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.853433\" y=\"82.922802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.026292\" y=\"92.54406\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.964361\" y=\"112.15213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.819024\" y=\"109.615256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.173123\" y=\"149.294141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.55597\" y=\"103.626762\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.63995\" y=\"138.212599\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.677726\" y=\"99.075096\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"423.363883\" y=\"150.011624\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.640673\" y=\"107.99623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"427.529331\" y=\"146.306218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"523.920028\" y=\"60.643392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"409.10979\" y=\"162.680265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"422.07824\" y=\"151.152666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.181779\" y=\"119.958439\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.199533\" y=\"93.277285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.28895\" y=\"79.870957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.268388\" y=\"98.549738\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.38612\" y=\"112.661311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"449.932193\" y=\"126.399554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.439537\" y=\"85.067101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.432095\" y=\"107.291008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.298961\" y=\"154.532884\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.549766\" y=\"120.515815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.042723\" y=\"83.64145\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.622892\" y=\"90.233327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"437.998754\" y=\"137.008221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.484592\" y=\"91.246156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"430.845079\" y=\"143.363545\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.460405\" y=\"100.157895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.511672\" y=\"110.775176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"449.355463\" y=\"126.912068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.506597\" y=\"85.006836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"517.528458\" y=\"66.324669\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"516.42667\" y=\"67.302867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.613136\" y=\"106.23994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.654007\" y=\"105.315313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"510.741603\" y=\"72.355429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.519709\" y=\"153.424487\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.393102\" y=\"99.329024\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.40962\" y=\"133.088516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"508.981672\" y=\"73.919553\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.337367\" y=\"87.823285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.017376\" y=\"112.992277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.962902\" y=\"82.823335\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"415.61783\" y=\"156.896825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.999606\" y=\"101.453862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.748854\" y=\"107.898909\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.09107\" y=\"101.372831\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"516.303409\" y=\"67.413361\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.108554\" y=\"92.469406\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.417142\" y=\"93.083397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.621659\" y=\"109.78962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"396.939092\" y=\"173.500892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"442.460841\" y=\"133.040871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.41205\" y=\"93.090082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.853821\" y=\"83.810809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.172613\" y=\"96.856297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.40034\" y=\"119.759267\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.185671\" y=\"101.289787\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.192848\" y=\"103.057101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.970777\" y=\"112.146199\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.118455\" y=\"116.455521\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.597016\" y=\"89.373596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.480006\" y=\"132.134406\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"504.899966\" y=\"77.546241\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.715685\" y=\"155.920984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"418.411098\" y=\"154.414338\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.397944\" y=\"111.768373\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"460.063456\" y=\"117.394599\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"468.821304\" y=\"109.612817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"416.96236\" y=\"155.693945\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.130713\" y=\"98.672654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"428.497372\" y=\"145.454414\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.013659\" y=\"108.552911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.847061\" y=\"89.147261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.739779\" y=\"91.022227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.751272\" y=\"78.568643\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"401.344143\" y=\"169.57223\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.554163\" y=\"128.515216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.252814\" y=\"109.22716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.779715\" y=\"123.86784\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.239832\" y=\"79.911027\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"436.901142\" y=\"137.989775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.118644\" y=\"108.459288\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.065979\" y=\"104.954054\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"429.225741\" y=\"144.804817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"518.406468\" y=\"65.544089\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.310027\" y=\"91.402303\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.729954\" y=\"103.471185\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"513.156044\" y=\"70.210887\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"400.570421\" y=\"170.27611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"422.266598\" y=\"150.993852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"425.826103\" y=\"147.825688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.649677\" y=\"78.658332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.345541\" y=\"114.475592\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.657008\" y=\"91.982574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.508864\" y=\"81.450318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.98571\" y=\"131.684465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"451.933688\" y=\"124.620793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.549504\" y=\"105.409115\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.570996\" y=\"159.603992\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.693213\" y=\"107.947584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"465.609623\" y=\"112.466204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.870861\" y=\"148.706864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.629511\" y=\"96.452791\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.98104\" y=\"128.130844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"497.022431\" y=\"84.54864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.319561\" y=\"86.062895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.262322\" y=\"140.329716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.710077\" y=\"84.825584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.268523\" y=\"93.216965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"453.865231\" y=\"122.905142\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.850468\" y=\"139.802542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.883417\" y=\"90.891197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"524.977021\" y=\"59.703552\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.630181\" y=\"124.003411\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"506.406169\" y=\"76.208579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.107251\" y=\"79.139304\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"435.215383\" y=\"139.478319\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"440.467419\" y=\"134.804817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"448.829007\" y=\"127.382589\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.113986\" y=\"90.688471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.637892\" y=\"139.991361\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.37187\" y=\"88.680198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.035821\" y=\"88.092405\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"500.247131\" y=\"81.682036\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.947077\" y=\"119.275812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"435.039359\" y=\"139.637247\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"485.238839\" y=\"95.01995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.285556\" y=\"97.644374\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"429.388235\" y=\"144.661435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"508.063344\" y=\"74.734643\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.353484\" y=\"104.695847\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"402.693333\" y=\"168.384065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"504.21295\" y=\"78.155137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.43788\" y=\"100.176448\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.453044\" y=\"105.495508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.212214\" y=\"82.601911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.398822\" y=\"89.546925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.396632\" y=\"120.650944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"413.396779\" y=\"158.877821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"469.415994\" y=\"109.082431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.331651\" y=\"82.49751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"478.870996\" y=\"100.688123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"491.773995\" y=\"89.211941\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.353049\" y=\"110.91779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"488.344305\" y=\"92.264543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.070665\" y=\"98.725333\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.104434\" y=\"107.583592\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.266317\" y=\"111.881472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.309379\" y=\"86.069326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.120969\" y=\"98.683116\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"481.952199\" y=\"97.939631\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.219905\" y=\"83.484378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.025899\" y=\"83.658264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.20944\" y=\"106.600412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.55309\" y=\"121.402396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.296849\" y=\"85.192756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.721232\" y=\"97.258061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.388448\" y=\"82.445288\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.767899\" y=\"120.321133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.950519\" y=\"111.273264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.75244\" y=\"83.010803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"519.396776\" y=\"64.66375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"502.852017\" y=\"79.365867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.33014\" y=\"104.716141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.478469\" y=\"91.251755\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"514.246383\" y=\"69.239882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.625642\" y=\"117.782781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"447.308166\" y=\"128.719564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.768035\" y=\"131.878048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"473.732292\" y=\"105.241359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"513.266939\" y=\"70.110825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.080152\" y=\"97.82751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"452.671373\" y=\"123.967986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"434.163478\" y=\"140.408879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"513.972915\" y=\"69.485101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.63357\" y=\"101.776513\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"499.871835\" y=\"82.020347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.25995\" y=\"91.446401\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"433.014338\" y=\"141.433144\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.721769\" y=\"96.368653\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"415.725756\" y=\"156.800548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"459.849463\" y=\"117.589303\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"457.699522\" y=\"119.493589\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"463.748162\" y=\"114.12296\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.109121\" y=\"96.913878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.178968\" y=\"96.848613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.428662\" y=\"121.516418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"466.956794\" y=\"111.272494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.881526\" y=\"78.452706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.506472\" y=\"121.446943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.162926\" y=\"102.198359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.651648\" y=\"96.424436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.808865\" y=\"103.397919\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"428.627297\" y=\"145.334419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"526.780627\" y=\"58.100197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"404.21258\" y=\"167.031269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.956364\" y=\"113.047022\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.912926\" y=\"92.645709\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.750151\" y=\"148.780446\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"498.567877\" y=\"83.174952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"511.879103\" y=\"71.343729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"443.219549\" y=\"132.36306\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"474.348096\" y=\"104.700356\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"437.582097\" y=\"137.375778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"479.338376\" y=\"100.266889\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.867571\" y=\"103.349686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"461.706053\" y=\"115.935628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"400.508367\" y=\"170.321155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.309659\" y=\"87.849387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.427505\" y=\"122.404195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"456.573416\" y=\"120.498362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"501.397217\" y=\"80.660899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.083594\" y=\"111.155627\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"429.932043\" y=\"144.172285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"414.135712\" y=\"158.215627\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"490.65008\" y=\"90.211586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"487.875433\" y=\"92.67946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"489.866256\" y=\"90.909125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"455.723771\" y=\"121.251911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"454.138479\" y=\"122.660301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"472.76757\" y=\"106.104994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"482.796616\" y=\"97.190298\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"471.771208\" y=\"106.988347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"475.956345\" y=\"103.269763\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"441.175991\" y=\"134.184724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"470.88646\" y=\"107.776945\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"492.38031\" y=\"88.669742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"493.116945\" y=\"88.018871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"476.27051\" y=\"102.99296\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"495.368922\" y=\"86.017359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"419.509006\" y=\"153.437821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"462.031276\" y=\"115.64848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"424.53792\" y=\"148.967591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"464.247182\" y=\"113.674584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"507.292806\" y=\"75.421435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"480.845935\" y=\"98.924777\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"496.844651\" y=\"84.702926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"522.118877\" y=\"62.243431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"440.758035\" y=\"134.552207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"483.083463\" y=\"96.935788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"512.746832\" y=\"70.571602\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"467.256175\" y=\"111.002037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"477.924476\" y=\"101.520639\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"412.366826\" y=\"159.78561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"503.24498\" y=\"79.019327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"514.047472\" y=\"69.414414\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 390.408313 162.185075 \n",
       "L 390.408313 60.435702 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 409.66731 179.384625 \n",
       "L 524.153149 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_33\">\n",
       "    <!-- RMSE: 0.000 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(397.59217 64.316362) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_34\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(400.617891 45.531) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_32\">\n",
       "    <path d=\"M 484.193407 95.949952 \n",
       "L 404.651056 166.643275 \n",
       "L 527.554689 57.412581 \n",
       "L 512.920995 70.418287 \n",
       "\" clip-path=\"url(#p86e636b471)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 562.786844 179.384625 \n",
       "L 706.464 179.384625 \n",
       "L 706.464 51.531 \n",
       "L 562.786844 51.531 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"574.397392\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(569.380704 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_34\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"637.941041\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_36\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(635.494228 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me850bab295\" x=\"701.484689\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_37\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(699.037877 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"562.786844\" y=\"168.981956\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_38\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(544.453469 172.131393) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_19\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"562.786844\" y=\"140.746617\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(544.453469 143.896055) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_20\">\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"562.786844\" y=\"112.511278\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_40\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(549.593219 115.660716) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_21\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"562.786844\" y=\"84.27594\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_41\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(549.593219 87.425377) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_22\">\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbcbf912d53\" x=\"562.786844\" y=\"56.040601\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_42\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(549.593219 59.190039) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_4\">\n",
       "    <path d=\"M 617.537943 130.72016 \n",
       "L 617.537943 130.560641 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.5567 120.926523 \n",
       "L 628.5567 120.766569 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.361652 106.883658 \n",
       "L 644.361652 106.723683 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.253415 72.334487 \n",
       "L 683.253415 72.17451 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.272681 130.962265 \n",
       "L 617.272681 130.802247 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.567848 83.594538 \n",
       "L 670.567848 83.434472 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.825538 116.243684 \n",
       "L 633.825538 116.083615 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.078686 130.258593 \n",
       "L 618.078686 130.09879 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.039033 100.948598 \n",
       "L 651.039033 100.788492 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.292013 93.628343 \n",
       "L 659.292013 93.468754 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.312298 101.584186 \n",
       "L 650.312298 101.424958 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.387488 112.207659 \n",
       "L 638.387488 112.047732 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.27077 141.612643 \n",
       "L 605.27077 141.456563 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.339711 112.233727 \n",
       "L 638.339711 112.073962 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.51803 119.197156 \n",
       "L 630.51803 119.038006 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.595022 95.123332 \n",
       "L 657.595022 94.963296 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.284994 128.288722 \n",
       "L 620.284994 128.128678 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.381088 96.215854 \n",
       "L 656.381088 96.056932 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.547838 144.041318 \n",
       "L 602.547838 143.88109 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.370703 96.223663 \n",
       "L 656.370703 96.064946 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.940632 122.358988 \n",
       "L 626.940632 122.198932 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.812032 105.59432 \n",
       "L 645.812032 105.43454 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.581994 113.816808 \n",
       "L 636.581994 113.657344 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.675586 87.074326 \n",
       "L 666.675586 86.914789 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.050998 93.827201 \n",
       "L 659.050998 93.667414 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.660293 95.94831 \n",
       "L 656.660293 95.789015 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.950807 149.0202 \n",
       "L 596.950807 148.860025 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.628053 97.760567 \n",
       "L 654.628053 97.601684 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.01393 116.116778 \n",
       "L 634.01393 115.958956 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.344774 74.021325 \n",
       "L 681.344774 73.861693 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.56333 90.701363 \n",
       "L 662.56333 90.541215 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.304559 135.374358 \n",
       "L 612.304559 135.214142 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.885223 74.420627 \n",
       "L 680.885223 74.260569 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.379373 163.747954 \n",
       "L 580.379373 163.587736 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.196942 129.244285 \n",
       "L 619.196942 129.0844 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.314146 130.928055 \n",
       "L 617.314146 130.768034 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.318453 81.17685 \n",
       "L 673.318453 81.017034 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 692.577617 64.043182 \n",
       "L 692.577617 63.882969 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.367381 104.205728 \n",
       "L 647.367381 104.045964 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.114363 107.968913 \n",
       "L 643.114363 107.80893 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.563897 111.118563 \n",
       "L 639.563897 110.960177 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.83997 159.78502 \n",
       "L 584.83997 159.624784 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.145189 110.615011 \n",
       "L 640.145189 110.457602 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.97945 102.7716 \n",
       "L 648.97945 102.611735 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.931395 119.712127 \n",
       "L 629.931395 119.551948 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.78536 135.83837 \n",
       "L 611.78536 135.678354 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.260157 98.095207 \n",
       "L 654.260157 97.935303 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.478016 140.547977 \n",
       "L 606.478016 140.388025 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.305963 148.704161 \n",
       "L 597.305963 148.544055 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 579.701991 164.340998 \n",
       "L 579.701991 164.180998 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.357361 145.992643 \n",
       "L 600.357361 145.832513 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 687.457328 68.588742 \n",
       "L 687.457328 68.428813 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.629773 71.093122 \n",
       "L 684.629773 70.933015 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.938389 137.470112 \n",
       "L 609.938389 137.310141 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 698.666527 58.625322 \n",
       "L 698.666527 58.465189 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.541142 103.156606 \n",
       "L 648.541142 102.998376 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.247655 89.215284 \n",
       "L 664.247655 89.055257 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.458821 120.109807 \n",
       "L 629.458821 119.950306 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.474836 161.885217 \n",
       "L 582.474836 161.724983 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.707682 64.803531 \n",
       "L 691.707682 64.643276 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.505147 117.41865 \n",
       "L 632.505147 117.258423 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.553189 142.264253 \n",
       "L 604.553189 142.104179 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.599632 87.128099 \n",
       "L 666.599632 86.967966 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 694.228756 62.556098 \n",
       "L 694.228756 62.395954 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.191323 98.166673 \n",
       "L 654.191323 98.007553 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.825194 144.679324 \n",
       "L 601.825194 144.520181 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.57524 122.687938 \n",
       "L 626.57524 122.528224 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.37091 161.099808 \n",
       "L 583.37091 160.939737 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.144781 153.282755 \n",
       "L 592.144781 153.122496 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.382629 97.979688 \n",
       "L 654.382629 97.820654 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.622035 74.658953 \n",
       "L 680.622035 74.49892 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.999681 130.293039 \n",
       "L 617.999681 130.133855 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.465258 93.441608 \n",
       "L 659.465258 93.282083 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.194612 107.934898 \n",
       "L 643.194612 107.775608 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.679248 159.921356 \n",
       "L 584.679248 159.761143 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.488746 139.680981 \n",
       "L 607.488746 139.521126 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.808958 150.032663 \n",
       "L 595.808958 149.872858 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.515472 157.398658 \n",
       "L 587.515472 157.238645 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.239355 67.00976 \n",
       "L 689.239355 66.849659 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.603487 111.999642 \n",
       "L 638.603487 111.839479 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.295495 148.708511 \n",
       "L 597.295495 148.548437 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.651103 103.941499 \n",
       "L 647.651103 103.782191 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.614043 100.438714 \n",
       "L 651.614043 100.278851 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.478704 156.551211 \n",
       "L 588.478704 156.390985 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.805829 96.704164 \n",
       "L 655.805829 96.544511 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.56543 144.919573 \n",
       "L 601.56543 144.759394 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.988969 149.876817 \n",
       "L 595.988969 149.716793 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.315962 152.252039 \n",
       "L 593.315962 152.091923 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.331548 99.809599 \n",
       "L 652.331548 99.649995 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.468771 132.574924 \n",
       "L 615.468771 132.415601 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.269584 69.648397 \n",
       "L 686.269584 69.4889 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.691304 83.493212 \n",
       "L 670.691304 83.333079 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.388589 88.198254 \n",
       "L 665.388589 88.038013 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.916423 90.389089 \n",
       "L 662.916423 90.229545 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.964161 128.534387 \n",
       "L 619.964161 128.375285 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.054349 131.161602 \n",
       "L 617.054349 131.002801 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.860638 107.374129 \n",
       "L 643.860638 107.214367 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.72197 126.10044 \n",
       "L 622.72197 125.942039 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.238219 110.559155 \n",
       "L 640.238219 110.399657 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.381892 100.646505 \n",
       "L 651.381892 100.486503 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.665753 140.378923 \n",
       "L 606.665753 140.219165 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.522307 81.857751 \n",
       "L 672.522307 81.697594 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.407946 72.184939 \n",
       "L 683.407946 72.024666 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.631252 113.769606 \n",
       "L 636.631252 113.610868 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.552729 127.157185 \n",
       "L 621.552729 126.997305 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.894682 143.745721 \n",
       "L 602.894682 143.585539 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.518108 135.19641 \n",
       "L 612.518108 135.037132 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.694311 72.812732 \n",
       "L 682.694311 72.652493 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.445156 122.805524 \n",
       "L 626.445156 122.645306 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.846202 163.316142 \n",
       "L 580.846202 163.156285 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.616453 133.329812 \n",
       "L 614.616453 133.170006 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.270417 92.727298 \n",
       "L 660.270417 92.568436 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.107757 116.009036 \n",
       "L 634.107757 115.849091 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.826374 143.838208 \n",
       "L 602.826374 143.680054 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.01837 108.082254 \n",
       "L 643.01837 107.922008 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.232947 127.467713 \n",
       "L 621.232947 127.30821 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.735795 88.753301 \n",
       "L 664.735795 88.59353 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.386912 122.859473 \n",
       "L 626.386912 122.69945 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.027333 152.500859 \n",
       "L 593.027333 152.341033 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.889549 103.747818 \n",
       "L 647.889549 103.58775 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.228696 89.229315 \n",
       "L 664.228696 89.069252 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 687.949227 68.152915 \n",
       "L 687.949227 67.992707 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.036919 97.402229 \n",
       "L 655.036919 97.242124 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.027159 76.073469 \n",
       "L 679.027159 75.913515 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.905394 148.163924 \n",
       "L 597.905394 148.00393 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.236413 74.088703 \n",
       "L 681.236413 73.929469 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.654133 103.970432 \n",
       "L 647.654133 103.810386 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.682079 157.25758 \n",
       "L 587.682079 157.097488 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.669714 131.50464 \n",
       "L 616.669714 131.344935 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.343031 75.790416 \n",
       "L 679.343031 75.630631 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.982106 141.002817 \n",
       "L 605.982106 140.842754 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.795768 150.935729 \n",
       "L 594.795768 150.775573 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.498613 112.09044 \n",
       "L 638.498613 111.931163 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.148027 140.847319 \n",
       "L 606.148027 140.687416 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.97406 88.574356 \n",
       "L 664.97406 88.414203 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.96194 107.242671 \n",
       "L 643.96194 107.083169 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.067054 131.135842 \n",
       "L 617.067054 130.975877 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.119437 106.212293 \n",
       "L 645.119437 106.052838 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.437723 117.46259 \n",
       "L 632.437723 117.303353 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.521035 156.506974 \n",
       "L 588.521035 156.346746 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.882579 147.297034 \n",
       "L 598.882579 147.136753 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.46282 112.984243 \n",
       "L 637.46282 112.824772 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.605282 97.800544 \n",
       "L 654.605282 97.64073 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.468499 153.00148 \n",
       "L 592.468499 152.84134 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.080542 158.680422 \n",
       "L 586.080542 158.520295 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.939177 106.367453 \n",
       "L 644.939177 106.207841 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.854417 81.590913 \n",
       "L 672.854417 81.431178 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.054782 70.71557 \n",
       "L 685.054782 70.55562 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.812375 83.382498 \n",
       "L 670.812375 83.222378 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.522603 89.860999 \n",
       "L 663.522603 89.701582 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.052432 157.810996 \n",
       "L 587.052432 157.650686 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.935088 139.26313 \n",
       "L 607.935088 139.103099 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.691419 95.92854 \n",
       "L 656.691419 95.768505 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.144589 65.30686 \n",
       "L 691.144589 65.146637 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.069292 109.824401 \n",
       "L 641.069292 109.664578 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.126718 160.407595 \n",
       "L 584.126718 160.24746 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.702968 128.812104 \n",
       "L 619.702968 128.653277 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.202154 84.813077 \n",
       "L 669.202154 84.653262 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.1693 90.187375 \n",
       "L 663.1693 90.028147 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.078093 121.358527 \n",
       "L 628.078093 121.198886 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.016448 126.738154 \n",
       "L 622.016448 126.580816 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.495545 98.778987 \n",
       "L 653.495545 98.61969 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.397237 84.635732 \n",
       "L 669.397237 84.475532 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.83446 121.587927 \n",
       "L 627.83446 121.428905 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.281509 157.619339 \n",
       "L 587.281509 157.459125 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.268524 121.196962 \n",
       "L 628.268524 121.03686 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.455048 96.130338 \n",
       "L 656.455048 95.970334 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.068876 149.801395 \n",
       "L 596.068876 149.641392 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.195534 76.812171 \n",
       "L 678.195534 76.651899 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.36709 65.114117 \n",
       "L 691.36709 64.953918 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.288837 130.947262 \n",
       "L 617.288837 130.787814 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.169119 130.150339 \n",
       "L 618.169119 129.990814 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.554146 143.154981 \n",
       "L 603.554146 142.995322 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.253974 93.64506 \n",
       "L 659.253974 93.485222 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.83054 81.59622 \n",
       "L 672.83054 81.436358 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.158076 90.176496 \n",
       "L 663.158076 90.01666 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.210923 83.012393 \n",
       "L 671.210923 82.852306 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.133708 157.742917 \n",
       "L 587.133708 157.582633 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.849654 134.003165 \n",
       "L 613.849654 133.843227 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.985564 84.104811 \n",
       "L 669.985564 83.945059 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.286849 154.93526 \n",
       "L 590.286849 154.775067 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.618914 111.984292 \n",
       "L 638.618914 111.825148 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.138183 103.521841 \n",
       "L 648.138183 103.362052 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.111947 90.224524 \n",
       "L 663.111947 90.064315 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.586783 98.698693 \n",
       "L 653.586783 98.539044 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.216602 147.000791 \n",
       "L 599.216602 146.842713 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.746571 152.779697 \n",
       "L 592.746571 152.62005 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.552078 128.03878 \n",
       "L 620.552078 127.878919 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.459572 119.229744 \n",
       "L 630.459572 119.069729 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.064692 87.609475 \n",
       "L 666.064692 87.449342 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.304412 109.601823 \n",
       "L 641.304412 109.441596 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.482966 75.680666 \n",
       "L 679.482966 75.520445 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.106863 90.212499 \n",
       "L 663.106863 90.052437 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.999249 66.329327 \n",
       "L 689.999249 66.169389 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.996291 83.249652 \n",
       "L 670.996291 83.090191 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 574.307104 169.141519 \n",
       "L 574.307104 168.981338 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.587698 113.782982 \n",
       "L 636.587698 113.622993 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.595351 73.787382 \n",
       "L 681.595351 73.627251 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.549785 127.151838 \n",
       "L 621.549785 126.992452 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.221361 74.132034 \n",
       "L 681.221361 73.971874 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.457762 156.568678 \n",
       "L 588.457762 156.408523 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.248866 82.988643 \n",
       "L 671.248866 82.8284 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.67282 160.81362 \n",
       "L 583.67282 160.653532 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.561494 80.925405 \n",
       "L 673.561494 80.76538 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.357658 161.094853 \n",
       "L 583.357658 160.934659 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.057912 129.394872 \n",
       "L 619.057912 129.23559 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.466443 101.469689 \n",
       "L 650.466443 101.310111 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.8717 82.467081 \n",
       "L 671.8717 82.307402 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.040568 155.162423 \n",
       "L 590.040568 155.002273 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.862998 85.990838 \n",
       "L 667.862998 85.831044 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.281311 98.068845 \n",
       "L 654.281311 97.90863 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.979965 84.985619 \n",
       "L 668.979965 84.826143 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.252523 130.959897 \n",
       "L 617.252523 130.800458 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.871708 151.74631 \n",
       "L 593.871708 151.586588 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.836228 154.444691 \n",
       "L 590.836228 154.284744 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.09554 97.344874 \n",
       "L 655.09554 97.184911 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.096919 112.455303 \n",
       "L 638.096919 112.295217 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.577195 147.577308 \n",
       "L 598.577195 147.417062 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.435417 137.923583 \n",
       "L 609.435417 137.766965 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.517125 104.969516 \n",
       "L 646.517125 104.809692 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.505756 147.652286 \n",
       "L 598.505756 147.492418 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.804306 123.333924 \n",
       "L 625.804306 123.181359 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.706378 155.462446 \n",
       "L 589.706378 155.302309 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.513592 99.63037 \n",
       "L 652.513592 99.471356 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.2627 153.18756 \n",
       "L 592.2627 153.027364 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.903335 154.390897 \n",
       "L 590.903335 154.230631 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.89111 110.852111 \n",
       "L 639.89111 110.692061 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.096957 115.119979 \n",
       "L 635.096957 114.959845 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.805381 75.381115 \n",
       "L 679.805381 75.221043 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.246418 108.769937 \n",
       "L 642.246418 108.609914 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.449111 138.793338 \n",
       "L 608.449111 138.633352 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.198859 95.479768 \n",
       "L 657.198859 95.319598 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.100808 160.435406 \n",
       "L 584.100808 160.275249 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.910957 141.935536 \n",
       "L 604.910957 141.77553 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.442397 65.938525 \n",
       "L 690.442397 65.778362 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.712442 151.005942 \n",
       "L 594.712442 150.845725 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.400909 95.291196 \n",
       "L 657.400909 95.131325 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.332302 136.244194 \n",
       "L 611.332302 136.084323 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.320749 129.140848 \n",
       "L 619.320749 128.980586 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.2625 88.322214 \n",
       "L 665.2625 88.163952 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.388184 97.100279 \n",
       "L 655.388184 96.944083 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.747603 151.858548 \n",
       "L 593.747603 151.698664 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.993684 89.451527 \n",
       "L 663.993684 89.291947 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.940827 96.578406 \n",
       "L 655.940827 96.4186 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.286142 141.621944 \n",
       "L 605.286142 141.462218 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.362818 117.552437 \n",
       "L 632.362818 117.39234 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.374983 113.997923 \n",
       "L 636.374983 113.841624 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.988632 65.459758 \n",
       "L 690.988632 65.300117 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.34895 89.124698 \n",
       "L 664.34895 88.964567 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.340147 129.12291 \n",
       "L 619.340147 128.962706 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.600114 100.439737 \n",
       "L 651.600114 100.279958 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.23742 95.42801 \n",
       "L 657.23742 95.268339 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.735824 113.660503 \n",
       "L 636.735824 113.500265 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.531747 84.51259 \n",
       "L 669.531747 84.352519 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.34169 122.002399 \n",
       "L 627.34169 121.84239 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.559036 80.942962 \n",
       "L 673.559036 80.783026 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.710699 119.899635 \n",
       "L 629.710699 119.739819 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.333282 132.677953 \n",
       "L 615.333282 132.518925 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.756224 123.41682 \n",
       "L 625.756224 123.256725 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.161506 88.407487 \n",
       "L 665.161506 88.247746 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.039826 65.414331 \n",
       "L 691.039826 65.254208 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.499513 81.878791 \n",
       "L 672.499513 81.718709 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.252282 118.550447 \n",
       "L 631.252282 118.390423 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.783683 138.494882 \n",
       "L 608.783683 138.334769 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.593765 152.003398 \n",
       "L 593.593765 151.843313 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.704386 155.468901 \n",
       "L 589.704386 155.30887 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.096133 116.899333 \n",
       "L 633.096133 116.739224 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 688.691788 67.50334 \n",
       "L 688.691788 67.343485 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.522613 119.192742 \n",
       "L 630.522613 119.032813 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.262461 157.628712 \n",
       "L 587.262461 157.468556 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.643567 143.05464 \n",
       "L 603.643567 142.8955 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.679075 79.956477 \n",
       "L 674.679075 79.796581 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.456671 111.243461 \n",
       "L 639.456671 111.083342 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.830293 86.023432 \n",
       "L 667.830293 85.863613 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.820888 89.595449 \n",
       "L 663.820888 89.43544 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.190503 78.583383 \n",
       "L 676.190503 78.423898 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.066777 107.144149 \n",
       "L 644.066777 106.983921 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.654588 117.291441 \n",
       "L 632.654588 117.131195 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.435185 90.793081 \n",
       "L 662.435185 90.634192 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.485897 119.211979 \n",
       "L 630.485897 119.051913 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.299922 82.963046 \n",
       "L 671.299922 82.803323 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.407227 78.401006 \n",
       "L 676.407227 78.240801 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.973931 80.572865 \n",
       "L 673.973931 80.412686 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.877871 131.316191 \n",
       "L 616.877871 131.156119 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 578.378379 165.532889 \n",
       "L 578.378379 165.373051 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.549837 116.525627 \n",
       "L 633.549837 116.365917 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 570.959274 172.115976 \n",
       "L 570.959274 171.955707 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.934915 110.824029 \n",
       "L 639.934915 110.663856 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.982462 93.894956 \n",
       "L 658.982462 93.73481 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.107466 139.993709 \n",
       "L 607.107466 139.833879 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.076041 75.14353 \n",
       "L 680.076041 74.983653 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.17386 96.401256 \n",
       "L 656.17386 96.241514 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.952022 151.676549 \n",
       "L 593.952022 151.516548 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.388026 126.419881 \n",
       "L 622.388026 126.259804 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.21843 146.115914 \n",
       "L 600.21843 145.955642 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.664599 146.642343 \n",
       "L 599.664599 146.484368 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.099649 70.681181 \n",
       "L 685.099649 70.52092 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.825641 123.363491 \n",
       "L 625.825641 123.203525 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.981825 75.232857 \n",
       "L 679.981825 75.072666 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.822316 104.703787 \n",
       "L 646.822316 104.543643 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.67487 74.618677 \n",
       "L 680.67487 74.458486 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.608668 144.887014 \n",
       "L 601.608668 144.727151 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.970779 97.47012 \n",
       "L 654.970779 97.309931 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.521051 142.304159 \n",
       "L 604.521051 142.144356 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.383577 97.087672 \n",
       "L 655.383577 96.927476 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.032474 92.071704 \n",
       "L 661.032474 91.91147 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.81123 90.479483 \n",
       "L 662.81123 90.32036 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.992141 89.444065 \n",
       "L 663.992141 89.284096 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.453878 155.68083 \n",
       "L 589.453878 155.520843 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.020672 148.069223 \n",
       "L 598.020672 147.908955 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.908685 149.030605 \n",
       "L 596.908685 148.87109 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.751985 111.001363 \n",
       "L 639.751985 110.841757 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.43414 147.698087 \n",
       "L 598.43414 147.537834 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.562634 80.92486 \n",
       "L 673.562634 80.766966 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.912807 151.702187 \n",
       "L 593.912807 151.543514 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.275406 137.173266 \n",
       "L 610.275406 137.013498 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.71677 149.249015 \n",
       "L 596.71677 149.089442 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.166762 76.844083 \n",
       "L 678.166762 76.683981 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.602965 92.46082 \n",
       "L 660.602965 92.301168 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.14998 82.186541 \n",
       "L 672.14998 82.026337 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.570046 153.805748 \n",
       "L 591.570046 153.646075 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.969925 152.546438 \n",
       "L 592.969925 152.386975 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.549951 95.16649 \n",
       "L 657.549951 95.006283 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.798501 152.69707 \n",
       "L 592.798501 152.537241 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.334901 125.537329 \n",
       "L 623.334901 125.378446 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.059812 106.265874 \n",
       "L 645.059812 106.105768 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.012136 96.529256 \n",
       "L 656.012136 96.369498 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.610654 121.771644 \n",
       "L 627.610654 121.611498 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.517725 92.534771 \n",
       "L 660.517725 92.37496 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.002124 99.19947 \n",
       "L 653.002124 99.039787 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.151098 126.616826 \n",
       "L 622.151098 126.456673 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.437584 110.370077 \n",
       "L 640.437584 110.210005 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.998736 116.110302 \n",
       "L 633.998736 115.950328 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.395019 155.746712 \n",
       "L 589.395019 155.587219 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 693.599935 63.118343 \n",
       "L 693.599935 62.9582 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.738064 153.650652 \n",
       "L 591.738064 153.491742 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.75747 130.543497 \n",
       "L 617.75747 130.384134 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.307519 85.607566 \n",
       "L 668.307519 85.447436 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.893849 107.302752 \n",
       "L 643.893849 107.14335 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.295976 137.146352 \n",
       "L 610.295976 136.98636 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.637027 94.194079 \n",
       "L 658.637027 94.033963 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.013364 135.577177 \n",
       "L 612.013364 135.418943 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.822188 139.354915 \n",
       "L 607.822188 139.194823 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.069153 87.591107 \n",
       "L 666.069153 87.430981 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.948539 70.850814 \n",
       "L 684.948539 70.690952 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.702189 70.143739 \n",
       "L 685.702189 69.983539 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.765884 140.26986 \n",
       "L 606.765884 140.111187 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.601806 90.687277 \n",
       "L 662.601806 90.528437 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.007851 133.850352 \n",
       "L 614.007851 133.690474 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.584203 150.233071 \n",
       "L 595.584203 150.073634 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.813717 133.139252 \n",
       "L 614.813717 132.979058 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 692.149168 64.41707 \n",
       "L 692.149168 64.256764 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.891423 72.643427 \n",
       "L 682.891423 72.483876 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.719112 97.683411 \n",
       "L 654.719112 97.523293 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.062341 105.366319 \n",
       "L 646.062341 105.206867 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.584986 81.780991 \n",
       "L 672.584986 81.621524 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.911291 133.942878 \n",
       "L 613.911291 133.783622 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.653103 152.8397 \n",
       "L 592.653103 152.679726 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.757689 145.639581 \n",
       "L 600.757689 145.479569 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.754655 101.201747 \n",
       "L 650.754655 101.041627 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.950047 107.267769 \n",
       "L 643.950047 107.108643 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.560325 84.501091 \n",
       "L 669.560325 84.341084 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.893638 155.284111 \n",
       "L 589.893638 155.124012 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.593468 92.458262 \n",
       "L 660.593468 92.29813 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.470216 111.250401 \n",
       "L 639.470216 111.091453 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.703859 99.465378 \n",
       "L 652.703859 99.305484 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.49281 66.779836 \n",
       "L 689.49281 66.619677 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.211951 137.2238 \n",
       "L 610.211951 137.063784 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.21526 131.898142 \n",
       "L 616.21526 131.739941 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.562826 157.352691 \n",
       "L 587.562826 157.192469 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.409934 75.743721 \n",
       "L 679.409934 75.583635 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.200099 150.57491 \n",
       "L 595.200099 150.414679 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.594535 141.322361 \n",
       "L 605.594535 141.163209 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.764888 163.401936 \n",
       "L 580.764888 163.241905 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.599644 88.006463 \n",
       "L 665.599644 87.846897 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.869628 136.647797 \n",
       "L 610.869628 136.487604 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.795382 129.603111 \n",
       "L 618.795382 129.443052 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.951135 121.450873 \n",
       "L 627.951135 121.296916 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.900207 163.26047 \n",
       "L 580.900207 163.10057 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.609247 146.653686 \n",
       "L 599.609247 146.493531 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.571076 112.028543 \n",
       "L 638.571076 111.868553 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.017199 94.7491 \n",
       "L 658.017199 94.589072 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 585.022795 159.622128 \n",
       "L 585.022795 159.46214 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.804111 92.261842 \n",
       "L 660.804111 92.102332 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.228275 69.680475 \n",
       "L 686.228275 69.520197 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.927246 107.254216 \n",
       "L 643.927246 107.095248 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.223076 111.449733 \n",
       "L 639.223076 111.290034 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.410037 153.947667 \n",
       "L 591.410037 153.787525 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.469612 75.659555 \n",
       "L 679.469612 75.50038 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.433549 98.814824 \n",
       "L 653.433549 98.655 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.733795 136.780062 \n",
       "L 610.733795 136.620388 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.601521 128.891998 \n",
       "L 619.601521 128.732037 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.48207 111.197402 \n",
       "L 639.48207 111.03829 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.494252 74.785731 \n",
       "L 680.494252 74.625998 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.017897 108.079492 \n",
       "L 643.017897 107.9193 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.043575 90.292185 \n",
       "L 663.043575 90.132252 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.84774 119.790716 \n",
       "L 629.84774 119.630903 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.171338 83.062701 \n",
       "L 671.171338 82.902549 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.048157 73.388755 \n",
       "L 682.048157 73.228869 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.016598 146.304893 \n",
       "L 600.016598 146.145274 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.486636 156.51667 \n",
       "L 588.486636 156.357181 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.563238 158.25759 \n",
       "L 586.563238 158.097424 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.39129 163.743233 \n",
       "L 580.39129 163.583616 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.249434 134.525557 \n",
       "L 613.249434 134.365391 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.722402 80.799872 \n",
       "L 673.722402 80.643293 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.384161 113.081531 \n",
       "L 637.384161 112.922106 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.952893 88.584377 \n",
       "L 664.952893 88.424343 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 698.296373 58.953883 \n",
       "L 698.296373 58.793599 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.185166 143.47314 \n",
       "L 603.185166 143.314339 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.388216 108.630202 \n",
       "L 642.388216 108.470359 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.19163 138.141027 \n",
       "L 609.19163 137.980917 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.478783 91.681687 \n",
       "L 661.478783 91.52202 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.750279 121.630881 \n",
       "L 627.750279 121.470747 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.72119 107.462897 \n",
       "L 643.72119 107.302722 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.818018 109.155804 \n",
       "L 641.818018 108.996407 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.64916 159.972915 \n",
       "L 584.64916 159.813525 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.630546 127.964663 \n",
       "L 620.630546 127.805332 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.793826 153.605728 \n",
       "L 591.793826 153.445501 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.19975 75.036278 \n",
       "L 680.19975 74.8761 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.168685 142.601024 \n",
       "L 604.168685 142.442228 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.86608 114.428585 \n",
       "L 635.86608 114.268436 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.887538 150.852606 \n",
       "L 594.887538 150.692868 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.192947 148.802263 \n",
       "L 597.192947 148.64247 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.338498 116.673511 \n",
       "L 633.338498 116.513727 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.316175 93.613304 \n",
       "L 659.316175 93.454257 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.430338 70.383422 \n",
       "L 685.430338 70.223209 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.646509 144.875931 \n",
       "L 601.646509 144.71598 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.693105 113.701194 \n",
       "L 636.693105 113.54104 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.560669 80.940172 \n",
       "L 673.560669 80.780023 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.182719 84.827515 \n",
       "L 669.182719 84.667289 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.725221 146.565887 \n",
       "L 599.725221 146.406385 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.430157 80.162741 \n",
       "L 674.430157 80.002643 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.962638 79.695195 \n",
       "L 674.962638 79.535136 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.35456 162.873139 \n",
       "L 581.35456 162.713156 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.729673 86.153704 \n",
       "L 667.729673 85.994737 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.847815 86.902111 \n",
       "L 666.847815 86.741846 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.005373 88.529416 \n",
       "L 665.005373 88.369516 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.917261 112.610199 \n",
       "L 637.917261 112.450191 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.8248 134.002869 \n",
       "L 613.8248 133.843279 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.127603 146.199476 \n",
       "L 600.127603 146.039797 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.804396 104.68363 \n",
       "L 646.804396 104.524102 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.001312 117.872061 \n",
       "L 632.001312 117.713748 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.784029 135.844916 \n",
       "L 611.784029 135.686267 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.070255 102.696017 \n",
       "L 649.070255 102.53606 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.119292 89.312581 \n",
       "L 664.119292 89.152715 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.645804 139.520297 \n",
       "L 607.645804 139.3602 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.752893 147.418889 \n",
       "L 598.752893 147.258823 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.35218 121.092408 \n",
       "L 628.35218 120.934024 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.985628 70.791421 \n",
       "L 684.985628 70.631469 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.302423 138.953862 \n",
       "L 608.302423 138.79463 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.925057 89.494349 \n",
       "L 663.925057 89.334128 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.081374 114.254389 \n",
       "L 636.081374 114.094324 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.632493 96.853621 \n",
       "L 655.632493 96.69409 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.014564 108.972656 \n",
       "L 642.014564 108.812751 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 585.43061 159.253452 \n",
       "L 585.43061 159.093335 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.6965 86.16793 \n",
       "L 667.6965 86.008044 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.914895 81.518067 \n",
       "L 672.914895 81.358173 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.953992 90.374016 \n",
       "L 662.953992 90.214013 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.526808 98.719195 \n",
       "L 653.526808 98.559351 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.596091 100.462153 \n",
       "L 651.596091 100.301969 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.925444 147.263185 \n",
       "L 598.925444 147.102916 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.606177 113.773638 \n",
       "L 636.606177 113.613755 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.450621 141.473 \n",
       "L 605.450621 141.312832 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.820524 143.782907 \n",
       "L 602.820524 143.62335 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.532458 114.751548 \n",
       "L 635.532458 114.593067 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.89993 96.62221 \n",
       "L 655.89993 96.462545 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.761082 82.531035 \n",
       "L 671.761082 82.370952 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.132539 78.637796 \n",
       "L 676.132539 78.477902 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 585.812989 158.930941 \n",
       "L 585.812989 158.771619 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 697.18917 59.943792 \n",
       "L 697.18917 59.783578 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.967424 77.027592 \n",
       "L 677.967424 76.867888 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.884784 150.854429 \n",
       "L 594.884784 150.694361 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.009745 110.770778 \n",
       "L 640.009745 110.610835 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.515172 140.510426 \n",
       "L 606.515172 140.350388 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.051145 130.236697 \n",
       "L 618.051145 130.076855 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 692.594104 64.02489 \n",
       "L 692.594104 63.864767 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.571217 138.665874 \n",
       "L 608.571217 138.506804 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.738124 100.331303 \n",
       "L 651.738124 100.17199 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.040757 125.838625 \n",
       "L 623.040757 125.678931 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 574.481609 168.995878 \n",
       "L 574.481609 168.835667 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.482531 138.780094 \n",
       "L 608.482531 138.620368 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.613524 129.760602 \n",
       "L 618.613524 129.600982 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.180765 143.504604 \n",
       "L 603.180765 143.345125 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.135505 141.749337 \n",
       "L 605.135505 141.589329 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.854942 141.12064 \n",
       "L 605.854942 140.960996 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.297115 99.847848 \n",
       "L 652.297115 99.68991 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.038535 116.948927 \n",
       "L 633.038535 116.78869 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.896475 77.0805 \n",
       "L 677.896475 76.920229 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.027909 109.844364 \n",
       "L 641.027909 109.684593 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.457528 107.67361 \n",
       "L 643.457528 107.513981 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.085665 90.235927 \n",
       "L 663.085665 90.075881 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.459255 86.350198 \n",
       "L 667.459255 86.19035 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.880541 93.075297 \n",
       "L 659.880541 92.915814 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.267486 82.083062 \n",
       "L 672.267486 81.92288 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.338847 146.011796 \n",
       "L 600.338847 145.851813 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.412326 90.822551 \n",
       "L 662.412326 90.662996 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.251623 136.317748 \n",
       "L 611.251623 136.158241 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.230261 120.33597 \n",
       "L 629.230261 120.176802 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.003869 101.869265 \n",
       "L 650.003869 101.709156 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.869553 83.325036 \n",
       "L 670.869553 83.164819 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.951455 142.807778 \n",
       "L 603.951455 142.647686 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.178315 147.039625 \n",
       "L 599.178315 146.879642 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.413659 132.603857 \n",
       "L 615.413659 132.446569 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.301842 158.48514 \n",
       "L 586.301842 158.325123 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.532531 94.292529 \n",
       "L 658.532531 94.132269 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.965002 91.258023 \n",
       "L 661.965002 91.098031 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.127626 144.412322 \n",
       "L 602.127626 144.252503 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.079458 134.684184 \n",
       "L 613.079458 134.524196 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.770722 117.223253 \n",
       "L 632.770722 117.064452 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.360242 145.100205 \n",
       "L 601.360242 144.940087 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.005648 136.535788 \n",
       "L 611.005648 136.376247 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.084834 103.540898 \n",
       "L 648.084834 103.386185 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.446385 129.044006 \n",
       "L 619.446385 128.885391 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 687.975779 68.129065 \n",
       "L 687.975779 67.968839 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.295755 156.704546 \n",
       "L 588.295755 156.544377 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 693.054426 63.616853 \n",
       "L 693.054426 63.456626 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.071361 92.041435 \n",
       "L 661.071361 91.881353 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.997161 85.880588 \n",
       "L 667.997161 85.720704 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.756081 163.413423 \n",
       "L 580.756081 163.253205 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.23296 136.304067 \n",
       "L 611.23296 136.144383 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.954398 100.134738 \n",
       "L 651.954398 99.97474 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.782059 102.951468 \n",
       "L 648.782059 102.792736 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 688.17683 67.945433 \n",
       "L 688.17683 67.785152 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.009653 92.080999 \n",
       "L 661.009653 91.921088 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.968743 163.224659 \n",
       "L 580.968743 163.06437 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.399845 120.204237 \n",
       "L 629.399845 120.045735 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.591152 99.573985 \n",
       "L 652.591152 99.414762 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.582159 104.023622 \n",
       "L 647.582159 103.865207 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.738173 90.556527 \n",
       "L 662.738173 90.396446 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.492716 111.237197 \n",
       "L 639.492716 111.077559 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.109493 112.443106 \n",
       "L 638.109493 112.283031 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.752612 76.323005 \n",
       "L 678.752612 76.162795 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.986031 148.100547 \n",
       "L 597.986031 147.940582 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.158275 155.050495 \n",
       "L 590.158275 154.890497 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.620137 94.216711 \n",
       "L 658.620137 94.056556 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.76349 77.198614 \n",
       "L 677.76349 77.038409 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.11993 83.103064 \n",
       "L 671.11993 82.943365 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.108483 122.226863 \n",
       "L 627.108483 122.066748 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.819345 76.266579 \n",
       "L 678.819345 76.106358 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.188597 74.165604 \n",
       "L 681.188597 74.005471 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.935517 165.915321 \n",
       "L 577.935517 165.755119 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.375584 132.63542 \n",
       "L 615.375584 132.476601 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.389023 162.850713 \n",
       "L 581.389023 162.690478 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.652213 76.41436 \n",
       "L 678.652213 76.254569 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.980685 80.551233 \n",
       "L 673.980685 80.391374 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.273145 99.852063 \n",
       "L 652.273145 99.691805 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.053489 117.841478 \n",
       "L 632.053489 117.681643 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.979352 132.994543 \n",
       "L 614.979352 132.834766 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.573167 114.696859 \n",
       "L 635.573167 114.536642 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.536567 133.399343 \n",
       "L 614.536567 133.240205 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.359454 92.668186 \n",
       "L 660.359454 92.508006 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.457969 126.327381 \n",
       "L 622.457969 126.16784 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.517499 129.851607 \n",
       "L 618.517499 129.69138 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.431281 95.277815 \n",
       "L 657.431281 95.118273 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.754697 86.988913 \n",
       "L 666.754697 86.828691 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.059872 158.676847 \n",
       "L 586.059872 158.517284 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.947983 138.356002 \n",
       "L 608.947983 138.196169 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.398556 81.968747 \n",
       "L 672.398556 81.808822 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.973942 160.552982 \n",
       "L 583.973942 160.392846 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.361625 120.222553 \n",
       "L 629.361625 120.062545 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.898156 110.846676 \n",
       "L 639.898156 110.686718 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.715299 114.573242 \n",
       "L 635.715299 114.413028 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.65045 125.284967 \n",
       "L 623.65045 125.125454 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.606924 131.545156 \n",
       "L 616.606924 131.385045 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.086936 129.357641 \n",
       "L 619.086936 129.198193 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.662655 152.828468 \n",
       "L 592.662655 152.668627 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.766102 144.737184 \n",
       "L 601.766102 144.577524 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.048621 148.047196 \n",
       "L 598.048621 147.887 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.191776 91.921974 \n",
       "L 661.191776 91.761819 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.539397 123.556776 \n",
       "L 625.539397 123.398143 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.688734 65.715295 \n",
       "L 690.688734 65.555004 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.168294 142.617855 \n",
       "L 604.168294 142.458005 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.19614 126.575429 \n",
       "L 622.19614 126.415304 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.136295 95.536648 \n",
       "L 657.136295 95.376647 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.069289 87.59152 \n",
       "L 666.069289 87.431516 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.910255 83.289437 \n",
       "L 670.910255 83.129486 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.717872 143.00447 \n",
       "L 603.717872 142.844566 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.168035 163.929652 \n",
       "L 580.168035 163.769427 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.683321 70.180462 \n",
       "L 685.683321 70.020482 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.103546 93.78958 \n",
       "L 659.103546 93.629346 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.624246 129.763608 \n",
       "L 618.624246 129.603499 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.897743 156.17253 \n",
       "L 588.897743 156.012329 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.63515 96.870884 \n",
       "L 655.63515 96.711012 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.980265 127.649303 \n",
       "L 620.980265 127.489553 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.626601 77.322663 \n",
       "L 677.626601 77.162439 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.466629 122.802221 \n",
       "L 626.466629 122.642487 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.613091 70.209537 \n",
       "L 685.613091 70.049516 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.626643 151.968327 \n",
       "L 593.626643 151.808184 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.286448 128.271814 \n",
       "L 620.286448 128.11161 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.574216 88.919823 \n",
       "L 664.574216 88.759715 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.055789 73.388505 \n",
       "L 682.055789 73.228203 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 675.065246 79.604129 \n",
       "L 675.065246 79.444635 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.702041 117.265813 \n",
       "L 632.702041 117.106084 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.366645 85.561979 \n",
       "L 668.366645 85.402584 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.817616 142.030749 \n",
       "L 604.817616 141.870731 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.041201 137.378334 \n",
       "L 610.041201 137.218542 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.26751 102.531041 \n",
       "L 649.26751 102.372316 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.741482 118.09561 \n",
       "L 631.741482 117.935905 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.801615 152.703847 \n",
       "L 592.801615 152.54358 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.17045 154.160324 \n",
       "L 591.17045 154.000119 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.240252 134.555499 \n",
       "L 613.240252 134.395893 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.34785 122.876434 \n",
       "L 626.34785 122.717544 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.66894 87.0554 \n",
       "L 666.66894 86.895434 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.581386 155.564575 \n",
       "L 589.581386 155.404356 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.076544 76.046606 \n",
       "L 679.076544 75.886715 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.720512 94.149457 \n",
       "L 658.720512 93.989846 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.887259 159.744802 \n",
       "L 584.887259 159.584529 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.216286 112.3373 \n",
       "L 638.216286 112.177566 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.492699 83.752363 \n",
       "L 670.492699 83.595233 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.590559 131.55296 \n",
       "L 616.590559 131.393202 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.456165 156.560031 \n",
       "L 588.456165 156.399963 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.041608 166.708624 \n",
       "L 577.041608 166.548394 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.506937 81.875361 \n",
       "L 672.506937 81.715416 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 693.360649 63.343499 \n",
       "L 693.360649 63.183918 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.476102 129.900348 \n",
       "L 618.476102 129.740405 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.368527 146.862729 \n",
       "L 599.368527 146.70261 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.176052 163.041385 \n",
       "L 581.176052 162.881157 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 617.637923 130.632059 \n",
       "L 617.637923 130.472465 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.376063 109.54232 \n",
       "L 641.376063 109.382283 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.519487 83.644552 \n",
       "L 670.519487 83.48512 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.275346 143.381264 \n",
       "L 603.275346 143.221605 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.279784 74.933854 \n",
       "L 680.279784 74.774112 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.653168 144.840367 \n",
       "L 601.653168 144.68048 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.109116 78.671223 \n",
       "L 676.109116 78.5111 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.660813 97.736239 \n",
       "L 654.660813 97.576139 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.897565 71.740348 \n",
       "L 683.897565 71.580298 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 675.525498 79.189136 \n",
       "L 675.525498 79.028997 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.043958 156.043867 \n",
       "L 589.043958 155.883886 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.874206 147.301648 \n",
       "L 598.874206 147.141706 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.727061 88.778107 \n",
       "L 664.727061 88.618256 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 699.93322 57.502799 \n",
       "L 699.93322 57.342528 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.454529 90.798879 \n",
       "L 662.454529 90.639172 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.198834 89.262224 \n",
       "L 664.198834 89.102442 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.551155 102.250921 \n",
       "L 649.551155 102.0914 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.904467 126.842423 \n",
       "L 621.904467 126.683229 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.633159 135.97228 \n",
       "L 611.633159 135.812041 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.443362 161.026578 \n",
       "L 583.443362 160.866323 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.589376 106.699267 \n",
       "L 644.589376 106.54045 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.524749 84.535222 \n",
       "L 669.524749 84.3753 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 585.279668 159.376206 \n",
       "L 585.279668 159.216107 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.75063 94.957383 \n",
       "L 657.75063 94.798587 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.060986 152.473646 \n",
       "L 593.060986 152.313502 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.964428 86.795012 \n",
       "L 666.964428 86.634904 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.866416 117.100567 \n",
       "L 632.866416 116.940412 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.357976 145.987827 \n",
       "L 600.357976 145.8278 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.954508 90.362908 \n",
       "L 662.954508 90.202822 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.510932 136.96304 \n",
       "L 610.510932 136.803596 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.332708 117.579372 \n",
       "L 632.332708 117.419272 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.318019 139.807914 \n",
       "L 607.318019 139.649009 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 675.682588 79.046463 \n",
       "L 675.682588 78.886257 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.18966 158.578775 \n",
       "L 586.18966 158.419062 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.828154 73.589073 \n",
       "L 681.828154 73.429013 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.745049 156.303835 \n",
       "L 588.745049 156.144301 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.180085 108.83128 \n",
       "L 642.180085 108.671401 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.436698 166.361758 \n",
       "L 577.436698 166.201512 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.250976 82.102702 \n",
       "L 672.250976 81.943858 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.519401 87.182575 \n",
       "L 666.519401 87.022995 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.346607 81.110014 \n",
       "L 673.346607 80.94989 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.619264 162.625364 \n",
       "L 581.619264 162.465608 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.766985 103.858613 \n",
       "L 647.766985 103.698455 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.021525 125.847999 \n",
       "L 623.021525 125.688403 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.834442 112.677305 \n",
       "L 637.834442 112.517841 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.553646 96.937161 \n",
       "L 655.553646 96.777021 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.812859 157.137205 \n",
       "L 587.812859 156.977012 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.216626 76.789616 \n",
       "L 678.216626 76.629807 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.706241 127.01632 \n",
       "L 621.706241 126.856087 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.660533 76.402104 \n",
       "L 678.660533 76.242278 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.906819 85.07101 \n",
       "L 668.906819 84.91074 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 575.152806 168.393655 \n",
       "L 575.152806 168.23335 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.24512 95.428308 \n",
       "L 657.24512 95.269992 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.633674 89.750998 \n",
       "L 663.633674 89.591632 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.416564 73.954342 \n",
       "L 681.416564 73.794832 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.103055 92.028932 \n",
       "L 661.103055 91.869788 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 693.335886 63.362147 \n",
       "L 693.335886 63.201844 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.550465 93.384327 \n",
       "L 659.550465 93.224739 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.995996 92.99604 \n",
       "L 659.995996 92.835957 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.788352 137.609081 \n",
       "L 609.788352 137.448851 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.550524 158.262276 \n",
       "L 586.550524 158.101952 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.375887 101.542066 \n",
       "L 650.375887 101.381867 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.641211 147.515567 \n",
       "L 598.641211 147.355302 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.167917 140.825585 \n",
       "L 606.167917 140.665519 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.997201 149.870307 \n",
       "L 595.997201 149.710581 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.733379 102.997655 \n",
       "L 648.733379 102.837513 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.952326 85.030172 \n",
       "L 668.952326 84.870422 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.710237 125.246162 \n",
       "L 623.710237 125.086088 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.28259 130.062984 \n",
       "L 618.28259 129.903099 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.287609 138.939231 \n",
       "L 608.287609 138.779708 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.813131 132.259483 \n",
       "L 615.813131 132.10003 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.538615 121.818009 \n",
       "L 627.538615 121.658512 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.194189 137.243824 \n",
       "L 610.194189 137.083796 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.618324 121.768263 \n",
       "L 627.618324 121.608146 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.695579 73.694239 \n",
       "L 681.695579 73.534558 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.896109 137.522694 \n",
       "L 609.896109 137.362656 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.691288 141.274238 \n",
       "L 605.691288 141.114856 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.891835 156.181199 \n",
       "L 588.891835 156.020944 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.439044 149.496179 \n",
       "L 596.439044 149.33759 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.392944 69.534265 \n",
       "L 686.392944 69.374284 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.430487 105.033828 \n",
       "L 646.430487 104.8741 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.990498 107.213057 \n",
       "L 643.990498 107.053074 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.653783 87.074268 \n",
       "L 666.653783 86.913969 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.950575 118.827299 \n",
       "L 630.950575 118.667678 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.993424 75.229417 \n",
       "L 679.993424 75.06939 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.689255 111.940376 \n",
       "L 638.689255 111.78076 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.143078 146.181393 \n",
       "L 600.143078 146.021806 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.572364 102.260477 \n",
       "L 649.572364 102.10056 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.215521 128.342804 \n",
       "L 620.215521 128.182678 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.473845 150.325424 \n",
       "L 595.473845 150.165407 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.398815 156.611532 \n",
       "L 588.398815 156.451399 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.039732 161.390876 \n",
       "L 583.039732 161.230852 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.854221 110.880809 \n",
       "L 639.854221 110.721232 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.133411 95.538249 \n",
       "L 657.133411 95.378235 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.17576 94.611148 \n",
       "L 658.17576 94.451681 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.913396 91.30834 \n",
       "L 661.913396 91.149806 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.167778 152.372578 \n",
       "L 593.167778 152.212777 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.628085 135.980462 \n",
       "L 611.628085 135.820256 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.103313 76.008239 \n",
       "L 679.103313 75.848048 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.92811 106.377269 \n",
       "L 644.92811 106.217708 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.096915 105.359356 \n",
       "L 646.096915 105.199675 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.112543 87.559241 \n",
       "L 666.112543 87.399694 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.335836 149.577256 \n",
       "L 596.335836 149.417424 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.24241 145.211993 \n",
       "L 601.24241 145.051881 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.783538 91.401052 \n",
       "L 661.783538 91.240963 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.376207 115.743778 \n",
       "L 634.376207 115.584902 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 687.99595 68.113971 \n",
       "L 687.99595 67.953743 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.291178 152.274865 \n",
       "L 593.291178 152.115269 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.798427 86.062165 \n",
       "L 667.798427 85.902478 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.701285 160.795581 \n",
       "L 583.701285 160.635281 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.863413 133.055675 \n",
       "L 614.863413 132.896144 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.695416 101.26078 \n",
       "L 650.695416 101.10056 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.092418 108.000689 \n",
       "L 643.092418 107.840454 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.014272 135.660236 \n",
       "L 612.014272 135.502061 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.626675 143.074661 \n",
       "L 603.626675 142.915282 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.384801 147.739103 \n",
       "L 598.384801 147.579003 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.652304 101.298708 \n",
       "L 650.652304 101.138606 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.787314 140.30088 \n",
       "L 606.787314 140.141609 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.319414 104.236572 \n",
       "L 647.319414 104.076841 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.730486 71.903618 \n",
       "L 683.730486 71.743343 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.226112 152.325462 \n",
       "L 593.226112 152.165429 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.603577 72.013393 \n",
       "L 683.603577 71.853123 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.475432 137.004812 \n",
       "L 610.475432 136.845009 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.03057 137.372703 \n",
       "L 610.03057 137.214609 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.78755 107.387386 \n",
       "L 643.78755 107.22742 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.262186 107.882199 \n",
       "L 643.262186 107.722662 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.922853 76.169138 \n",
       "L 678.922853 76.009014 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.806857 65.604302 \n",
       "L 690.806857 65.444094 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.414082 66.8496 \n",
       "L 689.414082 66.689543 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.820834 75.36694 \n",
       "L 679.820834 75.207276 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.572875 80.916305 \n",
       "L 673.572875 80.756238 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.963859 153.460714 \n",
       "L 591.963859 153.300858 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.274952 95.410565 \n",
       "L 657.274952 95.250532 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.803903 153.59409 \n",
       "L 591.803903 153.433945 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.042852 86.73337 \n",
       "L 667.042852 86.57327 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.144358 140.83864 \n",
       "L 606.144358 140.678599 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.858745 163.321093 \n",
       "L 580.858745 163.160952 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.325047 99.807143 \n",
       "L 652.325047 99.647056 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.775772 121.631957 \n",
       "L 627.775772 121.472137 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.48634 102.347475 \n",
       "L 649.48634 102.187464 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.974291 163.216051 \n",
       "L 580.974291 163.055735 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.483685 107.6743 \n",
       "L 643.483685 107.514174 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.861636 154.428344 \n",
       "L 590.861636 154.268032 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.506428 94.324944 \n",
       "L 658.506428 94.164915 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.294546 148.716673 \n",
       "L 597.294546 148.556905 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.541089 88.06399 \n",
       "L 665.541089 87.90371 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 578.10863 165.765679 \n",
       "L 578.10863 165.605438 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.179577 114.152631 \n",
       "L 636.179577 113.992528 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.011439 163.188618 \n",
       "L 581.011439 163.028659 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.430391 115.707024 \n",
       "L 634.430391 115.547284 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.220557 117.661458 \n",
       "L 632.220557 117.502043 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.861698 116.214037 \n",
       "L 633.861698 116.054139 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.034165 67.187763 \n",
       "L 689.034165 67.027627 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.027254 158.731694 \n",
       "L 586.027254 158.571454 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.44241 96.996122 \n",
       "L 655.44241 96.837882 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.902201 85.08031 \n",
       "L 668.902201 84.920121 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.367524 124.646505 \n",
       "L 624.367524 124.4868 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.18273 152.374992 \n",
       "L 593.18273 152.214971 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.225094 158.55418 \n",
       "L 586.225094 158.393947 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.180941 84.840194 \n",
       "L 669.180941 84.680218 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.470099 80.124721 \n",
       "L 674.470099 79.964889 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.722674 117.235463 \n",
       "L 632.722674 117.075475 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.498035 77.418783 \n",
       "L 677.498035 77.258743 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.907777 81.514838 \n",
       "L 672.907777 81.354944 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.760745 119.859645 \n",
       "L 629.760745 119.701492 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.967589 105.456421 \n",
       "L 645.967589 105.296315 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.687042 118.143947 \n",
       "L 631.687042 117.983959 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.472293 99.67746 \n",
       "L 652.472293 99.517311 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.352508 131.790248 \n",
       "L 616.352508 131.630016 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.425396 107.71508 \n",
       "L 643.425396 107.555314 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.130337 78.65455 \n",
       "L 676.130337 78.494413 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.739247 111.866158 \n",
       "L 638.739247 111.706433 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.199541 134.576107 \n",
       "L 613.199541 134.41651 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.856997 135.775349 \n",
       "L 611.856997 135.615702 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.548394 107.608625 \n",
       "L 643.548394 107.448668 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.973837 128.563728 \n",
       "L 619.973837 128.403466 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.371079 124.642374 \n",
       "L 624.371079 124.483234 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.084328 150.682079 \n",
       "L 595.084328 150.521984 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.410869 131.722105 \n",
       "L 616.410869 131.562264 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.840819 161.560659 \n",
       "L 582.840819 161.400372 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.73593 86.995583 \n",
       "L 666.73593 86.835454 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.941902 121.475513 \n",
       "L 627.941902 121.315327 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.705134 131.478243 \n",
       "L 616.705134 131.318302 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.493135 93.433425 \n",
       "L 659.493135 93.273333 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.132092 109.7565 \n",
       "L 641.132092 109.596937 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.359267 97.111078 \n",
       "L 655.359267 96.952311 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.1823 157.710107 \n",
       "L 587.1823 157.550073 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.796117 108.284117 \n",
       "L 642.796117 108.123967 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.212158 135.454774 \n",
       "L 612.212158 135.294802 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.486148 87.241303 \n",
       "L 666.486148 87.082254 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.152146 123.069975 \n",
       "L 626.152146 122.910048 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.417737 131.732479 \n",
       "L 616.417737 131.573838 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.206787 129.239304 \n",
       "L 619.206787 129.079261 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.800712 100.27652 \n",
       "L 651.800712 100.116725 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.659742 103.99679 \n",
       "L 647.659742 103.83949 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.453117 109.472284 \n",
       "L 641.453117 109.312128 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.643848 103.988006 \n",
       "L 647.643848 103.828379 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.10334 87.563887 \n",
       "L 666.10334 87.403745 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.46296 90.779184 \n",
       "L 662.46296 90.619521 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.150773 82.190232 \n",
       "L 672.150773 82.030188 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 675.207065 79.483935 \n",
       "L 675.207065 79.323671 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.052611 143.590379 \n",
       "L 603.052611 143.430435 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.696636 111.03359 \n",
       "L 639.696636 110.873922 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.681888 119.948919 \n",
       "L 629.681888 119.79031 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.029506 130.271168 \n",
       "L 618.029506 130.111754 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.82218 123.365796 \n",
       "L 625.82218 123.205909 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.924734 125.920403 \n",
       "L 622.924734 125.760799 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.847878 94.012228 \n",
       "L 658.847878 93.852032 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.155295 73.297403 \n",
       "L 682.155295 73.137597 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.148477 163.057579 \n",
       "L 581.148477 162.897424 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.736923 81.671442 \n",
       "L 672.736923 81.511385 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.561163 122.699942 \n",
       "L 626.561163 122.540158 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.494797 120.103937 \n",
       "L 629.494797 119.943994 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.126408 106.208303 \n",
       "L 645.126408 106.04863 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.004748 148.081692 \n",
       "L 598.004748 147.921615 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.483175 75.671296 \n",
       "L 679.483175 75.511057 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.824784 117.14257 \n",
       "L 632.824784 116.982364 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.339348 89.990516 \n",
       "L 663.339348 89.831518 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.629357 108.439719 \n",
       "L 642.629357 108.280026 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.275992 128.353872 \n",
       "L 620.275992 128.19675 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.150768 145.283396 \n",
       "L 601.150768 145.123181 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.365865 89.997103 \n",
       "L 663.365865 89.836801 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.465982 123.677705 \n",
       "L 625.465982 123.517882 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.825057 107.357377 \n",
       "L 643.825057 107.197303 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.534822 112.063857 \n",
       "L 638.534822 111.903778 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.463734 94.367584 \n",
       "L 658.463734 94.207578 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 578.778433 165.17312 \n",
       "L 578.778433 165.012984 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.397187 137.063645 \n",
       "L 610.397187 136.903589 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.118402 103.539577 \n",
       "L 648.118402 103.379695 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.680777 136.804556 \n",
       "L 610.680777 136.646605 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.211486 77.688167 \n",
       "L 677.211486 77.527955 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.490106 88.112306 \n",
       "L 665.490106 87.952223 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.911154 97.520318 \n",
       "L 654.911154 97.360303 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.984974 112.541667 \n",
       "L 637.984974 112.381513 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.204395 125.691612 \n",
       "L 623.204395 125.532119 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.712896 76.360857 \n",
       "L 678.712896 76.200719 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.336211 78.468876 \n",
       "L 676.336211 78.308798 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.011803 106.3004 \n",
       "L 645.011803 106.142286 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.338619 135.312122 \n",
       "L 612.338619 135.159201 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.789149 70.956631 \n",
       "L 684.789149 70.79668 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.106763 160.435211 \n",
       "L 584.106763 160.27529 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.292523 143.379073 \n",
       "L 603.292523 143.218945 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.172486 76.840355 \n",
       "L 678.172486 76.6803 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.515428 132.518429 \n",
       "L 615.515428 132.358463 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.134479 156.858904 \n",
       "L 588.134479 156.698654 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.860877 89.560635 \n",
       "L 663.860877 89.400533 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.803142 78.067117 \n",
       "L 676.803142 77.907082 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.90054 121.524007 \n",
       "L 627.90054 121.364126 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.224078 99.007776 \n",
       "L 653.224078 98.8476 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.603987 99.564395 \n",
       "L 652.603987 99.404147 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.093579 119.571944 \n",
       "L 630.093579 119.411951 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.25249 86.543607 \n",
       "L 667.25249 86.383376 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.219281 77.684747 \n",
       "L 677.219281 77.5246 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.154039 120.39429 \n",
       "L 629.154039 120.234073 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.625134 83.518824 \n",
       "L 670.625134 83.360383 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.839293 84.25089 \n",
       "L 669.839293 84.090748 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.393112 100.607942 \n",
       "L 651.393112 100.449267 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.572464 160.016453 \n",
       "L 584.572464 159.856227 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.274204 78.524775 \n",
       "L 676.274204 78.364603 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.556053 77.386481 \n",
       "L 677.556053 77.226262 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.671512 154.598735 \n",
       "L 590.671512 154.4386 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.632777 151.081994 \n",
       "L 594.632777 150.92222 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.625604 156.410202 \n",
       "L 588.625604 156.250042 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.299643 74.946574 \n",
       "L 680.299643 74.786858 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.782488 102.079475 \n",
       "L 649.782488 101.919495 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.013312 135.628131 \n",
       "L 612.013312 135.467905 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.790956 86.949573 \n",
       "L 666.790956 86.789468 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.192034 76.820814 \n",
       "L 678.192034 76.660723 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.581682 77.357732 \n",
       "L 677.581682 77.197536 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.987769 80.560684 \n",
       "L 673.987769 80.400696 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 569.317624 173.573097 \n",
       "L 569.317624 173.412802 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 585.51969 159.189424 \n",
       "L 585.51969 159.029287 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.843874 101.1234 \n",
       "L 650.843874 100.963137 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.070165 116.023502 \n",
       "L 634.070165 115.863917 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.245063 87.430354 \n",
       "L 666.245063 87.270447 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.727034 148.327243 \n",
       "L 597.727034 148.167116 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.733734 136.768383 \n",
       "L 610.733734 136.608655 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.321074 78.486264 \n",
       "L 676.321074 78.326967 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.389161 98.865115 \n",
       "L 653.389161 98.712076 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.160138 153.258472 \n",
       "L 592.160138 153.098635 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.355278 86.460897 \n",
       "L 667.355278 86.301092 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.392544 99.750481 \n",
       "L 652.392544 99.591679 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.781171 154.500239 \n",
       "L 590.781171 154.340085 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.188541 131.959237 \n",
       "L 616.188541 131.801008 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.48162 88.111925 \n",
       "L 665.48162 87.95183 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.635988 106.638857 \n",
       "L 644.635988 106.478935 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.385378 136.175065 \n",
       "L 611.385378 136.016101 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.697892 82.598123 \n",
       "L 671.697892 82.438062 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.606646 92.443694 \n",
       "L 660.606646 92.283491 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.86549 84.226969 \n",
       "L 669.86549 84.066815 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.4986 123.645789 \n",
       "L 625.4986 123.485813 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.745547 142.085271 \n",
       "L 604.745547 141.925862 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.993586 76.995029 \n",
       "L 677.993586 76.834836 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.790093 86.927868 \n",
       "L 666.790093 86.768199 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.98136 106.342009 \n",
       "L 644.98136 106.182007 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.097901 97.314367 \n",
       "L 655.097901 97.15461 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.968898 104.559194 \n",
       "L 646.968898 104.399114 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.670597 97.726997 \n",
       "L 654.670597 97.56675 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.662839 78.181398 \n",
       "L 676.662839 78.021267 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.762735 109.232151 \n",
       "L 641.762735 109.074246 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.270704 156.746154 \n",
       "L 588.270704 156.586163 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.905989 74.391337 \n",
       "L 680.905989 74.231604 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.304335 124.718915 \n",
       "L 624.304335 124.558748 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.761502 136.735463 \n",
       "L 610.761502 136.576413 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.800346 105.620119 \n",
       "L 645.800346 105.464047 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.595012 140.449174 \n",
       "L 606.595012 140.289278 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.737599 98.520242 \n",
       "L 653.737599 98.361567 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.180817 131.941105 \n",
       "L 616.180817 131.780927 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 698.141412 59.091798 \n",
       "L 698.141412 58.93151 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.755027 116.308779 \n",
       "L 633.755027 116.148924 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.659759 126.158529 \n",
       "L 622.659759 125.998932 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.131946 87.541504 \n",
       "L 666.131946 87.381712 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.440755 150.360267 \n",
       "L 595.440755 150.200483 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.717656 94.138924 \n",
       "L 658.717656 93.97983 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.895602 93.094568 \n",
       "L 659.895602 92.934757 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.480725 144.095128 \n",
       "L 602.480725 143.935598 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.768678 134.080478 \n",
       "L 613.768678 133.920513 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.81949 80.711003 \n",
       "L 673.81949 80.5508 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.087686 66.26506 \n",
       "L 690.087686 66.105827 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.571507 115.564382 \n",
       "L 634.571507 115.405704 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.452645 122.79912 \n",
       "L 626.452645 122.639106 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.46289 97.017236 \n",
       "L 655.46289 96.857399 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.789191 83.390124 \n",
       "L 670.789191 83.230045 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.048426 120.483309 \n",
       "L 629.048426 120.324026 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.041667 134.723213 \n",
       "L 613.041667 134.564133 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.233783 88.339795 \n",
       "L 665.233783 88.179619 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.203537 117.69616 \n",
       "L 632.203537 117.536164 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.169697 163.928067 \n",
       "L 580.169697 163.76784 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.322835 77.543566 \n",
       "L 677.322835 77.385295 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.349038 126.453445 \n",
       "L 622.349038 126.295865 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.874678 116.191372 \n",
       "L 633.874678 116.031476 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.297429 112.267337 \n",
       "L 638.297429 112.107231 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.904591 160.615421 \n",
       "L 583.904591 160.455152 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.776623 126.10839 \n",
       "L 622.776623 125.950086 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.608571 90.658978 \n",
       "L 662.608571 90.499989 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 574.124876 169.300507 \n",
       "L 574.124876 169.140272 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.488816 104.099798 \n",
       "L 647.488816 103.939634 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.423627 77.507333 \n",
       "L 677.423627 77.347347 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.993249 101.871989 \n",
       "L 649.993249 101.712535 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.465327 97.905253 \n",
       "L 654.465327 97.74527 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.457517 149.452 \n",
       "L 596.457517 149.291824 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.900934 144.622219 \n",
       "L 601.900934 144.463014 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 688.662146 67.515217 \n",
       "L 688.662146 67.355168 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.812351 79.814449 \n",
       "L 674.812351 79.654274 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.011392 115.198969 \n",
       "L 635.011392 115.039136 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.160079 110.639295 \n",
       "L 640.160079 110.48069 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.883555 123.299363 \n",
       "L 625.883555 123.140146 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.259117 125.635228 \n",
       "L 623.259117 125.475148 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 694.133387 62.650219 \n",
       "L 694.133387 62.48994 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.80516 88.722398 \n",
       "L 664.80516 88.562162 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.772148 118.070373 \n",
       "L 631.772148 117.91064 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.943805 95.701269 \n",
       "L 656.943805 95.541168 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.965247 69.912603 \n",
       "L 685.965247 69.752707 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.416119 74.832887 \n",
       "L 680.416119 74.673473 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.834807 94.00959 \n",
       "L 658.834807 93.849746 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.931801 161.487351 \n",
       "L 582.931801 161.327351 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.024763 116.962204 \n",
       "L 633.024763 116.802013 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.824722 70.927947 \n",
       "L 684.824722 70.767675 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.922499 133.926984 \n",
       "L 613.922499 133.767441 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.074965 111.560852 \n",
       "L 639.074965 111.401537 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.398618 66.863319 \n",
       "L 689.398618 66.703106 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.585152 100.468451 \n",
       "L 651.585152 100.308395 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.06027 95.608427 \n",
       "L 657.06027 95.448559 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.875885 88.659415 \n",
       "L 664.875885 88.499678 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.279587 82.959803 \n",
       "L 671.279587 82.799582 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.254065 117.635619 \n",
       "L 632.254065 117.475953 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.544728 128.051454 \n",
       "L 620.544728 127.89124 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.00915 166.740018 \n",
       "L 577.00915 166.579785 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.871343 128.650837 \n",
       "L 619.871343 128.490652 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.380041 83.76654 \n",
       "L 670.380041 83.606449 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.73664 87.897474 \n",
       "L 665.73664 87.737694 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.523719 84.521817 \n",
       "L 669.523719 84.361527 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.698963 118.157003 \n",
       "L 631.698963 117.99729 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.462383 89.908905 \n",
       "L 663.462383 89.748945 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.494655 122.752137 \n",
       "L 626.494655 122.592135 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.242964 110.529689 \n",
       "L 640.242964 110.370432 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.892811 101.975616 \n",
       "L 649.892811 101.815879 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.061898 90.263865 \n",
       "L 663.061898 90.104121 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.094586 77.791679 \n",
       "L 677.094586 77.631488 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.148338 102.629866 \n",
       "L 649.148338 102.46983 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.694718 111.028567 \n",
       "L 639.694718 110.868314 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.634081 95.086185 \n",
       "L 657.634081 94.926398 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.458134 124.594132 \n",
       "L 624.458134 124.434472 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_41\">\n",
       "    <g clip-path=\"url(#p4a8ef7f9e3)\">\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.537943\" y=\"130.6404\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"628.5567\" y=\"120.846546\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.361652\" y=\"106.80367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"683.253415\" y=\"72.254499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.272681\" y=\"130.882256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.567848\" y=\"83.514505\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.825538\" y=\"116.163649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.078686\" y=\"130.178691\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.039033\" y=\"100.868545\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.292013\" y=\"93.548549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.312298\" y=\"101.504572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.387488\" y=\"112.127696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.27077\" y=\"141.534603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.339711\" y=\"112.153844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"630.51803\" y=\"119.117581\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.595022\" y=\"95.043314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.284994\" y=\"128.2087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.381088\" y=\"96.136393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"602.547838\" y=\"143.961204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.370703\" y=\"96.144304\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.940632\" y=\"122.27896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.812032\" y=\"105.51443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.581994\" y=\"113.737076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.675586\" y=\"86.994558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.050998\" y=\"93.747307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.660293\" y=\"95.868662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.950807\" y=\"148.940112\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.628053\" y=\"97.681125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"634.01393\" y=\"116.037867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.344774\" y=\"73.941509\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.56333\" y=\"90.621289\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.304559\" y=\"135.29425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.885223\" y=\"74.340598\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.379373\" y=\"163.667845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.196942\" y=\"129.164342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.314146\" y=\"130.848045\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.318453\" y=\"81.096942\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"692.577617\" y=\"63.963076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.367381\" y=\"104.125846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.114363\" y=\"107.888922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.563897\" y=\"111.03937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.83997\" y=\"159.704902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"640.145189\" y=\"110.536306\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.97945\" y=\"102.691668\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.931395\" y=\"119.632037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.78536\" y=\"135.758362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.260157\" y=\"98.015255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.478016\" y=\"140.468001\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.305963\" y=\"148.624108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"579.701991\" y=\"164.260998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.357361\" y=\"145.912578\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"687.457328\" y=\"68.508778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"684.629773\" y=\"71.013069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"609.938389\" y=\"137.390126\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"698.666527\" y=\"58.545255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.541142\" y=\"103.077491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.247655\" y=\"89.135271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.458821\" y=\"120.030057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"582.474836\" y=\"161.8051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"691.707682\" y=\"64.723403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.505147\" y=\"117.338537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.553189\" y=\"142.184216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.599632\" y=\"87.048032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"694.228756\" y=\"62.476026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.191323\" y=\"98.087113\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.825194\" y=\"144.599753\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.57524\" y=\"122.608081\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.37091\" y=\"161.019772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.144781\" y=\"153.202626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.382629\" y=\"97.900171\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.622035\" y=\"74.578936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.999681\" y=\"130.213447\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.465258\" y=\"93.361845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.194612\" y=\"107.855253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.679248\" y=\"159.84125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"607.488746\" y=\"139.601054\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.808958\" y=\"149.95276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.515472\" y=\"157.318652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"689.239355\" y=\"66.929709\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.603487\" y=\"111.919561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.295495\" y=\"148.628474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.651103\" y=\"103.861845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.614043\" y=\"100.358783\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.478704\" y=\"156.471098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.805829\" y=\"96.624337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.56543\" y=\"144.839484\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.988969\" y=\"149.796805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.315962\" y=\"152.171981\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.331548\" y=\"99.729797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"615.468771\" y=\"132.495263\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"686.269584\" y=\"69.568649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.691304\" y=\"83.413145\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.388589\" y=\"88.118134\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.916423\" y=\"90.309317\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.964161\" y=\"128.454836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.054349\" y=\"131.082202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.860638\" y=\"107.294248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.72197\" y=\"126.02124\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"640.238219\" y=\"110.479406\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.381892\" y=\"100.566504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.665753\" y=\"140.299044\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.522307\" y=\"81.777673\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"683.407946\" y=\"72.104802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.631252\" y=\"113.690237\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"621.552729\" y=\"127.077245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"602.894682\" y=\"143.66563\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.518108\" y=\"135.116771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"682.694311\" y=\"72.732612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.445156\" y=\"122.725415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.846202\" y=\"163.236213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"614.616453\" y=\"133.249909\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.270417\" y=\"92.647867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"634.107757\" y=\"115.929063\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"602.826374\" y=\"143.759131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.01837\" y=\"108.002131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"621.232947\" y=\"127.387961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.735795\" y=\"88.673415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.386912\" y=\"122.779462\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.027333\" y=\"152.420946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.889549\" y=\"103.667784\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.228696\" y=\"89.149284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"687.949227\" y=\"68.072811\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.036919\" y=\"97.322176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.027159\" y=\"75.993492\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.905394\" y=\"148.083927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.236413\" y=\"74.009086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.654133\" y=\"103.890409\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.682079\" y=\"157.177534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.669714\" y=\"131.424788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.343031\" y=\"75.710524\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.982106\" y=\"140.922786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"594.795768\" y=\"150.855651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.498613\" y=\"112.010801\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.148027\" y=\"140.767367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.97406\" y=\"88.494279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.96194\" y=\"107.16292\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.067054\" y=\"131.055859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.119437\" y=\"106.132566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.437723\" y=\"117.382972\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.521035\" y=\"156.42686\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.882579\" y=\"147.216894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"637.46282\" y=\"112.904508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.605282\" y=\"97.720637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.468499\" y=\"152.92141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.080542\" y=\"158.600358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.939177\" y=\"106.287647\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.854417\" y=\"81.511046\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.054782\" y=\"70.635595\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.812375\" y=\"83.302438\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.522603\" y=\"89.78129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.052432\" y=\"157.730841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"607.935088\" y=\"139.183114\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.691419\" y=\"95.848523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"691.144589\" y=\"65.226749\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.069292\" y=\"109.744489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.126718\" y=\"160.327528\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.702968\" y=\"128.73269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.202154\" y=\"84.73317\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.1693\" y=\"90.107761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"628.078093\" y=\"121.278706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.016448\" y=\"126.659485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.495545\" y=\"98.699338\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.397237\" y=\"84.555632\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.83446\" y=\"121.508416\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.281509\" y=\"157.539232\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"628.268524\" y=\"121.116911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.455048\" y=\"96.050336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.068876\" y=\"149.721393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.195534\" y=\"76.732035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"691.36709\" y=\"65.034018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.288837\" y=\"130.867538\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.169119\" y=\"130.070576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.554146\" y=\"143.075151\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.253974\" y=\"93.565141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.83054\" y=\"81.516289\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.158076\" y=\"90.096578\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.210923\" y=\"82.93235\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.133708\" y=\"157.662775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.849654\" y=\"133.923196\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.985564\" y=\"84.024935\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.286849\" y=\"154.855163\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.618914\" y=\"111.90472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.138183\" y=\"103.441947\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.111947\" y=\"90.144419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.586783\" y=\"98.618869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"599.216602\" y=\"146.921752\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.746571\" y=\"152.699874\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.552078\" y=\"127.958849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"630.459572\" y=\"119.149736\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.064692\" y=\"87.529408\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.304412\" y=\"109.52171\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.482966\" y=\"75.600555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.106863\" y=\"90.132468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"689.999249\" y=\"66.249358\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.996291\" y=\"83.169922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"574.307104\" y=\"169.061428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.587698\" y=\"113.702988\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.595351\" y=\"73.707316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"621.549785\" y=\"127.072145\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.221361\" y=\"74.051954\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.457762\" y=\"156.4886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.248866\" y=\"82.908522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.67282\" y=\"160.733576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.561494\" y=\"80.845393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.357658\" y=\"161.014756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.057912\" y=\"129.315231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.466443\" y=\"101.3899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.8717\" y=\"82.387242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.040568\" y=\"155.082348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.862998\" y=\"85.910941\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.281311\" y=\"97.988738\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"668.979965\" y=\"84.905881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.252523\" y=\"130.880177\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.871708\" y=\"151.666449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.836228\" y=\"154.364717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.09554\" y=\"97.264892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.096919\" y=\"112.37526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.577195\" y=\"147.497185\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"609.435417\" y=\"137.845274\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.517125\" y=\"104.889604\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.505756\" y=\"147.572352\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.804306\" y=\"123.257641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.706378\" y=\"155.382378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.513592\" y=\"99.550863\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.2627\" y=\"153.107462\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.903335\" y=\"154.310764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.89111\" y=\"110.772086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"635.096957\" y=\"115.039912\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.805381\" y=\"75.301079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"642.246418\" y=\"108.689926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.449111\" y=\"138.713345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.198859\" y=\"95.399683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.100808\" y=\"160.355328\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.910957\" y=\"141.855533\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"690.442397\" y=\"65.858443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"594.712442\" y=\"150.925833\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.400909\" y=\"95.21126\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.332302\" y=\"136.164258\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.320749\" y=\"129.060717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.2625\" y=\"88.243083\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.388184\" y=\"97.022181\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.747603\" y=\"151.778606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.993684\" y=\"89.371737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.940827\" y=\"96.498503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.286142\" y=\"141.542081\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.362818\" y=\"117.472388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.374983\" y=\"113.919774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"690.988632\" y=\"65.379937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.34895\" y=\"89.044632\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.340147\" y=\"129.042808\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.600114\" y=\"100.359848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.23742\" y=\"95.348174\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.735824\" y=\"113.580384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.531747\" y=\"84.432555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.34169\" y=\"121.922394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.559036\" y=\"80.862994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.710699\" y=\"119.819727\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"615.333282\" y=\"132.598439\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.756224\" y=\"123.336772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.161506\" y=\"88.327617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"691.039826\" y=\"65.33427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.499513\" y=\"81.79875\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"631.252282\" y=\"118.470435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.783683\" y=\"138.414825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.593765\" y=\"151.923355\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.704386\" y=\"155.388886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.096133\" y=\"116.819278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"688.691788\" y=\"67.423413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"630.522613\" y=\"119.112778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.262461\" y=\"157.548634\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.643567\" y=\"142.97507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"674.679075\" y=\"79.876529\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.456671\" y=\"111.163401\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.830293\" y=\"85.943523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.820888\" y=\"89.515444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.190503\" y=\"78.503641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.066777\" y=\"107.064035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.654588\" y=\"117.211318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.435185\" y=\"90.713636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"630.485897\" y=\"119.131946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.299922\" y=\"82.883185\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.407227\" y=\"78.320903\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.973931\" y=\"80.492775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.877871\" y=\"131.236155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"578.378379\" y=\"165.45297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.549837\" y=\"116.445772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"570.959274\" y=\"172.035841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.934915\" y=\"110.743943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.982462\" y=\"93.814883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"607.107466\" y=\"139.913794\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.076041\" y=\"75.063591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.17386\" y=\"96.321385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.952022\" y=\"151.596548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.388026\" y=\"126.339843\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.21843\" y=\"146.035778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"599.664599\" y=\"146.563355\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.099649\" y=\"70.60105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.825641\" y=\"123.283508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.981825\" y=\"75.152761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.822316\" y=\"104.623715\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.67487\" y=\"74.538582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.608668\" y=\"144.807082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.970779\" y=\"97.390026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.521051\" y=\"142.224258\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.383577\" y=\"97.007574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.032474\" y=\"91.991587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.81123\" y=\"90.399922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.992141\" y=\"89.36408\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.453878\" y=\"155.600837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.020672\" y=\"147.989089\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.908685\" y=\"148.950847\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.751985\" y=\"110.92156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.43414\" y=\"147.617961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.562634\" y=\"80.845913\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.912807\" y=\"151.62285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.275406\" y=\"137.093382\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.71677\" y=\"149.169228\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.166762\" y=\"76.764032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.602965\" y=\"92.380994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.14998\" y=\"82.106439\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.570046\" y=\"153.725911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.969925\" y=\"152.466707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.549951\" y=\"95.086387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.798501\" y=\"152.617155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.334901\" y=\"125.457888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.059812\" y=\"106.185821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.012136\" y=\"96.449377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.610654\" y=\"121.691571\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.517725\" y=\"92.454865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.002124\" y=\"99.119629\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.151098\" y=\"126.536749\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"640.437584\" y=\"110.290041\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.998736\" y=\"116.030315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.395019\" y=\"155.666965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"693.599935\" y=\"63.038272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.738064\" y=\"153.571197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.75747\" y=\"130.463815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"668.307519\" y=\"85.527501\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.893849\" y=\"107.223051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.295976\" y=\"137.066356\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.637027\" y=\"94.114021\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.013364\" y=\"135.49806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"607.822188\" y=\"139.274869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.069153\" y=\"87.511044\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"684.948539\" y=\"70.770883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.702189\" y=\"70.063639\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.765884\" y=\"140.190523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.601806\" y=\"90.607857\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"614.007851\" y=\"133.770413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.584203\" y=\"150.153353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"614.813717\" y=\"133.059155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"692.149168\" y=\"64.336917\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"682.891423\" y=\"72.563651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.719112\" y=\"97.603352\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.062341\" y=\"105.286593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.584986\" y=\"81.701257\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.911291\" y=\"133.86325\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.653103\" y=\"152.759713\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.757689\" y=\"145.559575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.754655\" y=\"101.121687\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.950047\" y=\"107.188206\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.560325\" y=\"84.421087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.893638\" y=\"155.204061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.593468\" y=\"92.378196\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.470216\" y=\"111.170927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.703859\" y=\"99.385431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"689.49281\" y=\"66.699756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.211951\" y=\"137.143792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.21526\" y=\"131.819042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.562826\" y=\"157.27258\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.409934\" y=\"75.663678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.200099\" y=\"150.494795\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.594535\" y=\"141.242785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.764888\" y=\"163.32192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.599644\" y=\"87.92668\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.869628\" y=\"136.567701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.795382\" y=\"129.523082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.951135\" y=\"121.373895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.900207\" y=\"163.18052\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"599.609247\" y=\"146.573608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.571076\" y=\"111.948548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.017199\" y=\"94.669086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"585.022795\" y=\"159.542134\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.804111\" y=\"92.182087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"686.228275\" y=\"69.600336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.927246\" y=\"107.174732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.223076\" y=\"111.369883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.410037\" y=\"153.867596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.469612\" y=\"75.579968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.433549\" y=\"98.734912\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.733795\" y=\"136.700225\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.601521\" y=\"128.812018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.48207\" y=\"111.117846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.494252\" y=\"74.705864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.017897\" y=\"107.999396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.043575\" y=\"90.212218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.84774\" y=\"119.710809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.171338\" y=\"82.982625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"682.048157\" y=\"73.308812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.016598\" y=\"146.225084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.486636\" y=\"156.436926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.563238\" y=\"158.177507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.39129\" y=\"163.663425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.249434\" y=\"134.445474\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.722402\" y=\"80.721582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"637.384161\" y=\"113.001818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.952893\" y=\"88.50436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"698.296373\" y=\"58.873741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.185166\" y=\"143.39374\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"642.388216\" y=\"108.55028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"609.19163\" y=\"138.060972\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.478783\" y=\"91.601854\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.750279\" y=\"121.550814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.72119\" y=\"107.38281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.818018\" y=\"109.076105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.64916\" y=\"159.89322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.630546\" y=\"127.884998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.793826\" y=\"153.525614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.19975\" y=\"74.956189\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.168685\" y=\"142.521626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"635.86608\" y=\"114.348511\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"594.887538\" y=\"150.772737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.192947\" y=\"148.722367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.338498\" y=\"116.593619\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.316175\" y=\"93.53378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.430338\" y=\"70.303316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.646509\" y=\"144.795956\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.693105\" y=\"113.621117\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.560669\" y=\"80.860098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.182719\" y=\"84.747402\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"599.725221\" y=\"146.486136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"674.430157\" y=\"80.082692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"674.962638\" y=\"79.615166\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"581.35456\" y=\"162.793147\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.729673\" y=\"86.074221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.847815\" y=\"86.821979\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.005373\" y=\"88.449466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"637.917261\" y=\"112.530195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.8248\" y=\"133.923074\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.127603\" y=\"146.119636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.804396\" y=\"104.603866\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.001312\" y=\"117.792904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.784029\" y=\"135.765591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.070255\" y=\"102.616038\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.119292\" y=\"89.232648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"607.645804\" y=\"139.440248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.752893\" y=\"147.338856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"628.35218\" y=\"121.013216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"684.985628\" y=\"70.711445\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.302423\" y=\"138.874246\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.925057\" y=\"89.414239\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.081374\" y=\"114.174356\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.632493\" y=\"96.773855\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"642.014564\" y=\"108.892703\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"585.43061\" y=\"159.173393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.6965\" y=\"86.087987\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.914895\" y=\"81.43812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.953992\" y=\"90.294014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.526808\" y=\"98.639273\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.596091\" y=\"100.382061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.925444\" y=\"147.183051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.606177\" y=\"113.693697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.450621\" y=\"141.392916\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"602.820524\" y=\"143.703128\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"635.532458\" y=\"114.672307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.89993\" y=\"96.542377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.761082\" y=\"82.450993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.132539\" y=\"78.557849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"585.812989\" y=\"158.85128\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"697.18917\" y=\"59.863685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.967424\" y=\"76.94774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"594.884784\" y=\"150.774395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"640.009745\" y=\"110.690807\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.515172\" y=\"140.430407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.051145\" y=\"130.156776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"692.594104\" y=\"63.944828\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.571217\" y=\"138.586339\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.738124\" y=\"100.251647\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.040757\" y=\"125.758778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"574.481609\" y=\"168.915772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.482531\" y=\"138.700231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.613524\" y=\"129.680792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.180765\" y=\"143.424865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.135505\" y=\"141.669333\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.854942\" y=\"141.040818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.297115\" y=\"99.768879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.038535\" y=\"116.868808\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.896475\" y=\"77.000365\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.027909\" y=\"109.764478\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.457528\" y=\"107.593796\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.085665\" y=\"90.155904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.459255\" y=\"86.270274\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.880541\" y=\"92.995556\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.267486\" y=\"82.002971\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.338847\" y=\"145.931804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.412326\" y=\"90.742773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.251623\" y=\"136.237994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.230261\" y=\"120.256386\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.003869\" y=\"101.789211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.869553\" y=\"83.244928\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.951455\" y=\"142.727732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"599.178315\" y=\"146.959633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"615.413659\" y=\"132.525213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.301842\" y=\"158.405132\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.532531\" y=\"94.212399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.965002\" y=\"91.178027\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"602.127626\" y=\"144.332412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.079458\" y=\"134.60419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.770722\" y=\"117.143853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.360242\" y=\"145.020146\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.005648\" y=\"136.456017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.084834\" y=\"103.463542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.446385\" y=\"128.964698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"687.975779\" y=\"68.048952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.295755\" y=\"156.624462\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"693.054426\" y=\"63.536739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.071361\" y=\"91.961394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.997161\" y=\"85.800646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.756081\" y=\"163.333314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.23296\" y=\"136.224225\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.954398\" y=\"100.054739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.782059\" y=\"102.872102\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"688.17683\" y=\"67.865292\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.009653\" y=\"92.001044\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.968743\" y=\"163.144515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.399845\" y=\"120.124986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.591152\" y=\"99.494374\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.582159\" y=\"103.944415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.738173\" y=\"90.476486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.492716\" y=\"111.157378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.109493\" y=\"112.363069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.752612\" y=\"76.2429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.986031\" y=\"148.020564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.158275\" y=\"154.970496\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.620137\" y=\"94.136633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.76349\" y=\"77.118512\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.11993\" y=\"83.023214\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.108483\" y=\"122.146805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.819345\" y=\"76.186468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.188597\" y=\"74.085537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"577.935517\" y=\"165.83522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"615.375584\" y=\"132.55601\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"581.389023\" y=\"162.770595\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.652213\" y=\"76.334465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.980685\" y=\"80.471303\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.273145\" y=\"99.771934\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.053489\" y=\"117.761561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"614.979352\" y=\"132.914654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"635.573167\" y=\"114.616751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"614.536567\" y=\"133.319774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.359454\" y=\"92.588096\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.457969\" y=\"126.247611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.517499\" y=\"129.771493\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.431281\" y=\"95.198044\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.754697\" y=\"86.908802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.059872\" y=\"158.597065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.947983\" y=\"138.276086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.398556\" y=\"81.888785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.973942\" y=\"160.472914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.361625\" y=\"120.142549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.898156\" y=\"110.766697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"635.715299\" y=\"114.493135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.65045\" y=\"125.20521\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.606924\" y=\"131.465101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.086936\" y=\"129.277917\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.662655\" y=\"152.748547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.766102\" y=\"144.657354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.048621\" y=\"147.967098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.191776\" y=\"91.841897\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.539397\" y=\"123.47746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"690.688734\" y=\"65.635149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.168294\" y=\"142.53793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.19614\" y=\"126.495367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.136295\" y=\"95.456648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.069289\" y=\"87.511518\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.910255\" y=\"83.209461\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.717872\" y=\"142.924518\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.168035\" y=\"163.849539\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.683321\" y=\"70.100472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.103546\" y=\"93.709463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.624246\" y=\"129.683554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.897743\" y=\"156.092429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.63515\" y=\"96.790948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.980265\" y=\"127.569428\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.626601\" y=\"77.242551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.466629\" y=\"122.722354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.613091\" y=\"70.129526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.626643\" y=\"151.888256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.286448\" y=\"128.191712\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.574216\" y=\"88.839769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"682.055789\" y=\"73.308354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"675.065246\" y=\"79.524382\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.702041\" y=\"117.185948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"668.366645\" y=\"85.482281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.817616\" y=\"141.95074\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.041201\" y=\"137.298438\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.26751\" y=\"102.451678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"631.741482\" y=\"118.015758\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.801615\" y=\"152.623714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.17045\" y=\"154.080222\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.240252\" y=\"134.475696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.34785\" y=\"122.796989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.66894\" y=\"86.975417\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.581386\" y=\"155.484465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.076544\" y=\"75.966661\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.720512\" y=\"94.069652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.887259\" y=\"159.664666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.216286\" y=\"112.257433\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.492699\" y=\"83.673798\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.590559\" y=\"131.473081\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.456165\" y=\"156.479997\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"577.041608\" y=\"166.628509\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.506937\" y=\"81.795388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"693.360649\" y=\"63.263709\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.476102\" y=\"129.820377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"599.368527\" y=\"146.78267\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"581.176052\" y=\"162.961271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"617.637923\" y=\"130.552262\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.376063\" y=\"109.462301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.519487\" y=\"83.564836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.275346\" y=\"143.301435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.279784\" y=\"74.853983\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.653168\" y=\"144.760423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.109116\" y=\"78.591161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.660813\" y=\"97.656189\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"683.897565\" y=\"71.660323\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"675.525498\" y=\"79.109067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"589.043958\" y=\"155.963877\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.874206\" y=\"147.221677\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.727061\" y=\"88.698182\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"699.93322\" y=\"57.422664\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.454529\" y=\"90.719026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.198834\" y=\"89.182333\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.551155\" y=\"102.17116\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"621.904467\" y=\"126.762826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.633159\" y=\"135.892161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.443362\" y=\"160.946451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.589376\" y=\"106.619859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.524749\" y=\"84.455261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"585.279668\" y=\"159.296156\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.75063\" y=\"94.877985\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.060986\" y=\"152.393574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.964428\" y=\"86.714958\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.866416\" y=\"117.020489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.357976\" y=\"145.907813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.954508\" y=\"90.282865\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.510932\" y=\"136.883318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.332708\" y=\"117.499322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"607.318019\" y=\"139.728461\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"675.682588\" y=\"78.96636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.18966\" y=\"158.498918\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.828154\" y=\"73.509043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.745049\" y=\"156.224068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"642.180085\" y=\"108.75134\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"577.436698\" y=\"166.281635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.250976\" y=\"82.02328\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.519401\" y=\"87.102785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.346607\" y=\"81.029952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"581.619264\" y=\"162.545486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.766985\" y=\"103.778534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.021525\" y=\"125.768201\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"637.834442\" y=\"112.597573\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.553646\" y=\"96.857091\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.812859\" y=\"157.057108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.216626\" y=\"76.709712\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"621.706241\" y=\"126.936203\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.660533\" y=\"76.322191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"668.906819\" y=\"84.990875\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"575.152806\" y=\"168.313503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.24512\" y=\"95.34915\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.633674\" y=\"89.671315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.416564\" y=\"73.874587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.103055\" y=\"91.94936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"693.335886\" y=\"63.281996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.550465\" y=\"93.304533\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.995996\" y=\"92.915998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"609.788352\" y=\"137.528966\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.550524\" y=\"158.182114\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.375887\" y=\"101.461967\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.641211\" y=\"147.435434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.167917\" y=\"140.745552\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.997201\" y=\"149.790444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.733379\" y=\"102.917584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"668.952326\" y=\"84.950297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.710237\" y=\"125.166125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.28259\" y=\"129.983042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"608.287609\" y=\"138.85947\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"615.813131\" y=\"132.179757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.538615\" y=\"121.738261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.194189\" y=\"137.16381\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.618324\" y=\"121.688204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"681.695579\" y=\"73.614399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"609.896109\" y=\"137.442675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"605.691288\" y=\"141.194547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.891835\" y=\"156.101072\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.439044\" y=\"149.416885\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"686.392944\" y=\"69.454274\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.430487\" y=\"104.953964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.990498\" y=\"107.133066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.653783\" y=\"86.994119\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"630.950575\" y=\"118.747489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.993424\" y=\"75.149403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.689255\" y=\"111.860568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"600.143078\" y=\"146.1016\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.572364\" y=\"102.180518\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.215521\" y=\"128.262741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.473845\" y=\"150.245416\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.398815\" y=\"156.531466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.039732\" y=\"161.310864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.854221\" y=\"110.80102\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.133411\" y=\"95.458242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.17576\" y=\"94.531415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.913396\" y=\"91.229073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.167778\" y=\"152.292678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.628085\" y=\"135.900359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.103313\" y=\"75.928144\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.92811\" y=\"106.297488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.096915\" y=\"105.279515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.112543\" y=\"87.479468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.335836\" y=\"149.49734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.24241\" y=\"145.131937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"661.783538\" y=\"91.321007\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"634.376207\" y=\"115.66434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"687.99595\" y=\"68.033857\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.291178\" y=\"152.195067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.798427\" y=\"85.982322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.701285\" y=\"160.715431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"614.863413\" y=\"132.97591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.695416\" y=\"101.18067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.092418\" y=\"107.920571\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.014272\" y=\"135.581148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.626675\" y=\"142.994972\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.384801\" y=\"147.659053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.652304\" y=\"101.218657\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.787314\" y=\"140.221245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.319414\" y=\"104.156707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"683.730486\" y=\"71.823481\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.226112\" y=\"152.245445\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"683.603577\" y=\"71.933258\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.475432\" y=\"136.92491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.03057\" y=\"137.293656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.78755\" y=\"107.307403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.262186\" y=\"107.802431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.922853\" y=\"76.089076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"690.806857\" y=\"65.524198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"689.414082\" y=\"66.769572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.820834\" y=\"75.287108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.572875\" y=\"80.836271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.963859\" y=\"153.380786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.274952\" y=\"95.330548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"591.803903\" y=\"153.514017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.042852\" y=\"86.65332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.144358\" y=\"140.758619\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.858745\" y=\"163.241023\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.325047\" y=\"99.7271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.775772\" y=\"121.552047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.48634\" y=\"102.267469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.974291\" y=\"163.135893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.483685\" y=\"107.594237\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.861636\" y=\"154.348188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.506428\" y=\"94.244929\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.294546\" y=\"148.636789\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.541089\" y=\"87.98385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"578.10863\" y=\"165.685558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"636.179577\" y=\"114.072579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"581.011439\" y=\"163.108638\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"634.430391\" y=\"115.627154\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.220557\" y=\"117.58175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.861698\" y=\"116.134088\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"689.034165\" y=\"67.107695\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.027254\" y=\"158.651574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.44241\" y=\"96.917002\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"668.902201\" y=\"85.000215\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"624.367524\" y=\"124.566653\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"593.18273\" y=\"152.294982\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"586.225094\" y=\"158.474063\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.180941\" y=\"84.760206\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"674.470099\" y=\"80.044805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.722674\" y=\"117.155469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.498035\" y=\"77.338763\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.907777\" y=\"81.434891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.760745\" y=\"119.780569\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.967589\" y=\"105.376368\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"631.687042\" y=\"118.063953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.472293\" y=\"99.597385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.352508\" y=\"131.710132\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.425396\" y=\"107.635197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.130337\" y=\"78.574481\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.739247\" y=\"111.786296\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.199541\" y=\"134.496308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.856997\" y=\"135.695526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.548394\" y=\"107.528646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.973837\" y=\"128.483597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"624.371079\" y=\"124.562804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.084328\" y=\"150.602032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.410869\" y=\"131.642185\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"582.840819\" y=\"161.480515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.73593\" y=\"86.915519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.941902\" y=\"121.39542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.705134\" y=\"131.398272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.493135\" y=\"93.353379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.132092\" y=\"109.676718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.359267\" y=\"97.031695\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"587.1823\" y=\"157.63009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"642.796117\" y=\"108.204042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.212158\" y=\"135.374788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.486148\" y=\"87.161778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.152146\" y=\"122.990012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.417737\" y=\"131.653159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.206787\" y=\"129.159283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.800712\" y=\"100.196623\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.659742\" y=\"103.91814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.453117\" y=\"109.392206\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.643848\" y=\"103.908192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.10334\" y=\"87.483816\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.46296\" y=\"90.699352\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.150773\" y=\"82.11021\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"675.207065\" y=\"79.403803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.052611\" y=\"143.510407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.696636\" y=\"110.953756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.681888\" y=\"119.869614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"618.029506\" y=\"130.191461\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.82218\" y=\"123.285853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.924734\" y=\"125.840601\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.847878\" y=\"93.93213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"682.155295\" y=\"73.2175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"581.148477\" y=\"162.977501\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"672.736923\" y=\"81.591414\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.561163\" y=\"122.62005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.494797\" y=\"120.023965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.126408\" y=\"106.128467\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"598.004748\" y=\"148.001654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"679.483175\" y=\"75.591177\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.824784\" y=\"117.062467\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.339348\" y=\"89.911017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"642.629357\" y=\"108.359872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.275992\" y=\"128.275311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.150768\" y=\"145.203288\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.365865\" y=\"89.916952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.465982\" y=\"123.597793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"643.825057\" y=\"107.27734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.534822\" y=\"111.983818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.463734\" y=\"94.287581\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"578.778433\" y=\"165.093052\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.397187\" y=\"136.983617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"648.118402\" y=\"103.459636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.680777\" y=\"136.72558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.211486\" y=\"77.608061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.490106\" y=\"88.032264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.911154\" y=\"97.440311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"637.984974\" y=\"112.46159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.204395\" y=\"125.611866\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.712896\" y=\"76.280788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.336211\" y=\"78.388837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.011803\" y=\"106.221343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.338619\" y=\"135.235661\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"684.789149\" y=\"70.876656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.106763\" y=\"160.355251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"603.292523\" y=\"143.299009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.172486\" y=\"76.760327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"615.515428\" y=\"132.438446\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.134479\" y=\"156.778779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.860877\" y=\"89.480584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.803142\" y=\"77.9871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"627.90054\" y=\"121.444066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.224078\" y=\"98.927688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.603987\" y=\"99.484271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"630.093579\" y=\"119.491948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.25249\" y=\"86.463491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.219281\" y=\"77.604674\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.154039\" y=\"120.314182\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.625134\" y=\"83.439603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.839293\" y=\"84.170819\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.393112\" y=\"100.528605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"584.572464\" y=\"159.93634\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.274204\" y=\"78.444689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.556053\" y=\"77.306371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.671512\" y=\"154.518667\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"594.632777\" y=\"151.002107\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.625604\" y=\"156.330122\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.299643\" y=\"74.866716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.782488\" y=\"101.999485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"612.013312\" y=\"135.548018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.790956\" y=\"86.86952\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"678.192034\" y=\"76.740769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.581682\" y=\"77.277634\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.987769\" y=\"80.48069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"569.317624\" y=\"173.492949\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"585.51969\" y=\"159.109356\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"650.843874\" y=\"101.043269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"634.070165\" y=\"115.943709\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.245063\" y=\"87.3504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"597.727034\" y=\"148.24718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.733734\" y=\"136.688519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.321074\" y=\"78.406616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.389161\" y=\"98.788596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"592.160138\" y=\"153.178554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"667.355278\" y=\"86.380994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"652.392544\" y=\"99.67108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"590.781171\" y=\"154.420162\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.188541\" y=\"131.880122\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.48162\" y=\"88.031877\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.635988\" y=\"106.558896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"611.385378\" y=\"136.095583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.697892\" y=\"82.518092\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"660.606646\" y=\"92.363593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.86549\" y=\"84.146892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.4986\" y=\"123.565801\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"604.745547\" y=\"142.005566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.993586\" y=\"76.914932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.790093\" y=\"86.848034\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"644.98136\" y=\"106.262008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.097901\" y=\"97.234489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"646.968898\" y=\"104.479154\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.670597\" y=\"97.646874\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"676.662839\" y=\"78.101332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"641.762735\" y=\"109.153198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"588.270704\" y=\"156.666159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.905989\" y=\"74.311471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"624.304335\" y=\"124.638832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"610.761502\" y=\"136.655938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"645.800346\" y=\"105.542083\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"606.595012\" y=\"140.369226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"653.737599\" y=\"98.440904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"616.180817\" y=\"131.861016\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"698.141412\" y=\"59.011654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.755027\" y=\"116.228852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.659759\" y=\"126.078731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"666.131946\" y=\"87.461608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"595.440755\" y=\"150.280375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.717656\" y=\"94.059377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"659.895602\" y=\"93.014662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"602.480725\" y=\"144.015363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.768678\" y=\"134.000496\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"673.81949\" y=\"80.630902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"690.087686\" y=\"66.185443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"634.571507\" y=\"115.485043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.452645\" y=\"122.719113\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"655.46289\" y=\"96.937317\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.789191\" y=\"83.310085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"629.048426\" y=\"120.403668\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.041667\" y=\"134.643673\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.233783\" y=\"88.259707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.203537\" y=\"117.616162\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"580.169697\" y=\"163.847953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.322835\" y=\"77.46443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.349038\" y=\"126.374655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.874678\" y=\"116.111424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"638.297429\" y=\"112.187284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"583.904591\" y=\"160.535286\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"622.776623\" y=\"126.029238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"662.608571\" y=\"90.579483\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"574.124876\" y=\"169.220389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"647.488816\" y=\"104.019716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.423627\" y=\"77.42734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.993249\" y=\"101.792262\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"654.465327\" y=\"97.825262\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"596.457517\" y=\"149.371912\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"601.900934\" y=\"144.542616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"688.662146\" y=\"67.435192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"674.812351\" y=\"79.734361\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"635.011392\" y=\"115.119053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"640.160079\" y=\"110.559993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"625.883555\" y=\"123.219754\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"623.259117\" y=\"125.555188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"694.133387\" y=\"62.570079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.80516\" y=\"88.64228\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"631.772148\" y=\"117.990506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"656.943805\" y=\"95.621219\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"685.965247\" y=\"69.832655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"680.416119\" y=\"74.75318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"658.834807\" y=\"93.929668\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"582.931801\" y=\"161.407351\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"633.024763\" y=\"116.882108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"684.824722\" y=\"70.847811\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"613.922499\" y=\"133.847213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.074965\" y=\"111.481194\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"689.398618\" y=\"66.783212\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"651.585152\" y=\"100.388423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.06027\" y=\"95.528493\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"664.875885\" y=\"88.579546\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"671.279587\" y=\"82.879692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"632.254065\" y=\"117.555786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"620.544728\" y=\"127.971347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"577.00915\" y=\"166.659901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"619.871343\" y=\"128.570744\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"670.380041\" y=\"83.686494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"665.73664\" y=\"87.817584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"669.523719\" y=\"84.441672\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"631.698963\" y=\"118.077146\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.462383\" y=\"89.828925\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"626.494655\" y=\"122.672136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"640.242964\" y=\"110.45006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.892811\" y=\"101.895747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"663.061898\" y=\"90.183993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"677.094586\" y=\"77.711583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"649.148338\" y=\"102.549848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"639.694718\" y=\"110.94844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"657.634081\" y=\"95.006291\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#m6c2c26cb29\" x=\"624.458134\" y=\"124.514302\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 562.786844 168.981956 \n",
       "L 562.786844 56.040601 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 574.397392 179.384625 \n",
       "L 701.484689 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_43\">\n",
       "    <!-- RMSE: 0.000 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(569.970702 64.316362) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_44\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(572.727172 45.531) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_42\">\n",
       "    <path d=\"M 617.537943 130.64333 \n",
       "L 698.666527 58.545077 \n",
       "L 574.307104 169.062194 \n",
       "L 681.221361 74.048441 \n",
       "\" clip-path=\"url(#p4a8ef7f9e3)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_45\">\n",
       "   <!-- Verification with training data -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(255.00075 18.8475) scale(0.16 -0.16)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-56\" d=\"M 1803 0 \n",
       "L 28 4581 \n",
       "L 684 4581 \n",
       "L 1875 1253 \n",
       "Q 2019 853 2116 503 \n",
       "Q 2222 878 2363 1253 \n",
       "L 3600 4581 \n",
       "L 4219 4581 \n",
       "L 2425 0 \n",
       "L 1803 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-77\" d=\"M 1034 0 \n",
       "L 19 3319 \n",
       "L 600 3319 \n",
       "L 1128 1403 \n",
       "L 1325 691 \n",
       "Q 1338 744 1497 1375 \n",
       "L 2025 3319 \n",
       "L 2603 3319 \n",
       "L 3100 1394 \n",
       "L 3266 759 \n",
       "L 3456 1400 \n",
       "L 4025 3319 \n",
       "L 4572 3319 \n",
       "L 3534 0 \n",
       "L 2950 0 \n",
       "L 2422 1988 \n",
       "L 2294 2553 \n",
       "L 1622 0 \n",
       "L 1034 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-68\" d=\"M 422 0 \n",
       "L 422 4581 \n",
       "L 984 4581 \n",
       "L 984 2938 \n",
       "Q 1378 3394 1978 3394 \n",
       "Q 2347 3394 2619 3248 \n",
       "Q 2891 3103 3008 2847 \n",
       "Q 3125 2591 3125 2103 \n",
       "L 3125 0 \n",
       "L 2563 0 \n",
       "L 2563 2103 \n",
       "Q 2563 2525 2380 2717 \n",
       "Q 2197 2909 1863 2909 \n",
       "Q 1613 2909 1392 2779 \n",
       "Q 1172 2650 1078 2428 \n",
       "Q 984 2206 984 1816 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-67\" d=\"M 319 -275 \n",
       "L 866 -356 \n",
       "Q 900 -609 1056 -725 \n",
       "Q 1266 -881 1628 -881 \n",
       "Q 2019 -881 2231 -725 \n",
       "Q 2444 -569 2519 -288 \n",
       "Q 2563 -116 2559 434 \n",
       "Q 2191 0 1641 0 \n",
       "Q 956 0 581 494 \n",
       "Q 206 988 206 1678 \n",
       "Q 206 2153 378 2554 \n",
       "Q 550 2956 876 3175 \n",
       "Q 1203 3394 1644 3394 \n",
       "Q 2231 3394 2613 2919 \n",
       "L 2613 3319 \n",
       "L 3131 3319 \n",
       "L 3131 450 \n",
       "Q 3131 -325 2973 -648 \n",
       "Q 2816 -972 2473 -1159 \n",
       "Q 2131 -1347 1631 -1347 \n",
       "Q 1038 -1347 672 -1080 \n",
       "Q 306 -813 319 -275 \n",
       "z\n",
       "M 784 1719 \n",
       "Q 784 1066 1043 766 \n",
       "Q 1303 466 1694 466 \n",
       "Q 2081 466 2343 764 \n",
       "Q 2606 1063 2606 1700 \n",
       "Q 2606 2309 2336 2618 \n",
       "Q 2066 2928 1684 2928 \n",
       "Q 1309 2928 1046 2623 \n",
       "Q 784 2319 784 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-56\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"61.199219\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"116.814453\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"150.115234\"/>\n",
       "    <use xlink:href=\"#ArialMT-66\" x=\"172.332031\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"200.115234\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"222.332031\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"272.332031\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"327.947266\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"355.730469\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"377.947266\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"433.5625\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"489.177734\"/>\n",
       "    <use xlink:href=\"#ArialMT-77\" x=\"516.960938\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"589.177734\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"611.394531\"/>\n",
       "    <use xlink:href=\"#ArialMT-68\" x=\"639.177734\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"694.792969\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"722.576172\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"750.359375\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"783.660156\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"839.275391\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"861.492188\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"917.107422\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"939.324219\"/>\n",
       "    <use xlink:href=\"#ArialMT-67\" x=\"994.939453\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"1050.554688\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"1078.337891\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"1133.953125\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"1189.568359\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"1217.351562\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pf2d8b3ac00\">\n",
       "   <rect x=\"45.65125\" y=\"51.531\" width=\"143.677156\" height=\"127.853625\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p9688c5624f\">\n",
       "   <rect x=\"218.029781\" y=\"51.531\" width=\"143.677156\" height=\"127.853625\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p86e636b471\">\n",
       "   <rect x=\"390.408313\" y=\"51.531\" width=\"143.677156\" height=\"127.853625\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p4a8ef7f9e3\">\n",
       "   <rect x=\"562.786844\" y=\"51.531\" width=\"143.677156\" height=\"127.853625\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1000x300 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"713.664pt\" height=\"215.712pt\" viewBox=\"0 0 713.664 215.712\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:38.785945</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M -0 215.712 \n",
       "L 713.664 215.712 \n",
       "L 713.664 0 \n",
       "L -0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 179.384625 \n",
       "L 178.320844 179.384625 \n",
       "L 178.320844 51.1485 \n",
       "L 38.312875 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m3f2ae540a0\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"74.486585\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(69.469897 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"121.155335\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.708522 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"167.824085\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(165.377273 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_4\">\n",
       "     <!-- True -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(98.628359 206.604) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <defs>\n",
       "       <path id=\"mc4dcb94989\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"38.312875\" y=\"159.824267\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 162.973704) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"38.312875\" y=\"134.178075\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 137.327513) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"38.312875\" y=\"108.531884\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 111.681322) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"38.312875\" y=\"82.885693\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 86.03513) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"38.312875\" y=\"57.239502\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 60.388939) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_10\">\n",
       "     <!-- Predicted -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(14.0715 135.543562) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"100\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"155.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"211.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"233.447266\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"283.447266\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"366.845703\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_1\">\n",
       "    <path d=\"M 46.89872 139.716137 \n",
       "L 46.89872 131.311104 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.947073 151.389544 \n",
       "L 64.947073 135.385294 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.888227 89.086275 \n",
       "L 161.888227 74.892913 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.549933 88.213209 \n",
       "L 166.549933 72.710017 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.147709 139.299232 \n",
       "L 58.147709 109.588464 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 50.04253 159.255597 \n",
       "L 50.04253 128.675529 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.203583 145.758094 \n",
       "L 68.203583 129.384732 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.465863 87.859424 \n",
       "L 163.465863 80.41512 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.084057 129.699979 \n",
       "L 84.084057 111.315402 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.7259 128.032298 \n",
       "L 93.7259 111.78622 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.622725 90.860131 \n",
       "L 166.622725 78.39256 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 111.894308 115.679645 \n",
       "L 111.894308 105.226558 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.850972 89.395289 \n",
       "L 171.850972 72.602288 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.035526 137.921467 \n",
       "L 78.035526 121.400584 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.308787 146.865892 \n",
       "L 69.308787 137.932347 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.957872 147.104677 \n",
       "L 53.957872 134.581142 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.083708 130.565771 \n",
       "L 84.083708 114.838386 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.002503 93.403027 \n",
       "L 162.002503 83.487138 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.718364 90.543151 \n",
       "L 164.718364 76.509977 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.374222 89.965146 \n",
       "L 168.374222 73.02285 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 157.379754 94.671359 \n",
       "L 157.379754 68.277314 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.626473 97.263437 \n",
       "L 162.626473 78.415461 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 138.882855 108.434434 \n",
       "L 138.882855 100.126404 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 158.688918 92.712697 \n",
       "L 158.688918 81.423129 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.674386 89.0018 \n",
       "L 171.674386 68.636676 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.187758 147.376605 \n",
       "L 70.187758 135.695897 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.731946 84.025922 \n",
       "L 168.731946 75.962893 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.821173 87.932757 \n",
       "L 162.821173 80.996658 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.398658 116.389844 \n",
       "L 89.398658 105.404655 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.280574 96.964838 \n",
       "L 169.280574 78.906243 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 142.584139 112.628455 \n",
       "L 142.584139 92.272391 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.335472 140.57699 \n",
       "L 69.335472 125.578143 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.477021 88.96364 \n",
       "L 163.477021 66.289953 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.898828 89.94906 \n",
       "L 165.898828 76.367111 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.376198 89.001266 \n",
       "L 161.376198 76.876296 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.172201 83.547853 \n",
       "L 163.172201 72.045119 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.59697 144.74372 \n",
       "L 54.59697 129.594071 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.595659 85.663976 \n",
       "L 167.595659 75.541599 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.153302 151.820961 \n",
       "L 53.153302 125.28993 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.780709 94.873389 \n",
       "L 163.780709 73.964798 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 105.665604 119.646852 \n",
       "L 105.665604 105.421718 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.738855 125.511026 \n",
       "L 87.738855 120.634694 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.074358 132.771553 \n",
       "L 81.074358 121.441758 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.316665 86.148977 \n",
       "L 170.316665 69.219718 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.199778 134.596801 \n",
       "L 88.199778 120.130104 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.415902 126.618397 \n",
       "L 99.415902 114.106995 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 51.532816 167.375289 \n",
       "L 51.532816 149.657352 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.613872 124.773598 \n",
       "L 87.613872 115.054854 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 50.753669 152.203509 \n",
       "L 50.753669 137.383065 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 145.074881 97.255244 \n",
       "L 145.074881 85.847365 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 44.803954 157.931056 \n",
       "L 44.803954 137.335163 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.659268 145.121835 \n",
       "L 71.659268 137.401783 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.802089 115.040289 \n",
       "L 163.802089 84.388563 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.115142 143.957894 \n",
       "L 59.115142 131.922892 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 159.916156 85.598979 \n",
       "L 159.916156 75.795278 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 156.986891 116.251843 \n",
       "L 156.986891 107.404412 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 124.527344 126.922122 \n",
       "L 124.527344 111.75409 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 114.639341 118.541359 \n",
       "L 114.639341 106.655593 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.213354 119.113115 \n",
       "L 88.213354 109.805516 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.580969 85.309509 \n",
       "L 163.580969 75.772278 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 159.688011 100.875977 \n",
       "L 159.688011 86.789729 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.383027 88.257985 \n",
       "L 164.383027 75.340774 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 50.119537 156.984654 \n",
       "L 50.119537 147.185696 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 46.057788 165.529158 \n",
       "L 46.057788 138.907096 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 148.18576 93.106134 \n",
       "L 148.18576 73.879154 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.905558 138.424492 \n",
       "L 56.905558 126.7856 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.211258 140.723793 \n",
       "L 59.211258 128.061834 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.91202 84.07832 \n",
       "L 167.91202 75.288385 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.434672 88.099066 \n",
       "L 167.434672 79.375885 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.761027 104.733905 \n",
       "L 164.761027 82.969451 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 107.217764 124.789128 \n",
       "L 107.217764 111.417533 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.505763 86.027198 \n",
       "L 169.505763 71.232386 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.725353 96.089818 \n",
       "L 169.725353 82.528107 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 94.914757 132.069051 \n",
       "L 94.914757 114.927626 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.286748 123.763473 \n",
       "L 92.286748 109.8547 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.897325 164.675439 \n",
       "L 58.897325 146.879804 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.354624 81.69939 \n",
       "L 171.354624 71.486382 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.995141 152.552472 \n",
       "L 52.995141 139.151196 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.369789 89.32825 \n",
       "L 164.369789 80.070967 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.818843 78.017276 \n",
       "L 164.818843 68.052512 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.302442 139.56798 \n",
       "L 69.302442 124.236663 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.76092 122.910464 \n",
       "L 99.76092 115.717263 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.858848 135.627509 \n",
       "L 63.858848 122.001058 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.552922 91.041494 \n",
       "L 168.552922 72.323351 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.131173 89.278616 \n",
       "L 170.131173 73.362072 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.699589 163.201612 \n",
       "L 59.699589 152.308185 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 155.819263 105.135213 \n",
       "L 155.819263 86.542506 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.787241 146.9647 \n",
       "L 60.787241 131.101152 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 108.71222 119.295396 \n",
       "L 108.71222 106.945372 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 98.252359 121.049991 \n",
       "L 98.252359 114.319082 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.848546 92.361066 \n",
       "L 169.848546 82.093937 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.426901 152.076886 \n",
       "L 71.426901 136.190139 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 126.883629 116.042419 \n",
       "L 126.883629 93.235517 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 113.871494 114.150586 \n",
       "L 113.871494 101.102789 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 116.142331 120.626159 \n",
       "L 116.142331 99.412208 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.318237 151.026794 \n",
       "L 59.318237 132.412871 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.446139 134.62493 \n",
       "L 77.446139 123.142847 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.700484 86.181392 \n",
       "L 160.700484 72.122911 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.662328 101.068726 \n",
       "L 163.662328 89.738811 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 45.007428 159.251782 \n",
       "L 45.007428 139.632785 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.972208 105.696414 \n",
       "L 99.972208 94.359072 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.406326 87.902745 \n",
       "L 162.406326 75.495361 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.220912 88.035482 \n",
       "L 163.220912 77.225196 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.541302 98.548754 \n",
       "L 162.541302 90.223469 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 129.904994 118.295533 \n",
       "L 129.904994 108.26393 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.248511 137.178483 \n",
       "L 78.248511 118.845359 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.573038 124.261968 \n",
       "L 93.573038 114.471075 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.100547 129.97394 \n",
       "L 60.100547 108.22457 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.177964 126.217598 \n",
       "L 63.177964 116.445704 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.074951 155.010213 \n",
       "L 60.074951 139.032256 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 46.434118 155.207351 \n",
       "L 46.434118 136.151918 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.242657 87.346251 \n",
       "L 162.242657 77.307581 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.39572 124.120534 \n",
       "L 96.39572 111.424481 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.972224 85.609726 \n",
       "L 166.972224 77.862896 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.786283 83.736211 \n",
       "L 168.786283 73.685543 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.353323 96.748468 \n",
       "L 167.353323 82.624803 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 157.554823 96.278802 \n",
       "L 157.554823 86.843495 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.25197 161.931188 \n",
       "L 56.25197 149.161335 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.544193 83.667696 \n",
       "L 166.544193 73.512648 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.74634 91.061658 \n",
       "L 168.74634 79.897178 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.376497 128.640681 \n",
       "L 62.376497 112.1749 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.011217 82.019589 \n",
       "L 166.011217 71.025802 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.702281 92.578512 \n",
       "L 161.702281 77.840799 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.388519 94.708593 \n",
       "L 164.388519 85.023484 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.196238 136.092082 \n",
       "L 69.196238 130.618114 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.746199 158.231242 \n",
       "L 59.746199 142.412539 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.935482 91.767296 \n",
       "L 168.935482 82.45244 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.329342 101.965029 \n",
       "L 161.329342 87.358235 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.17373 120.285773 \n",
       "L 64.17373 106.624018 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.340509 143.163655 \n",
       "L 90.340509 114.776102 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.393645 150.871679 \n",
       "L 59.393645 141.66063 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 120.679827 109.645706 \n",
       "L 120.679827 99.349602 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 48.259954 152.734883 \n",
       "L 48.259954 134.400924 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.429297 94.214786 \n",
       "L 165.429297 85.565302 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.110964 141.568035 \n",
       "L 63.110964 135.762321 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.052246 130.197799 \n",
       "L 87.052246 118.920101 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.359 99.1087 \n",
       "L 167.359 89.234333 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 112.454983 125.703551 \n",
       "L 112.454983 116.828568 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.391453 93.516226 \n",
       "L 161.391453 82.360609 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 104.1365 117.992276 \n",
       "L 104.1365 110.527857 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 149.6407 110.911619 \n",
       "L 149.6407 99.908139 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 139.862083 97.573334 \n",
       "L 139.862083 86.13651 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 129.32383 117.803017 \n",
       "L 129.32383 98.15028 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.475255 77.355802 \n",
       "L 166.475255 69.998629 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 157.418157 92.915656 \n",
       "L 157.418157 74.938899 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 140.057973 112.503152 \n",
       "L 140.057973 100.174366 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.385952 91.844488 \n",
       "L 167.385952 80.864855 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 93.987488 134.577604 \n",
       "L 93.987488 112.850656 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.512198 86.988268 \n",
       "L 161.512198 77.600782 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.091938 108.072545 \n",
       "L 165.091938 90.029072 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.447254 104.379518 \n",
       "L 165.447254 81.813015 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 152.238854 110.370861 \n",
       "L 152.238854 98.446133 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.857749 147.409131 \n",
       "L 68.857749 136.037958 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 50.475275 158.809505 \n",
       "L 50.475275 146.29924 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.796783 137.086205 \n",
       "L 78.796783 129.978631 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 124.503355 115.066493 \n",
       "L 124.503355 103.670395 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 113.468023 118.203656 \n",
       "L 113.468023 109.162605 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.77244 141.597235 \n",
       "L 87.77244 124.527555 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 109.379289 118.207749 \n",
       "L 109.379289 111.203399 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.592543 134.459035 \n",
       "L 62.592543 113.548992 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.760465 151.699643 \n",
       "L 66.760465 132.642332 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.802528 148.596897 \n",
       "L 64.802528 139.266341 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.821637 107.545356 \n",
       "L 164.821637 91.256865 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.847734 142.459553 \n",
       "L 85.847734 123.09775 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.877192 98.105055 \n",
       "L 161.877192 80.204132 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.316016 85.683787 \n",
       "L 169.316016 75.733833 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.725393 148.774979 \n",
       "L 62.725393 134.554174 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.987453 99.892279 \n",
       "L 163.987453 82.141492 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.990125 86.954402 \n",
       "L 161.990125 76.534579 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.479359 148.231904 \n",
       "L 57.479359 138.918793 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.837397 92.396219 \n",
       "L 167.837397 79.050573 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 49.323837 151.147709 \n",
       "L 49.323837 140.194977 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.956349 85.885277 \n",
       "L 166.956349 72.708828 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.434448 88.321859 \n",
       "L 166.434448 78.490816 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.98503 145.988759 \n",
       "L 63.98503 135.409236 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.667732 165.296049 \n",
       "L 53.667732 145.594995 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 138.943728 112.390283 \n",
       "L 138.943728 98.32547 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 151.206623 112.806068 \n",
       "L 151.206623 100.474326 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.853945 84.177238 \n",
       "L 161.853945 72.466446 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.363315 89.264216 \n",
       "L 167.363315 80.436991 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.540451 82.829684 \n",
       "L 168.540451 67.691456 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.332853 98.946826 \n",
       "L 167.332853 83.087014 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.447542 141.87975 \n",
       "L 59.447542 127.729603 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 50.106851 167.967188 \n",
       "L 50.106851 149.638351 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.978853 93.72899 \n",
       "L 164.978853 87.886757 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 73.876061 134.850789 \n",
       "L 73.876061 126.166011 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 49.598469 139.369285 \n",
       "L 49.598469 124.07192 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 142.683293 104.060647 \n",
       "L 142.683293 96.803201 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.858278 133.700998 \n",
       "L 62.858278 119.867775 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.229323 84.43674 \n",
       "L 169.229323 73.938383 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.770209 94.863163 \n",
       "L 166.770209 85.238465 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.020855 168.239905 \n",
       "L 52.020855 159.599776 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 106.885422 121.730068 \n",
       "L 106.885422 105.312353 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.259462 109.452555 \n",
       "L 163.259462 83.723342 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 139.201939 103.527591 \n",
       "L 139.201939 88.397897 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.689164 123.678908 \n",
       "L 96.689164 112.88496 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.94524 83.897164 \n",
       "L 166.94524 73.628854 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.513733 151.678192 \n",
       "L 58.513733 142.799565 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.001709 82.904215 \n",
       "L 168.001709 74.59332 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.822391 153.811008 \n",
       "L 53.822391 142.165471 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 125.252455 113.705278 \n",
       "L 125.252455 95.405955 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.709716 73.753179 \n",
       "L 166.709716 65.068191 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.161969 87.888529 \n",
       "L 162.161969 75.899119 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.389234 92.726553 \n",
       "L 167.389234 82.375932 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.730287 148.901197 \n",
       "L 56.730287 140.479831 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 49.150778 148.052256 \n",
       "L 49.150778 122.218116 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.347008 148.6863 \n",
       "L 65.347008 133.418014 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.613018 87.200022 \n",
       "L 164.613018 78.419985 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.778699 138.632188 \n",
       "L 65.778699 128.335845 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 117.641783 95.15646 \n",
       "L 117.641783 82.981801 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.930858 91.53397 \n",
       "L 163.930858 78.640099 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 151.706621 101.341016 \n",
       "L 151.706621 91.422861 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.228102 109.117898 \n",
       "L 131.228102 101.809747 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 99.70341 122.604173 \n",
       "L 99.70341 107.297624 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.066078 83.07328 \n",
       "L 166.066078 75.665097 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 112.864576 120.702661 \n",
       "L 112.864576 111.409892 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.109582 90.611615 \n",
       "L 163.109582 80.918655 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 49.324167 151.968804 \n",
       "L 49.324167 123.368861 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 61.843127 126.967759 \n",
       "L 61.843127 116.838844 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.731982 82.997729 \n",
       "L 170.731982 65.437253 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.361011 82.700774 \n",
       "L 168.361011 65.877485 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 51.678191 148.006864 \n",
       "L 51.678191 137.4412 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.008106 137.306565 \n",
       "L 69.008106 121.715407 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.740525 108.141652 \n",
       "L 167.740525 89.404865 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.321759 147.375673 \n",
       "L 71.321759 135.063056 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.250219 155.698627 \n",
       "L 60.250219 130.734362 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.114751 90.570663 \n",
       "L 163.114751 80.067024 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 122.855845 122.829668 \n",
       "L 122.855845 101.725785 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.790735 85.410162 \n",
       "L 162.790735 73.218466 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.465379 92.361939 \n",
       "L 162.465379 80.236735 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.025147 88.22886 \n",
       "L 165.025147 79.15872 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.266521 82.775918 \n",
       "L 169.266521 74.693533 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.300016 90.619006 \n",
       "L 163.300016 80.687416 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.832791 109.99977 \n",
       "L 162.832791 98.029735 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.13272 90.632991 \n",
       "L 163.13272 78.465542 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.10252 77.265243 \n",
       "L 170.10252 58.356533 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 79.789823 137.887529 \n",
       "L 79.789823 119.547814 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.710119 147.234633 \n",
       "L 64.710119 139.068838 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.206855 91.511804 \n",
       "L 171.206855 65.289972 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.885256 111.184653 \n",
       "L 131.885256 100.172987 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.771665 88.235392 \n",
       "L 161.771665 73.308601 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.886721 132.159262 \n",
       "L 81.886721 125.788557 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 55.643766 142.615502 \n",
       "L 55.643766 132.918245 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.148563 139.486212 \n",
       "L 80.148563 123.180703 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.498517 91.805324 \n",
       "L 170.498517 75.660935 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.643045 85.6885 \n",
       "L 169.643045 75.794592 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 137.015301 97.658128 \n",
       "L 137.015301 84.019541 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.201394 133.423444 \n",
       "L 65.201394 120.063205 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.186197 137.521261 \n",
       "L 76.186197 118.886827 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.452065 141.134364 \n",
       "L 70.452065 133.356464 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.37912 126.039254 \n",
       "L 65.37912 118.058486 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.305591 94.505535 \n",
       "L 160.305591 76.610417 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.954052 149.279572 \n",
       "L 72.954052 137.468899 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.632124 96.288693 \n",
       "L 161.632124 87.256399 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.442416 96.03911 \n",
       "L 162.442416 87.399217 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.757024 165.350272 \n",
       "L 62.757024 152.791134 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.352388 85.807886 \n",
       "L 167.352388 77.661185 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.668842 93.312755 \n",
       "L 165.668842 83.072204 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.663662 170.889565 \n",
       "L 53.663662 153.772781 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.589422 93.334913 \n",
       "L 166.589422 77.611067 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.753149 98.953233 \n",
       "L 164.753149 91.418575 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.724041 83.693158 \n",
       "L 167.724041 72.543077 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.871655 104.448809 \n",
       "L 161.871655 85.886373 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.236847 87.01174 \n",
       "L 167.236847 76.097054 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.956944 134.073911 \n",
       "L 87.956944 125.039696 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.299099 120.362923 \n",
       "L 163.299099 99.410089 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 51.803597 150.631206 \n",
       "L 51.803597 139.535539 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 45.981202 162.986929 \n",
       "L 45.981202 137.046155 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 152.873715 99.057844 \n",
       "L 152.873715 86.284427 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.532055 87.44627 \n",
       "L 165.532055 77.440429 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.722607 87.364059 \n",
       "L 165.722607 77.30338 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.914592 148.308454 \n",
       "L 56.914592 138.51747 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 47.724179 154.605658 \n",
       "L 47.724179 135.007356 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 113.261153 118.339195 \n",
       "L 113.261153 109.641645 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.586832 96.70061 \n",
       "L 165.586832 79.160327 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.809773 93.296619 \n",
       "L 160.809773 81.902133 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.302249 94.357864 \n",
       "L 164.302249 84.480998 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.408321 86.091455 \n",
       "L 167.408321 74.977215 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.270055 88.106281 \n",
       "L 170.270055 68.525819 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.551146 101.997889 \n",
       "L 160.551146 88.019987 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 132.795957 108.79083 \n",
       "L 132.795957 96.597265 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.167807 133.503151 \n",
       "L 76.167807 121.048655 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 159.289905 90.846348 \n",
       "L 159.289905 77.742503 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.580132 92.316872 \n",
       "L 164.580132 84.062765 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 80.180074 145.60562 \n",
       "L 80.180074 123.940817 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.062744 82.853532 \n",
       "L 162.062744 77.490272 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.661199 147.935059 \n",
       "L 52.661199 135.596849 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.356703 149.986211 \n",
       "L 57.356703 142.396568 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.998537 79.984687 \n",
       "L 162.998537 67.490215 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.101634 149.232249 \n",
       "L 59.101634 130.030549 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.410436 137.845885 \n",
       "L 66.410436 124.127326 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 100.624424 135.309318 \n",
       "L 100.624424 112.057431 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.409273 151.124357 \n",
       "L 57.409273 137.880916 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.275185 136.484236 \n",
       "L 81.275185 110.189973 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.643818 84.184765 \n",
       "L 163.643818 75.77105 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.208019 124.832277 \n",
       "L 90.208019 117.350916 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.682278 96.320031 \n",
       "L 167.682278 82.910828 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.172011 86.714225 \n",
       "L 163.172011 77.439952 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.799639 84.020347 \n",
       "L 168.799639 72.182006 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 128.259544 98.640386 \n",
       "L 128.259544 78.075966 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 86.29361 112.136225 \n",
       "L 86.29361 101.592822 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.247293 96.351347 \n",
       "L 162.247293 80.906295 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.698077 89.967169 \n",
       "L 169.698077 79.164029 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 148.665602 113.109408 \n",
       "L 148.665602 101.718511 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.542723 88.311814 \n",
       "L 166.542723 78.412492 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.376727 77.754963 \n",
       "L 168.376727 65.107195 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.561222 87.682419 \n",
       "L 162.561222 81.52435 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 48.797532 173.55571 \n",
       "L 48.797532 157.293963 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.111673 137.622005 \n",
       "L 85.111673 122.596538 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.420592 151.152508 \n",
       "L 53.420592 137.41821 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 115.123037 125.46857 \n",
       "L 115.123037 107.711444 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 48.48642 147.446216 \n",
       "L 48.48642 135.342975 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 54.23696 146.393929 \n",
       "L 54.23696 133.029496 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.730614 141.347737 \n",
       "L 71.730614 128.100416 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.434075 88.159755 \n",
       "L 171.434075 75.506787 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.179713 134.172691 \n",
       "L 78.179713 119.016077 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.304663 87.872292 \n",
       "L 166.304663 78.208426 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.723923 84.13144 \n",
       "L 163.723923 75.522408 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 87.977872 120.338438 \n",
       "L 87.977872 111.807771 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.440067 153.29694 \n",
       "L 65.440067 135.421666 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 68.236319 116.457243 \n",
       "L 68.236319 99.755629 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.222583 87.868045 \n",
       "L 167.222583 79.653536 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 50.134817 147.580222 \n",
       "L 50.134817 130.995018 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.751285 135.476114 \n",
       "L 72.751285 121.675237 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.925124 94.899144 \n",
       "L 166.925124 85.899425 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.199291 86.653815 \n",
       "L 168.199291 79.241395 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.912103 93.591831 \n",
       "L 161.912103 82.65327 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.533496 128.979391 \n",
       "L 83.533496 117.952661 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.565904 96.05522 \n",
       "L 165.565904 84.627508 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 143.619692 115.867165 \n",
       "L 143.619692 103.564968 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.162546 131.633631 \n",
       "L 84.162546 120.357794 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.331394 96.945806 \n",
       "L 166.331394 78.876706 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.460365 95.18115 \n",
       "L 160.460365 82.757775 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.412126 97.232715 \n",
       "L 161.412126 87.191273 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.79326 96.983605 \n",
       "L 160.79326 78.717027 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.150712 165.330587 \n",
       "L 52.150712 151.584647 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.504041 82.169044 \n",
       "L 164.504041 70.281102 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.375279 93.37658 \n",
       "L 163.375279 84.322887 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.967767 90.999827 \n",
       "L 162.967767 76.279945 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 83.416218 138.512951 \n",
       "L 83.416218 125.556284 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.915917 150.616875 \n",
       "L 64.915917 131.387816 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 118.15825 114.235313 \n",
       "L 118.15825 105.475252 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.999403 98.722042 \n",
       "L 160.999403 81.401469 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.110984 86.128871 \n",
       "L 166.110984 78.232409 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.057467 102.918371 \n",
       "L 162.057467 73.054189 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 44.845128 162.042738 \n",
       "L 44.845128 148.743269 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 153.027464 100.536782 \n",
       "L 153.027464 82.403447 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.929297 100.887717 \n",
       "L 163.929297 82.211067 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.237346 157.681399 \n",
       "L 77.237346 130.268647 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.418652 158.554761 \n",
       "L 57.418652 147.001117 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.766949 89.277327 \n",
       "L 165.766949 78.771992 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.157999 145.722358 \n",
       "L 90.157999 131.089916 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 98.660211 125.161331 \n",
       "L 98.660211 108.04952 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 156.39928 103.580444 \n",
       "L 156.39928 87.915307 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.743446 95.562532 \n",
       "L 170.743446 79.651634 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.921763 101.340029 \n",
       "L 162.921763 80.870639 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 103.784169 121.903731 \n",
       "L 103.784169 115.618355 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 69.419426 151.468008 \n",
       "L 69.419426 134.872008 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 91.252325 129.199404 \n",
       "L 91.252325 112.955349 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.277453 88.380792 \n",
       "L 165.277453 75.546837 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.83357 171.364484 \n",
       "L 56.83357 152.433814 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.267524 133.15379 \n",
       "L 58.267524 119.198656 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.80992 93.198836 \n",
       "L 165.80992 76.616244 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.458434 96.76264 \n",
       "L 164.458434 78.506081 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.64184 153.297447 \n",
       "L 58.64184 139.916413 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.733017 80.394593 \n",
       "L 163.733017 72.827528 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.902798 86.513482 \n",
       "L 165.902798 77.394816 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 64.034563 153.413679 \n",
       "L 64.034563 142.086369 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.659012 146.995491 \n",
       "L 62.659012 132.986793 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.857675 86.748092 \n",
       "L 163.857675 69.678476 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 137.245227 110.538989 \n",
       "L 137.245227 97.046135 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.349009 95.913779 \n",
       "L 167.349009 81.651765 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.597831 80.230395 \n",
       "L 169.597831 72.276147 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 124.581399 109.22442 \n",
       "L 124.581399 97.74817 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.309322 99.37264 \n",
       "L 164.309322 80.792294 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.454269 95.204303 \n",
       "L 169.454269 84.547918 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 51.495748 161.539797 \n",
       "L 51.495748 139.830258 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.438562 106.856744 \n",
       "L 163.438562 91.19928 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.77358 128.223693 \n",
       "L 76.77358 122.561855 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.318259 74.444089 \n",
       "L 166.318259 65.774403 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.497029 90.956244 \n",
       "L 165.497029 75.853935 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 95.466568 126.252803 \n",
       "L 95.466568 111.862137 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 124.812194 121.511925 \n",
       "L 124.812194 107.109733 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.19051 87.060862 \n",
       "L 166.19051 68.116748 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.189196 94.115725 \n",
       "L 161.189196 79.986444 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.778497 95.276144 \n",
       "L 165.778497 86.490883 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.279867 148.41463 \n",
       "L 66.279867 132.325283 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 66.684569 125.65344 \n",
       "L 66.684569 115.903119 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 104.119893 113.660941 \n",
       "L 104.119893 86.072821 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 110.326659 117.76889 \n",
       "L 110.326659 107.849017 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.816779 119.054725 \n",
       "L 77.816779 102.777673 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.240164 91.810822 \n",
       "L 165.240164 78.517164 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.768454 87.495363 \n",
       "L 170.768454 78.719116 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 101.332977 119.137466 \n",
       "L 101.332977 111.888564 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 158.376743 85.064613 \n",
       "L 158.376743 66.959928 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.984924 91.477527 \n",
       "L 164.984924 73.420208 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 59.71879 156.126962 \n",
       "L 59.71879 139.725282 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.412632 147.411268 \n",
       "L 52.412632 137.35767 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 156.133239 96.916168 \n",
       "L 156.133239 87.185034 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.403689 126.12984 \n",
       "L 74.403689 114.342193 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.322813 91.04206 \n",
       "L 169.322813 67.005741 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 53.123147 158.094543 \n",
       "L 53.123147 148.715633 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.400691 81.416374 \n",
       "L 163.400691 68.131638 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.946106 154.917808 \n",
       "L 63.946106 142.264374 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.932501 89.024527 \n",
       "L 163.932501 80.981746 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 112.120728 114.374843 \n",
       "L 112.120728 103.30909 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.648117 148.82113 \n",
       "L 62.648117 138.228808 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.232516 86.243306 \n",
       "L 165.232516 74.840422 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 55.531893 153.061204 \n",
       "L 55.531893 141.228819 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.61545 99.28954 \n",
       "L 168.61545 85.785572 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.942022 129.608877 \n",
       "L 81.942022 117.525422 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.894392 83.467906 \n",
       "L 164.894392 75.14586 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.358021 73.110029 \n",
       "L 165.358021 61.470664 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.269825 79.84297 \n",
       "L 163.269825 56.977415 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.865278 90.88179 \n",
       "L 166.865278 84.160506 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.810151 83.896398 \n",
       "L 166.810151 79.513539 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.035909 137.531898 \n",
       "L 78.035909 125.423569 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 46.38938 160.417063 \n",
       "L 46.38938 142.291767 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 47.23362 169.555626 \n",
       "L 47.23362 146.908903 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 49.837813 147.464849 \n",
       "L 49.837813 131.511419 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.335299 85.162396 \n",
       "L 162.335299 71.198946 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.405729 97.083032 \n",
       "L 166.405729 82.647898 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 65.889826 142.808425 \n",
       "L 65.889826 130.441274 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 132.608284 105.655377 \n",
       "L 132.608284 77.951876 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.716457 86.941506 \n",
       "L 167.716457 78.624295 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 101.642456 117.336102 \n",
       "L 101.642456 103.916057 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 74.91502 130.887961 \n",
       "L 74.91502 114.045019 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.056141 106.867934 \n",
       "L 166.056141 91.490975 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.151715 98.926749 \n",
       "L 161.151715 82.856137 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 57.83971 160.816007 \n",
       "L 57.83971 144.921694 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 126.690042 95.091269 \n",
       "L 126.690042 82.287795 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.607725 123.920216 \n",
       "L 162.607725 111.199039 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 78.533101 136.978468 \n",
       "L 78.533101 124.442378 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.381832 103.137935 \n",
       "L 165.381832 88.866683 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.697817 98.050936 \n",
       "L 168.697817 78.7434 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 81.908703 128.867059 \n",
       "L 81.908703 120.515045 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.740219 148.174366 \n",
       "L 56.740219 140.41677 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 51.636495 147.120375 \n",
       "L 51.636495 136.952775 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.826806 106.40261 \n",
       "L 160.826806 90.776602 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.593698 96.139782 \n",
       "L 162.593698 78.049161 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 96.4273 115.013665 \n",
       "L 96.4273 105.674362 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 70.113268 131.948736 \n",
       "L 70.113268 115.109164 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.955975 80.476014 \n",
       "L 165.955975 64.82168 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 161.914728 86.701304 \n",
       "L 161.914728 75.929259 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 46.113189 152.550589 \n",
       "L 46.113189 135.101581 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.461621 149.533092 \n",
       "L 60.461621 137.260137 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 60.405915 145.056423 \n",
       "L 60.405915 137.332632 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 55.503525 157.505978 \n",
       "L 55.503525 134.700116 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 46.385407 144.528869 \n",
       "L 46.385407 130.229924 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 100.117452 108.939913 \n",
       "L 100.117452 100.285142 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 170.991202 88.129421 \n",
       "L 170.991202 69.97765 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.502787 87.844994 \n",
       "L 168.502787 80.520179 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 63.87557 145.452482 \n",
       "L 63.87557 133.54275 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 159.681293 97.161682 \n",
       "L 159.681293 86.057411 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 58.083165 148.596343 \n",
       "L 58.083165 138.329922 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 62.973737 151.085319 \n",
       "L 62.973737 136.599795 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 152.137326 103.56658 \n",
       "L 152.137326 86.384029 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 88.702318 127.510211 \n",
       "L 88.702318 119.352022 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 155.287802 101.112921 \n",
       "L 155.287802 86.177642 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 171.869124 99.735303 \n",
       "L 171.869124 81.071128 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 90.082024 131.300325 \n",
       "L 90.082024 120.234499 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 103.079104 114.45854 \n",
       "L 103.079104 98.968989 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 92.483924 127.518951 \n",
       "L 92.483924 119.060259 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 157.854446 97.16514 \n",
       "L 157.854446 79.671904 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 56.025995 155.208913 \n",
       "L 56.025995 148.353198 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.131402 106.591333 \n",
       "L 164.131402 89.928433 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 169.033019 80.694765 \n",
       "L 169.033019 67.156378 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 76.167673 142.230165 \n",
       "L 76.167673 124.036107 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 89.680129 125.197826 \n",
       "L 89.680129 101.179939 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.04166 157.090995 \n",
       "L 52.04166 141.14713 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 155.156102 99.255465 \n",
       "L 155.156102 89.703193 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.500445 133.376655 \n",
       "L 85.500445 125.149756 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.582834 78.176267 \n",
       "L 162.582834 71.619519 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.908448 91.284912 \n",
       "L 164.908448 82.519195 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 168.566743 89.234848 \n",
       "L 168.566743 78.511644 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.617199 99.262179 \n",
       "L 162.617199 83.746881 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 85.581043 129.258902 \n",
       "L 85.581043 118.666551 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 77.947346 126.131834 \n",
       "L 77.947346 113.884269 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.289755 102.6919 \n",
       "L 167.289755 87.703189 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.977026 100.319443 \n",
       "L 163.977026 87.582313 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 158.345048 110.133239 \n",
       "L 158.345048 102.264639 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 52.342243 152.28025 \n",
       "L 52.342243 143.190744 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.409866 85.027841 \n",
       "L 163.409866 73.294804 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.377182 100.598056 \n",
       "L 167.377182 88.54732 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 71.54848 138.60266 \n",
       "L 71.54848 129.28984 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 165.876681 100.954873 \n",
       "L 165.876681 85.889045 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.153028 117.393668 \n",
       "L 84.153028 107.178314 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 158.238654 101.433418 \n",
       "L 158.238654 88.462897 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 98.378001 122.392752 \n",
       "L 98.378001 110.863243 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 162.679062 94.771364 \n",
       "L 162.679062 78.423847 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 84.685365 131.928212 \n",
       "L 84.685365 124.216701 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 164.0673 97.192876 \n",
       "L 164.0673 81.052233 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 163.136187 91.630016 \n",
       "L 163.136187 73.605557 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.398244 107.596273 \n",
       "L 131.398244 96.7769 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 72.518073 140.193237 \n",
       "L 72.518073 126.698311 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 160.056792 88.285508 \n",
       "L 160.056792 66.169703 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 167.709278 89.304039 \n",
       "L 167.709278 74.946786 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 166.565401 79.136583 \n",
       "L 166.565401 68.641859 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 131.440447 101.254586 \n",
       "L 131.440447 86.821579 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 119.078095 100.580241 \n",
       "L 119.078095 69.308108 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_9\">\n",
       "    <defs>\n",
       "     <path id=\"mbf7c8a7f08\" d=\"M 0 1 \n",
       "C 0.265203 1 0.51958 0.894634 0.707107 0.707107 \n",
       "C 0.894634 0.51958 1 0.265203 1 0 \n",
       "C 1 -0.265203 0.894634 -0.51958 0.707107 -0.707107 \n",
       "C 0.51958 -0.894634 0.265203 -1 0 -1 \n",
       "C -0.265203 -1 -0.51958 -0.894634 -0.707107 -0.707107 \n",
       "C -0.894634 -0.51958 -1 -0.265203 -1 0 \n",
       "C -1 0.265203 -0.894634 0.51958 -0.707107 0.707107 \n",
       "C -0.51958 0.894634 -0.265203 1 0 1 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p45d028abef)\">\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"46.89872\" y=\"135.51362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"64.947073\" y=\"143.387419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.888227\" y=\"81.989594\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.549933\" y=\"80.461613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"58.147709\" y=\"124.443848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"50.04253\" y=\"143.965563\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"68.203583\" y=\"137.571413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.465863\" y=\"84.137272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"84.084057\" y=\"120.50769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"93.7259\" y=\"119.909259\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.622725\" y=\"84.626345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"111.894308\" y=\"110.453102\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"171.850972\" y=\"80.998789\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"78.035526\" y=\"129.661025\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"69.308787\" y=\"142.39912\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.957872\" y=\"140.84291\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"84.083708\" y=\"122.702078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.002503\" y=\"88.445083\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.718364\" y=\"83.526564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.374222\" y=\"81.493998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"157.379754\" y=\"81.474337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.626473\" y=\"87.839449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"138.882855\" y=\"104.280419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"158.688918\" y=\"87.067913\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"171.674386\" y=\"78.819238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"70.187758\" y=\"141.536251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.731946\" y=\"79.994407\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.821173\" y=\"84.464708\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"89.398658\" y=\"110.89725\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.280574\" y=\"87.93554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"142.584139\" y=\"102.450423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"69.335472\" y=\"133.077566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.477021\" y=\"77.626797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.898828\" y=\"83.158085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.376198\" y=\"82.938781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.172201\" y=\"77.796486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"54.59697\" y=\"137.168895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.595659\" y=\"80.602788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.153302\" y=\"138.555445\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.780709\" y=\"84.419094\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"105.665604\" y=\"112.534285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"87.738855\" y=\"123.07286\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"81.074358\" y=\"127.106656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.316665\" y=\"77.684348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"88.199778\" y=\"127.363453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"99.415902\" y=\"120.362696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"51.532816\" y=\"158.516321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"87.613872\" y=\"119.914226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"50.753669\" y=\"144.793287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"145.074881\" y=\"91.551305\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"44.803954\" y=\"147.633109\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"71.659268\" y=\"141.261809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.802089\" y=\"99.714426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.115142\" y=\"137.940393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"159.916156\" y=\"80.697128\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"156.986891\" y=\"111.828127\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"124.527344\" y=\"119.338106\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"114.639341\" y=\"112.598476\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"88.213354\" y=\"114.459316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.580969\" y=\"80.540893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"159.688011\" y=\"93.832853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.383027\" y=\"81.79938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"50.119537\" y=\"152.085175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"46.057788\" y=\"152.218127\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"148.18576\" y=\"83.492644\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.905558\" y=\"132.605046\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.211258\" y=\"134.392814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.91202\" y=\"79.683353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.434672\" y=\"83.737475\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.761027\" y=\"93.851678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"107.217764\" y=\"118.103331\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.505763\" y=\"78.629792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.725353\" y=\"89.308962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"94.914757\" y=\"123.498338\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"92.286748\" y=\"116.809087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"58.897325\" y=\"155.777621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"171.354624\" y=\"76.592886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.995141\" y=\"145.851834\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.369789\" y=\"84.699608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.818843\" y=\"73.034894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"69.302442\" y=\"131.902322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"99.76092\" y=\"119.313863\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"63.858848\" y=\"128.814284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.552922\" y=\"81.682423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.131173\" y=\"81.320344\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.699589\" y=\"157.754899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"155.819263\" y=\"95.83886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"60.787241\" y=\"139.032926\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"108.71222\" y=\"113.120384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"98.252359\" y=\"117.684537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.848546\" y=\"87.227502\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"71.426901\" y=\"144.133512\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"126.883629\" y=\"104.638968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"113.871494\" y=\"107.626688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"116.142331\" y=\"110.019184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.318237\" y=\"141.719832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"77.446139\" y=\"128.883888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.700484\" y=\"79.152152\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.662328\" y=\"95.403768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"45.007428\" y=\"149.442283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"99.972208\" y=\"100.027743\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.406326\" y=\"81.699053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.220912\" y=\"82.630339\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.541302\" y=\"94.386112\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"129.904994\" y=\"113.279732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"78.248511\" y=\"128.011921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"93.573038\" y=\"119.366522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"60.100547\" y=\"119.099255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"63.177964\" y=\"121.331651\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"60.074951\" y=\"147.021234\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"46.434118\" y=\"145.679634\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.242657\" y=\"82.326916\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"96.39572\" y=\"117.772508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.972224\" y=\"81.736311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.786283\" y=\"78.710877\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.353323\" y=\"89.686636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"157.554823\" y=\"91.561149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.25197\" y=\"155.546261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.544193\" y=\"78.590172\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.74634\" y=\"85.479418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.376497\" y=\"120.40779\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.011217\" y=\"76.522696\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.702281\" y=\"85.209656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.388519\" y=\"89.866038\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"69.196238\" y=\"133.355098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.746199\" y=\"150.321891\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.935482\" y=\"87.109868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.329342\" y=\"94.661632\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"64.17373\" y=\"113.454896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"90.340509\" y=\"128.969878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.393645\" y=\"146.266155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"120.679827\" y=\"104.497654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"48.259954\" y=\"143.567904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.429297\" y=\"89.890044\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"63.110964\" y=\"138.665178\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"87.052246\" y=\"124.55895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.359\" y=\"94.171517\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"112.454983\" y=\"121.266059\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.391453\" y=\"87.938417\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"104.1365\" y=\"114.260066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"149.6407\" y=\"105.409879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"139.862083\" y=\"91.854922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"129.32383\" y=\"107.976648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.475255\" y=\"73.677215\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"157.418157\" y=\"83.927277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"140.057973\" y=\"106.338759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.385952\" y=\"86.354672\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"93.987488\" y=\"123.71413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.512198\" y=\"82.294525\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.091938\" y=\"99.050809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.447254\" y=\"93.096267\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"152.238854\" y=\"104.408497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"68.857749\" y=\"141.723544\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"50.475275\" y=\"152.554372\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"78.796783\" y=\"133.532418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"124.503355\" y=\"109.368444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"113.468023\" y=\"113.68313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"87.77244\" y=\"133.062395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"109.379289\" y=\"114.705574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.592543\" y=\"124.004014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"66.760465\" y=\"142.170988\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"64.802528\" y=\"143.931619\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.821637\" y=\"99.40111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"85.847734\" y=\"132.778652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.877192\" y=\"89.154593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.316016\" y=\"80.70881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.725393\" y=\"141.664576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.987453\" y=\"91.016885\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.990125\" y=\"81.74449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"57.479359\" y=\"143.575348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.837397\" y=\"85.723396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"49.323837\" y=\"145.671343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.956349\" y=\"79.297053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.434448\" y=\"83.406337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"63.98503\" y=\"140.698998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.667732\" y=\"155.445522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"138.943728\" y=\"105.357876\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"151.206623\" y=\"106.640197\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.853945\" y=\"78.321842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.363315\" y=\"84.850603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.540451\" y=\"75.26057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.332853\" y=\"91.01692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.447542\" y=\"134.804677\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"50.106851\" y=\"158.80277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.978853\" y=\"90.807873\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"73.876061\" y=\"130.5084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"49.598469\" y=\"131.720603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"142.683293\" y=\"100.431924\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.858278\" y=\"126.784386\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.229323\" y=\"79.187561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.770209\" y=\"90.050814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.020855\" y=\"163.919841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"106.885422\" y=\"113.521211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.259462\" y=\"96.587949\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"139.201939\" y=\"95.962744\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"96.689164\" y=\"118.281934\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.94524\" y=\"78.763009\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"58.513733\" y=\"147.238879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.001709\" y=\"78.748767\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.822391\" y=\"147.98824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"125.252455\" y=\"104.555617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.709716\" y=\"69.410685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.161969\" y=\"81.893824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.389234\" y=\"87.551242\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.730287\" y=\"144.690514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"49.150778\" y=\"135.135186\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"65.347008\" y=\"141.052157\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.613018\" y=\"82.810004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"65.778699\" y=\"133.484016\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"117.641783\" y=\"89.069131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.930858\" y=\"85.087035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"151.706621\" y=\"96.381939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"131.228102\" y=\"105.463822\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"99.70341\" y=\"114.950898\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.066078\" y=\"79.369188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"112.864576\" y=\"116.056277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.109582\" y=\"85.765135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"49.324167\" y=\"137.668832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"61.843127\" y=\"121.903301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.731982\" y=\"74.217491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.361011\" y=\"74.289129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"51.678191\" y=\"142.724032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"69.008106\" y=\"129.510986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.740525\" y=\"98.773259\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"71.321759\" y=\"141.219365\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"60.250219\" y=\"143.216494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.114751\" y=\"85.318844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"122.855845\" y=\"112.277727\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.790735\" y=\"79.314314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.465379\" y=\"86.299337\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.025147\" y=\"83.69379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.266521\" y=\"78.734725\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.300016\" y=\"85.653211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.832791\" y=\"104.014752\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.13272\" y=\"84.549266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.10252\" y=\"67.810888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"79.789823\" y=\"128.717672\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"64.710119\" y=\"143.151735\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"171.206855\" y=\"78.400888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"131.885256\" y=\"105.67882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.771665\" y=\"80.771997\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"81.886721\" y=\"128.97391\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"55.643766\" y=\"137.766873\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"80.148563\" y=\"131.333458\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.498517\" y=\"83.733129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.643045\" y=\"80.741546\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"137.015301\" y=\"90.838834\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"65.201394\" y=\"126.743325\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"76.186197\" y=\"128.204044\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"70.452065\" y=\"137.245414\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"65.37912\" y=\"122.04887\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.305591\" y=\"85.557976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"72.954052\" y=\"143.374235\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.632124\" y=\"91.772546\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.442416\" y=\"91.719163\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.757024\" y=\"159.070703\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.352388\" y=\"81.734536\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.668842\" y=\"88.19248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.663662\" y=\"162.331173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.589422\" y=\"85.47299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.753149\" y=\"95.185904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.724041\" y=\"78.118118\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.871655\" y=\"95.167591\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.236847\" y=\"81.554397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"87.956944\" y=\"129.556804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.299099\" y=\"109.886506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"51.803597\" y=\"145.083373\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"45.981202\" y=\"150.016542\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"152.873715\" y=\"92.671135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.532055\" y=\"82.44335\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.722607\" y=\"82.33372\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.914592\" y=\"143.412962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"47.724179\" y=\"144.806507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"113.261153\" y=\"113.99042\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.586832\" y=\"87.930469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.809773\" y=\"87.599376\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.302249\" y=\"89.419431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.408321\" y=\"80.534335\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.270055\" y=\"78.31605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.551146\" y=\"95.008938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"132.795957\" y=\"102.694048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"76.167807\" y=\"127.275903\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"159.289905\" y=\"84.294425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.580132\" y=\"88.189818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"80.180074\" y=\"134.773218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.062744\" y=\"80.171902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.661199\" y=\"141.765954\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"57.356703\" y=\"146.191389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.998537\" y=\"73.737451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.101634\" y=\"139.631399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"66.410436\" y=\"130.986605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"100.624424\" y=\"123.683375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"57.409273\" y=\"144.502636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"81.275185\" y=\"123.337105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.643818\" y=\"79.977908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"90.208019\" y=\"121.091597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.682278\" y=\"89.615429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.172011\" y=\"82.077089\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.799639\" y=\"78.101177\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"128.259544\" y=\"88.358176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"86.29361\" y=\"106.864524\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.247293\" y=\"88.628821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.698077\" y=\"84.565599\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"148.665602\" y=\"107.41396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.542723\" y=\"83.362153\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.376727\" y=\"71.431079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.561222\" y=\"84.603384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"48.797532\" y=\"165.424837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"85.111673\" y=\"130.109271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.420592\" y=\"144.285359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"115.123037\" y=\"116.590007\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"48.48642\" y=\"141.394596\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"54.23696\" y=\"139.711713\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"71.730614\" y=\"134.724076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"171.434075\" y=\"81.833271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"78.179713\" y=\"126.594384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.304663\" y=\"83.040359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.723923\" y=\"79.826924\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"87.977872\" y=\"116.073105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"65.440067\" y=\"144.359303\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"68.236319\" y=\"108.106436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.222583\" y=\"83.76079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"50.134817\" y=\"139.28762\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"72.751285\" y=\"128.575676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.925124\" y=\"90.399284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.199291\" y=\"82.947605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.912103\" y=\"88.122551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"83.533496\" y=\"123.466026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.565904\" y=\"90.341364\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"143.619692\" y=\"109.716066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"84.162546\" y=\"125.995713\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.331394\" y=\"87.911256\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.460365\" y=\"88.969462\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.412126\" y=\"92.211994\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.79326\" y=\"87.850316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.150712\" y=\"158.457617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.504041\" y=\"76.225073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.375279\" y=\"88.849733\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.967767\" y=\"83.639886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"83.416218\" y=\"132.034617\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"64.915917\" y=\"141.002346\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"118.15825\" y=\"109.855283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.999403\" y=\"90.061755\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.110984\" y=\"82.18064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.057467\" y=\"87.98628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"44.845128\" y=\"155.393003\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"153.027464\" y=\"91.470114\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.929297\" y=\"91.549392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"77.237346\" y=\"143.975023\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"57.418652\" y=\"152.777939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.766949\" y=\"84.02466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"90.157999\" y=\"138.406137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"98.660211\" y=\"116.605426\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"156.39928\" y=\"95.747876\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.743446\" y=\"87.607083\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.921763\" y=\"91.105334\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"103.784169\" y=\"118.761043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"69.419426\" y=\"143.170008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"91.252325\" y=\"121.077376\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.277453\" y=\"81.963815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.83357\" y=\"161.899149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"58.267524\" y=\"126.176223\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.80992\" y=\"84.90754\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.458434\" y=\"87.63436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"58.64184\" y=\"146.60693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.733017\" y=\"76.611061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.902798\" y=\"81.954149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"64.034563\" y=\"147.750024\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.659012\" y=\"139.991142\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.857675\" y=\"78.213284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"137.245227\" y=\"103.792562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.349009\" y=\"88.782772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.597831\" y=\"76.253271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"124.581399\" y=\"103.486295\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.309322\" y=\"90.082467\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.454269\" y=\"89.87611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"51.495748\" y=\"150.685028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.438562\" y=\"99.028012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"76.77358\" y=\"125.392774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.318259\" y=\"70.109246\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.497029\" y=\"83.40509\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"95.466568\" y=\"119.05747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"124.812194\" y=\"114.310829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.19051\" y=\"77.588805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.189196\" y=\"87.051085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.778497\" y=\"90.883514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"66.279867\" y=\"140.369957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"66.684569\" y=\"120.778279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"104.119893\" y=\"99.866881\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"110.326659\" y=\"112.808954\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"77.816779\" y=\"110.916199\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.240164\" y=\"85.163993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.768454\" y=\"83.10724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"101.332977\" y=\"115.513015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"158.376743\" y=\"76.01227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.984924\" y=\"82.448868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"59.71879\" y=\"147.926122\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.412632\" y=\"142.384469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"156.133239\" y=\"92.050601\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"74.403689\" y=\"120.236017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.322813\" y=\"79.0239\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"53.123147\" y=\"153.405088\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.400691\" y=\"74.774006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"63.946106\" y=\"148.591091\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.932501\" y=\"85.003136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"112.120728\" y=\"108.841967\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.648117\" y=\"143.524969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.232516\" y=\"80.541864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"55.531893\" y=\"147.145012\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.61545\" y=\"92.537556\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"81.942022\" y=\"123.56715\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.894392\" y=\"79.306883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.358021\" y=\"67.290346\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.269825\" y=\"68.410192\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.865278\" y=\"87.521148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.810151\" y=\"81.704969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"78.035909\" y=\"131.477734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"46.38938\" y=\"151.354415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"47.23362\" y=\"158.232264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"49.837813\" y=\"139.488134\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.335299\" y=\"78.180671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.405729\" y=\"89.865465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"65.889826\" y=\"136.62485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"132.608284\" y=\"91.803626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.716457\" y=\"82.782901\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"101.642456\" y=\"110.62608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"74.91502\" y=\"122.46649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.056141\" y=\"99.179454\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.151715\" y=\"90.891443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"57.83971\" y=\"152.868851\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"126.690042\" y=\"88.689532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.607725\" y=\"117.559627\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"78.533101\" y=\"130.710423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.381832\" y=\"96.002309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.697817\" y=\"88.397168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"81.908703\" y=\"124.691052\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.740219\" y=\"144.295568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"51.636495\" y=\"142.036575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.826806\" y=\"98.589606\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.593698\" y=\"87.094471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"96.4273\" y=\"110.344014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"70.113268\" y=\"123.52895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.955975\" y=\"72.648847\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"161.914728\" y=\"81.315282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"46.113189\" y=\"143.826085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"60.461621\" y=\"143.396614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"60.405915\" y=\"141.194527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"55.503525\" y=\"146.103047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"46.385407\" y=\"137.379396\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"100.117452\" y=\"104.612527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"170.991202\" y=\"79.053536\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.502787\" y=\"84.182586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"63.87557\" y=\"139.497616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"159.681293\" y=\"91.609547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"58.083165\" y=\"143.463133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"62.973737\" y=\"143.842557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"152.137326\" y=\"94.975304\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"88.702318\" y=\"123.431116\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"155.287802\" y=\"93.645281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"171.869124\" y=\"90.403215\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"90.082024\" y=\"125.767412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"103.079104\" y=\"106.713764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"92.483924\" y=\"123.289605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"157.854446\" y=\"88.418522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"56.025995\" y=\"151.781056\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.131402\" y=\"98.259883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"169.033019\" y=\"73.925572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"76.167673\" y=\"133.133136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"89.680129\" y=\"113.188882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.04166\" y=\"149.119062\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"155.156102\" y=\"94.479329\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"85.500445\" y=\"129.263206\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.582834\" y=\"74.897893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.908448\" y=\"86.902053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"168.566743\" y=\"83.873246\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.617199\" y=\"91.50453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"85.581043\" y=\"123.962726\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"77.947346\" y=\"120.008051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.289755\" y=\"95.197544\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.977026\" y=\"93.950878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"158.345048\" y=\"106.198939\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"52.342243\" y=\"147.735497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.409866\" y=\"79.161323\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.377182\" y=\"94.572688\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"71.54848\" y=\"133.94625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"165.876681\" y=\"93.421959\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"84.153028\" y=\"112.285991\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"158.238654\" y=\"94.948157\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"98.378001\" y=\"116.627998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"162.679062\" y=\"86.597605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"84.685365\" y=\"128.072456\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"164.0673\" y=\"89.122555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"163.136187\" y=\"82.617786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"131.398244\" y=\"102.186587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"72.518073\" y=\"133.445774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"160.056792\" y=\"77.227605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"167.709278\" y=\"82.125413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"166.565401\" y=\"73.889221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"131.440447\" y=\"94.038082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"119.078095\" y=\"84.944175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 159.824267 \n",
       "L 38.312875 57.239502 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 74.486585 179.384625 \n",
       "L 167.824085 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_11\">\n",
       "    <!-- RMSE: 0.311 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(45.313273 63.972112) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-52\" d=\"M 503 0 \n",
       "L 503 4581 \n",
       "L 2534 4581 \n",
       "Q 3147 4581 3465 4457 \n",
       "Q 3784 4334 3975 4021 \n",
       "Q 4166 3709 4166 3331 \n",
       "Q 4166 2844 3850 2509 \n",
       "Q 3534 2175 2875 2084 \n",
       "Q 3116 1969 3241 1856 \n",
       "Q 3506 1613 3744 1247 \n",
       "L 4541 0 \n",
       "L 3778 0 \n",
       "L 3172 953 \n",
       "Q 2906 1366 2734 1584 \n",
       "Q 2563 1803 2427 1890 \n",
       "Q 2291 1978 2150 2013 \n",
       "Q 2047 2034 1813 2034 \n",
       "L 1109 2034 \n",
       "L 1109 0 \n",
       "L 503 0 \n",
       "z\n",
       "M 1109 2559 \n",
       "L 2413 2559 \n",
       "Q 2828 2559 3062 2645 \n",
       "Q 3297 2731 3419 2920 \n",
       "Q 3541 3109 3541 3331 \n",
       "Q 3541 3656 3305 3865 \n",
       "Q 3069 4075 2559 4075 \n",
       "L 1109 4075 \n",
       "L 1109 2559 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-4d\" d=\"M 475 0 \n",
       "L 475 4581 \n",
       "L 1388 4581 \n",
       "L 2472 1338 \n",
       "Q 2622 884 2691 659 \n",
       "Q 2769 909 2934 1394 \n",
       "L 4031 4581 \n",
       "L 4847 4581 \n",
       "L 4847 0 \n",
       "L 4263 0 \n",
       "L 4263 3834 \n",
       "L 2931 0 \n",
       "L 2384 0 \n",
       "L 1059 3900 \n",
       "L 1059 0 \n",
       "L 475 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-53\" d=\"M 288 1472 \n",
       "L 859 1522 \n",
       "Q 900 1178 1048 958 \n",
       "Q 1197 738 1509 602 \n",
       "Q 1822 466 2213 466 \n",
       "Q 2559 466 2825 569 \n",
       "Q 3091 672 3220 851 \n",
       "Q 3350 1031 3350 1244 \n",
       "Q 3350 1459 3225 1620 \n",
       "Q 3100 1781 2813 1891 \n",
       "Q 2628 1963 1997 2114 \n",
       "Q 1366 2266 1113 2400 \n",
       "Q 784 2572 623 2826 \n",
       "Q 463 3081 463 3397 \n",
       "Q 463 3744 659 4045 \n",
       "Q 856 4347 1234 4503 \n",
       "Q 1613 4659 2075 4659 \n",
       "Q 2584 4659 2973 4495 \n",
       "Q 3363 4331 3572 4012 \n",
       "Q 3781 3694 3797 3291 \n",
       "L 3216 3247 \n",
       "Q 3169 3681 2898 3903 \n",
       "Q 2628 4125 2100 4125 \n",
       "Q 1550 4125 1298 3923 \n",
       "Q 1047 3722 1047 3438 \n",
       "Q 1047 3191 1225 3031 \n",
       "Q 1400 2872 2139 2705 \n",
       "Q 2878 2538 3153 2413 \n",
       "Q 3553 2228 3743 1945 \n",
       "Q 3934 1663 3934 1294 \n",
       "Q 3934 928 3725 604 \n",
       "Q 3516 281 3123 101 \n",
       "Q 2731 -78 2241 -78 \n",
       "Q 1619 -78 1198 103 \n",
       "Q 778 284 539 648 \n",
       "Q 300 1013 288 1472 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-45\" d=\"M 506 0 \n",
       "L 506 4581 \n",
       "L 3819 4581 \n",
       "L 3819 4041 \n",
       "L 1113 4041 \n",
       "L 1113 2638 \n",
       "L 3647 2638 \n",
       "L 3647 2100 \n",
       "L 1113 2100 \n",
       "L 1113 541 \n",
       "L 3925 541 \n",
       "L 3925 0 \n",
       "L 506 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3a\" d=\"M 578 2678 \n",
       "L 578 3319 \n",
       "L 1219 3319 \n",
       "L 1219 2678 \n",
       "L 578 2678 \n",
       "z\n",
       "M 578 0 \n",
       "L 578 641 \n",
       "L 1219 641 \n",
       "L 1219 0 \n",
       "L 578 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-33\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"531.736328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_12\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(56.287109 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_10\">\n",
       "    <path d=\"M 162.840044 85.624606 \n",
       "L 171.956845 80.614589 \n",
       "L 44.676874 150.559606 \n",
       "L 53.123685 145.917773 \n",
       "\" clip-path=\"url(#p45d028abef)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 214.360594 179.384625 \n",
       "L 354.368562 179.384625 \n",
       "L 354.368562 51.1485 \n",
       "L 214.360594 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"245.90611\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(240.889422 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"290.015167\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(287.568355 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"334.124224\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(331.677412 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"214.360594\" y=\"159.18344\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.027219 162.332877) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"214.360594\" y=\"137.105674\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.027219 140.255112) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"214.360594\" y=\"115.027909\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.166969 118.177347) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"214.360594\" y=\"92.950144\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.166969 96.099581) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"214.360594\" y=\"70.872379\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.166969 74.021816) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_2\">\n",
       "    <path d=\"M 252.795214 154.593523 \n",
       "L 252.795214 154.20609 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.195021 141.547263 \n",
       "L 264.195021 140.69041 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.60087 121.443141 \n",
       "L 284.60087 120.688713 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.201266 102.167202 \n",
       "L 303.201266 101.606262 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.84106 127.81869 \n",
       "L 278.84106 125.919163 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.091929 133.515224 \n",
       "L 277.091929 130.514324 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.144744 130.568163 \n",
       "L 275.144744 129.679952 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.039215 86.212009 \n",
       "L 319.039215 85.932167 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.928994 146.827477 \n",
       "L 255.928994 145.484743 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.480968 146.603322 \n",
       "L 258.480968 145.747583 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.65464 120.679782 \n",
       "L 284.65464 120.142774 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.378178 115.211485 \n",
       "L 290.378178 114.699334 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.736903 101.707952 \n",
       "L 303.736903 100.719363 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.782773 150.998458 \n",
       "L 255.782773 149.90212 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.484567 141.102794 \n",
       "L 264.484567 140.760536 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 251.842316 152.8972 \n",
       "L 251.842316 152.207686 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.037332 114.949037 \n",
       "L 290.037332 114.026805 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.699957 114.114127 \n",
       "L 291.699957 113.569416 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.590303 80.064841 \n",
       "L 325.590303 79.238975 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.290193 117.664436 \n",
       "L 288.290193 116.525853 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 341.461178 64.192174 \n",
       "L 341.461178 62.641887 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.501467 76.280365 \n",
       "L 329.501467 75.149301 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.530737 108.65109 \n",
       "L 296.530737 108.264534 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.84573 81.566106 \n",
       "L 323.84573 80.85477 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.169408 112.396122 \n",
       "L 293.169408 111.127793 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.132447 140.227343 \n",
       "L 263.132447 139.596321 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.926526 97.100149 \n",
       "L 307.926526 96.810536 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.463185 91.742037 \n",
       "L 313.463185 91.373353 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.434038 137.194588 \n",
       "L 269.434038 136.514383 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.460914 83.867471 \n",
       "L 321.460914 82.811275 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.951114 102.416694 \n",
       "L 300.951114 101.263923 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.604832 111.85031 \n",
       "L 294.604832 111.176753 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.44461 111.881285 \n",
       "L 293.44461 110.629727 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.820187 128.798799 \n",
       "L 276.820187 128.163708 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.970544 73.539543 \n",
       "L 331.970544 72.796249 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.262688 99.997406 \n",
       "L 305.262688 99.457466 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.537566 140.663971 \n",
       "L 264.537566 139.914817 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.269522 121.695568 \n",
       "L 283.269522 121.226933 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.627606 133.619793 \n",
       "L 268.627606 131.815845 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.143984 81.432996 \n",
       "L 325.143984 79.898453 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.256319 116.113884 \n",
       "L 290.256319 115.274892 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.136402 109.984002 \n",
       "L 295.136402 109.787994 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.101078 121.105419 \n",
       "L 284.101078 120.432685 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.174242 97.847066 \n",
       "L 307.174242 96.789537 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.840657 101.99306 \n",
       "L 303.840657 101.279096 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.898204 140.30122 \n",
       "L 264.898204 139.626865 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.699149 131.416269 \n",
       "L 273.699149 130.775603 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.83455 134.74705 \n",
       "L 270.83455 134.336398 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.471843 138.789143 \n",
       "L 269.471843 137.945724 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.460596 124.861152 \n",
       "L 279.460596 124.273554 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.45048 131.812698 \n",
       "L 273.45048 131.000111 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.925668 125.329809 \n",
       "L 279.925668 124.911938 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.573103 106.68691 \n",
       "L 301.573103 104.818864 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.716544 124.546318 \n",
       "L 280.716544 123.997141 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.166339 81.767262 \n",
       "L 323.166339 81.357105 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.166884 101.163443 \n",
       "L 304.166884 100.764866 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.586187 95.031052 \n",
       "L 310.586187 94.324354 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.380894 143.202513 \n",
       "L 262.380894 142.602683 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.643932 121.492967 \n",
       "L 283.643932 120.956029 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.970361 88.090809 \n",
       "L 316.970361 87.598546 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.259824 111.877894 \n",
       "L 295.259824 111.095555 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.1459 99.921345 \n",
       "L 305.1459 99.250301 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.092524 139.359405 \n",
       "L 262.092524 138.847541 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.391157 137.777007 \n",
       "L 267.391157 136.206511 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.405711 74.906477 \n",
       "L 331.405711 73.801352 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.334315 105.828297 \n",
       "L 299.334315 105.330698 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.678477 134.166532 \n",
       "L 270.678477 133.511212 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.650232 108.480516 \n",
       "L 296.650232 108.13529 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.640946 94.95937 \n",
       "L 309.640946 94.537598 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.678592 92.080669 \n",
       "L 312.678592 91.020853 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.767712 116.990992 \n",
       "L 288.767712 116.262774 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.123262 90.223467 \n",
       "L 316.123262 89.486941 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.437407 92.771424 \n",
       "L 312.437407 92.183106 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.989631 125.995144 \n",
       "L 279.989631 125.18143 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.91868 127.535332 \n",
       "L 277.91868 126.881708 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.744926 148.784549 \n",
       "L 258.744926 147.649422 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.875383 88.718682 \n",
       "L 316.875383 88.282367 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.510086 130.845577 \n",
       "L 274.510086 130.072955 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.398804 79.816914 \n",
       "L 325.398804 79.454649 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.144282 96.854671 \n",
       "L 308.144282 96.33773 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.269599 133.605858 \n",
       "L 269.269599 132.692438 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.583756 112.451563 \n",
       "L 292.583756 112.087254 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.273217 128.681521 \n",
       "L 276.273217 128.007543 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.589766 108.106176 \n",
       "L 297.589766 106.908128 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.487489 101.675119 \n",
       "L 304.487489 100.920545 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.154808 126.082142 \n",
       "L 279.154808 125.529518 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.219938 105.470813 \n",
       "L 299.219938 104.646116 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.687022 131.43613 \n",
       "L 274.687022 130.702502 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.883982 116.326696 \n",
       "L 291.883982 115.704323 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.62989 129.584886 \n",
       "L 275.62989 129.289245 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.117717 94.318479 \n",
       "L 310.117717 93.75045 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.793516 141.99041 \n",
       "L 264.793516 141.353871 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.745554 108.56735 \n",
       "L 295.745554 107.318543 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.637488 128.824398 \n",
       "L 276.637488 128.148716 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.625962 121.150747 \n",
       "L 288.625962 119.927294 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 252.771798 156.946282 \n",
       "L 252.771798 155.766278 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.414823 133.662809 \n",
       "L 271.414823 133.057401 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.996211 89.492037 \n",
       "L 315.996211 88.563885 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.361107 82.649143 \n",
       "L 322.361107 82.139214 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 243.460204 167.983526 \n",
       "L 243.460204 166.154862 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.558357 101.657675 \n",
       "L 303.558357 101.17171 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.792016 108.375087 \n",
       "L 296.792016 107.882574 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.670443 93.648941 \n",
       "L 311.670443 93.199534 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.319521 121.134331 \n",
       "L 284.319521 120.808625 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.29839 103.069324 \n",
       "L 302.29839 102.579395 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.766352 122.281735 \n",
       "L 283.766352 120.86911 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.905666 139.276071 \n",
       "L 264.905666 138.82724 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.638597 106.413201 \n",
       "L 300.638597 105.130837 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.881238 102.562878 \n",
       "L 302.881238 102.037098 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 252.795214 153.295618 \n",
       "L 252.795214 152.592774 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 239.43123 165.806443 \n",
       "L 239.43123 164.612572 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.857445 92.012264 \n",
       "L 312.857445 91.548881 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.654385 135.712089 \n",
       "L 270.654385 135.120062 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.28698 107.172338 \n",
       "L 298.28698 106.849061 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.972699 90.452199 \n",
       "L 314.972699 89.712155 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.73017 85.833749 \n",
       "L 318.73017 84.931458 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.788014 102.999935 \n",
       "L 301.788014 102.570518 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.768478 134.392299 \n",
       "L 272.768478 133.668466 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.437869 95.743138 \n",
       "L 309.437869 95.234345 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.823452 107.448918 \n",
       "L 297.823452 106.926191 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.893695 118.330269 \n",
       "L 286.893695 117.503277 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.866523 93.52484 \n",
       "L 311.866523 93.035138 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.860354 108.484565 \n",
       "L 296.860354 107.496463 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.68383 109.331235 \n",
       "L 295.68383 108.878301 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.405508 115.971124 \n",
       "L 289.405508 115.713886 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.376558 149.445715 \n",
       "L 258.376558 148.399775 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.062748 93.794707 \n",
       "L 311.062748 93.490026 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.737221 108.673608 \n",
       "L 296.737221 107.695242 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.346447 117.6065 \n",
       "L 288.346447 117.042666 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 248.762676 157.441104 \n",
       "L 248.762676 155.62167 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.180802 120.778648 \n",
       "L 282.180802 120.295365 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.704104 124.771974 \n",
       "L 280.704104 124.349598 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 243.393896 163.578594 \n",
       "L 243.393896 162.411711 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.833149 109.508968 \n",
       "L 295.833149 109.111413 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.589794 129.679981 \n",
       "L 275.589794 129.43899 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.202 140.176546 \n",
       "L 266.202 139.627748 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.64784 122.521308 \n",
       "L 282.64784 122.042614 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.486567 116.726795 \n",
       "L 288.486567 116.282385 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.065374 90.245855 \n",
       "L 315.065374 89.709688 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.753895 103.345543 \n",
       "L 301.753895 103.079523 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.689142 117.143487 \n",
       "L 289.689142 116.670672 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.115239 126.88403 \n",
       "L 279.115239 126.334692 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.214162 122.01739 \n",
       "L 284.214162 120.792908 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.352112 114.959139 \n",
       "L 290.352112 114.618891 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.787166 83.526599 \n",
       "L 321.787166 82.664196 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.701153 120.613034 \n",
       "L 284.701153 120.042811 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.874625 105.409621 \n",
       "L 299.874625 104.857191 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.095137 148.015451 \n",
       "L 256.095137 146.931123 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.234248 105.380698 \n",
       "L 300.234248 104.924291 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.029166 105.119778 \n",
       "L 301.029166 104.099416 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.183521 115.534237 \n",
       "L 290.183521 114.396783 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.017452 120.21793 \n",
       "L 285.017452 119.706479 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.810152 125.551161 \n",
       "L 279.810152 124.91908 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.966859 131.142429 \n",
       "L 273.966859 130.566349 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.243305 126.777807 \n",
       "L 278.243305 126.444987 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.676647 130.51357 \n",
       "L 274.676647 129.894295 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.792123 127.016211 \n",
       "L 278.792123 126.530328 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 250.011191 157.058003 \n",
       "L 250.011191 156.184486 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.456754 138.167014 \n",
       "L 266.456754 137.817734 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.34306 126.393392 \n",
       "L 279.34306 125.25669 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.889959 120.966325 \n",
       "L 284.889959 119.467756 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.929811 126.502404 \n",
       "L 278.929811 126.169535 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.152257 127.178835 \n",
       "L 278.152257 126.259946 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.865833 127.077211 \n",
       "L 279.865833 125.910515 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.138131 90.268678 \n",
       "L 315.138131 89.38727 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.764638 117.139019 \n",
       "L 288.764638 116.67611 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.58829 131.077532 \n",
       "L 274.58829 130.281405 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.379592 91.418899 \n",
       "L 313.379592 90.277255 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.705487 84.752934 \n",
       "L 320.705487 84.32279 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.292788 145.840347 \n",
       "L 259.292788 145.354097 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.006253 98.482151 \n",
       "L 307.006253 98.04017 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.786625 128.564433 \n",
       "L 276.786625 128.113987 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.216328 109.930184 \n",
       "L 295.216328 109.20722 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.009975 110.453424 \n",
       "L 295.009975 109.930452 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 252.736637 151.123081 \n",
       "L 252.736637 150.509902 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.356138 144.918636 \n",
       "L 260.356138 143.688797 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.977819 134.084145 \n",
       "L 270.977819 133.354353 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.121762 101.71267 \n",
       "L 304.121762 101.175383 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.396468 101.85085 \n",
       "L 303.396468 101.129699 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 313.441083 91.57818 \n",
       "L 313.441083 91.193902 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.351022 119.858561 \n",
       "L 285.351022 118.993965 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.557639 118.24257 \n",
       "L 287.557639 117.473351 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.342962 102.443467 \n",
       "L 302.342962 101.856063 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.769833 148.001926 \n",
       "L 256.769833 146.949085 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.728092 101.522879 \n",
       "L 303.728092 101.264168 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.498391 115.647539 \n",
       "L 289.498391 115.187378 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.429243 127.984033 \n",
       "L 276.429243 127.213805 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.404911 121.714906 \n",
       "L 283.404911 121.421789 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.551059 106.541118 \n",
       "L 298.551059 105.965219 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.959914 104.7362 \n",
       "L 299.959914 104.129166 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.742658 106.213906 \n",
       "L 298.742658 105.819571 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.681215 125.824074 \n",
       "L 279.681215 125.368025 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.972732 141.147999 \n",
       "L 264.972732 140.363307 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.060366 80.570236 \n",
       "L 325.060366 79.080869 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.013472 118.922994 \n",
       "L 288.013472 118.038908 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.633504 124.851953 \n",
       "L 280.633504 124.323888 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.912136 117.575293 \n",
       "L 287.912136 116.970704 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.774867 122.271614 \n",
       "L 282.774867 121.901289 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.912469 96.074651 \n",
       "L 308.912469 95.693275 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.709755 129.101137 \n",
       "L 276.709755 128.447606 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.978275 109.507887 \n",
       "L 294.978275 108.355397 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.938919 92.295544 \n",
       "L 312.938919 91.811098 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.412056 75.900941 \n",
       "L 329.412056 75.240039 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.968327 125.221296 \n",
       "L 279.968327 124.769244 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 252.239484 156.000976 \n",
       "L 252.239484 155.609427 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.374529 117.345267 \n",
       "L 288.374529 115.764601 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 249.920187 161.374478 \n",
       "L 249.920187 160.609859 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.97394 92.003532 \n",
       "L 312.97394 91.553419 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.811768 141.875441 \n",
       "L 262.811768 141.417341 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 335.958094 68.881647 \n",
       "L 335.958094 68.219814 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.896808 99.587606 \n",
       "L 306.896808 98.875012 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.496707 133.67468 \n",
       "L 271.496707 133.300947 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.507413 120.862094 \n",
       "L 284.507413 120.527247 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.719961 126.198148 \n",
       "L 279.719961 125.250778 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.98906 84.349345 \n",
       "L 320.98906 83.976088 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.310947 130.954965 \n",
       "L 274.310947 130.464286 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.624346 82.444284 \n",
       "L 322.624346 82.050987 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.424381 130.062465 \n",
       "L 276.424381 128.137733 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.090418 106.308832 \n",
       "L 299.090418 105.971021 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.635473 99.064912 \n",
       "L 306.635473 98.104675 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.966197 122.569552 \n",
       "L 282.966197 121.802651 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.111936 112.39965 \n",
       "L 293.111936 112.006177 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.004633 139.621253 \n",
       "L 263.004633 138.427347 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.469079 85.041735 \n",
       "L 320.469079 84.281899 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.042526 121.347605 \n",
       "L 284.042526 120.80582 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.913256 143.523659 \n",
       "L 258.913256 141.981566 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.981439 92.358013 \n",
       "L 312.981439 91.894185 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.208392 145.401081 \n",
       "L 261.208392 144.223948 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.605157 80.030741 \n",
       "L 325.605157 79.332744 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.535707 86.606647 \n",
       "L 318.535707 85.970315 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.59431 98.714492 \n",
       "L 306.59431 98.276611 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.787169 96.459649 \n",
       "L 308.787169 96.072036 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.357655 90.645566 \n",
       "L 314.357655 90.293732 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.27426 76.966494 \n",
       "L 328.27426 76.416766 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.30058 103.511429 \n",
       "L 301.30058 102.870972 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.856313 105.506789 \n",
       "L 299.856313 104.507797 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.804579 119.437772 \n",
       "L 286.804579 118.727211 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.712327 146.236514 \n",
       "L 259.712327 145.892274 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.959685 117.130017 \n",
       "L 287.959685 115.547701 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.03729 134.274507 \n",
       "L 271.03729 133.731335 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.212278 80.068718 \n",
       "L 325.212278 79.248286 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.978412 127.080643 \n",
       "L 277.978412 126.800884 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.270661 132.60166 \n",
       "L 273.270661 132.211915 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.46687 146.633103 \n",
       "L 259.46687 145.723008 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.26196 96.327652 \n",
       "L 309.26196 95.3427 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.508638 98.057104 \n",
       "L 307.508638 97.623956 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 337.752865 67.056758 \n",
       "L 337.752865 66.26622 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.329969 102.982847 \n",
       "L 302.329969 102.342871 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 239.96439 167.666363 \n",
       "L 239.96439 166.405105 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.019406 145.362927 \n",
       "L 261.019406 144.835972 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.185054 129.124096 \n",
       "L 276.185054 128.756684 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.884445 87.652303 \n",
       "L 317.884445 86.931883 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.46134 132.362234 \n",
       "L 273.46134 131.61592 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.005063 114.84572 \n",
       "L 290.005063 114.529878 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.321861 106.010966 \n",
       "L 299.321861 105.612307 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.634593 115.719803 \n",
       "L 290.634593 115.190052 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.410617 93.03254 \n",
       "L 312.410617 92.710063 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.843137 114.995476 \n",
       "L 289.843137 114.481011 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.260041 126.315556 \n",
       "L 279.260041 125.596614 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.031534 122.025427 \n",
       "L 284.031534 121.087833 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.247749 109.989111 \n",
       "L 295.247749 109.697796 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 328.036812 77.489338 \n",
       "L 328.036812 76.81085 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.791655 95.412147 \n",
       "L 310.791655 94.255202 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 322.321398 82.599793 \n",
       "L 322.321398 82.099042 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.808187 120.550718 \n",
       "L 284.808187 120.119545 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.748243 96.976869 \n",
       "L 310.748243 95.749089 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.666716 145.808799 \n",
       "L 261.666716 145.041944 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 220.724592 173.44026 \n",
       "L 220.724592 171.435236 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 342.343153 62.461076 \n",
       "L 342.343153 61.946281 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.84015 113.674094 \n",
       "L 291.84015 113.240708 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.363642 95.32269 \n",
       "L 309.363642 94.788357 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.505377 118.985331 \n",
       "L 286.505377 118.506795 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.074591 123.767508 \n",
       "L 282.074591 122.85247 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.297984 131.674441 \n",
       "L 273.297984 131.22207 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.368291 117.129731 \n",
       "L 288.368291 116.239052 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.489323 78.137526 \n",
       "L 326.489323 77.559022 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.046151 122.043095 \n",
       "L 283.046151 121.633907 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.018105 107.169972 \n",
       "L 298.018105 106.626459 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.352813 109.00575 \n",
       "L 296.352813 107.872231 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.070049 128.009636 \n",
       "L 278.070049 127.37446 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.391007 125.645436 \n",
       "L 279.391007 124.890103 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.323035 141.66971 \n",
       "L 263.323035 140.987078 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.392899 102.587463 \n",
       "L 303.392899 101.7667 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.907425 110.512696 \n",
       "L 294.907425 110.108804 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 247.338965 164.929231 \n",
       "L 247.338965 163.498109 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.139947 94.90142 \n",
       "L 310.139947 94.680643 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.97708 133.511622 \n",
       "L 269.97708 132.924327 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.75234 116.334654 \n",
       "L 288.75234 115.965728 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 311.39881 94.480067 \n",
       "L 311.39881 93.696434 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.660072 135.979965 \n",
       "L 268.660072 134.692639 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 284.925434 120.522311 \n",
       "L 284.925434 119.758247 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.457735 146.528395 \n",
       "L 259.457735 145.37398 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.793244 150.105169 \n",
       "L 255.793244 149.352414 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.43689 132.988047 \n",
       "L 274.43689 130.773414 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.219186 85.54289 \n",
       "L 319.219186 85.156049 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.434787 122.398891 \n",
       "L 282.434787 122.096982 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.526962 87.532869 \n",
       "L 317.526962 86.7298 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.86737 96.40535 \n",
       "L 308.86737 95.991809 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.78253 104.768407 \n",
       "L 300.78253 104.132843 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.247359 76.426635 \n",
       "L 329.247359 75.480854 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.216112 123.744108 \n",
       "L 282.216112 123.164426 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.781714 107.489259 \n",
       "L 297.781714 106.880372 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 320.143581 85.640183 \n",
       "L 320.143581 84.98177 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 283.554547 121.915868 \n",
       "L 283.554547 121.342167 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.259227 115.760672 \n",
       "L 290.259227 115.092369 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.076891 96.831232 \n",
       "L 308.076891 96.289978 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.473428 127.76787 \n",
       "L 277.473428 127.503203 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.069603 136.887794 \n",
       "L 268.069603 136.309756 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.334334 124.739246 \n",
       "L 279.334334 123.722506 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.430042 148.197027 \n",
       "L 261.430042 147.272758 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.603842 145.945868 \n",
       "L 258.603842 145.151021 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.313922 138.214721 \n",
       "L 268.313922 137.520215 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.726821 152.671015 \n",
       "L 253.726821 151.937107 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.393645 139.413916 \n",
       "L 265.393645 138.828334 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.868593 99.043961 \n",
       "L 306.868593 98.1492 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.032322 131.486798 \n",
       "L 275.032322 130.656011 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.544629 77.869694 \n",
       "L 327.544629 77.408457 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.431412 85.872435 \n",
       "L 319.431412 85.464922 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.041904 117.204455 \n",
       "L 288.041904 116.845075 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.552444 146.494708 \n",
       "L 262.552444 145.112764 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.990309 105.149698 \n",
       "L 299.990309 104.251302 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.943844 117.128007 \n",
       "L 287.943844 116.850556 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.838573 146.391926 \n",
       "L 258.838573 145.387995 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.728486 130.833539 \n",
       "L 274.728486 130.315198 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.510471 95.558436 \n",
       "L 309.510471 95.113012 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.858203 101.181952 \n",
       "L 303.858203 100.907367 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.043156 76.05927 \n",
       "L 329.043156 75.426277 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.670162 120.541466 \n",
       "L 285.670162 120.066807 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.53482 88.770847 \n",
       "L 316.53482 88.246385 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.621665 92.463806 \n",
       "L 312.621665 91.954881 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 265.67789 139.452835 \n",
       "L 265.67789 138.82877 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.612705 125.274435 \n",
       "L 280.612705 124.339412 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.321165 77.981871 \n",
       "L 327.321165 77.477825 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.406971 73.13581 \n",
       "L 331.406971 72.614608 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.353634 96.42806 \n",
       "L 309.353634 95.453803 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.210254 128.289583 \n",
       "L 277.210254 127.63582 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.289311 99.892137 \n",
       "L 305.289311 99.40804 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.591621 107.367446 \n",
       "L 298.591621 106.928148 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.1137 98.27541 \n",
       "L 307.1137 97.509715 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.126637 118.721838 \n",
       "L 287.126637 118.008436 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.3013 133.866348 \n",
       "L 269.3013 132.93807 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.020083 131.199284 \n",
       "L 274.020083 130.861922 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.505575 98.145519 \n",
       "L 307.505575 97.025889 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.855736 119.360806 \n",
       "L 285.855736 119.06021 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.925079 89.858687 \n",
       "L 314.925079 87.681688 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.412437 132.284649 \n",
       "L 273.412437 131.758672 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.568331 75.447206 \n",
       "L 329.568331 74.392086 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.798858 109.593505 \n",
       "L 296.798858 108.205093 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 255.42432 148.389381 \n",
       "L 255.42432 146.969609 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.06263 135.514918 \n",
       "L 267.06263 134.823927 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.932237 109.343553 \n",
       "L 295.932237 108.794332 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.928123 98.806743 \n",
       "L 306.928123 98.078324 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.499776 153.832257 \n",
       "L 253.499776 152.712906 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 337.408302 67.898967 \n",
       "L 337.408302 67.263704 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.439105 103.840764 \n",
       "L 301.439105 103.114145 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.196089 105.927832 \n",
       "L 300.196089 104.928308 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.134051 125.159343 \n",
       "L 280.134051 124.912659 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 251.720795 153.021748 \n",
       "L 251.720795 151.861528 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.799671 138.042106 \n",
       "L 266.799671 137.156177 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.786386 122.641388 \n",
       "L 282.786386 122.056671 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.902292 96.96773 \n",
       "L 308.902292 96.227098 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.794062 122.231594 \n",
       "L 282.794062 121.68254 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.40979 129.258077 \n",
       "L 276.40979 128.362537 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 293.372188 111.853025 \n",
       "L 293.372188 110.774393 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 275.699915 128.208324 \n",
       "L 275.699915 127.398883 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 321.237516 84.289759 \n",
       "L 321.237516 83.94285 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.537582 104.650845 \n",
       "L 300.537582 104.270791 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.724898 122.862365 \n",
       "L 282.724898 122.252787 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.499909 148.133559 \n",
       "L 258.499909 147.393865 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.35056 92.487566 \n",
       "L 312.35056 91.66365 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 259.982456 144.131606 \n",
       "L 259.982456 143.283218 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.615627 97.134511 \n",
       "L 307.615627 96.549457 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.180989 100.380185 \n",
       "L 305.180989 100.015605 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.609229 123.104597 \n",
       "L 282.609229 122.536088 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.536925 116.572069 \n",
       "L 290.536925 115.670383 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.41931 82.03117 \n",
       "L 323.41931 81.4544 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.764012 133.744169 \n",
       "L 271.764012 132.399276 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.999192 115.436663 \n",
       "L 289.999192 114.715191 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.601233 116.665289 \n",
       "L 288.601233 116.372565 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.816788 98.492288 \n",
       "L 306.816788 98.11844 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.871551 90.103197 \n",
       "L 314.871551 89.30334 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.903997 130.707204 \n",
       "L 274.903997 130.11979 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.342443 148.246433 \n",
       "L 256.342443 147.586702 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 301.532973 104.132012 \n",
       "L 301.532973 103.058996 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.799264 102.682368 \n",
       "L 302.799264 101.812804 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.189896 117.147723 \n",
       "L 288.189896 116.800675 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.353333 137.501904 \n",
       "L 268.353333 136.440724 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.460596 125.610749 \n",
       "L 279.460596 125.263451 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.672598 128.828487 \n",
       "L 279.672598 127.138745 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.224818 116.428139 \n",
       "L 289.224818 115.921995 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.205541 131.033477 \n",
       "L 274.205541 130.357524 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.733101 100.493132 \n",
       "L 304.733101 99.79554 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 316.693125 88.415648 \n",
       "L 316.693125 88.075035 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 289.92275 115.299225 \n",
       "L 289.92275 115.001619 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.260865 93.078775 \n",
       "L 312.260865 92.257547 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 333.671433 72.269564 \n",
       "L 333.671433 70.894404 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 232.493297 169.287762 \n",
       "L 232.493297 168.291789 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.201724 154.011207 \n",
       "L 253.201724 153.473333 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.517004 125.426414 \n",
       "L 279.517004 124.963481 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.260223 119.08691 \n",
       "L 286.260223 118.421996 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.488303 110.624597 \n",
       "L 294.488303 109.253754 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 280.766244 125.171914 \n",
       "L 280.766244 124.75559 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.64754 113.401477 \n",
       "L 291.64754 112.664266 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 285.93439 119.746206 \n",
       "L 285.93439 119.131774 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.509374 117.904876 \n",
       "L 287.509374 117.577685 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.599741 108.920618 \n",
       "L 296.599741 108.3883 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.48851 132.688491 \n",
       "L 272.48851 132.113012 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.572046 108.594617 \n",
       "L 297.572046 108.068109 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 256.249969 149.315605 \n",
       "L 256.249969 148.721163 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.566185 86.560432 \n",
       "L 318.566185 86.047539 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.864877 123.426215 \n",
       "L 281.864877 122.913909 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.234685 95.887528 \n",
       "L 309.234685 95.445945 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 306.12603 99.616757 \n",
       "L 306.12603 98.928357 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 329.180376 76.840787 \n",
       "L 329.180376 75.469152 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 303.921273 101.143907 \n",
       "L 303.921273 100.813586 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 296.452318 108.661076 \n",
       "L 296.452318 108.505906 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 269.033843 136.184948 \n",
       "L 269.033843 135.569955 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 223.470479 173.55571 \n",
       "L 223.470479 172.287656 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.89679 142.899215 \n",
       "L 257.89679 141.673084 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.863788 143.544252 \n",
       "L 260.863788 142.817711 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 325.143189 80.722994 \n",
       "L 325.143189 79.960159 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 302.329969 103.255776 \n",
       "L 302.329969 102.325231 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.738684 127.214453 \n",
       "L 277.738684 126.642418 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 273.368893 133.238392 \n",
       "L 273.368893 131.344053 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.540929 99.614131 \n",
       "L 305.540929 99.1543 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 268.234926 137.201087 \n",
       "L 268.234926 136.452515 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.96326 138.331193 \n",
       "L 267.96326 137.51152 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.50872 118.917606 \n",
       "L 286.50872 118.073588 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 318.778567 88.683368 \n",
       "L 318.778567 87.698065 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 262.584996 144.973885 \n",
       "L 262.584996 143.953113 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 338.364411 66.84527 \n",
       "L 338.364411 66.103617 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.187683 100.49147 \n",
       "L 304.187683 99.92994 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.385862 140.975785 \n",
       "L 264.385862 140.093404 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 317.149686 89.079784 \n",
       "L 317.149686 88.076972 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.125141 115.711577 \n",
       "L 290.125141 114.591685 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 274.898851 130.152406 \n",
       "L 274.898851 129.820357 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 287.253738 118.303736 \n",
       "L 287.253738 117.984438 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.933063 144.892157 \n",
       "L 260.933063 144.497602 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 332.873233 73.233835 \n",
       "L 332.873233 72.075028 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 319.339817 86.233736 \n",
       "L 319.339817 85.420852 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 271.717714 133.499338 \n",
       "L 271.717714 133.166935 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 298.198375 106.178727 \n",
       "L 298.198375 105.271707 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 300.224211 105.687099 \n",
       "L 300.224211 104.82058 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.429756 92.713747 \n",
       "L 312.429756 92.286294 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.273007 137.835552 \n",
       "L 266.273007 137.073462 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 253.862134 152.731715 \n",
       "L 253.862134 152.049668 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.288923 138.148399 \n",
       "L 267.288923 137.716302 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.976576 143.213274 \n",
       "L 267.976576 141.762221 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 257.200477 148.902994 \n",
       "L 257.200477 147.934332 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 279.115239 126.140572 \n",
       "L 279.115239 125.812806 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 297.891413 107.468534 \n",
       "L 297.891413 106.211596 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.043578 91.293818 \n",
       "L 314.043578 90.993808 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 266.75095 139.439983 \n",
       "L 266.75095 138.802011 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.885097 109.53076 \n",
       "L 295.885097 109.018801 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 286.642093 118.481479 \n",
       "L 286.642093 118.018714 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 260.054035 141.741111 \n",
       "L 260.054035 140.881665 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 295.863858 110.272507 \n",
       "L 295.863858 109.145555 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 276.238966 129.304681 \n",
       "L 276.238966 128.944643 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.717497 124.149714 \n",
       "L 281.717497 123.391617 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 314.698606 91.63795 \n",
       "L 314.698606 90.589151 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.627316 127.960812 \n",
       "L 277.627316 127.315149 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.392863 126.784358 \n",
       "L 278.392863 126.078355 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 258.744926 146.757665 \n",
       "L 258.744926 146.406019 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.172329 82.18485 \n",
       "L 323.172329 81.291111 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.567448 136.808642 \n",
       "L 267.567448 136.505791 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.352437 99.758515 \n",
       "L 305.352437 98.761236 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 308.218963 97.278519 \n",
       "L 308.218963 96.528434 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.370472 141.785347 \n",
       "L 263.370472 140.493666 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 264.431464 144.517206 \n",
       "L 264.431464 143.024858 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 270.684496 135.177598 \n",
       "L 270.684496 133.909347 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.832169 126.510581 \n",
       "L 278.832169 126.074672 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 263.746986 141.025574 \n",
       "L 263.746986 140.641135 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 315.087337 90.088635 \n",
       "L 315.087337 89.857476 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.088823 98.159987 \n",
       "L 307.088823 97.77636 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.37555 113.834571 \n",
       "L 291.37555 113.36843 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.243691 111.3213 \n",
       "L 294.243691 110.527433 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 292.626394 112.633727 \n",
       "L 292.626394 112.279325 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 281.282633 124.28279 \n",
       "L 281.282633 123.675023 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 305.392229 99.620824 \n",
       "L 305.392229 98.762161 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 310.674826 94.376025 \n",
       "L 310.674826 93.706784 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 294.203542 110.915727 \n",
       "L 294.203542 110.602549 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 261.708761 144.599311 \n",
       "L 261.708761 144.12602 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.287199 98.409015 \n",
       "L 307.287199 97.866334 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 326.483271 78.900127 \n",
       "L 326.483271 78.330643 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 277.631966 126.979625 \n",
       "L 277.631966 126.477133 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 304.341449 100.285358 \n",
       "L 304.341449 99.663407 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 282.931858 122.475265 \n",
       "L 282.931858 122.048134 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 323.968943 81.572241 \n",
       "L 323.968943 80.869281 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 278.881034 125.485184 \n",
       "L 278.881034 124.962287 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 327.440431 77.959336 \n",
       "L 327.440431 77.122289 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 272.995897 132.216763 \n",
       "L 272.995897 131.819431 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 307.905408 97.479612 \n",
       "L 307.905408 96.727004 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 309.493406 95.999896 \n",
       "L 309.493406 94.910519 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 290.177689 115.669866 \n",
       "L 290.177689 115.104573 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 291.109234 113.752746 \n",
       "L 291.109234 113.088127 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 299.390287 107.687227 \n",
       "L 299.390287 105.934217 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 288.727727 116.512562 \n",
       "L 288.727727 115.773508 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 312.246743 93.291232 \n",
       "L 312.246743 92.855339 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 267.014383 138.622595 \n",
       "L 267.014383 137.750092 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 331.950177 74.760987 \n",
       "L 331.950177 72.414081 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_19\">\n",
       "    <g clip-path=\"url(#pab1a286812)\">\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"252.795214\" y=\"154.399807\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.195021\" y=\"141.118836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.60087\" y=\"121.065927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.201266\" y=\"101.886732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.84106\" y=\"126.868927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.091929\" y=\"132.014774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"275.144744\" y=\"130.124057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"319.039215\" y=\"86.072088\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"255.928994\" y=\"146.15611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.480968\" y=\"146.175453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.65464\" y=\"120.411278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.378178\" y=\"114.955409\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.736903\" y=\"101.213657\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"255.782773\" y=\"150.450289\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.484567\" y=\"140.931665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"251.842316\" y=\"152.552443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.037332\" y=\"114.487921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"291.699957\" y=\"113.841772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.590303\" y=\"79.651908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.290193\" y=\"117.095144\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"341.461178\" y=\"63.417031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"329.501467\" y=\"75.714833\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.530737\" y=\"108.457812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"323.84573\" y=\"81.210438\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"293.169408\" y=\"111.761957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"263.132447\" y=\"139.911832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.926526\" y=\"96.955342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"313.463185\" y=\"91.557695\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"269.434038\" y=\"136.854485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"321.460914\" y=\"83.339373\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.951114\" y=\"101.840309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"294.604832\" y=\"111.513531\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"293.44461\" y=\"111.255506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.820187\" y=\"128.481253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"331.970544\" y=\"73.167896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.262688\" y=\"99.727436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.537566\" y=\"140.289394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"283.269522\" y=\"121.461251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"268.627606\" y=\"132.717819\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.143984\" y=\"80.665724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.256319\" y=\"115.694388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.136402\" y=\"109.885998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.101078\" y=\"120.769052\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.174242\" y=\"97.318302\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.840657\" y=\"101.636078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.898204\" y=\"139.964043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.699149\" y=\"131.095936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"270.83455\" y=\"134.541724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"269.471843\" y=\"138.367433\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.460596\" y=\"124.567353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.45048\" y=\"131.406405\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.925668\" y=\"125.120874\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.573103\" y=\"105.752887\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"280.716544\" y=\"124.271729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"323.166339\" y=\"81.562183\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"304.166884\" y=\"100.964155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"310.586187\" y=\"94.677703\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"262.380894\" y=\"142.902598\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"283.643932\" y=\"121.224498\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"316.970361\" y=\"87.844678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.259824\" y=\"111.486724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.1459\" y=\"99.585823\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"262.092524\" y=\"139.103473\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.391157\" y=\"136.991759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"331.405711\" y=\"74.353915\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.334315\" y=\"105.579497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"270.678477\" y=\"133.838872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.650232\" y=\"108.307903\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.640946\" y=\"94.748484\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.678592\" y=\"91.550761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.767712\" y=\"116.626883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"316.123262\" y=\"89.855204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.437407\" y=\"92.477265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.989631\" y=\"125.588287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.91868\" y=\"127.20852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.744926\" y=\"148.216985\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"316.875383\" y=\"88.500525\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.510086\" y=\"130.459266\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.398804\" y=\"79.635781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.144282\" y=\"96.5962\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"269.269599\" y=\"133.149148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"292.583756\" y=\"112.269408\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.273217\" y=\"128.344532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"297.589766\" y=\"107.507152\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"304.487489\" y=\"101.297832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.154808\" y=\"125.80583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.219938\" y=\"105.058464\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.687022\" y=\"131.069316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"291.883982\" y=\"116.01551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"275.62989\" y=\"129.437066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"310.117717\" y=\"94.034464\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.793516\" y=\"141.672141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.745554\" y=\"107.942946\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.637488\" y=\"128.486557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.625962\" y=\"120.53902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"252.771798\" y=\"156.35628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"271.414823\" y=\"133.360105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"315.996211\" y=\"89.027961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"322.361107\" y=\"82.394178\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"243.460204\" y=\"167.069194\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.558357\" y=\"101.414692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.792016\" y=\"108.128831\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"311.670443\" y=\"93.424238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.319521\" y=\"120.971478\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"302.29839\" y=\"102.824359\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"283.766352\" y=\"121.575423\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.905666\" y=\"139.051656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.638597\" y=\"105.772019\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"302.881238\" y=\"102.299988\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"252.795214\" y=\"152.944196\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"239.43123\" y=\"165.209507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.857445\" y=\"91.780572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"270.654385\" y=\"135.416076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"298.28698\" y=\"107.0107\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"314.972699\" y=\"90.082177\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"318.73017\" y=\"85.382603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.788014\" y=\"102.785227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"272.768478\" y=\"134.030383\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.437869\" y=\"95.488741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"297.823452\" y=\"107.187554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"286.893695\" y=\"117.916773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"311.866523\" y=\"93.279989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.860354\" y=\"107.990514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.68383\" y=\"109.104768\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.405508\" y=\"115.842505\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.376558\" y=\"148.922745\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"311.062748\" y=\"93.642366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.737221\" y=\"108.184425\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.346447\" y=\"117.324583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"248.762676\" y=\"156.531387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.180802\" y=\"120.537006\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"280.704104\" y=\"124.560786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"243.393896\" y=\"162.995153\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.833149\" y=\"109.31019\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"275.589794\" y=\"129.559485\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"266.202\" y=\"139.902147\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.64784\" y=\"122.281961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.486567\" y=\"116.50459\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"315.065374\" y=\"89.977772\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.753895\" y=\"103.212533\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.689142\" y=\"116.90708\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.115239\" y=\"126.609361\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.214162\" y=\"121.405149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.352112\" y=\"114.789015\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"321.787166\" y=\"83.095397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.701153\" y=\"120.327922\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.874625\" y=\"105.133406\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"256.095137\" y=\"147.473287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.234248\" y=\"105.152495\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.029166\" y=\"104.609597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.183521\" y=\"114.96551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"285.017452\" y=\"119.962204\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.810152\" y=\"125.235121\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.966859\" y=\"130.854389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.243305\" y=\"126.611397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.676647\" y=\"130.203932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.792123\" y=\"126.77327\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"250.011191\" y=\"156.621245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"266.456754\" y=\"137.992374\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.34306\" y=\"125.825041\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.889959\" y=\"120.217041\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.929811\" y=\"126.33597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.152257\" y=\"126.719391\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.865833\" y=\"126.493863\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"315.138131\" y=\"89.827974\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.764638\" y=\"116.907564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.58829\" y=\"130.679468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"313.379592\" y=\"90.848077\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"320.705487\" y=\"84.537862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"259.292788\" y=\"145.597222\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.006253\" y=\"98.261161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.786625\" y=\"128.33921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.216328\" y=\"109.568702\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.009975\" y=\"110.191938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"252.736637\" y=\"150.816491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"260.356138\" y=\"144.303717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"270.977819\" y=\"133.719249\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"304.121762\" y=\"101.444026\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.396468\" y=\"101.490275\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"313.441083\" y=\"91.386041\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"285.351022\" y=\"119.426263\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.557639\" y=\"117.857961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"302.342962\" y=\"102.149765\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"256.769833\" y=\"147.475506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.728092\" y=\"101.393523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.498391\" y=\"115.417459\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.429243\" y=\"127.598919\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"283.404911\" y=\"121.568348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"298.551059\" y=\"106.253169\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.959914\" y=\"104.432683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"298.742658\" y=\"106.016739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.681215\" y=\"125.596049\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.972732\" y=\"140.755653\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.060366\" y=\"79.825553\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.013472\" y=\"118.480951\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"280.633504\" y=\"124.587921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.912136\" y=\"117.272999\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.774867\" y=\"122.086452\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.912469\" y=\"95.883963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.709755\" y=\"128.774371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"294.978275\" y=\"108.931642\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.938919\" y=\"92.053321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"329.412056\" y=\"75.57049\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.968327\" y=\"124.99527\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"252.239484\" y=\"155.805202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.374529\" y=\"116.554934\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"249.920187\" y=\"160.992169\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.97394\" y=\"91.778475\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"262.811768\" y=\"141.646391\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"335.958094\" y=\"68.550731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.896808\" y=\"99.231309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"271.496707\" y=\"133.487813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.507413\" y=\"120.694671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.719961\" y=\"125.724463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"320.98906\" y=\"84.162716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.310947\" y=\"130.709626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"322.624346\" y=\"82.247635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.424381\" y=\"129.100099\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.090418\" y=\"106.139927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.635473\" y=\"98.584793\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.966197\" y=\"122.186101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"293.111936\" y=\"112.202914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"263.004633\" y=\"139.0243\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"320.469079\" y=\"84.661817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.042526\" y=\"121.076713\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.913256\" y=\"142.752613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.981439\" y=\"92.126099\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"261.208392\" y=\"144.812515\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.605157\" y=\"79.681743\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"318.535707\" y=\"86.288481\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.59431\" y=\"98.495551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.787169\" y=\"96.265842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"314.357655\" y=\"90.469649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"328.27426\" y=\"76.69163\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.30058\" y=\"103.1912\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.856313\" y=\"105.007293\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"286.804579\" y=\"119.082491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"259.712327\" y=\"146.064394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.959685\" y=\"116.338859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"271.03729\" y=\"134.002921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.212278\" y=\"79.658502\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.978412\" y=\"126.940763\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.270661\" y=\"132.406788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"259.46687\" y=\"146.178055\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.26196\" y=\"95.835176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.508638\" y=\"97.84053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"337.752865\" y=\"66.661489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"302.329969\" y=\"102.662859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"239.96439\" y=\"167.035734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"261.019406\" y=\"145.09945\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.185054\" y=\"128.94039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"317.884445\" y=\"87.292093\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.46134\" y=\"131.989077\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.005063\" y=\"114.687799\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.321861\" y=\"105.811637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.634593\" y=\"115.454928\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.410617\" y=\"92.871301\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.843137\" y=\"114.738243\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.260041\" y=\"125.956085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.031534\" y=\"121.55663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.247749\" y=\"109.843453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"328.036812\" y=\"77.150094\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"310.791655\" y=\"94.833674\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"322.321398\" y=\"82.349418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.808187\" y=\"120.335131\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"310.748243\" y=\"96.362979\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"261.666716\" y=\"145.425372\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"220.724592\" y=\"172.437748\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"342.343153\" y=\"62.203678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"291.84015\" y=\"113.457401\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.363642\" y=\"95.055524\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"286.505377\" y=\"118.746063\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.074591\" y=\"123.309989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.297984\" y=\"131.448255\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.368291\" y=\"116.684392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"326.489323\" y=\"77.848274\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"283.046151\" y=\"121.838501\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"298.018105\" y=\"106.898215\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.352813\" y=\"108.43899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.070049\" y=\"127.692048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.391007\" y=\"125.267769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"263.323035\" y=\"141.328394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.392899\" y=\"102.177082\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"294.907425\" y=\"110.31075\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"247.338965\" y=\"164.21367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"310.139947\" y=\"94.791031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"269.97708\" y=\"133.217975\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.75234\" y=\"116.150191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"311.39881\" y=\"94.08825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"268.660072\" y=\"135.336302\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"284.925434\" y=\"120.140279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"259.457735\" y=\"145.951187\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"255.793244\" y=\"149.728792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.43689\" y=\"131.880731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"319.219186\" y=\"85.349469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.434787\" y=\"122.247937\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"317.526962\" y=\"87.131334\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.86737\" y=\"96.19858\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.78253\" y=\"104.450625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"329.247359\" y=\"75.953744\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.216112\" y=\"123.454267\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"297.781714\" y=\"107.184816\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"320.143581\" y=\"85.310976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"283.554547\" y=\"121.629018\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.259227\" y=\"115.42652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.076891\" y=\"96.560605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.473428\" y=\"127.635537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"268.069603\" y=\"136.598775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.334334\" y=\"124.230876\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"261.430042\" y=\"147.734892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.603842\" y=\"145.548444\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"268.313922\" y=\"137.867468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"253.726821\" y=\"152.304061\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"265.393645\" y=\"139.121125\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.868593\" y=\"98.596581\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"275.032322\" y=\"131.071404\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"327.544629\" y=\"77.639076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"319.431412\" y=\"85.668679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.041904\" y=\"117.024765\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"262.552444\" y=\"145.803736\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.990309\" y=\"104.7005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.943844\" y=\"116.989282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.838573\" y=\"145.889961\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.728486\" y=\"130.574368\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.510471\" y=\"95.335724\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.858203\" y=\"101.04466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"329.043156\" y=\"75.742773\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"285.670162\" y=\"120.304136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"316.53482\" y=\"88.508616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.621665\" y=\"92.209343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"265.67789\" y=\"139.140802\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"280.612705\" y=\"124.806923\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"327.321165\" y=\"77.729848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"331.406971\" y=\"72.875209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.353634\" y=\"95.940931\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.210254\" y=\"127.962701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.289311\" y=\"99.650088\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"298.591621\" y=\"107.147797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.1137\" y=\"97.892562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.126637\" y=\"118.365137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"269.3013\" y=\"133.402209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.020083\" y=\"131.030603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.505575\" y=\"97.585704\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"285.855736\" y=\"119.210508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"314.925079\" y=\"88.770187\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.412437\" y=\"132.021661\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"329.568331\" y=\"74.919646\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.798858\" y=\"108.899299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"255.42432\" y=\"147.679495\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.06263\" y=\"135.169422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.932237\" y=\"109.068943\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.928123\" y=\"98.442534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"253.499776\" y=\"153.272582\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"337.408302\" y=\"67.581335\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.439105\" y=\"103.477454\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.196089\" y=\"105.42807\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"280.134051\" y=\"125.036001\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"251.720795\" y=\"152.441638\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"266.799671\" y=\"137.599142\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.786386\" y=\"122.349029\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.902292\" y=\"96.597414\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.794062\" y=\"121.957067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.40979\" y=\"128.810307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"293.372188\" y=\"111.313709\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"275.699915\" y=\"127.803603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"321.237516\" y=\"84.116305\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.537582\" y=\"104.460818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.724898\" y=\"122.557576\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.499909\" y=\"147.763712\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.35056\" y=\"92.075608\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"259.982456\" y=\"143.707412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.615627\" y=\"96.841984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.180989\" y=\"100.197895\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.609229\" y=\"122.820342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.536925\" y=\"116.121226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"323.41931\" y=\"81.742785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"271.764012\" y=\"133.071722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.999192\" y=\"115.075927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.601233\" y=\"116.518927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.816788\" y=\"98.305364\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"314.871551\" y=\"89.703269\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.903997\" y=\"130.413497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"256.342443\" y=\"147.916567\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"301.532973\" y=\"103.595504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"302.799264\" y=\"102.247586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.189896\" y=\"116.974199\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"268.353333\" y=\"136.971314\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.460596\" y=\"125.4371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.672598\" y=\"127.983616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.224818\" y=\"116.175067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.205541\" y=\"130.6955\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"304.733101\" y=\"100.144336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"316.693125\" y=\"88.245341\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"289.92275\" y=\"115.150422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.260865\" y=\"92.668161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"333.671433\" y=\"71.581984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"232.493297\" y=\"168.789776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"253.201724\" y=\"153.74227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.517004\" y=\"125.194948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"286.260223\" y=\"118.754453\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"294.488303\" y=\"109.939176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"280.766244\" y=\"124.963752\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"291.64754\" y=\"113.032871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"285.93439\" y=\"119.43899\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.509374\" y=\"117.741281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.599741\" y=\"108.654459\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"272.48851\" y=\"132.400751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"297.572046\" y=\"108.331363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"256.249969\" y=\"149.018384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"318.566185\" y=\"86.303986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"281.864877\" y=\"123.170062\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.234685\" y=\"95.666737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"306.12603\" y=\"99.272557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"329.180376\" y=\"76.15497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"303.921273\" y=\"100.978747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"296.452318\" y=\"108.583491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"269.033843\" y=\"135.877451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"223.470479\" y=\"172.921683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"257.89679\" y=\"142.28615\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"260.863788\" y=\"143.180981\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"325.143189\" y=\"80.341577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"302.329969\" y=\"102.790504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.738684\" y=\"126.928435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"273.368893\" y=\"132.291222\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.540929\" y=\"99.384216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"268.234926\" y=\"136.826801\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.96326\" y=\"137.921357\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"286.50872\" y=\"118.495597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"318.778567\" y=\"88.190717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"262.584996\" y=\"144.463499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"338.364411\" y=\"66.474443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"304.187683\" y=\"100.210705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.385862\" y=\"140.534594\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"317.149686\" y=\"88.578378\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.125141\" y=\"115.151631\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"274.898851\" y=\"129.986381\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"287.253738\" y=\"118.144087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"260.933063\" y=\"144.69488\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"332.873233\" y=\"72.654431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"319.339817\" y=\"85.827294\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"271.717714\" y=\"133.333137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"298.198375\" y=\"105.725217\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"300.224211\" y=\"105.25384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.429756\" y=\"92.50002\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"266.273007\" y=\"137.454507\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"253.862134\" y=\"152.390692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.288923\" y=\"137.93235\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.976576\" y=\"142.487747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"257.200477\" y=\"148.418663\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"279.115239\" y=\"125.976689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"297.891413\" y=\"106.840065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"314.043578\" y=\"91.143813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"266.75095\" y=\"139.120997\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.885097\" y=\"109.27478\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"286.642093\" y=\"118.250097\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"260.054035\" y=\"141.311388\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"295.863858\" y=\"109.709031\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"276.238966\" y=\"129.124662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"281.717497\" y=\"123.770665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"314.698606\" y=\"91.113551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.627316\" y=\"127.637981\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.392863\" y=\"126.431356\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"258.744926\" y=\"146.581842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"323.172329\" y=\"81.737981\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.567448\" y=\"136.657216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.352437\" y=\"99.259876\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"308.218963\" y=\"96.903476\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"263.370472\" y=\"141.139506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"264.431464\" y=\"143.771032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"270.684496\" y=\"134.543472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.832169\" y=\"126.292626\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"263.746986\" y=\"140.833355\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"315.087337\" y=\"89.973055\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.088823\" y=\"97.968173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"291.37555\" y=\"113.601501\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"294.243691\" y=\"110.924367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"292.626394\" y=\"112.456526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"281.282633\" y=\"123.978906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"305.392229\" y=\"99.191493\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"310.674826\" y=\"94.041404\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"294.203542\" y=\"110.759138\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"261.708761\" y=\"144.362665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.287199\" y=\"98.137675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"326.483271\" y=\"78.615385\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"277.631966\" y=\"126.728379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"304.341449\" y=\"99.974382\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"282.931858\" y=\"122.261699\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"323.968943\" y=\"81.220761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"278.881034\" y=\"125.223735\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"327.440431\" y=\"77.540812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"272.995897\" y=\"132.018097\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"307.905408\" y=\"97.103308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"309.493406\" y=\"95.455208\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"290.177689\" y=\"115.387219\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"291.109234\" y=\"113.420436\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"299.390287\" y=\"106.810722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"288.727727\" y=\"116.143035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"312.246743\" y=\"93.073285\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"267.014383\" y=\"138.186344\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"331.950177\" y=\"73.587534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 214.360594 159.18344 \n",
       "L 214.360594 70.872379 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 245.90611 179.384625 \n",
       "L 334.124224 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_21\">\n",
       "    <!-- RMSE: 0.057 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(221.360992 63.972112) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-35\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-37\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_22\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(249.948578 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_20\">\n",
       "    <path d=\"M 313.531832 91.486467 \n",
       "L 348.004564 56.977415 \n",
       "L 243.093468 161.999044 \n",
       "L 270.786624 134.276711 \n",
       "\" clip-path=\"url(#pab1a286812)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 390.408312 179.384625 \n",
       "L 530.416281 179.384625 \n",
       "L 530.416281 51.1485 \n",
       "L 390.408312 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"409.397787\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(404.3811 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"465.070906\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(462.624094 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"520.744025\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(518.297212 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"390.408312\" y=\"176.283694\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- −3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074937 179.433132) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"390.408312\" y=\"152.976432\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074937 156.12587) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"390.408312\" y=\"129.66917\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074937 132.818608) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"390.408312\" y=\"106.361908\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214687 109.511346) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"390.408312\" y=\"83.054647\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214687 86.204084) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"390.408312\" y=\"59.747385\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214687 62.896822) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_3\">\n",
       "    <path d=\"M 503.843576 74.366108 \n",
       "L 503.843576 72.850727 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.871356 107.436104 \n",
       "L 464.871356 104.281123 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.942129 123.647415 \n",
       "L 427.942129 119.904696 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.216046 136.448591 \n",
       "L 431.216046 134.466162 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 511.786871 72.089909 \n",
       "L 511.786871 64.976314 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.638146 104.087304 \n",
       "L 474.638146 94.901653 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.90543 89.833088 \n",
       "L 486.90543 85.88796 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.271593 125.462331 \n",
       "L 444.271593 124.109247 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.022231 114.572832 \n",
       "L 460.022231 110.206812 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.883805 125.567882 \n",
       "L 444.883805 122.863062 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.598084 124.855088 \n",
       "L 442.598084 122.765776 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.461907 126.582074 \n",
       "L 440.461907 124.409521 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.456215 134.63949 \n",
       "L 431.456215 130.71451 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.686676 109.603886 \n",
       "L 462.686676 105.538914 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.701986 104.774962 \n",
       "L 466.701986 103.160125 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.129119 96.841277 \n",
       "L 480.129119 93.500938 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.548083 92.45575 \n",
       "L 482.548083 89.907487 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.67147 128.661858 \n",
       "L 439.67147 125.126621 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.211563 121.404952 \n",
       "L 449.211563 118.831647 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.737289 98.925476 \n",
       "L 476.737289 95.229797 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.715668 118.626641 \n",
       "L 432.715668 112.337118 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 396.772311 163.266169 \n",
       "L 396.772311 158.731499 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.885079 99.58593 \n",
       "L 475.885079 97.394388 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.855786 91.923352 \n",
       "L 484.855786 88.123637 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.581113 117.285063 \n",
       "L 453.581113 113.353446 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.402177 92.166013 \n",
       "L 482.402177 89.840915 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 405.512294 155.507955 \n",
       "L 405.512294 154.312458 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.231726 109.480423 \n",
       "L 462.231726 107.873606 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.536205 99.329746 \n",
       "L 473.536205 96.390369 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.999895 101.48375 \n",
       "L 474.999895 96.882396 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.511803 117.120984 \n",
       "L 457.511803 111.912912 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.221594 99.067405 \n",
       "L 476.221594 96.445046 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.73119 83.968889 \n",
       "L 493.73119 78.096702 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.099364 137.886834 \n",
       "L 430.099364 134.094922 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.771428 106.579024 \n",
       "L 467.771428 103.877515 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.450944 138.00703 \n",
       "L 427.450944 135.265633 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.010479 77.397238 \n",
       "L 501.010479 73.766299 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.016097 152.85505 \n",
       "L 416.016097 150.088985 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.887151 86.932273 \n",
       "L 491.887151 80.539167 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.537475 159.882398 \n",
       "L 413.537475 153.657359 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.578015 105.746926 \n",
       "L 465.578015 102.625005 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.801958 97.108003 \n",
       "L 475.801958 96.325995 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.533287 130.869711 \n",
       "L 437.533287 127.945831 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.196974 99.435255 \n",
       "L 474.196974 95.504582 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.2708 81.287019 \n",
       "L 498.2708 77.342232 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 440.373969 130.494758 \n",
       "L 440.373969 127.014039 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.860587 85.707786 \n",
       "L 489.860587 83.277722 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.413663 108.723729 \n",
       "L 461.413663 107.214544 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.041328 91.39568 \n",
       "L 486.041328 89.363685 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.082023 148.886359 \n",
       "L 423.082023 144.774435 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.230543 75.784659 \n",
       "L 504.230543 71.833127 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.524072 107.131772 \n",
       "L 464.524072 105.218906 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.760645 146.367891 \n",
       "L 422.760645 139.483814 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.772197 99.064548 \n",
       "L 472.772197 95.768893 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.680294 68.750739 \n",
       "L 510.680294 66.996232 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.754418 111.726818 \n",
       "L 459.754418 109.714876 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.37005 134.129527 \n",
       "L 436.37005 131.237605 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 420.977424 141.561069 \n",
       "L 420.977424 139.346613 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.559825 85.21378 \n",
       "L 491.559825 82.429156 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.381482 82.289706 \n",
       "L 495.381482 80.047889 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.359951 103.895381 \n",
       "L 469.359951 100.428534 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.275415 101.810413 \n",
       "L 472.275415 99.685824 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.258288 95.618379 \n",
       "L 479.258288 93.839111 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.536344 80.96552 \n",
       "L 499.536344 75.341851 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.712365 162.501271 \n",
       "L 409.712365 158.74794 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.902575 80.327113 \n",
       "L 497.902575 77.997685 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.04694 92.506446 \n",
       "L 486.04694 89.350061 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.30084 95.110076 \n",
       "L 477.30084 93.279728 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.967796 93.170927 \n",
       "L 481.967796 91.231622 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.609034 123.163691 \n",
       "L 444.609034 118.035618 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.825417 131.975388 \n",
       "L 437.825417 129.109469 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.917109 125.639439 \n",
       "L 443.917109 122.740721 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.544557 79.72506 \n",
       "L 497.544557 76.988828 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.362065 130.893198 \n",
       "L 441.362065 126.597552 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.933319 110.832947 \n",
       "L 461.933319 107.361679 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.284146 90.817783 \n",
       "L 482.284146 87.711238 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.533742 88.960555 \n",
       "L 485.533742 86.501478 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.44853 79.97071 \n",
       "L 498.44853 77.256964 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.829092 135.926159 \n",
       "L 430.829092 134.358964 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.09066 140.77873 \n",
       "L 425.09066 138.385825 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.995438 102.552753 \n",
       "L 471.995438 98.922949 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.587257 104.519132 \n",
       "L 469.587257 102.808221 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.780027 92.56708 \n",
       "L 482.780027 89.167144 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.368839 134.890975 \n",
       "L 432.368839 128.958168 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.414001 74.606448 \n",
       "L 501.414001 69.821798 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.719213 98.597634 \n",
       "L 476.719213 96.235173 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.701815 128.731213 \n",
       "L 442.701815 125.245862 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.002434 73.827252 \n",
       "L 508.002434 70.617377 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.779316 139.258282 \n",
       "L 426.779316 135.982095 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.559426 133.785017 \n",
       "L 433.559426 132.450543 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.848794 126.31176 \n",
       "L 441.848794 124.163662 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.343258 120.187423 \n",
       "L 451.343258 118.056174 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.036154 150.398839 \n",
       "L 409.036154 145.914757 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.596409 112.180265 \n",
       "L 457.596409 108.689045 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.580597 102.754416 \n",
       "L 474.580597 97.465577 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.04039 100.747504 \n",
       "L 476.04039 97.250878 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.315487 115.590991 \n",
       "L 457.315487 112.794283 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.359166 121.919577 \n",
       "L 449.359166 117.596596 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.627352 102.081141 \n",
       "L 471.627352 99.874862 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.73104 77.529918 \n",
       "L 505.73104 71.758865 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.612811 87.351101 \n",
       "L 487.612811 85.246173 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.75971 156.005539 \n",
       "L 419.75971 152.51314 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.808937 133.997152 \n",
       "L 433.808937 131.565716 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.308233 114.069006 \n",
       "L 456.308233 112.768564 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.12494 94.402779 \n",
       "L 481.12494 92.150061 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.171117 100.806206 \n",
       "L 474.171117 96.948726 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 435.705607 131.976228 \n",
       "L 435.705607 130.223123 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.695413 73.859865 \n",
       "L 506.695413 67.599467 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.179033 87.59649 \n",
       "L 490.179033 85.658209 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.514019 100.267557 \n",
       "L 474.514019 97.07814 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.669769 76.896228 \n",
       "L 503.669769 73.580652 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.18841 129.139957 \n",
       "L 442.18841 126.318981 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.721066 145.999479 \n",
       "L 412.721066 143.874446 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.042012 139.871704 \n",
       "L 425.042012 137.989391 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.44178 103.300604 \n",
       "L 471.44178 100.576761 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.810115 84.454993 \n",
       "L 494.810115 81.835605 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.840657 113.5513 \n",
       "L 459.840657 111.042185 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.611001 89.731095 \n",
       "L 485.611001 87.500868 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.8454 98.333107 \n",
       "L 475.8454 96.48208 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.522831 79.265286 \n",
       "L 497.522831 77.145127 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.182686 97.692579 \n",
       "L 478.182686 93.964628 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.387026 112.875817 \n",
       "L 456.387026 110.716942 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.028257 117.633206 \n",
       "L 456.028257 113.717648 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 414.64591 147.081292 \n",
       "L 414.64591 144.649831 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.719909 87.394996 \n",
       "L 488.719909 86.005551 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.949952 99.309719 \n",
       "L 473.949952 95.561428 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.163508 106.583368 \n",
       "L 466.163508 105.132404 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.98475 129.800061 \n",
       "L 438.98475 126.6924 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 502.197661 76.276172 \n",
       "L 502.197661 73.220685 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 428.812564 138.107758 \n",
       "L 428.812564 134.025531 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.553101 84.678034 \n",
       "L 490.553101 82.793138 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.022307 135.22537 \n",
       "L 433.022307 133.162567 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.914988 96.884731 \n",
       "L 477.914988 92.714786 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.44376 79.362805 \n",
       "L 499.44376 77.637751 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.747152 92.316358 \n",
       "L 484.747152 91.231735 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.885894 137.062462 \n",
       "L 429.885894 135.169972 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.077379 117.71886 \n",
       "L 453.077379 116.062927 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.395442 119.487154 \n",
       "L 451.395442 117.595293 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.521297 119.416444 \n",
       "L 451.521297 116.877381 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.341029 81.633515 \n",
       "L 495.341029 80.502209 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.563892 142.889185 \n",
       "L 431.563892 139.576439 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.074964 129.640331 \n",
       "L 438.074964 125.559989 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 418.409424 146.059971 \n",
       "L 418.409424 141.219828 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.485426 96.346512 \n",
       "L 477.485426 94.49164 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.988046 148.517506 \n",
       "L 419.988046 144.686962 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.799279 121.783188 \n",
       "L 448.799279 119.498373 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.426321 107.983041 \n",
       "L 465.426321 105.632673 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.260763 111.520693 \n",
       "L 462.260763 106.251797 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.104899 99.110369 \n",
       "L 475.104899 96.835445 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.171602 88.425663 \n",
       "L 488.171602 83.587123 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.586679 89.734565 \n",
       "L 488.586679 85.465335 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.733878 90.411811 \n",
       "L 485.733878 88.072812 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.645193 86.950133 \n",
       "L 489.645193 84.411557 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.464036 91.598915 \n",
       "L 485.464036 88.530554 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.683004 86.676984 \n",
       "L 488.683004 84.869154 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.178344 121.541809 \n",
       "L 449.178344 118.889821 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.359904 136.303856 \n",
       "L 429.359904 133.641235 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.001492 111.585453 \n",
       "L 458.001492 108.254807 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.571202 145.231869 \n",
       "L 417.571202 143.616083 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.238065 120.453748 \n",
       "L 450.238065 115.700892 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.474537 113.976184 \n",
       "L 459.474537 109.391707 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.410877 102.017329 \n",
       "L 471.410877 100.366697 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 508.948909 72.152458 \n",
       "L 508.948909 69.233521 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.5235 109.15762 \n",
       "L 463.5235 104.993713 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.851001 126.880021 \n",
       "L 444.851001 123.62941 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.511049 108.126441 \n",
       "L 467.511049 105.301005 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.663069 109.307993 \n",
       "L 465.663069 104.553108 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.259902 86.208824 \n",
       "L 490.259902 81.281872 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.457623 125.226037 \n",
       "L 444.457623 122.931702 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.546326 92.311872 \n",
       "L 483.546326 89.810811 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.919906 75.478944 \n",
       "L 503.919906 73.233814 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.55861 78.977018 \n",
       "L 500.55861 76.506365 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.171553 120.94578 \n",
       "L 448.171553 118.730365 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.504716 85.647426 \n",
       "L 490.504716 83.85835 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.376145 105.122328 \n",
       "L 465.376145 102.593661 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 501.058508 78.34543 \n",
       "L 501.058508 74.050408 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.051557 137.361725 \n",
       "L 422.051557 134.126015 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.108239 140.627097 \n",
       "L 424.108239 137.979113 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.049855 87.584049 \n",
       "L 489.049855 84.549973 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.210276 85.638894 \n",
       "L 490.210276 83.782551 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.900817 88.594258 \n",
       "L 491.900817 85.009014 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 416.072233 150.937375 \n",
       "L 416.072233 146.449249 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.527453 75.899617 \n",
       "L 503.527453 72.123361 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.949136 80.473347 \n",
       "L 498.949136 76.460202 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.683219 111.407587 \n",
       "L 459.683219 110.326068 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.290595 107.388463 \n",
       "L 465.290595 105.501978 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.164154 75.77229 \n",
       "L 505.164154 70.873329 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.729741 130.125858 \n",
       "L 438.729741 129.138466 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.759432 64.950977 \n",
       "L 514.759432 61.450845 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.90831 105.110217 \n",
       "L 467.90831 102.931458 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.319908 85.678711 \n",
       "L 491.319908 83.65462 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 517.598256 63.61509 \n",
       "L 517.598256 61.5554 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.374411 105.188765 \n",
       "L 467.374411 102.285581 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.508627 120.224922 \n",
       "L 452.508627 114.941747 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.426252 108.661729 \n",
       "L 464.426252 105.320914 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.053111 141.371037 \n",
       "L 426.053111 139.220612 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.52919 89.420218 \n",
       "L 484.52919 86.100986 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.870664 90.253525 \n",
       "L 485.870664 88.581542 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.39141 93.381548 \n",
       "L 482.39141 92.007562 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.698252 80.447129 \n",
       "L 497.698252 78.219271 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.518672 106.216683 \n",
       "L 470.518672 100.707732 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.635974 79.108493 \n",
       "L 498.635974 76.605744 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 452.574797 117.486398 \n",
       "L 452.574797 114.790038 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.133774 109.916216 \n",
       "L 463.133774 107.901699 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.594472 92.655296 \n",
       "L 481.594472 91.451373 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.349121 82.675487 \n",
       "L 496.349121 75.069127 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.071575 117.910455 \n",
       "L 453.071575 115.110071 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.404434 129.237527 \n",
       "L 442.404434 126.029426 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.436106 96.161676 \n",
       "L 477.436106 94.034083 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.992693 135.284721 \n",
       "L 434.992693 132.453493 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.002455 140.139975 \n",
       "L 427.002455 136.813096 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.364141 160.258907 \n",
       "L 415.364141 158.016677 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 504.150436 75.491058 \n",
       "L 504.150436 73.942299 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.211822 102.96904 \n",
       "L 469.211822 100.228244 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.38664 91.065816 \n",
       "L 485.38664 89.086007 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.919095 81.723701 \n",
       "L 495.919095 79.244367 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.765054 140.744387 \n",
       "L 425.765054 138.751194 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.856364 73.67813 \n",
       "L 505.856364 67.958256 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.757169 71.669117 \n",
       "L 507.757169 69.487736 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.598913 110.744805 \n",
       "L 460.598913 106.540596 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.694778 106.207937 \n",
       "L 469.694778 103.082666 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.394864 80.554906 \n",
       "L 497.394864 78.709479 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.814136 109.193023 \n",
       "L 465.814136 104.008552 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.121444 125.340917 \n",
       "L 448.121444 122.381723 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.60998 108.206628 \n",
       "L 463.60998 106.022036 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.450724 121.023745 \n",
       "L 448.450724 117.210357 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.807451 99.675268 \n",
       "L 473.807451 97.9612 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 451.326773 115.716715 \n",
       "L 451.326773 110.368888 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.85405 94.719331 \n",
       "L 480.85405 91.421019 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 469.221919 103.660501 \n",
       "L 469.221919 100.967166 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.941331 110.151397 \n",
       "L 459.941331 107.655229 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 434.51297 132.68873 \n",
       "L 434.51297 130.704717 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.373008 109.676067 \n",
       "L 461.373008 108.336172 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.518014 104.886954 \n",
       "L 467.518014 102.966894 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.040153 152.500183 \n",
       "L 417.040153 149.22241 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.684797 107.190219 \n",
       "L 466.684797 102.884042 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.149744 107.74487 \n",
       "L 470.149744 104.319872 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.581983 94.498364 \n",
       "L 478.581983 93.039147 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.043338 117.975106 \n",
       "L 453.043338 111.056291 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.900083 145.596813 \n",
       "L 419.900083 142.775821 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.267054 119.678284 \n",
       "L 448.267054 116.790082 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.195372 119.121 \n",
       "L 450.195372 117.547457 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.51119 74.32419 \n",
       "L 503.51119 72.513339 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 421.949447 143.541747 \n",
       "L 421.949447 139.752012 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.348736 98.750348 \n",
       "L 474.348736 96.262269 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.940895 97.325999 \n",
       "L 477.940895 95.512507 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.947241 86.173264 \n",
       "L 490.947241 83.329905 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.382189 81.020357 \n",
       "L 497.382189 77.450445 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 436.394834 131.756737 \n",
       "L 436.394834 127.030429 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.651678 102.428713 \n",
       "L 473.651678 99.35522 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.150146 85.978873 \n",
       "L 490.150146 84.446844 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.217119 145.637284 \n",
       "L 419.217119 142.355589 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.479694 97.329792 \n",
       "L 476.479694 95.73366 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.250368 140.372274 \n",
       "L 425.250368 138.694205 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.697978 94.509113 \n",
       "L 479.697978 93.010945 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.68644 96.524945 \n",
       "L 479.68644 93.636178 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.584602 102.455513 \n",
       "L 470.584602 101.398924 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 439.658038 130.176281 \n",
       "L 439.658038 127.568095 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.327765 79.944058 \n",
       "L 497.327765 77.027523 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.570526 92.836022 \n",
       "L 483.570526 89.398041 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.37151 78.916304 \n",
       "L 498.37151 77.670356 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.306829 88.196124 \n",
       "L 486.306829 85.946997 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.880693 150.480263 \n",
       "L 415.880693 145.267212 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.370276 106.007886 \n",
       "L 467.370276 103.517161 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.676122 110.910727 \n",
       "L 463.676122 108.976215 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.227262 103.590053 \n",
       "L 471.227262 100.059176 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.312575 83.499459 \n",
       "L 493.312575 80.982141 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.299713 76.963696 \n",
       "L 505.299713 72.285861 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.198419 117.69698 \n",
       "L 453.198419 115.86874 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 503.033613 75.706978 \n",
       "L 503.033613 73.71817 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.954345 68.223372 \n",
       "L 510.954345 65.949857 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.051273 86.63585 \n",
       "L 491.051273 84.879828 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.52653 81.913294 \n",
       "L 496.52653 77.553547 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 411.931238 152.33072 \n",
       "L 411.931238 150.407108 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.633679 88.038617 \n",
       "L 490.633679 84.838264 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.997618 122.024711 \n",
       "L 448.997618 119.147626 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.404849 88.984959 \n",
       "L 487.404849 87.155584 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.272498 85.003483 \n",
       "L 487.272498 81.881592 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.94527 137.802107 \n",
       "L 423.94527 132.486225 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 420.932066 145.645019 \n",
       "L 420.932066 143.086034 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 429.00901 137.374096 \n",
       "L 429.00901 133.843396 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.839503 115.240938 \n",
       "L 455.839503 112.374331 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.688697 95.391638 \n",
       "L 479.688697 92.269188 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.692347 123.142596 \n",
       "L 446.692347 121.267411 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.319141 110.510017 \n",
       "L 460.319141 107.210851 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.547814 89.891488 \n",
       "L 485.547814 88.832304 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 494.161687 82.944156 \n",
       "L 494.161687 80.735361 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.56382 84.139802 \n",
       "L 492.56382 82.444602 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.822975 89.319101 \n",
       "L 487.822975 86.466287 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 466.240195 106.340389 \n",
       "L 466.240195 102.33974 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.450069 89.622993 \n",
       "L 487.450069 86.858035 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.694788 130.212809 \n",
       "L 433.694788 125.563755 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.167615 80.499517 \n",
       "L 497.167615 77.471836 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.707794 130.00679 \n",
       "L 446.707794 123.480199 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.798257 138.440104 \n",
       "L 426.798257 136.860391 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.421487 90.763202 \n",
       "L 483.421487 89.397302 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.069809 94.188103 \n",
       "L 483.069809 90.58944 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.116569 131.693025 \n",
       "L 438.116569 129.4906 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.129498 122.174453 \n",
       "L 448.129498 119.593074 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.023935 144.218667 \n",
       "L 424.023935 139.959547 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.791513 105.402432 \n",
       "L 468.791513 102.270565 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.522302 84.920903 \n",
       "L 491.522302 82.138081 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.860185 95.900102 \n",
       "L 480.860185 92.981265 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.372944 83.527955 \n",
       "L 492.372944 80.921072 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.944418 144.707923 \n",
       "L 422.944418 142.402804 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 485.859032 91.18088 \n",
       "L 485.859032 89.262433 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 441.831164 125.624071 \n",
       "L 441.831164 124.603387 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.767788 83.118002 \n",
       "L 492.767788 80.355307 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.991231 125.759305 \n",
       "L 443.991231 122.998489 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.519473 77.752177 \n",
       "L 500.519473 75.444816 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 421.531617 140.76632 \n",
       "L 421.531617 136.638353 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.270203 82.441383 \n",
       "L 495.270203 78.938271 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.751952 78.872283 \n",
       "L 499.751952 75.444636 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.738895 115.553617 \n",
       "L 455.738895 113.839767 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.965589 97.535726 \n",
       "L 478.965589 94.307279 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 447.370973 124.120934 \n",
       "L 447.370973 120.762532 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 410.870505 144.280043 \n",
       "L 410.870505 142.732979 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.257986 95.689795 \n",
       "L 478.257986 94.162308 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.328171 106.934658 \n",
       "L 465.328171 105.360744 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.961426 102.748543 \n",
       "L 471.961426 98.461182 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.382439 82.381366 \n",
       "L 496.382439 78.908892 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.259647 104.126261 \n",
       "L 468.259647 102.532583 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 505.537252 76.142694 \n",
       "L 505.537252 72.653914 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 459.609102 112.652916 \n",
       "L 459.609102 110.802014 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 417.594991 155.752752 \n",
       "L 417.594991 153.787069 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 446.148626 123.529964 \n",
       "L 446.148626 122.232867 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.547664 102.829616 \n",
       "L 471.547664 100.335412 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.985545 111.016672 \n",
       "L 460.985545 109.354548 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.997568 85.806884 \n",
       "L 490.997568 84.162307 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.996492 102.956514 \n",
       "L 471.996492 100.795215 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.493682 118.366448 \n",
       "L 453.493682 115.344174 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.363699 122.135444 \n",
       "L 445.363699 118.519873 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.980029 133.451898 \n",
       "L 432.980029 130.975733 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 492.288849 83.487358 \n",
       "L 492.288849 81.100261 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.764478 134.481247 \n",
       "L 437.764478 129.156413 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 511.406301 69.579179 \n",
       "L 511.406301 66.155158 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.51992 113.606269 \n",
       "L 456.51992 111.730595 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.646385 105.081044 \n",
       "L 467.646385 102.899792 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.868533 82.134554 \n",
       "L 495.868533 78.342758 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.175302 139.991353 \n",
       "L 430.175302 136.917044 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.68771 111.933317 \n",
       "L 462.68771 108.270254 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.810296 125.3721 \n",
       "L 445.810296 123.998458 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.394822 116.063818 \n",
       "L 457.394822 111.654466 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.820037 99.645878 \n",
       "L 473.820037 98.16635 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.76267 160.689502 \n",
       "L 424.76267 150.811048 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.487434 69.577893 \n",
       "L 510.487434 67.355331 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.361609 111.606835 \n",
       "L 461.361609 108.690118 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.202512 109.837795 \n",
       "L 464.202512 103.419641 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.320396 119.003053 \n",
       "L 456.320396 111.463583 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.180083 90.159821 \n",
       "L 486.180083 87.990179 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.812241 99.269472 \n",
       "L 474.812241 97.085642 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.569178 98.531264 \n",
       "L 476.569178 94.635461 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 415.576448 148.261629 \n",
       "L 415.576448 144.917336 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 489.694894 86.298736 \n",
       "L 489.694894 83.947955 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.042306 83.399163 \n",
       "L 493.042306 80.334448 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 445.654181 132.425298 \n",
       "L 445.654181 127.647808 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.998976 130.542766 \n",
       "L 438.998976 129.075985 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.647507 136.538495 \n",
       "L 430.647507 132.080961 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.080774 127.972907 \n",
       "L 438.080774 125.16626 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 509.884123 72.535855 \n",
       "L 509.884123 69.201804 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.869799 90.514104 \n",
       "L 487.869799 86.93207 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 500.137357 78.729883 \n",
       "L 500.137357 75.511938 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 458.293623 113.712244 \n",
       "L 458.293623 108.445139 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.345098 137.769994 \n",
       "L 432.345098 132.892904 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 472.080388 101.093585 \n",
       "L 472.080388 97.887183 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 470.908658 102.527492 \n",
       "L 470.908658 101.146181 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 425.219352 145.654556 \n",
       "L 425.219352 143.220123 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.994104 103.614359 \n",
       "L 468.994104 100.036649 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.064112 118.969845 \n",
       "L 453.064112 116.81104 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.716381 131.341006 \n",
       "L 433.716381 126.566405 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.415654 143.764086 \n",
       "L 426.415654 140.769466 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.954976 99.429338 \n",
       "L 477.954976 96.548003 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.847762 125.566754 \n",
       "L 443.847762 123.376887 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 413.561112 152.107246 \n",
       "L 413.561112 149.637927 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.159308 108.22688 \n",
       "L 461.159308 103.697225 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 460.691786 112.497088 \n",
       "L 460.691786 109.98885 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.109614 84.500724 \n",
       "L 491.109614 80.607446 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.441803 86.401817 \n",
       "L 490.441803 84.210406 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.672123 92.308328 \n",
       "L 482.672123 90.681307 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.616446 104.130992 \n",
       "L 468.616446 102.502078 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.829135 137.384948 \n",
       "L 423.829135 134.106701 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 432.022484 135.757524 \n",
       "L 432.022484 133.648129 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 426.90928 135.886406 \n",
       "L 426.90928 133.303957 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.89597 72.952613 \n",
       "L 507.89597 67.734382 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.680885 89.113788 \n",
       "L 487.680885 84.667422 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 490.771621 86.084581 \n",
       "L 490.771621 84.455118 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.654531 100.397029 \n",
       "L 473.654531 97.118751 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.078701 80.873921 \n",
       "L 496.078701 78.65744 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 397.05798 173.55571 \n",
       "L 397.05798 167.371587 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 462.845098 110.932558 \n",
       "L 462.845098 108.259684 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.254078 82.268946 \n",
       "L 495.254078 79.413933 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.709096 79.956393 \n",
       "L 498.709096 77.367667 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.142794 111.060955 \n",
       "L 461.142794 109.75437 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.700731 118.78887 \n",
       "L 448.700731 117.346042 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.567122 96.621841 \n",
       "L 479.567122 92.150331 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.181777 82.586089 \n",
       "L 495.181777 79.519636 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.399706 109.579092 \n",
       "L 463.399706 107.322174 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.867145 94.517536 \n",
       "L 480.867145 92.734457 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.490496 99.35374 \n",
       "L 474.490496 97.093328 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.890189 90.905155 \n",
       "L 487.890189 87.901918 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.641076 81.469918 \n",
       "L 495.641076 77.655042 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 496.619102 80.93104 \n",
       "L 496.619102 79.068579 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 423.649583 136.309869 \n",
       "L 423.649583 131.29214 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.298476 103.633696 \n",
       "L 468.298476 101.273813 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.735449 104.387349 \n",
       "L 468.735449 103.060198 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.531335 118.180741 \n",
       "L 453.531335 115.908943 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.9045 96.810057 \n",
       "L 477.9045 94.588632 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.041826 117.601875 \n",
       "L 453.041826 114.244561 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.125164 98.400504 \n",
       "L 475.125164 96.403628 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 483.112595 92.734437 \n",
       "L 483.112595 90.132494 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.053587 118.969746 \n",
       "L 454.053587 116.523092 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.770723 95.774477 \n",
       "L 478.770723 94.149196 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 409.491329 155.653583 \n",
       "L 409.491329 151.775512 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 507.150716 75.65189 \n",
       "L 507.150716 69.456144 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.995834 107.110612 \n",
       "L 464.995834 105.597943 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 442.297874 126.170476 \n",
       "L 442.297874 125.322898 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.627869 104.778777 \n",
       "L 465.627869 101.910693 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 495.152348 83.221329 \n",
       "L 495.152348 80.08384 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 512.082641 68.576807 \n",
       "L 512.082641 62.781313 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 488.370431 88.872969 \n",
       "L 488.370431 85.750082 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.782852 105.205932 \n",
       "L 468.782852 102.33283 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.090761 117.632227 \n",
       "L 455.090761 114.225203 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 475.285575 101.259851 \n",
       "L 475.285575 97.807126 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 398.396761 164.385417 \n",
       "L 398.396761 157.299239 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 476.49963 98.01057 \n",
       "L 476.49963 95.940876 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.917533 139.93242 \n",
       "L 431.917533 136.666256 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.168738 89.713195 \n",
       "L 486.168738 86.129327 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 461.736696 109.942033 \n",
       "L 461.736696 106.340903 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.7723 126.898311 \n",
       "L 443.7723 123.026079 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 477.409002 96.609964 \n",
       "L 477.409002 93.084818 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 480.417755 94.978052 \n",
       "L 480.417755 92.993766 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 517.395394 65.199664 \n",
       "L 517.395394 60.931948 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 465.639328 113.941031 \n",
       "L 465.639328 109.332473 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.449516 117.978117 \n",
       "L 457.449516 112.877013 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.550036 100.460842 \n",
       "L 474.550036 96.645632 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 464.300504 107.744382 \n",
       "L 464.300504 106.254846 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.593195 89.166661 \n",
       "L 486.593195 87.940988 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.036243 84.715382 \n",
       "L 491.036243 83.182909 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 456.974938 113.759427 \n",
       "L 456.974938 109.808128 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 515.143216 66.938637 \n",
       "L 515.143216 62.766058 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.213072 103.732615 \n",
       "L 467.213072 102.12102 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 509.566952 71.178119 \n",
       "L 509.566952 67.139138 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 491.41008 90.860411 \n",
       "L 491.41008 85.583185 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 448.991055 120.90279 \n",
       "L 448.991055 118.597972 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 499.194117 78.848401 \n",
       "L 499.194117 75.566622 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.81043 99.182058 \n",
       "L 474.81043 96.691553 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.104514 73.369986 \n",
       "L 506.104514 71.730182 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.213229 92.747936 \n",
       "L 482.213229 89.512317 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 520.074762 64.998478 \n",
       "L 520.074762 60.461608 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 482.405057 92.298322 \n",
       "L 482.405057 91.119303 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.25287 109.891091 \n",
       "L 467.25287 103.727614 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.91782 104.868464 \n",
       "L 467.91782 103.700842 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 471.409177 103.621963 \n",
       "L 471.409177 100.810689 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 463.773398 106.477353 \n",
       "L 463.773398 104.583463 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.293778 84.124579 \n",
       "L 493.293778 82.186112 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 478.343058 96.956789 \n",
       "L 478.343058 94.426848 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.494885 144.351385 \n",
       "L 422.494885 140.98926 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.672319 102.165204 \n",
       "L 473.672319 100.216203 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 427.476255 142.431961 \n",
       "L 427.476255 138.894893 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 498.174584 78.295446 \n",
       "L 498.174584 74.188972 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 443.998117 126.257962 \n",
       "L 443.998117 123.54773 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 422.688861 141.892583 \n",
       "L 422.688861 137.953771 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 430.846301 136.250719 \n",
       "L 430.846301 134.604536 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 454.164163 117.168949 \n",
       "L 454.164163 113.969794 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.447978 90.875437 \n",
       "L 481.447978 89.291201 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 412.815455 156.779936 \n",
       "L 412.815455 151.751521 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.926025 115.918867 \n",
       "L 453.926025 111.885923 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 484.76908 93.005527 \n",
       "L 484.76908 88.928332 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 406.987239 155.243105 \n",
       "L 406.987239 150.473658 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.390387 95.535446 \n",
       "L 479.390387 91.803651 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.195052 96.846751 \n",
       "L 479.195052 93.800626 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 438.752404 131.929509 \n",
       "L 438.752404 130.033935 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 481.373784 92.992397 \n",
       "L 481.373784 91.897302 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 479.518875 95.2458 \n",
       "L 479.518875 93.162772 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.107119 100.044885 \n",
       "L 474.107119 97.43821 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 473.262363 100.86813 \n",
       "L 473.262363 97.802489 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 453.376315 117.563809 \n",
       "L 453.376315 116.076852 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 457.833559 110.700812 \n",
       "L 457.833559 108.094492 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 514.116558 70.508143 \n",
       "L 514.116558 64.3056 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 474.76409 99.400534 \n",
       "L 474.76409 96.713641 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 497.325241 80.317593 \n",
       "L 497.325241 79.31217 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 510.180643 68.562153 \n",
       "L 510.180643 66.698298 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 424.698067 140.830716 \n",
       "L 424.698067 136.967518 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 486.483326 89.554378 \n",
       "L 486.483326 87.506982 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 468.363574 104.83266 \n",
       "L 468.363574 103.292225 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 403.275781 162.417818 \n",
       "L 403.275781 157.569673 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 487.548888 87.835622 \n",
       "L 487.548888 84.375538 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 437.177864 130.940736 \n",
       "L 437.177864 127.870702 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 444.339318 127.340431 \n",
       "L 444.339318 125.381915 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 450.773757 118.99192 \n",
       "L 450.773757 115.618787 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 455.892838 115.901115 \n",
       "L 455.892838 113.785687 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 419.093679 146.010426 \n",
       "L 419.093679 143.721677 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 431.247068 137.702008 \n",
       "L 431.247068 133.578235 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 408.979345 154.154803 \n",
       "L 408.979345 151.64108 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 467.346819 107.570507 \n",
       "L 467.346819 105.027374 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 433.126407 149.048584 \n",
       "L 433.126407 140.652657 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 449.764685 119.506598 \n",
       "L 449.764685 116.738028 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 493.580761 83.485117 \n",
       "L 493.580761 80.971057 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 407.791855 147.902045 \n",
       "L 407.791855 143.949013 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 506.026488 72.614443 \n",
       "L 506.026488 64.533218 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_30\">\n",
       "    <g clip-path=\"url(#pbd6ccea723)\">\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"503.843576\" y=\"73.608418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"464.871356\" y=\"105.858613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"427.942129\" y=\"121.776055\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"431.216046\" y=\"135.457377\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"511.786871\" y=\"68.533111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.638146\" y=\"99.494479\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.90543\" y=\"87.860524\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"444.271593\" y=\"124.785789\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"460.022231\" y=\"112.389822\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"444.883805\" y=\"124.215472\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"442.598084\" y=\"123.810432\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"440.461907\" y=\"125.495798\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"431.456215\" y=\"132.677\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"462.686676\" y=\"107.5714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"466.701986\" y=\"103.967544\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"480.129119\" y=\"95.171108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.548083\" y=\"91.181618\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"439.67147\" y=\"126.89424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"449.211563\" y=\"120.1183\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.737289\" y=\"97.077637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"432.715668\" y=\"115.48188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"396.772311\" y=\"160.998834\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"475.885079\" y=\"98.490159\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"484.855786\" y=\"90.023494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.581113\" y=\"115.319254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.402177\" y=\"91.003464\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"405.512294\" y=\"154.910207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"462.231726\" y=\"108.677014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.536205\" y=\"97.860057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.999895\" y=\"99.183073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"457.511803\" y=\"114.516948\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.221594\" y=\"97.756225\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"493.73119\" y=\"81.032796\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"430.099364\" y=\"135.990878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.771428\" y=\"105.22827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"427.450944\" y=\"136.636332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"501.010479\" y=\"75.581769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"416.016097\" y=\"151.472017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.887151\" y=\"83.73572\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"413.537475\" y=\"156.769878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.578015\" y=\"104.185965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"475.801958\" y=\"96.716999\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"437.533287\" y=\"129.407771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.196974\" y=\"97.469919\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.2708\" y=\"79.314625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"440.373969\" y=\"128.754398\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"489.860587\" y=\"84.492754\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.413663\" y=\"107.969137\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.041328\" y=\"90.379682\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"423.082023\" y=\"146.830397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"504.230543\" y=\"73.808893\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"464.524072\" y=\"106.175339\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"422.760645\" y=\"142.925853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"472.772197\" y=\"97.41672\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"510.680294\" y=\"67.873486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"459.754418\" y=\"110.720847\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"436.37005\" y=\"132.683566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"420.977424\" y=\"140.453841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.559825\" y=\"83.821468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.381482\" y=\"81.168797\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"469.359951\" y=\"102.161958\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"472.275415\" y=\"100.748119\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.258288\" y=\"94.728745\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"499.536344\" y=\"78.153685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"409.712365\" y=\"160.624605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.902575\" y=\"79.162399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.04694\" y=\"90.928254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.30084\" y=\"94.194902\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"481.967796\" y=\"92.201275\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"444.609034\" y=\"120.599654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"437.825417\" y=\"130.542429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"443.917109\" y=\"124.19008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.544557\" y=\"78.356944\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"441.362065\" y=\"128.745375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.933319\" y=\"109.097313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.284146\" y=\"89.26451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.533742\" y=\"87.731017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.44853\" y=\"78.613837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"430.829092\" y=\"135.142561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"425.09066\" y=\"139.582277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.995438\" y=\"100.737851\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"469.587257\" y=\"103.663676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.780027\" y=\"90.867112\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"432.368839\" y=\"131.924571\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"501.414001\" y=\"72.214123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.719213\" y=\"97.416403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"442.701815\" y=\"126.988538\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"508.002434\" y=\"72.222315\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"426.779316\" y=\"137.620189\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"433.559426\" y=\"133.11778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"441.848794\" y=\"125.237711\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"451.343258\" y=\"119.121799\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"409.036154\" y=\"148.156798\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"457.596409\" y=\"110.434655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.580597\" y=\"100.109996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.04039\" y=\"98.999191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"457.315487\" y=\"114.192637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"449.359166\" y=\"119.758086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.627352\" y=\"100.978002\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"505.73104\" y=\"74.644392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.612811\" y=\"86.298637\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"419.75971\" y=\"154.25934\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"433.808937\" y=\"132.781434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"456.308233\" y=\"113.418785\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"481.12494\" y=\"93.27642\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.171117\" y=\"98.877466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"435.705607\" y=\"131.099675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"506.695413\" y=\"70.729666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.179033\" y=\"86.62735\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.514019\" y=\"98.672848\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"503.669769\" y=\"75.23844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"442.18841\" y=\"127.729469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"412.721066\" y=\"144.936963\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"425.042012\" y=\"138.930548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.44178\" y=\"101.938682\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"494.810115\" y=\"83.145299\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"459.840657\" y=\"112.296742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.611001\" y=\"88.615982\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"475.8454\" y=\"97.407593\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.522831\" y=\"78.205206\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"478.182686\" y=\"95.828603\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"456.387026\" y=\"111.796379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"456.028257\" y=\"115.675427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"414.64591\" y=\"145.865561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"488.719909\" y=\"86.700274\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.949952\" y=\"97.435573\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"466.163508\" y=\"105.857886\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.98475\" y=\"128.246231\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"502.197661\" y=\"74.748429\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"428.812564\" y=\"136.066644\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.553101\" y=\"83.735586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"433.022307\" y=\"134.193968\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.914988\" y=\"94.799759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"499.44376\" y=\"78.500278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"484.747152\" y=\"91.774047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"429.885894\" y=\"136.116217\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.077379\" y=\"116.890894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"451.395442\" y=\"118.541224\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"451.521297\" y=\"118.146913\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.341029\" y=\"81.067862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"431.563892\" y=\"141.232812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.074964\" y=\"127.60016\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"418.409424\" y=\"143.6399\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.485426\" y=\"95.419076\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"419.988046\" y=\"146.602234\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.799279\" y=\"120.64078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.426321\" y=\"106.807857\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"462.260763\" y=\"108.886245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"475.104899\" y=\"97.972907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"488.171602\" y=\"86.006393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"488.586679\" y=\"87.59995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.733878\" y=\"89.242311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"489.645193\" y=\"85.680845\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.464036\" y=\"90.064735\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"488.683004\" y=\"85.773069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"449.178344\" y=\"120.215815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"429.359904\" y=\"134.972545\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"458.001492\" y=\"109.92013\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"417.571202\" y=\"144.423976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"450.238065\" y=\"118.07732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"459.474537\" y=\"111.683945\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.410877\" y=\"101.192013\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"508.948909\" y=\"70.692989\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"463.5235\" y=\"107.075666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"444.851001\" y=\"125.254715\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.511049\" y=\"106.713723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.663069\" y=\"106.930551\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.259902\" y=\"83.745348\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"444.457623\" y=\"124.078869\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"483.546326\" y=\"91.061342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"503.919906\" y=\"74.356379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"500.55861\" y=\"77.741692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.171553\" y=\"119.838072\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.504716\" y=\"84.752888\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.376145\" y=\"103.857995\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"501.058508\" y=\"76.197919\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"422.051557\" y=\"135.74387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"424.108239\" y=\"139.303105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"489.049855\" y=\"86.067011\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.210276\" y=\"84.710722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.900817\" y=\"86.801636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"416.072233\" y=\"148.693312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"503.527453\" y=\"74.011489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.949136\" y=\"78.466775\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"459.683219\" y=\"110.866827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.290595\" y=\"106.445221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"505.164154\" y=\"73.32281\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.729741\" y=\"129.632162\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"514.759432\" y=\"63.200911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.90831\" y=\"104.020838\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.319908\" y=\"84.666666\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"517.598256\" y=\"62.585245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.374411\" y=\"103.737173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"452.508627\" y=\"117.583334\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"464.426252\" y=\"106.991321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"426.053111\" y=\"140.295825\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"484.52919\" y=\"87.760602\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.870664\" y=\"89.417534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.39141\" y=\"92.694555\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.698252\" y=\"79.3332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"470.518672\" y=\"103.462207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.635974\" y=\"77.857118\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"452.574797\" y=\"116.138218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"463.133774\" y=\"108.908957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"481.594472\" y=\"92.053334\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"496.349121\" y=\"78.872307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.071575\" y=\"116.510263\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"442.404434\" y=\"127.633477\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.436106\" y=\"95.097879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"434.992693\" y=\"133.869107\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"427.002455\" y=\"138.476535\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"415.364141\" y=\"159.137792\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"504.150436\" y=\"74.716678\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"469.211822\" y=\"101.598642\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.38664\" y=\"90.075911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.919095\" y=\"80.484034\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"425.765054\" y=\"139.747791\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"505.856364\" y=\"70.818193\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"507.757169\" y=\"70.578427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"460.598913\" y=\"108.642701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"469.694778\" y=\"104.645302\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.394864\" y=\"79.632193\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.814136\" y=\"106.600788\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.121444\" y=\"123.86132\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"463.60998\" y=\"107.114332\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.450724\" y=\"119.117051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.807451\" y=\"98.818234\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"451.326773\" y=\"113.042801\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"480.85405\" y=\"93.070175\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"469.221919\" y=\"102.313833\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"459.941331\" y=\"108.903313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"434.51297\" y=\"131.696723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.373008\" y=\"109.006119\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.518014\" y=\"103.926924\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"417.040153\" y=\"150.861297\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"466.684797\" y=\"105.03713\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"470.149744\" y=\"106.032371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"478.581983\" y=\"93.768756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.043338\" y=\"114.515698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"419.900083\" y=\"144.186317\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.267054\" y=\"118.234183\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"450.195372\" y=\"118.334229\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"503.51119\" y=\"73.418765\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"421.949447\" y=\"141.646879\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.348736\" y=\"97.506309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.940895\" y=\"96.419253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.947241\" y=\"84.751584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.382189\" y=\"79.235401\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"436.394834\" y=\"129.393583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.651678\" y=\"100.891967\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.150146\" y=\"85.212859\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"419.217119\" y=\"143.996437\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.479694\" y=\"96.531726\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"425.250368\" y=\"139.53324\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.697978\" y=\"93.760029\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.68644\" y=\"95.080562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"470.584602\" y=\"101.927219\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"439.658038\" y=\"128.872188\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.327765\" y=\"78.48579\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"483.570526\" y=\"91.117032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.37151\" y=\"78.29333\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.306829\" y=\"87.071561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"415.880693\" y=\"147.873737\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.370276\" y=\"104.762523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"463.676122\" y=\"109.943471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.227262\" y=\"101.824614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"493.312575\" y=\"82.2408\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"505.299713\" y=\"74.624778\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.198419\" y=\"116.78286\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"503.033613\" y=\"74.712574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"510.954345\" y=\"67.086615\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.051273\" y=\"85.757839\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"496.52653\" y=\"79.73342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"411.931238\" y=\"151.368914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.633679\" y=\"86.43844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.997618\" y=\"120.586168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.404849\" y=\"88.070271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.272498\" y=\"83.442537\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"423.94527\" y=\"135.144166\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"420.932066\" y=\"144.365526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"429.00901\" y=\"135.608746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"455.839503\" y=\"113.807635\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.688697\" y=\"93.830413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"446.692347\" y=\"122.205004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"460.319141\" y=\"108.860434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.547814\" y=\"89.361896\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"494.161687\" y=\"81.839759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"492.56382\" y=\"83.292202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.822975\" y=\"87.892694\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"466.240195\" y=\"104.340065\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.450069\" y=\"88.240514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"433.694788\" y=\"127.888282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.167615\" y=\"78.985676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"446.707794\" y=\"126.743495\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"426.798257\" y=\"137.650248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"483.421487\" y=\"90.080252\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"483.069809\" y=\"92.388771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.116569\" y=\"130.591813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.129498\" y=\"120.883764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"424.023935\" y=\"142.089107\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.791513\" y=\"103.836499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.522302\" y=\"83.529492\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"480.860185\" y=\"94.440683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"492.372944\" y=\"82.224514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"422.944418\" y=\"143.555364\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"485.859032\" y=\"90.221657\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"441.831164\" y=\"125.113729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"492.767788\" y=\"81.736655\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"443.991231\" y=\"124.378897\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"500.519473\" y=\"76.598496\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"421.531617\" y=\"138.702336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.270203\" y=\"80.689827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"499.751952\" y=\"77.15846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"455.738895\" y=\"114.696692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"478.965589\" y=\"95.921503\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"447.370973\" y=\"122.441733\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"410.870505\" y=\"143.506511\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"478.257986\" y=\"94.926052\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.328171\" y=\"106.147701\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.961426\" y=\"100.604862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"496.382439\" y=\"80.645129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.259647\" y=\"103.329422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"505.537252\" y=\"74.398304\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"459.609102\" y=\"111.727465\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"417.594991\" y=\"154.769911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"446.148626\" y=\"122.881415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.547664\" y=\"101.582514\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"460.985545\" y=\"110.18561\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.997568\" y=\"84.984595\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.996492\" y=\"101.875864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.493682\" y=\"116.855311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"445.363699\" y=\"120.327658\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"432.980029\" y=\"132.213815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"492.288849\" y=\"82.29381\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"437.764478\" y=\"131.81883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"511.406301\" y=\"67.867169\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"456.51992\" y=\"112.668432\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.646385\" y=\"103.990418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.868533\" y=\"80.238656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"430.175302\" y=\"138.454198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"462.68771\" y=\"110.101786\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"445.810296\" y=\"124.685279\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"457.394822\" y=\"113.859142\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.820037\" y=\"98.906114\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"424.76267\" y=\"155.750275\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"510.487434\" y=\"68.466612\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.361609\" y=\"110.148476\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"464.202512\" y=\"106.628718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"456.320396\" y=\"115.233318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.180083\" y=\"89.075\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.812241\" y=\"98.177557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.569178\" y=\"96.583363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"415.576448\" y=\"146.589482\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"489.694894\" y=\"85.123345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"493.042306\" y=\"81.866806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"445.654181\" y=\"130.036553\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.998976\" y=\"129.809375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"430.647507\" y=\"134.309728\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.080774\" y=\"126.569584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"509.884123\" y=\"70.86883\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.869799\" y=\"88.723087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"500.137357\" y=\"77.12091\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"458.293623\" y=\"111.078692\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"432.345098\" y=\"135.331449\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"472.080388\" y=\"99.490384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"470.908658\" y=\"101.836837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"425.219352\" y=\"144.43734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.994104\" y=\"101.825504\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.064112\" y=\"117.890443\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"433.716381\" y=\"128.953706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"426.415654\" y=\"142.266776\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.954976\" y=\"97.988671\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"443.847762\" y=\"124.471821\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"413.561112\" y=\"150.872586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.159308\" y=\"105.962053\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"460.691786\" y=\"111.242969\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.109614\" y=\"82.554085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.441803\" y=\"85.306111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.672123\" y=\"91.494817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.616446\" y=\"103.316535\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"423.829135\" y=\"135.745824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"432.022484\" y=\"134.702826\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"426.90928\" y=\"134.595182\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"507.89597\" y=\"70.343497\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.680885\" y=\"86.890605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"490.771621\" y=\"85.26985\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.654531\" y=\"98.75789\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"496.078701\" y=\"79.76568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"397.05798\" y=\"170.463649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"462.845098\" y=\"109.596121\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.254078\" y=\"80.841439\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.709096\" y=\"78.66203\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.142794\" y=\"110.407662\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.700731\" y=\"118.067456\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.567122\" y=\"94.386086\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.181777\" y=\"81.052862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"463.399706\" y=\"108.450633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"480.867145\" y=\"93.625996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.490496\" y=\"98.223534\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.890189\" y=\"89.403536\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.641076\" y=\"79.56248\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"496.619102\" y=\"79.999809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"423.649583\" y=\"133.801004\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.298476\" y=\"102.453755\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.735449\" y=\"103.723774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.531335\" y=\"117.044842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.9045\" y=\"95.699345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.041826\" y=\"115.923218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"475.125164\" y=\"97.402066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"483.112595\" y=\"91.433466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"454.053587\" y=\"117.746419\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"478.770723\" y=\"94.961836\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"409.491329\" y=\"153.714547\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"507.150716\" y=\"72.554017\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"464.995834\" y=\"106.354278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"442.297874\" y=\"125.746687\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.627869\" y=\"103.344735\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"495.152348\" y=\"81.652584\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"512.082641\" y=\"65.67906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"488.370431\" y=\"87.311526\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.782852\" y=\"103.769381\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"455.090761\" y=\"115.928715\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"475.285575\" y=\"99.533489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"398.396761\" y=\"160.842328\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"476.49963\" y=\"96.975723\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"431.917533\" y=\"138.299338\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.168738\" y=\"87.921261\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"461.736696\" y=\"108.141468\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"443.7723\" y=\"124.962195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"477.409002\" y=\"94.847391\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"480.417755\" y=\"93.985909\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"517.395394\" y=\"63.065806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"465.639328\" y=\"111.636752\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"457.449516\" y=\"115.427565\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.550036\" y=\"98.553237\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"464.300504\" y=\"106.999614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.593195\" y=\"88.553824\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.036243\" y=\"83.949145\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"456.974938\" y=\"111.783777\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"515.143216\" y=\"64.852347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.213072\" y=\"102.926818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"509.566952\" y=\"69.158629\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"491.41008\" y=\"88.221798\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"448.991055\" y=\"119.750381\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"499.194117\" y=\"77.207511\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.81043\" y=\"97.936806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"506.104514\" y=\"72.550084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.213229\" y=\"91.130127\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"520.074762\" y=\"62.730043\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"482.405057\" y=\"91.708812\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.25287\" y=\"106.809352\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.91782\" y=\"104.284653\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"471.409177\" y=\"102.216326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"463.773398\" y=\"105.530408\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"493.293778\" y=\"83.155345\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"478.343058\" y=\"95.691819\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"422.494885\" y=\"142.670322\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.672319\" y=\"101.190703\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"427.476255\" y=\"140.663427\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"498.174584\" y=\"76.242209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"443.998117\" y=\"124.902846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"422.688861\" y=\"139.923177\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"430.846301\" y=\"135.427627\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"454.164163\" y=\"115.569372\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"481.447978\" y=\"90.083319\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"412.815455\" y=\"154.265729\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.926025\" y=\"113.902395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"484.76908\" y=\"90.96693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"406.987239\" y=\"152.858382\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.390387\" y=\"93.669549\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.195052\" y=\"95.323689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"438.752404\" y=\"130.981722\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"481.373784\" y=\"92.444849\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"479.518875\" y=\"94.204286\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.107119\" y=\"98.741548\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"473.262363\" y=\"99.335309\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"453.376315\" y=\"116.82033\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"457.833559\" y=\"109.397652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"514.116558\" y=\"67.406872\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"474.76409\" y=\"98.057087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"497.325241\" y=\"79.814882\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"510.180643\" y=\"67.630226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"424.698067\" y=\"138.899117\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"486.483326\" y=\"88.53068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"468.363574\" y=\"104.062442\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"403.275781\" y=\"159.993745\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"487.548888\" y=\"86.10558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"437.177864\" y=\"129.405719\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"444.339318\" y=\"126.361173\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"450.773757\" y=\"117.305353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"455.892838\" y=\"114.843401\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"419.093679\" y=\"144.866051\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"431.247068\" y=\"135.640121\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"408.979345\" y=\"152.897942\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"467.346819\" y=\"106.29894\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"433.126407\" y=\"144.850621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"449.764685\" y=\"118.122313\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"493.580761\" y=\"82.228087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"407.791855\" y=\"145.925529\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"506.026488\" y=\"68.57383\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 390.408312 176.283694 \n",
       "L 390.408312 59.747385 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 409.397787 179.384625 \n",
       "L 520.744025 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_32\">\n",
       "    <!-- RMSE: 0.103 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(397.408711 63.972112) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-33\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_33\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(398.783297 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_31\">\n",
       "    <path d=\"M 481.880118 92.28773 \n",
       "L 404.519096 157.06131 \n",
       "L 524.052283 56.977415 \n",
       "L 509.819896 68.894045 \n",
       "\" clip-path=\"url(#pbd6ccea723)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 566.456031 179.384625 \n",
       "L 706.464 179.384625 \n",
       "L 706.464 51.1485 \n",
       "L 566.456031 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_32\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"572.912438\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(567.895751 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"637.948393\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(635.50158 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_34\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3f2ae540a0\" x=\"702.984348\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_36\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(700.537535 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"173.471765\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_37\">\n",
       "      <!-- −2.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 176.621202) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"158.701796\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_38\">\n",
       "      <!-- −1.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 161.851233) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_19\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"143.931827\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- −1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 147.081265) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_20\">\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"129.161859\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_40\">\n",
       "      <!-- −0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 132.311296) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_21\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"114.39189\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_41\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 117.541327) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_22\">\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"99.621921\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_42\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 102.771359) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_23\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"84.851952\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_43\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 88.00139) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_24\">\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"70.081984\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_44\">\n",
       "      <!-- 1.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 73.231421) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_25\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc4dcb94989\" x=\"566.456031\" y=\"55.312015\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_45\">\n",
       "      <!-- 2.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 58.461453) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"LineCollection_4\">\n",
       "    <path d=\"M 656.146795 99.778805 \n",
       "L 656.146795 99.140708 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.48217 152.405729 \n",
       "L 595.48217 151.063114 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.324019 165.074783 \n",
       "L 580.324019 163.4841 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.415388 117.655112 \n",
       "L 634.415388 116.663623 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.29959 72.564707 \n",
       "L 686.29959 68.910233 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 575.680974 171.102501 \n",
       "L 575.680974 166.608622 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.238566 72.453138 \n",
       "L 685.238566 70.455534 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.130047 145.346208 \n",
       "L 603.130047 144.830091 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.092255 117.295295 \n",
       "L 635.092255 115.23949 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.726024 136.036704 \n",
       "L 614.726024 134.894116 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.188336 117.720841 \n",
       "L 634.188336 116.852409 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 605.503972 143.997155 \n",
       "L 605.503972 143.092423 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.819473 71.227199 \n",
       "L 684.819473 69.465632 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.530229 94.243031 \n",
       "L 662.530229 92.356354 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.211419 76.203515 \n",
       "L 679.211419 75.5211 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.154561 114.044407 \n",
       "L 640.154561 112.858596 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.02011 120.852413 \n",
       "L 632.02011 119.719738 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.65892 153.286714 \n",
       "L 596.65892 151.913574 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.592897 82.945619 \n",
       "L 671.592897 81.778778 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.170207 79.68931 \n",
       "L 676.170207 78.159439 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.743323 148.791604 \n",
       "L 600.743323 145.655637 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.754822 127.401252 \n",
       "L 625.754822 125.570067 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.816823 149.40302 \n",
       "L 599.816823 148.562986 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 599.161106 149.100447 \n",
       "L 599.161106 147.517015 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.348036 69.132776 \n",
       "L 690.348036 67.134489 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.253663 95.359491 \n",
       "L 658.253663 94.378126 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.941517 111.435133 \n",
       "L 640.941517 110.881983 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.944615 150.826175 \n",
       "L 597.944615 150.132818 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.779657 86.521058 \n",
       "L 669.779657 85.321313 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.309655 69.682797 \n",
       "L 691.309655 67.488071 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.247993 103.067334 \n",
       "L 652.247993 100.606401 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.623513 118.042151 \n",
       "L 636.623513 116.804982 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.443445 148.628594 \n",
       "L 602.443445 146.044073 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.397744 66.101761 \n",
       "L 689.397744 64.240419 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.253411 148.979149 \n",
       "L 600.253411 147.824426 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.344921 149.113188 \n",
       "L 601.344921 148.021671 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.107494 82.067197 \n",
       "L 673.107494 80.573303 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.300063 91.355074 \n",
       "L 664.300063 90.182533 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.831813 78.784431 \n",
       "L 682.831813 75.776112 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.607889 156.637308 \n",
       "L 594.607889 153.740086 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.22215 96.777529 \n",
       "L 657.22215 95.503301 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.904818 126.113681 \n",
       "L 624.904818 125.765689 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.985773 138.41373 \n",
       "L 610.985773 137.340181 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.818004 73.531783 \n",
       "L 684.818004 71.740781 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.861036 144.2436 \n",
       "L 607.861036 142.637167 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.881738 86.25477 \n",
       "L 668.881738 84.708613 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.047553 104.087231 \n",
       "L 651.047553 103.013917 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.484811 108.353564 \n",
       "L 645.484811 107.733756 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.490134 99.630555 \n",
       "L 655.490134 98.736017 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.321766 172.441808 \n",
       "L 577.321766 170.458739 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.462956 98.044365 \n",
       "L 658.462956 96.372566 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.736618 86.747802 \n",
       "L 666.736618 85.902799 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 579.261488 167.190025 \n",
       "L 579.261488 163.696841 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.761738 71.328219 \n",
       "L 686.761738 70.023004 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.727369 134.979893 \n",
       "L 616.727369 134.220596 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.052233 112.705834 \n",
       "L 641.052233 111.931778 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.083815 158.782512 \n",
       "L 590.083815 157.476161 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.499433 100.52817 \n",
       "L 653.499433 99.500661 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.610931 130.457514 \n",
       "L 619.610931 129.450076 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.885814 138.05215 \n",
       "L 612.885814 137.060341 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.023442 104.438304 \n",
       "L 649.023442 103.143711 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.327018 126.902385 \n",
       "L 625.327018 125.961918 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.290372 107.195482 \n",
       "L 646.290372 106.426838 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.320362 92.89662 \n",
       "L 664.320362 90.000112 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 576.711155 171.599538 \n",
       "L 576.711155 169.505399 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.754314 129.567679 \n",
       "L 622.754314 128.557041 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.747189 67.961855 \n",
       "L 689.747189 66.702777 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.960165 94.652185 \n",
       "L 660.960165 93.944321 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.553998 96.78548 \n",
       "L 657.553998 96.062305 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.864856 135.398569 \n",
       "L 615.864856 133.222826 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.276496 144.4547 \n",
       "L 606.276496 143.310822 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.307253 82.475364 \n",
       "L 673.307253 81.229051 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.449252 83.530917 \n",
       "L 672.449252 82.289498 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.86425 77.776694 \n",
       "L 678.86425 75.770615 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.059781 73.150487 \n",
       "L 686.059781 71.661461 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.12333 89.519165 \n",
       "L 665.12333 87.777102 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 675.657032 81.061575 \n",
       "L 675.657032 79.925553 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.64879 141.046946 \n",
       "L 608.64879 139.7581 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.271845 122.739569 \n",
       "L 628.271845 122.054813 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.43623 147.551477 \n",
       "L 601.43623 146.48875 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.743967 78.250672 \n",
       "L 678.743967 76.743056 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.841929 114.704652 \n",
       "L 636.841929 114.136209 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.721451 163.75066 \n",
       "L 583.721451 162.378247 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.733755 98.353895 \n",
       "L 654.733755 96.214179 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.078659 90.192397 \n",
       "L 665.078659 88.17613 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.389927 107.485424 \n",
       "L 646.389927 106.436585 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.2724 154.939135 \n",
       "L 595.2724 153.457897 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.465116 87.733493 \n",
       "L 667.465116 86.238807 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 578.092633 169.752962 \n",
       "L 578.092633 168.206016 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.073922 160.439047 \n",
       "L 588.073922 159.895884 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.928114 96.055864 \n",
       "L 657.928114 95.169402 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.203425 86.358475 \n",
       "L 669.203425 85.511808 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.4197 126.533408 \n",
       "L 624.4197 124.465053 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.168243 100.529635 \n",
       "L 653.168243 99.166218 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 696.882413 62.375994 \n",
       "L 696.882413 59.456805 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.693345 134.142541 \n",
       "L 618.693345 132.737988 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.311718 100.602153 \n",
       "L 654.311718 99.45846 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.982723 164.694547 \n",
       "L 583.982723 162.54228 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.624469 152.006469 \n",
       "L 597.624469 150.951672 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.913997 130.192911 \n",
       "L 624.913997 127.383252 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.527941 119.117081 \n",
       "L 632.527941 118.117604 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.698115 144.278535 \n",
       "L 604.698115 142.920901 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.214437 140.305051 \n",
       "L 610.214437 139.222593 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 623.953107 127.59531 \n",
       "L 623.953107 127.113178 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.701606 113.198835 \n",
       "L 639.701606 112.285925 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.113135 108.615243 \n",
       "L 646.113135 106.810368 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.506456 139.813045 \n",
       "L 610.506456 139.008468 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.722207 81.482704 \n",
       "L 674.722207 78.430198 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.527394 91.810906 \n",
       "L 663.527394 90.924207 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 697.047527 58.780334 \n",
       "L 697.047527 56.977415 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.995597 114.618617 \n",
       "L 639.995597 113.167515 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.001827 153.87055 \n",
       "L 595.001827 152.660763 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.50009 146.721754 \n",
       "L 602.50009 145.821743 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.174955 119.725853 \n",
       "L 632.174955 118.933959 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.390931 88.146366 \n",
       "L 668.390931 86.910189 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.882568 98.893427 \n",
       "L 654.882568 97.823925 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.221944 137.481818 \n",
       "L 613.221944 136.646259 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.544984 105.292531 \n",
       "L 647.544984 104.187802 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.541067 107.130308 \n",
       "L 646.541067 106.369416 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.354533 73.779054 \n",
       "L 683.354533 72.719093 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.2851 158.923286 \n",
       "L 592.2851 157.264398 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.881997 120.429885 \n",
       "L 630.881997 119.607159 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.41054 160.969092 \n",
       "L 586.41054 159.279373 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.54378 78.868624 \n",
       "L 677.54378 77.895083 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.444891 132.227586 \n",
       "L 618.444891 131.632345 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.807369 151.174497 \n",
       "L 598.807369 149.493431 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.576338 96.367988 \n",
       "L 657.576338 95.782452 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.547189 148.072964 \n",
       "L 600.547189 146.839787 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.121507 137.39265 \n",
       "L 615.121507 136.028388 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.359504 93.484512 \n",
       "L 664.359504 91.311788 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.573702 89.882401 \n",
       "L 666.573702 88.960999 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.685804 81.32895 \n",
       "L 674.685804 80.425971 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.471225 143.310347 \n",
       "L 607.471225 141.501725 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.60974 89.558636 \n",
       "L 666.60974 88.802504 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.439987 106.51512 \n",
       "L 647.439987 106.049022 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.812232 141.211935 \n",
       "L 609.812232 140.265996 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.316244 89.546504 \n",
       "L 665.316244 88.862291 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.787312 152.548831 \n",
       "L 596.787312 151.773196 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.132747 156.121307 \n",
       "L 592.132747 155.134653 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 646.992957 106.557079 \n",
       "L 646.992957 106.076689 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.79239 103.633902 \n",
       "L 649.79239 102.367834 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 693.919426 65.974214 \n",
       "L 693.919426 64.141334 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.661095 168.834224 \n",
       "L 580.661095 166.532269 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 689.64438 67.821339 \n",
       "L 689.64438 67.050603 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.810451 155.876825 \n",
       "L 593.810451 154.261372 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.500152 141.906008 \n",
       "L 608.500152 140.993015 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.398488 98.421735 \n",
       "L 655.398488 97.386762 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 692.152479 64.800392 \n",
       "L 692.152479 62.478448 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.96648 138.869517 \n",
       "L 611.96648 137.960196 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.553474 86.157945 \n",
       "L 674.553474 84.047236 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.077481 105.665035 \n",
       "L 648.077481 103.7113 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.761461 73.906947 \n",
       "L 681.761461 72.899405 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.148392 112.795565 \n",
       "L 640.148392 111.646067 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.198081 131.356447 \n",
       "L 621.198081 130.016189 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.724411 108.863391 \n",
       "L 643.724411 108.126561 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.286278 109.022226 \n",
       "L 643.286278 107.848542 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.792937 108.721534 \n",
       "L 644.792937 107.554148 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 692.917916 64.364686 \n",
       "L 692.917916 62.745867 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.860242 163.46167 \n",
       "L 584.860242 162.704424 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.688687 169.420966 \n",
       "L 580.688687 166.953183 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.1699 145.951811 \n",
       "L 607.1699 144.138327 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.34371 109.166088 \n",
       "L 645.34371 108.511709 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.041137 84.527867 \n",
       "L 672.041137 83.144818 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.546682 113.764188 \n",
       "L 641.546682 112.114069 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.413451 105.33359 \n",
       "L 648.413451 103.866581 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.285892 74.248627 \n",
       "L 686.285892 73.089066 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.343051 98.125927 \n",
       "L 660.343051 96.215761 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.504104 117.347261 \n",
       "L 635.504104 115.246148 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.000496 161.002302 \n",
       "L 587.000496 160.017848 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 687.390779 70.785414 \n",
       "L 687.390779 69.654261 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.822669 77.7662 \n",
       "L 678.822669 76.78467 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.03401 117.149981 \n",
       "L 636.03401 116.160455 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.483413 98.061579 \n",
       "L 654.483413 97.075202 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.498359 112.224906 \n",
       "L 641.498359 111.384121 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.057353 71.954321 \n",
       "L 686.057353 70.732436 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.70002 147.623564 \n",
       "L 603.70002 145.611407 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.085446 159.509672 \n",
       "L 587.085446 158.052651 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.238411 165.53239 \n",
       "L 582.238411 164.432976 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 609.405482 141.4413 \n",
       "L 609.405482 140.051146 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.671024 94.189036 \n",
       "L 659.671024 93.42536 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.274497 93.555202 \n",
       "L 659.274497 91.789539 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.114497 80.037126 \n",
       "L 680.114497 77.914283 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 611.34575 141.598749 \n",
       "L 611.34575 139.937591 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.055614 137.888013 \n",
       "L 615.055614 135.938504 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.17148 138.102517 \n",
       "L 612.17148 137.660762 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.795815 124.857078 \n",
       "L 626.795815 124.010597 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 591.613068 161.706283 \n",
       "L 591.613068 159.532858 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.27237 147.21883 \n",
       "L 602.27237 146.773043 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.760785 113.836688 \n",
       "L 636.760785 112.466511 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.344751 91.772233 \n",
       "L 662.344751 90.908198 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.356713 97.460166 \n",
       "L 657.356713 96.707714 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.74411 105.470191 \n",
       "L 647.74411 104.610517 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.971609 85.862397 \n",
       "L 672.971609 84.597294 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.848469 147.628292 \n",
       "L 600.848469 145.149822 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.549335 168.490607 \n",
       "L 580.549335 166.817662 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.6751 152.678976 \n",
       "L 597.6751 151.691292 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.565692 100.581439 \n",
       "L 653.565692 99.326027 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.520995 86.159727 \n",
       "L 668.520995 85.459767 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.633612 104.568946 \n",
       "L 648.633612 103.957585 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.884649 126.926713 \n",
       "L 625.884649 125.94991 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.630588 72.295935 \n",
       "L 686.630588 69.588051 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.071109 105.249346 \n",
       "L 649.071109 104.025495 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 579.258861 169.190902 \n",
       "L 579.258861 167.899139 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.499877 100.076612 \n",
       "L 653.499877 99.227515 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.354927 117.548073 \n",
       "L 634.354927 116.948223 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.115789 92.415272 \n",
       "L 658.115789 88.340592 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.360057 82.969286 \n",
       "L 671.360057 81.80028 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.864866 129.632812 \n",
       "L 620.864866 128.479783 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 683.940857 73.203657 \n",
       "L 683.940857 72.313575 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.827511 125.691808 \n",
       "L 624.827511 124.593555 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.945335 162.968786 \n",
       "L 584.945335 161.611287 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.460358 117.279809 \n",
       "L 636.460358 116.386089 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.217634 84.676762 \n",
       "L 671.217634 83.967052 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.786804 81.721026 \n",
       "L 672.786804 80.499549 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.302394 123.028376 \n",
       "L 628.302394 122.187143 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.124004 96.319709 \n",
       "L 658.124004 95.362815 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 590.938487 157.5019 \n",
       "L 590.938487 156.660948 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.541363 69.90696 \n",
       "L 685.541363 66.998971 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.961966 137.096147 \n",
       "L 614.961966 136.256331 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 693.237795 65.924638 \n",
       "L 693.237795 63.813178 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.242135 89.453041 \n",
       "L 668.242135 88.097205 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.25677 89.984174 \n",
       "L 666.25677 89.278495 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.683567 77.319838 \n",
       "L 679.683567 75.410472 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.329542 103.997967 \n",
       "L 649.329542 102.701145 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.202658 131.418578 \n",
       "L 621.202658 130.467826 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.665692 164.922083 \n",
       "L 584.665692 163.030698 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.183682 147.200234 \n",
       "L 601.183682 146.484347 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.870349 69.510536 \n",
       "L 685.870349 67.129917 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.584299 133.772352 \n",
       "L 616.584299 132.531593 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.549133 153.214917 \n",
       "L 595.549133 152.094989 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.209683 116.126039 \n",
       "L 635.209683 115.23245 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.47737 95.140956 \n",
       "L 657.47737 94.335366 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 615.20855 135.087667 \n",
       "L 615.20855 134.509076 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.943831 130.455887 \n",
       "L 620.943831 129.573821 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.84248 168.646688 \n",
       "L 580.84248 166.996445 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.017034 72.977114 \n",
       "L 684.017034 70.902907 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.087059 90.250482 \n",
       "L 666.087059 88.636342 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.343657 118.853265 \n",
       "L 632.343657 118.304122 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.976574 81.360783 \n",
       "L 677.976574 77.898932 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 585.246616 162.646277 \n",
       "L 585.246616 161.424996 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.843603 164.498105 \n",
       "L 581.843603 163.125336 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.586823 136.106575 \n",
       "L 614.586823 135.486246 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.517601 116.059449 \n",
       "L 637.517601 115.298557 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.636712 142.764581 \n",
       "L 607.636712 141.155414 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.619392 77.343022 \n",
       "L 678.619392 76.242357 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 664.599933 90.881696 \n",
       "L 664.599933 90.097509 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.296844 139.445086 \n",
       "L 610.296844 138.163596 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.388536 137.3231 \n",
       "L 614.388536 135.829198 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.138274 131.521527 \n",
       "L 619.138274 129.690189 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 694.425389 68.221784 \n",
       "L 694.425389 66.764122 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.319146 146.354816 \n",
       "L 603.319146 145.717405 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.64112 152.32559 \n",
       "L 597.64112 150.72969 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.449018 101.887421 \n",
       "L 652.449018 101.036695 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.920725 133.487892 \n",
       "L 616.920725 132.872268 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.051346 125.746618 \n",
       "L 627.051346 125.079677 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.709613 153.91964 \n",
       "L 595.709613 152.719302 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.506981 97.181168 \n",
       "L 657.506981 96.711 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.359736 109.196068 \n",
       "L 642.359736 108.195218 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.143731 108.971781 \n",
       "L 645.143731 107.539973 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.210714 93.426779 \n",
       "L 661.210714 92.009478 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.034531 117.33863 \n",
       "L 635.034531 116.77847 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.218786 94.231969 \n",
       "L 661.218786 93.282311 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 579.938124 169.642897 \n",
       "L 579.938124 166.76115 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.569141 103.517748 \n",
       "L 649.569141 102.486474 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.210976 113.345975 \n",
       "L 639.210976 112.565795 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.8487 159.563717 \n",
       "L 589.8487 157.628617 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.02041 107.132983 \n",
       "L 647.02041 106.018902 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.576141 100.919997 \n",
       "L 655.576141 98.775066 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.569124 149.532435 \n",
       "L 598.569124 148.762389 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.235273 110.473255 \n",
       "L 643.235273 109.594501 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.410879 95.897998 \n",
       "L 659.410879 94.829863 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.272397 99.516243 \n",
       "L 656.272397 98.792044 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.870033 156.625351 \n",
       "L 594.870033 154.600677 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.542623 152.653696 \n",
       "L 596.542623 151.867943 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.612575 116.083651 \n",
       "L 636.612575 114.567185 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.370973 165.35455 \n",
       "L 582.370973 164.107292 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.538395 77.303976 \n",
       "L 678.538395 76.594551 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.299771 97.812248 \n",
       "L 656.299771 96.38322 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.618468 86.250477 \n",
       "L 670.618468 83.928089 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.641269 84.010285 \n",
       "L 670.641269 82.781772 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.398122 155.294937 \n",
       "L 594.398122 153.793407 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.060991 78.588871 \n",
       "L 676.060991 77.361074 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 661.830827 95.196793 \n",
       "L 661.830827 93.821676 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.506953 149.306249 \n",
       "L 600.506953 148.50845 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.641153 103.314751 \n",
       "L 651.641153 101.730547 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.668591 144.317428 \n",
       "L 604.668591 143.851351 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.479958 91.778275 \n",
       "L 663.479958 90.810431 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.887887 105.872646 \n",
       "L 647.887887 105.107806 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.579218 126.462709 \n",
       "L 625.579218 124.999794 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.566576 79.505298 \n",
       "L 680.566576 77.738204 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.042219 114.27677 \n",
       "L 639.042219 113.00368 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.803297 85.901852 \n",
       "L 673.803297 83.495839 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.037002 79.539804 \n",
       "L 677.037002 77.51689 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 648.816827 104.901306 \n",
       "L 648.816827 102.225754 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 601.28374 147.816897 \n",
       "L 601.28374 147.059014 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.497438 123.462181 \n",
       "L 627.497438 122.933992 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 640.042148 111.750781 \n",
       "L 640.042148 110.226935 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 586.751252 161.201764 \n",
       "L 586.751252 160.347977 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.526104 83.974218 \n",
       "L 669.526104 82.979298 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.759122 166.624692 \n",
       "L 582.759122 164.564722 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.410193 145.020702 \n",
       "L 607.410193 143.841969 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.877745 146.43632 \n",
       "L 603.877745 145.283789 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.926306 85.185942 \n",
       "L 668.926306 83.998171 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.111916 66.120496 \n",
       "L 690.111916 64.860576 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.947641 125.772574 \n",
       "L 625.947641 124.65308 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.982328 84.257162 \n",
       "L 670.982328 83.426843 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.833139 128.263273 \n",
       "L 622.833139 127.759817 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.021568 87.456242 \n",
       "L 668.021568 86.235144 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 645.471316 107.84025 \n",
       "L 645.471316 106.659159 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.736359 110.556155 \n",
       "L 642.736359 109.518961 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.290042 163.841425 \n",
       "L 584.290042 162.053246 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.007004 123.17181 \n",
       "L 631.007004 121.610813 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.437718 70.291722 \n",
       "L 686.437718 68.805931 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.040669 116.819186 \n",
       "L 637.040669 116.04593 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.146366 90.148042 \n",
       "L 666.146366 88.685779 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.963102 76.057366 \n",
       "L 682.963102 74.361429 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 622.125596 128.796552 \n",
       "L 622.125596 128.127719 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.551371 135.792085 \n",
       "L 614.551371 135.12814 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.384899 104.864048 \n",
       "L 649.384899 104.268584 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 688.767387 69.514394 \n",
       "L 688.767387 67.466273 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.166483 111.552766 \n",
       "L 642.166483 110.038963 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 671.078468 84.425503 \n",
       "L 671.078468 83.809136 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 627.902711 125.150526 \n",
       "L 627.902711 123.556519 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.407539 141.873629 \n",
       "L 608.407539 141.073805 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.887382 123.07182 \n",
       "L 629.887382 122.180472 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 652.011265 101.117964 \n",
       "L 652.011265 100.597112 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 598.299893 150.560935 \n",
       "L 598.299893 149.633633 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.786068 77.139892 \n",
       "L 680.786068 76.396172 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.799254 91.371387 \n",
       "L 663.799254 90.628691 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 595.548555 154.853573 \n",
       "L 595.548555 153.855774 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.048364 70.328213 \n",
       "L 691.048364 68.781767 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.271103 114.609781 \n",
       "L 639.271103 113.169501 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.028418 154.960711 \n",
       "L 592.028418 153.918484 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.636555 139.685965 \n",
       "L 610.636555 138.655141 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.844641 168.377365 \n",
       "L 577.844641 165.936319 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 637.125034 115.369363 \n",
       "L 637.125034 113.857932 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 618.923814 133.389595 \n",
       "L 618.923814 132.6558 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.376925 127.627098 \n",
       "L 624.376925 126.712252 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 630.254003 125.13025 \n",
       "L 630.254003 123.155234 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.626974 133.915699 \n",
       "L 616.626974 132.63901 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.185491 77.332831 \n",
       "L 681.185491 75.582325 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.97143 118.356316 \n",
       "L 632.97143 117.833832 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.20092 152.652577 \n",
       "L 596.20092 150.754962 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 672.878067 82.513019 \n",
       "L 672.878067 81.919633 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.216548 169.717175 \n",
       "L 582.216548 164.837446 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.543414 137.770592 \n",
       "L 613.543414 136.896031 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.47732 151.291625 \n",
       "L 596.47732 149.922039 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.283249 69.936359 \n",
       "L 690.283249 67.349796 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 690.931897 69.844009 \n",
       "L 690.931897 66.084302 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.591508 88.665878 \n",
       "L 666.591508 87.771997 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.892247 122.244136 \n",
       "L 629.892247 121.32986 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.211191 166.450413 \n",
       "L 580.211191 164.338036 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.709102 133.853267 \n",
       "L 616.709102 132.30456 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 583.454919 164.850303 \n",
       "L 583.454919 163.767259 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 681.958956 75.126862 \n",
       "L 681.958956 73.805106 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.642597 86.410844 \n",
       "L 669.642597 84.348983 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.420374 76.672954 \n",
       "L 678.420374 76.025516 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.191378 110.919334 \n",
       "L 643.191378 108.994099 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 581.430907 165.953752 \n",
       "L 581.430907 164.711414 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.047378 90.687126 \n",
       "L 666.047378 89.299793 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.775782 162.252408 \n",
       "L 584.775782 160.456888 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.116481 112.60449 \n",
       "L 641.116481 111.229644 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 684.319602 73.667919 \n",
       "L 684.319602 71.328722 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.569975 144.377516 \n",
       "L 603.569975 142.499695 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 589.21515 159.715176 \n",
       "L 589.21515 158.377117 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 602.487822 147.525034 \n",
       "L 602.487822 146.884702 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.557479 126.312238 \n",
       "L 625.557479 125.357493 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.826928 133.331198 \n",
       "L 616.826928 132.055237 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.340359 91.224172 \n",
       "L 663.340359 90.314653 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.444175 150.533983 \n",
       "L 597.444175 148.61227 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 593.406115 154.587936 \n",
       "L 593.406115 153.139037 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.618574 86.960254 \n",
       "L 667.618574 85.807658 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 678.675025 77.01651 \n",
       "L 678.675025 76.0417 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 626.494744 127.467346 \n",
       "L 626.494744 126.483044 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 656.498115 98.746207 \n",
       "L 656.498115 96.956667 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 685.408064 74.330944 \n",
       "L 685.408064 73.083196 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 631.022273 121.817941 \n",
       "L 631.022273 120.053764 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.733092 126.647547 \n",
       "L 625.733092 125.474027 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 639.021769 112.985832 \n",
       "L 639.021769 112.367498 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.790519 120.265873 \n",
       "L 632.790519 119.622493 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.155878 138.638922 \n",
       "L 612.155878 137.101779 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.340552 116.430894 \n",
       "L 636.340552 115.4959 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.040516 135.697326 \n",
       "L 614.040516 134.436289 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.008004 104.482027 \n",
       "L 650.008004 102.09911 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.98744 74.666903 \n",
       "L 682.98744 72.747877 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.033484 115.130691 \n",
       "L 638.033484 114.418099 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 655.109944 98.849521 \n",
       "L 655.109944 97.366471 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.955731 109.819757 \n",
       "L 641.955731 108.953922 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.643762 107.137503 \n",
       "L 649.643762 104.381533 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 597.975015 150.787704 \n",
       "L 597.975015 149.89121 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.940737 94.971793 \n",
       "L 660.940737 93.677013 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.625846 116.068922 \n",
       "L 636.625846 114.848475 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.395263 75.333506 \n",
       "L 682.395263 74.786112 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.864671 125.760255 \n",
       "L 625.864671 125.186986 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 592.629994 159.261518 \n",
       "L 592.629994 157.341202 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.294284 124.397522 \n",
       "L 628.294284 122.936613 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.437895 118.402306 \n",
       "L 634.437895 117.368733 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.42922 88.709512 \n",
       "L 665.42922 87.980828 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.061949 95.363566 \n",
       "L 659.061949 94.549223 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.779054 80.535381 \n",
       "L 677.779054 79.250867 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.049287 103.251214 \n",
       "L 650.049287 101.259398 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.722342 122.630905 \n",
       "L 629.722342 121.838331 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 580.359625 165.132532 \n",
       "L 580.359625 163.091104 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 632.703447 119.679335 \n",
       "L 632.703447 118.759033 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.01715 80.381488 \n",
       "L 674.01715 79.854054 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.032884 96.695468 \n",
       "L 658.032884 95.684857 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.043809 87.156035 \n",
       "L 668.043809 86.229503 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.297953 136.94662 \n",
       "L 616.297953 135.712377 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 594.728486 154.485224 \n",
       "L 594.728486 153.592856 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.87502 93.345794 \n",
       "L 660.87502 92.363396 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 610.430922 140.631323 \n",
       "L 610.430922 139.678646 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 616.585823 134.279304 \n",
       "L 616.585823 133.601869 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 612.314907 138.122358 \n",
       "L 612.314907 136.644653 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 625.943268 126.813246 \n",
       "L 625.943268 124.221176 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.846751 96.921299 \n",
       "L 658.846751 96.301475 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 654.090458 99.427272 \n",
       "L 654.090458 99.098999 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.224274 104.811859 \n",
       "L 649.224274 103.606238 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 634.458973 119.286461 \n",
       "L 634.458973 117.893628 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.652869 144.830531 \n",
       "L 608.652869 142.383198 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 644.231603 109.849539 \n",
       "L 644.231603 108.50705 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 606.028835 144.124093 \n",
       "L 606.028835 142.895532 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.428631 115.979986 \n",
       "L 636.428631 114.509985 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 697.935878 62.04988 \n",
       "L 697.935878 60.500097 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.158965 99.584492 \n",
       "L 658.158965 96.210165 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 662.127135 91.975744 \n",
       "L 662.127135 91.118777 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 647.984007 105.537802 \n",
       "L 647.984007 104.083826 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.54218 86.138286 \n",
       "L 670.54218 84.597585 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 633.311855 119.011566 \n",
       "L 633.311855 117.580451 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.960814 168.73336 \n",
       "L 577.960814 166.855725 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.664207 84.80667 \n",
       "L 670.664207 83.310056 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 596.154338 152.382294 \n",
       "L 596.154338 151.468039 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.155241 132.663637 \n",
       "L 621.155241 131.025351 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.983467 70.062666 \n",
       "L 691.983467 68.044833 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.253978 124.952092 \n",
       "L 628.253978 122.887265 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.249889 86.06458 \n",
       "L 670.249889 84.563578 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 663.596535 91.8975 \n",
       "L 663.596535 91.269426 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.198637 116.360292 \n",
       "L 636.198637 115.825844 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 613.127251 135.971755 \n",
       "L 613.127251 135.353423 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 607.772709 140.084677 \n",
       "L 607.772709 138.170808 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 643.646147 109.104628 \n",
       "L 643.646147 107.24979 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 677.383673 79.898997 \n",
       "L 677.383673 79.218157 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.026799 94.465048 \n",
       "L 659.026799 92.655175 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 653.657188 99.184548 \n",
       "L 653.657188 96.986531 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 579.292435 167.125023 \n",
       "L 579.292435 166.043542 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.169171 83.036056 \n",
       "L 673.169171 81.455074 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.635634 126.503491 \n",
       "L 624.635634 125.520214 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.438963 103.203331 \n",
       "L 651.438963 102.454975 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.81781 77.227939 \n",
       "L 679.81781 75.64929 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 686.232817 70.285265 \n",
       "L 686.232817 68.289732 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.395234 88.315626 \n",
       "L 666.395234 87.788799 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 691.576861 69.473028 \n",
       "L 691.576861 66.951656 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 665.240519 90.095837 \n",
       "L 665.240519 89.605471 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 608.964293 142.123574 \n",
       "L 608.964293 141.009661 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 628.014242 124.423051 \n",
       "L 628.014242 123.725151 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.34274 115.43331 \n",
       "L 638.34274 114.541993 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 658.038295 97.137918 \n",
       "L 658.038295 95.763912 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.069817 164.359418 \n",
       "L 582.069817 162.889983 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.345068 82.673458 \n",
       "L 674.345068 81.910354 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.739767 130.359385 \n",
       "L 620.739767 128.596936 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 676.661844 81.92742 \n",
       "L 676.661844 79.883806 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 635.1973 117.394904 \n",
       "L 635.1973 116.136268 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 682.606502 75.290782 \n",
       "L 682.606502 73.365433 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 641.186202 112.670917 \n",
       "L 641.186202 111.980783 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 588.250958 160.499769 \n",
       "L 588.250958 158.870738 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 673.260322 82.622151 \n",
       "L 673.260322 81.928831 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 582.518906 166.51267 \n",
       "L 582.518906 164.247251 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 657.88709 97.719032 \n",
       "L 657.88709 95.989411 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 619.845983 133.367039 \n",
       "L 619.845983 131.413352 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 642.153036 116.151742 \n",
       "L 642.153036 113.985718 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 668.455286 87.650969 \n",
       "L 668.455286 85.788443 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 679.447484 77.704659 \n",
       "L 679.447484 76.681674 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.828483 102.398983 \n",
       "L 650.828483 101.625171 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 603.590269 145.067296 \n",
       "L 603.590269 144.654362 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.467261 121.676979 \n",
       "L 629.467261 120.893632 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 670.667358 84.637049 \n",
       "L 670.667358 83.634152 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 600.579594 148.977886 \n",
       "L 600.579594 147.662893 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 624.722638 126.670962 \n",
       "L 624.722638 126.03584 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 621.756023 129.631223 \n",
       "L 621.756023 128.549328 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.936171 76.605338 \n",
       "L 680.936171 73.735677 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 629.61181 124.255111 \n",
       "L 629.61181 123.169656 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 651.294001 103.162827 \n",
       "L 651.294001 102.682254 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 667.552353 88.125343 \n",
       "L 667.552353 87.306158 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.3831 163.909708 \n",
       "L 584.3831 162.303925 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 649.023939 103.520729 \n",
       "L 649.023939 102.640508 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 638.826324 113.567933 \n",
       "L 638.826324 112.940236 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 614.21189 137.537653 \n",
       "L 614.21189 135.603798 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 680.605314 79.310182 \n",
       "L 680.605314 77.952662 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 584.742022 162.931648 \n",
       "L 584.742022 161.419704 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 659.828463 94.849298 \n",
       "L 659.828463 93.948309 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 674.72873 82.670939 \n",
       "L 674.72873 81.173035 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.907343 95.302919 \n",
       "L 660.907343 94.477563 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 620.922798 130.458694 \n",
       "L 620.922798 129.522695 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 587.169557 161.923905 \n",
       "L 587.169557 159.928655 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 604.812732 144.649906 \n",
       "L 604.812732 143.607577 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 669.86832 86.091996 \n",
       "L 669.86832 85.013281 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 577.411013 173.413219 \n",
       "L 577.411013 169.396835 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 650.58906 102.462463 \n",
       "L 650.58906 101.289023 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 636.37158 114.695204 \n",
       "L 636.37158 113.525672 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 666.731171 90.560341 \n",
       "L 666.731171 88.9562 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "    <path d=\"M 660.143437 93.582975 \n",
       "L 660.143437 89.821238 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #1f77b4; stroke-opacity: 0.3; stroke-width: 0.1\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_44\">\n",
       "    <g clip-path=\"url(#p2e81996491)\">\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"656.146795\" y=\"99.459757\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"595.48217\" y=\"151.734421\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.324019\" y=\"164.279441\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"634.415388\" y=\"117.159367\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.29959\" y=\"70.73747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"575.680974\" y=\"168.855562\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"685.238566\" y=\"71.454336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"603.130047\" y=\"145.08815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"635.092255\" y=\"116.267392\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.726024\" y=\"135.46541\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"634.188336\" y=\"117.286625\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"605.503972\" y=\"143.544789\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"684.819473\" y=\"70.346416\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"662.530229\" y=\"93.299693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"679.211419\" y=\"75.862308\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"640.154561\" y=\"113.451502\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.02011\" y=\"120.286075\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"596.65892\" y=\"152.600144\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"671.592897\" y=\"82.362198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"676.170207\" y=\"78.924375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"600.743323\" y=\"147.22362\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.754822\" y=\"126.48566\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"599.816823\" y=\"148.983003\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"599.161106\" y=\"148.308731\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"690.348036\" y=\"68.133633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.253663\" y=\"94.868808\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"640.941517\" y=\"111.158558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"597.944615\" y=\"150.479496\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"669.779657\" y=\"85.921186\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"691.309655\" y=\"68.585434\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"652.247993\" y=\"101.836867\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.623513\" y=\"117.423567\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"602.443445\" y=\"147.336333\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"689.397744\" y=\"65.17109\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"600.253411\" y=\"148.401787\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"601.344921\" y=\"148.56743\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"673.107494\" y=\"81.32025\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"664.300063\" y=\"90.768803\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"682.831813\" y=\"77.280272\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"594.607889\" y=\"155.188697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.22215\" y=\"96.140415\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.904818\" y=\"125.939685\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"610.985773\" y=\"137.876955\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"684.818004\" y=\"72.636282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"607.861036\" y=\"143.440384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.881738\" y=\"85.481691\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"651.047553\" y=\"103.550574\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"645.484811\" y=\"108.04366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"655.490134\" y=\"99.183286\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"577.321766\" y=\"171.450273\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.462956\" y=\"97.208466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.736618\" y=\"86.3253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"579.261488\" y=\"165.443433\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.761738\" y=\"70.675611\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.727369\" y=\"134.600244\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"641.052233\" y=\"112.318806\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"590.083815\" y=\"158.129336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"653.499433\" y=\"100.014416\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"619.610931\" y=\"129.953795\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"612.885814\" y=\"137.556245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.023442\" y=\"103.791008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.327018\" y=\"126.432151\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"646.290372\" y=\"106.81116\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"664.320362\" y=\"91.448366\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"576.711155\" y=\"170.552469\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"622.754314\" y=\"129.06236\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"689.747189\" y=\"67.332316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"660.960165\" y=\"94.298253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.553998\" y=\"96.423892\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"615.864856\" y=\"134.310698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"606.276496\" y=\"143.882761\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"673.307253\" y=\"81.852207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"672.449252\" y=\"82.910207\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.86425\" y=\"76.773654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.059781\" y=\"72.405974\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"665.12333\" y=\"88.648133\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"675.657032\" y=\"80.493564\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"608.64879\" y=\"140.402523\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"628.271845\" y=\"122.397191\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"601.43623\" y=\"147.020113\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.743967\" y=\"77.496864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.841929\" y=\"114.420431\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"583.721451\" y=\"163.064454\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"654.733755\" y=\"97.284037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"665.078659\" y=\"89.184264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"646.389927\" y=\"106.961005\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"595.2724\" y=\"154.198516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"667.465116\" y=\"86.98615\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"578.092633\" y=\"168.979489\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"588.073922\" y=\"160.167466\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.928114\" y=\"95.612633\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"669.203425\" y=\"85.935141\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.4197\" y=\"125.49923\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"653.168243\" y=\"99.847927\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"696.882413\" y=\"60.9164\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"618.693345\" y=\"133.440265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"654.311718\" y=\"100.030307\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"583.982723\" y=\"163.618413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"597.624469\" y=\"151.479071\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.913997\" y=\"128.788081\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.527941\" y=\"118.617343\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"604.698115\" y=\"143.599718\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"610.214437\" y=\"139.763822\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"623.953107\" y=\"127.354244\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"639.701606\" y=\"112.74238\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"646.113135\" y=\"107.712805\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"610.506456\" y=\"139.410756\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"674.722207\" y=\"79.956451\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"663.527394\" y=\"91.367557\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"697.047527\" y=\"57.878875\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"639.995597\" y=\"113.893066\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"595.001827\" y=\"153.265656\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"602.50009\" y=\"146.271749\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.174955\" y=\"119.329906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.390931\" y=\"87.528278\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"654.882568\" y=\"98.358676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"613.221944\" y=\"137.064038\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"647.544984\" y=\"104.740167\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"646.541067\" y=\"106.749862\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"683.354533\" y=\"73.249073\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"592.2851\" y=\"158.093842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"630.881997\" y=\"120.018522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"586.41054\" y=\"160.124233\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"677.54378\" y=\"78.381853\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"618.444891\" y=\"131.929966\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"598.807369\" y=\"150.333964\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.576338\" y=\"96.07522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"600.547189\" y=\"147.456375\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"615.121507\" y=\"136.710519\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"664.359504\" y=\"92.39815\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.573702\" y=\"89.4217\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"674.685804\" y=\"80.87746\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"607.471225\" y=\"142.406036\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.60974\" y=\"89.18057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"647.439987\" y=\"106.282071\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"609.812232\" y=\"140.738965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"665.316244\" y=\"89.204397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"596.787312\" y=\"152.161014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"592.132747\" y=\"155.62798\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"646.992957\" y=\"106.316884\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.79239\" y=\"103.000868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"693.919426\" y=\"65.057774\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.661095\" y=\"167.683247\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"689.64438\" y=\"67.435971\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"593.810451\" y=\"155.069098\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"608.500152\" y=\"141.449512\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"655.398488\" y=\"97.904249\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"692.152479\" y=\"63.63942\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"611.96648\" y=\"138.414856\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"674.553474\" y=\"85.10259\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"648.077481\" y=\"104.688168\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"681.761461\" y=\"73.403176\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"640.148392\" y=\"112.220816\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"621.198081\" y=\"130.686318\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"643.724411\" y=\"108.494976\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"643.286278\" y=\"108.435384\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"644.792937\" y=\"108.137841\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"692.917916\" y=\"63.555277\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.860242\" y=\"163.083047\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.688687\" y=\"168.187075\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"607.1699\" y=\"145.045069\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"645.34371\" y=\"108.838898\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"672.041137\" y=\"83.836342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"641.546682\" y=\"112.939129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"648.413451\" y=\"104.600085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.285892\" y=\"73.668847\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"660.343051\" y=\"97.170844\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"635.504104\" y=\"116.296704\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"587.000496\" y=\"160.510075\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"687.390779\" y=\"70.219838\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.822669\" y=\"77.275435\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.03401\" y=\"116.655218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"654.483413\" y=\"97.568391\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"641.498359\" y=\"111.804513\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.057353\" y=\"71.343379\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"603.70002\" y=\"146.617486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"587.085446\" y=\"158.781161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"582.238411\" y=\"164.982683\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"609.405482\" y=\"140.746223\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"659.671024\" y=\"93.807198\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"659.274497\" y=\"92.672371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"680.114497\" y=\"78.975705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"611.34575\" y=\"140.76817\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"615.055614\" y=\"136.913258\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"612.17148\" y=\"137.88164\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"626.795815\" y=\"124.433837\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"591.613068\" y=\"160.61957\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"602.27237\" y=\"146.995936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.760785\" y=\"113.1516\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"662.344751\" y=\"91.340216\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.356713\" y=\"97.08394\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"647.74411\" y=\"105.040354\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"672.971609\" y=\"85.229846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"600.848469\" y=\"146.389057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.549335\" y=\"167.654135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"597.6751\" y=\"152.185134\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"653.565692\" y=\"99.953733\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.520995\" y=\"85.809747\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"648.633612\" y=\"104.263265\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.884649\" y=\"126.438311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.630588\" y=\"70.941993\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.071109\" y=\"104.63742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"579.258861\" y=\"168.545021\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"653.499877\" y=\"99.652064\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"634.354927\" y=\"117.248148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.115789\" y=\"90.377932\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"671.360057\" y=\"82.384783\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"620.864866\" y=\"129.056298\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"683.940857\" y=\"72.758616\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.827511\" y=\"125.142682\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.945335\" y=\"162.290037\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.460358\" y=\"116.832949\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"671.217634\" y=\"84.321907\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"672.786804\" y=\"81.110287\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"628.302394\" y=\"122.607759\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.124004\" y=\"95.841262\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"590.938487\" y=\"157.081424\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"685.541363\" y=\"68.452965\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.961966\" y=\"136.676239\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"693.237795\" y=\"64.868908\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.242135\" y=\"88.775123\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.25677\" y=\"89.631335\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"679.683567\" y=\"76.365155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.329542\" y=\"103.349556\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"621.202658\" y=\"130.943202\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.665692\" y=\"163.97639\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"601.183682\" y=\"146.84229\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"685.870349\" y=\"68.320227\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.584299\" y=\"133.151973\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"595.549133\" y=\"152.654953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"635.209683\" y=\"115.679245\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.47737\" y=\"94.738161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"615.20855\" y=\"134.798371\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"620.943831\" y=\"130.014854\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.84248\" y=\"167.821567\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"684.017034\" y=\"71.940011\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.087059\" y=\"89.443412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.343657\" y=\"118.578694\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"677.976574\" y=\"79.629858\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"585.246616\" y=\"162.035636\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"581.843603\" y=\"163.81172\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.586823\" y=\"135.796411\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"637.517601\" y=\"115.679003\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"607.636712\" y=\"141.959998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.619392\" y=\"76.792689\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"664.599933\" y=\"90.489602\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"610.296844\" y=\"138.804341\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.388536\" y=\"136.576149\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"619.138274\" y=\"130.605858\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"694.425389\" y=\"67.492953\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"603.319146\" y=\"146.036111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"597.64112\" y=\"151.52764\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"652.449018\" y=\"101.462058\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.920725\" y=\"133.18008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"627.051346\" y=\"125.413148\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"595.709613\" y=\"153.319471\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.506981\" y=\"96.946084\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"642.359736\" y=\"108.695643\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"645.143731\" y=\"108.255877\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"661.210714\" y=\"92.718129\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"635.034531\" y=\"117.05855\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"661.218786\" y=\"93.75714\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"579.938124\" y=\"168.202023\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.569141\" y=\"103.002111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"639.210976\" y=\"112.955885\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"589.8487\" y=\"158.596167\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"647.02041\" y=\"106.575942\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"655.576141\" y=\"99.847532\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"598.569124\" y=\"149.147412\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"643.235273\" y=\"110.033878\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"659.410879\" y=\"95.36393\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"656.272397\" y=\"99.154143\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"594.870033\" y=\"155.613014\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"596.542623\" y=\"152.260819\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.612575\" y=\"115.325418\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"582.370973\" y=\"164.730921\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.538395\" y=\"76.949264\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"656.299771\" y=\"97.097734\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.618468\" y=\"85.089283\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.641269\" y=\"83.396028\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"594.398122\" y=\"154.544172\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"676.060991\" y=\"77.974973\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"661.830827\" y=\"94.509235\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"600.506953\" y=\"148.907349\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"651.641153\" y=\"102.522649\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"604.668591\" y=\"144.084389\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"663.479958\" y=\"91.294353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"647.887887\" y=\"105.490226\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.579218\" y=\"125.731251\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"680.566576\" y=\"78.621751\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"639.042219\" y=\"113.640225\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"673.803297\" y=\"84.698846\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"677.037002\" y=\"78.528347\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"648.816827\" y=\"103.56353\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"601.28374\" y=\"147.437955\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"627.497438\" y=\"123.198087\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"640.042148\" y=\"110.988858\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"586.751252\" y=\"160.774871\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"669.526104\" y=\"83.476758\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"582.759122\" y=\"165.594707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"607.410193\" y=\"144.431336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"603.877745\" y=\"145.860055\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.926306\" y=\"84.592057\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"690.111916\" y=\"65.490536\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.947641\" y=\"125.212827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.982328\" y=\"83.842003\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"622.833139\" y=\"128.011545\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.021568\" y=\"86.845693\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"645.471316\" y=\"107.249705\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"642.736359\" y=\"110.037558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.290042\" y=\"162.947336\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"631.007004\" y=\"122.391312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.437718\" y=\"69.548827\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"637.040669\" y=\"116.432558\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.146366\" y=\"89.416911\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"682.963102\" y=\"75.209397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"622.125596\" y=\"128.462135\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.551371\" y=\"135.460113\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.384899\" y=\"104.566316\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"688.767387\" y=\"68.490334\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"642.166483\" y=\"110.795864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"671.078468\" y=\"84.11732\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"627.902711\" y=\"124.353522\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"608.407539\" y=\"141.473717\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"629.887382\" y=\"122.626146\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"652.011265\" y=\"100.857538\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"598.299893\" y=\"150.097284\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"680.786068\" y=\"76.768032\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"663.799254\" y=\"91.000039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"595.548555\" y=\"154.354674\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"691.048364\" y=\"69.55499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"639.271103\" y=\"113.889641\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"592.028418\" y=\"154.439597\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"610.636555\" y=\"139.170553\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"577.844641\" y=\"167.156842\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"637.125034\" y=\"114.613648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"618.923814\" y=\"133.022697\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.376925\" y=\"127.169675\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"630.254003\" y=\"124.142742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.626974\" y=\"133.277355\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"681.185491\" y=\"76.457578\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.97143\" y=\"118.095074\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"596.20092\" y=\"151.703769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"672.878067\" y=\"82.216326\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"582.216548\" y=\"167.277311\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"613.543414\" y=\"137.333312\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"596.47732\" y=\"150.606832\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"690.283249\" y=\"68.643078\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"690.931897\" y=\"67.964155\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.591508\" y=\"88.218938\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"629.892247\" y=\"121.786998\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.211191\" y=\"165.394224\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.709102\" y=\"133.078913\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"583.454919\" y=\"164.308781\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"681.958956\" y=\"74.465984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"669.642597\" y=\"85.379914\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.420374\" y=\"76.349235\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"643.191378\" y=\"109.956716\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"581.430907\" y=\"165.332583\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.047378\" y=\"89.993459\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.775782\" y=\"161.354648\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"641.116481\" y=\"111.917067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"684.319602\" y=\"72.498321\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"603.569975\" y=\"143.438605\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"589.21515\" y=\"159.046147\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"602.487822\" y=\"147.204868\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.557479\" y=\"125.834866\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.826928\" y=\"132.693218\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"663.340359\" y=\"90.769413\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"597.444175\" y=\"149.573126\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"593.406115\" y=\"153.863486\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"667.618574\" y=\"86.383956\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"678.675025\" y=\"76.529105\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"626.494744\" y=\"126.975195\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"656.498115\" y=\"97.851437\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"685.408064\" y=\"73.70707\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"631.022273\" y=\"120.935852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.733092\" y=\"126.060787\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"639.021769\" y=\"112.676665\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.790519\" y=\"119.944183\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"612.155878\" y=\"137.87035\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.340552\" y=\"115.963397\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.040516\" y=\"135.066807\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"650.008004\" y=\"103.290568\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"682.98744\" y=\"73.70739\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"638.033484\" y=\"114.774395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"655.109944\" y=\"98.107996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"641.955731\" y=\"109.386839\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.643762\" y=\"105.759518\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"597.975015\" y=\"150.339457\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"660.940737\" y=\"94.324403\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.625846\" y=\"115.458698\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"682.395263\" y=\"75.059809\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.864671\" y=\"125.473621\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"592.629994\" y=\"158.30136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"628.294284\" y=\"123.667067\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"634.437895\" y=\"117.88552\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"665.42922\" y=\"88.34517\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"659.061949\" y=\"94.956395\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"677.779054\" y=\"79.893124\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"650.049287\" y=\"102.255306\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"629.722342\" y=\"122.234618\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"580.359625\" y=\"164.111818\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"632.703447\" y=\"119.219184\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"674.01715\" y=\"80.117771\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.032884\" y=\"96.190163\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.043809\" y=\"86.692769\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.297953\" y=\"136.329499\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"594.728486\" y=\"154.03904\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"660.87502\" y=\"92.854595\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"610.430922\" y=\"140.154984\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"616.585823\" y=\"133.940587\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"612.314907\" y=\"137.383506\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"625.943268\" y=\"125.517211\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.846751\" y=\"96.611387\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"654.090458\" y=\"99.263136\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.224274\" y=\"104.209048\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"634.458973\" y=\"118.590045\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"608.652869\" y=\"143.606864\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"644.231603\" y=\"109.178295\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"606.028835\" y=\"143.509813\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.428631\" y=\"115.244986\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"697.935878\" y=\"61.274988\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.158965\" y=\"97.897329\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"662.127135\" y=\"91.54726\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"647.984007\" y=\"104.810814\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.54218\" y=\"85.367936\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"633.311855\" y=\"118.296008\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"577.960814\" y=\"167.794543\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.664207\" y=\"84.058363\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"596.154338\" y=\"151.925167\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"621.155241\" y=\"131.844494\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"691.983467\" y=\"69.053749\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"628.253978\" y=\"123.919679\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.249889\" y=\"85.314079\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"663.596535\" y=\"91.583463\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.198637\" y=\"116.093068\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"613.127251\" y=\"135.662589\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"607.772709\" y=\"139.127742\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"643.646147\" y=\"108.177209\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"677.383673\" y=\"79.558577\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"659.026799\" y=\"93.560111\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"653.657188\" y=\"98.08554\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"579.292435\" y=\"166.584282\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"673.169171\" y=\"82.245565\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.635634\" y=\"126.011852\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"651.438963\" y=\"102.829153\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"679.81781\" y=\"76.438614\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"686.232817\" y=\"69.287498\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.395234\" y=\"88.052213\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"691.576861\" y=\"68.212342\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"665.240519\" y=\"89.850654\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"608.964293\" y=\"141.566618\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"628.014242\" y=\"124.074101\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"638.34274\" y=\"114.987652\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"658.038295\" y=\"96.450915\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"582.069817\" y=\"163.6247\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"674.345068\" y=\"82.291906\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"620.739767\" y=\"129.478161\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"676.661844\" y=\"80.905613\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"635.1973\" y=\"116.765586\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"682.606502\" y=\"74.328108\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"641.186202\" y=\"112.32585\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"588.250958\" y=\"159.685253\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"673.260322\" y=\"82.275491\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"582.518906\" y=\"165.37996\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"657.88709\" y=\"96.854221\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"619.845983\" y=\"132.390196\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"642.153036\" y=\"115.06873\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"668.455286\" y=\"86.719706\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"679.447484\" y=\"77.193166\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"650.828483\" y=\"102.012077\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"603.590269\" y=\"144.860829\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"629.467261\" y=\"121.285306\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"670.667358\" y=\"84.135601\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"600.579594\" y=\"148.32039\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"624.722638\" y=\"126.353401\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"621.756023\" y=\"129.090276\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"680.936171\" y=\"75.170508\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"629.61181\" y=\"123.712383\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"651.294001\" y=\"102.92254\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"667.552353\" y=\"87.71575\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.3831\" y=\"163.106816\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"649.023939\" y=\"103.080619\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"638.826324\" y=\"113.254085\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"614.21189\" y=\"136.570726\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"680.605314\" y=\"78.631422\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"584.742022\" y=\"162.175676\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"659.828463\" y=\"94.398804\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"674.72873\" y=\"81.921987\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"660.907343\" y=\"94.890241\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"620.922798\" y=\"129.990694\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"587.169557\" y=\"160.92628\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"604.812732\" y=\"144.128741\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"669.86832\" y=\"85.552639\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"577.411013\" y=\"171.405027\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"650.58906\" y=\"101.875743\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"636.37158\" y=\"114.110438\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"666.731171\" y=\"89.758271\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "     <use xlink:href=\"#mbf7c8a7f08\" x=\"660.143437\" y=\"91.702106\" style=\"fill: #1f77b4; fill-opacity: 0.3; stroke: #1f77b4; stroke-opacity: 0.3\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 566.456031 173.471765 \n",
       "L 566.456031 55.312015 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 572.912438 179.384625 \n",
       "L 702.984348 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_46\">\n",
       "    <!-- RMSE: 0.041 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(573.45643 63.972112) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-52\"/>\n",
       "     <use xlink:href=\"#ArialMT-4d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-53\" x=\"155.517578\"/>\n",
       "     <use xlink:href=\"#ArialMT-45\" x=\"222.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-3a\" x=\"288.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"316.699219\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"344.482422\"/>\n",
       "     <use xlink:href=\"#ArialMT-2e\" x=\"400.097656\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"427.880859\"/>\n",
       "     <use xlink:href=\"#ArialMT-34\" x=\"483.496094\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"539.111328\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"text_47\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(574.561766 45.1485) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_45\">\n",
       "    <path d=\"M 617.066134 133.361723 \n",
       "L 700.100001 57.932209 \n",
       "L 572.82003 173.55571 \n",
       "L 682.24514 74.151898 \n",
       "\" clip-path=\"url(#p2e81996491)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_48\">\n",
       "   <!-- Validation with test data -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(272.93075 18.6525) scale(0.16 -0.16)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-56\" d=\"M 1803 0 \n",
       "L 28 4581 \n",
       "L 684 4581 \n",
       "L 1875 1253 \n",
       "Q 2019 853 2116 503 \n",
       "Q 2222 878 2363 1253 \n",
       "L 3600 4581 \n",
       "L 4219 4581 \n",
       "L 2425 0 \n",
       "L 1803 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-77\" d=\"M 1034 0 \n",
       "L 19 3319 \n",
       "L 600 3319 \n",
       "L 1128 1403 \n",
       "L 1325 691 \n",
       "Q 1338 744 1497 1375 \n",
       "L 2025 3319 \n",
       "L 2603 3319 \n",
       "L 3100 1394 \n",
       "L 3266 759 \n",
       "L 3456 1400 \n",
       "L 4025 3319 \n",
       "L 4572 3319 \n",
       "L 3534 0 \n",
       "L 2950 0 \n",
       "L 2422 1988 \n",
       "L 2294 2553 \n",
       "L 1622 0 \n",
       "L 1034 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-68\" d=\"M 422 0 \n",
       "L 422 4581 \n",
       "L 984 4581 \n",
       "L 984 2938 \n",
       "Q 1378 3394 1978 3394 \n",
       "Q 2347 3394 2619 3248 \n",
       "Q 2891 3103 3008 2847 \n",
       "Q 3125 2591 3125 2103 \n",
       "L 3125 0 \n",
       "L 2563 0 \n",
       "L 2563 2103 \n",
       "Q 2563 2525 2380 2717 \n",
       "Q 2197 2909 1863 2909 \n",
       "Q 1613 2909 1392 2779 \n",
       "Q 1172 2650 1078 2428 \n",
       "Q 984 2206 984 1816 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-56\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"59.324219\"/>\n",
       "    <use xlink:href=\"#ArialMT-6c\" x=\"114.939453\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"137.15625\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"159.373047\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"214.988281\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"270.603516\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"298.386719\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"320.603516\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"376.21875\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"431.833984\"/>\n",
       "    <use xlink:href=\"#ArialMT-77\" x=\"459.617188\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"531.833984\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"554.050781\"/>\n",
       "    <use xlink:href=\"#ArialMT-68\" x=\"581.833984\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"637.449219\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"665.232422\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"693.015625\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"748.630859\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"798.630859\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"826.414062\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"854.197266\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"909.8125\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"965.427734\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"993.210938\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p45d028abef\">\n",
       "   <rect x=\"38.312875\" y=\"51.1485\" width=\"140.007969\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pab1a286812\">\n",
       "   <rect x=\"214.360594\" y=\"51.1485\" width=\"140.007969\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pbd6ccea723\">\n",
       "   <rect x=\"390.408312\" y=\"51.1485\" width=\"140.007969\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p2e81996491\">\n",
       "   <rect x=\"566.456031\" y=\"51.1485\" width=\"140.007969\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1000x300 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "rmse = lambda y, y_hat: jnp.sqrt(jnp.mean((y - y_hat)**2))\n",
    "\n",
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(10, 3), tight_layout=True)\n",
    "fig.suptitle('Verification with training data', fontsize=16)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].errorbar(y_train_scaled[:1000, i], means_train[:, i], yerr=2 * stdevs_train[:, i], fmt='o', ms=2, alpha=0.3, lw=0.1)\n",
    "    ax[i].plot(datasets[o_name].y, datasets[o_name].y, \"r-\", lw=0.5, zorder=100)\n",
    "    ax[i].annotate(f\"RMSE: {rmse(y_train_scaled[:1000, i], means_train[:, i]):.3f}\", xy=(0.05, 0.9), xycoords='axes fraction')\n",
    "    ax[i].set_title(o_name)\n",
    "    sns.despine(trim=True, ax=ax[i])\n",
    "ax[0].set_xlabel('True')\n",
    "ax[0].set_ylabel('Predicted')\n",
    "\n",
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(10, 3), tight_layout=True)\n",
    "fig.suptitle('Validation with test data', fontsize=16)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].errorbar(y_test_scaled[:, i], means_test[:, i], yerr=2 * stdevs_test[:, i], fmt='o', ms=2, alpha=0.3, lw=0.1)\n",
    "    ax[i].plot(datasets[o_name].y, datasets[o_name].y, \"r-\", lw=0.5, zorder=100)\n",
    "    ax[i].annotate(f\"RMSE: {rmse(y_test_scaled[:, i], means_test[:, i]):.3f}\", xy=(0.05, 0.9), xycoords='axes fraction')\n",
    "    ax[i].set_title(o_name)\n",
    "    sns.despine(trim=True, ax=ax[i])\n",
    "ax[0].set_xlabel('True')\n",
    "ax[0].set_ylabel('Predicted');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "As expected, we've fit the training data perfectly (all points lie on the red line). However, we mostly care about how well we predict unseen (test) data. The root mean square error (RSME) along with the parity plots show that some outputs are predicted better than others.\n",
    "\n",
    "For GPs, parity plots and RSME values are good for checking if our predictive *mean* function is correct. However, they do not say anything about whether our *uncertainty* estimates are correct. For that, we must look at the standardized errors.\n",
    "\n",
    "### Standardized errors\n",
    "\n",
    "For the $i^\\text{th}$ test data point, the *standardized error* $e_i$ is\n",
    "\n",
    "$$\n",
    "e_i = \\frac{y_i - m(x_i)}{\\sigma(x_i)}\n",
    "$$\n",
    "\n",
    "where $y_i$ is the true output, and $m(x_i)$ and $\\sigma(x_i)$ are the mean and standard deviation of the prediction, respectively."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "metadata": {},
   "outputs": [],
   "source": [
    "standardized_errors = (y_test_scaled - means_test) / stdevs_test"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's use these standardized errors to validate the GP's uncertainty estimates.\n",
    "\n",
    "#### Error histogram\n",
    "\n",
    "The basic GP model (which is what we have) assumes normally distributed errors. Let's check this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 24,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"713.664pt\" height=\"215.712pt\" viewBox=\"0 0 713.664 215.712\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:39.237758</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 215.712 \n",
       "L 713.664 215.712 \n",
       "L 713.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 7.2 192.164125 \n",
       "L 174.24 192.164125 \n",
       "L 174.24 51.1485 \n",
       "L 7.2 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m293f33ce49\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"83.499705\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(81.052893 206.763) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"163.506057\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(158.612432 206.763) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 14.792727 192.164125 \n",
       "L 22.385455 192.164125 \n",
       "L 22.385455 186.059552 \n",
       "L 14.792727 186.059552 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 22.385455 192.164125 \n",
       "L 29.978182 192.164125 \n",
       "L 29.978182 183.007266 \n",
       "L 22.385455 183.007266 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 29.978182 192.164125 \n",
       "L 37.570909 192.164125 \n",
       "L 37.570909 183.007266 \n",
       "L 29.978182 183.007266 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 37.570909 192.164125 \n",
       "L 45.163636 192.164125 \n",
       "L 45.163636 176.902694 \n",
       "L 37.570909 176.902694 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 45.163636 192.164125 \n",
       "L 52.756364 192.164125 \n",
       "L 52.756364 178.428837 \n",
       "L 45.163636 178.428837 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 52.756364 192.164125 \n",
       "L 60.349091 192.164125 \n",
       "L 60.349091 167.745835 \n",
       "L 52.756364 167.745835 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 60.349091 192.164125 \n",
       "L 67.941818 192.164125 \n",
       "L 67.941818 118.909255 \n",
       "L 60.349091 118.909255 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 67.941818 192.164125 \n",
       "L 75.534545 192.164125 \n",
       "L 75.534545 76.177247 \n",
       "L 67.941818 76.177247 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 75.534545 192.164125 \n",
       "L 83.127273 192.164125 \n",
       "L 83.127273 57.86353 \n",
       "L 75.534545 57.86353 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 83.127273 192.164125 \n",
       "L 90.72 192.164125 \n",
       "L 90.72 60.915816 \n",
       "L 83.127273 60.915816 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 90.72 192.164125 \n",
       "L 98.312727 192.164125 \n",
       "L 98.312727 96.017108 \n",
       "L 90.72 96.017108 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 98.312727 192.164125 \n",
       "L 105.905455 192.164125 \n",
       "L 105.905455 131.1184 \n",
       "L 98.312727 131.1184 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 105.905455 192.164125 \n",
       "L 113.498182 192.164125 \n",
       "L 113.498182 155.53669 \n",
       "L 105.905455 155.53669 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 113.498182 192.164125 \n",
       "L 121.090909 192.164125 \n",
       "L 121.090909 170.798121 \n",
       "L 113.498182 170.798121 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 121.090909 192.164125 \n",
       "L 128.683636 192.164125 \n",
       "L 128.683636 187.585696 \n",
       "L 121.090909 187.585696 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path d=\"M 128.683636 192.164125 \n",
       "L 136.276364 192.164125 \n",
       "L 136.276364 187.585696 \n",
       "L 128.683636 187.585696 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path d=\"M 136.276364 192.164125 \n",
       "L 143.869091 192.164125 \n",
       "L 143.869091 192.164125 \n",
       "L 136.276364 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_20\">\n",
       "    <path d=\"M 143.869091 192.164125 \n",
       "L 151.461818 192.164125 \n",
       "L 151.461818 190.637982 \n",
       "L 143.869091 190.637982 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_21\">\n",
       "    <path d=\"M 151.461818 192.164125 \n",
       "L 159.054545 192.164125 \n",
       "L 159.054545 190.637982 \n",
       "L 151.461818 190.637982 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_22\">\n",
       "    <path d=\"M 159.054545 192.164125 \n",
       "L 166.647273 192.164125 \n",
       "L 166.647273 189.111839 \n",
       "L 159.054545 189.111839 \n",
       "z\n",
       "\" clip-path=\"url(#paec8eba238)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_23\">\n",
       "    <path d=\"M 83.499705 192.164125 \n",
       "L 163.506057 192.164125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_3\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(38.69025 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_24\">\n",
       "    <path d=\"M 184.608 192.164125 \n",
       "L 351.648 192.164125 \n",
       "L 351.648 51.1485 \n",
       "L 184.608 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"217.918941\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- −20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(210.455441 206.763) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"267.890425\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(265.443613 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"317.861909\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(312.968284 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\"/>\n",
       "   <g id=\"patch_25\">\n",
       "    <path d=\"M 192.200727 192.164125 \n",
       "L 199.793455 192.164125 \n",
       "L 199.793455 190.62044 \n",
       "L 192.200727 190.62044 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_26\">\n",
       "    <path d=\"M 199.793455 192.164125 \n",
       "L 207.386182 192.164125 \n",
       "L 207.386182 192.164125 \n",
       "L 199.793455 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_27\">\n",
       "    <path d=\"M 207.386182 192.164125 \n",
       "L 214.978909 192.164125 \n",
       "L 214.978909 191.392282 \n",
       "L 207.386182 191.392282 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_28\">\n",
       "    <path d=\"M 214.978909 192.164125 \n",
       "L 222.571636 192.164125 \n",
       "L 222.571636 191.392282 \n",
       "L 214.978909 191.392282 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_29\">\n",
       "    <path d=\"M 222.571636 192.164125 \n",
       "L 230.164364 192.164125 \n",
       "L 230.164364 189.076755 \n",
       "L 222.571636 189.076755 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_30\">\n",
       "    <path d=\"M 230.164364 192.164125 \n",
       "L 237.757091 192.164125 \n",
       "L 237.757091 190.62044 \n",
       "L 230.164364 190.62044 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_31\">\n",
       "    <path d=\"M 237.757091 192.164125 \n",
       "L 245.349818 192.164125 \n",
       "L 245.349818 187.53307 \n",
       "L 237.757091 187.53307 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_32\">\n",
       "    <path d=\"M 245.349818 192.164125 \n",
       "L 252.942545 192.164125 \n",
       "L 252.942545 182.902015 \n",
       "L 245.349818 182.902015 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_33\">\n",
       "    <path d=\"M 252.942545 192.164125 \n",
       "L 260.535273 192.164125 \n",
       "L 260.535273 159.74674 \n",
       "L 252.942545 159.74674 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_34\">\n",
       "    <path d=\"M 260.535273 192.164125 \n",
       "L 268.128 192.164125 \n",
       "L 268.128 60.9509 \n",
       "L 260.535273 60.9509 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_35\">\n",
       "    <path d=\"M 268.128 192.164125 \n",
       "L 275.720727 192.164125 \n",
       "L 275.720727 57.86353 \n",
       "L 268.128 57.86353 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_36\">\n",
       "    <path d=\"M 275.720727 192.164125 \n",
       "L 283.313455 192.164125 \n",
       "L 283.313455 159.74674 \n",
       "L 275.720727 159.74674 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_37\">\n",
       "    <path d=\"M 283.313455 192.164125 \n",
       "L 290.906182 192.164125 \n",
       "L 290.906182 170.552535 \n",
       "L 283.313455 170.552535 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_38\">\n",
       "    <path d=\"M 290.906182 192.164125 \n",
       "L 298.498909 192.164125 \n",
       "L 298.498909 189.076755 \n",
       "L 290.906182 189.076755 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_39\">\n",
       "    <path d=\"M 298.498909 192.164125 \n",
       "L 306.091636 192.164125 \n",
       "L 306.091636 187.53307 \n",
       "L 298.498909 187.53307 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_40\">\n",
       "    <path d=\"M 306.091636 192.164125 \n",
       "L 313.684364 192.164125 \n",
       "L 313.684364 190.62044 \n",
       "L 306.091636 190.62044 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_41\">\n",
       "    <path d=\"M 313.684364 192.164125 \n",
       "L 321.277091 192.164125 \n",
       "L 321.277091 191.392282 \n",
       "L 313.684364 191.392282 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_42\">\n",
       "    <path d=\"M 321.277091 192.164125 \n",
       "L 328.869818 192.164125 \n",
       "L 328.869818 191.392282 \n",
       "L 321.277091 191.392282 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_43\">\n",
       "    <path d=\"M 328.869818 192.164125 \n",
       "L 336.462545 192.164125 \n",
       "L 336.462545 192.164125 \n",
       "L 328.869818 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_44\">\n",
       "    <path d=\"M 336.462545 192.164125 \n",
       "L 344.055273 192.164125 \n",
       "L 344.055273 190.62044 \n",
       "L 336.462545 190.62044 \n",
       "z\n",
       "\" clip-path=\"url(#pd3da8410e9)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_45\">\n",
       "    <path d=\"M 217.918941 192.164125 \n",
       "L 317.861909 192.164125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_7\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(233.712 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_46\">\n",
       "    <path d=\"M 362.016 192.164125 \n",
       "L 529.056 192.164125 \n",
       "L 529.056 51.1485 \n",
       "L 362.016 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"374.388002\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(366.924502 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"448.103896\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(445.657084 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"521.81979\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(516.926165 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\"/>\n",
       "   <g id=\"patch_47\">\n",
       "    <path d=\"M 369.608727 192.164125 \n",
       "L 377.201455 192.164125 \n",
       "L 377.201455 191.553668 \n",
       "L 369.608727 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_48\">\n",
       "    <path d=\"M 377.201455 192.164125 \n",
       "L 384.794182 192.164125 \n",
       "L 384.794182 192.164125 \n",
       "L 377.201455 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_49\">\n",
       "    <path d=\"M 384.794182 192.164125 \n",
       "L 392.386909 192.164125 \n",
       "L 392.386909 191.553668 \n",
       "L 384.794182 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_50\">\n",
       "    <path d=\"M 392.386909 192.164125 \n",
       "L 399.979636 192.164125 \n",
       "L 399.979636 192.164125 \n",
       "L 392.386909 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_51\">\n",
       "    <path d=\"M 399.979636 192.164125 \n",
       "L 407.572364 192.164125 \n",
       "L 407.572364 191.553668 \n",
       "L 399.979636 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_52\">\n",
       "    <path d=\"M 407.572364 192.164125 \n",
       "L 415.165091 192.164125 \n",
       "L 415.165091 191.553668 \n",
       "L 407.572364 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_53\">\n",
       "    <path d=\"M 415.165091 192.164125 \n",
       "L 422.757818 192.164125 \n",
       "L 422.757818 190.94321 \n",
       "L 415.165091 190.94321 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_54\">\n",
       "    <path d=\"M 422.757818 192.164125 \n",
       "L 430.350545 192.164125 \n",
       "L 430.350545 187.890924 \n",
       "L 422.757818 187.890924 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_55\">\n",
       "    <path d=\"M 430.350545 192.164125 \n",
       "L 437.943273 192.164125 \n",
       "L 437.943273 173.850407 \n",
       "L 430.350545 173.850407 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_56\">\n",
       "    <path d=\"M 437.943273 192.164125 \n",
       "L 445.536 192.164125 \n",
       "L 445.536 120.130169 \n",
       "L 437.943273 120.130169 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_57\">\n",
       "    <path d=\"M 445.536 192.164125 \n",
       "L 453.128727 192.164125 \n",
       "L 453.128727 57.86353 \n",
       "L 445.536 57.86353 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_58\">\n",
       "    <path d=\"M 453.128727 192.164125 \n",
       "L 460.721455 192.164125 \n",
       "L 460.721455 137.222972 \n",
       "L 453.128727 137.222972 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_59\">\n",
       "    <path d=\"M 460.721455 192.164125 \n",
       "L 468.314182 192.164125 \n",
       "L 468.314182 181.786352 \n",
       "L 460.721455 181.786352 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_60\">\n",
       "    <path d=\"M 468.314182 192.164125 \n",
       "L 475.906909 192.164125 \n",
       "L 475.906909 188.501381 \n",
       "L 468.314182 188.501381 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_61\">\n",
       "    <path d=\"M 475.906909 192.164125 \n",
       "L 483.499636 192.164125 \n",
       "L 483.499636 190.332753 \n",
       "L 475.906909 190.332753 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_62\">\n",
       "    <path d=\"M 483.499636 192.164125 \n",
       "L 491.092364 192.164125 \n",
       "L 491.092364 191.553668 \n",
       "L 483.499636 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_63\">\n",
       "    <path d=\"M 491.092364 192.164125 \n",
       "L 498.685091 192.164125 \n",
       "L 498.685091 192.164125 \n",
       "L 491.092364 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_64\">\n",
       "    <path d=\"M 498.685091 192.164125 \n",
       "L 506.277818 192.164125 \n",
       "L 506.277818 192.164125 \n",
       "L 498.685091 192.164125 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_65\">\n",
       "    <path d=\"M 506.277818 192.164125 \n",
       "L 513.870545 192.164125 \n",
       "L 513.870545 191.553668 \n",
       "L 506.277818 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_66\">\n",
       "    <path d=\"M 513.870545 192.164125 \n",
       "L 521.463273 192.164125 \n",
       "L 521.463273 191.553668 \n",
       "L 513.870545 191.553668 \n",
       "z\n",
       "\" clip-path=\"url(#pd32a520041)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_67\">\n",
       "    <path d=\"M 374.388002 192.164125 \n",
       "L 521.81979 192.164125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_11\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(383.907 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_68\">\n",
       "    <path d=\"M 539.424 192.164125 \n",
       "L 706.464 192.164125 \n",
       "L 706.464 51.1485 \n",
       "L 539.424 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"556.31573\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(548.85223 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"620.849404\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(618.402592 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m293f33ce49\" x=\"685.383078\" y=\"192.164125\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(680.489453 206.763) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\"/>\n",
       "   <g id=\"patch_69\">\n",
       "    <path d=\"M 547.016727 192.164125 \n",
       "L 554.609455 192.164125 \n",
       "L 554.609455 190.442322 \n",
       "L 547.016727 190.442322 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_70\">\n",
       "    <path d=\"M 554.609455 192.164125 \n",
       "L 562.202182 192.164125 \n",
       "L 562.202182 190.442322 \n",
       "L 554.609455 190.442322 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_71\">\n",
       "    <path d=\"M 562.202182 192.164125 \n",
       "L 569.794909 192.164125 \n",
       "L 569.794909 186.998717 \n",
       "L 562.202182 186.998717 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_72\">\n",
       "    <path d=\"M 569.794909 192.164125 \n",
       "L 577.387636 192.164125 \n",
       "L 577.387636 180.111507 \n",
       "L 569.794909 180.111507 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_73\">\n",
       "    <path d=\"M 577.387636 192.164125 \n",
       "L 584.980364 192.164125 \n",
       "L 584.980364 162.893482 \n",
       "L 577.387636 162.893482 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_74\">\n",
       "    <path d=\"M 584.980364 192.164125 \n",
       "L 592.573091 192.164125 \n",
       "L 592.573091 157.728075 \n",
       "L 584.980364 157.728075 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_75\">\n",
       "    <path d=\"M 592.573091 192.164125 \n",
       "L 600.165818 192.164125 \n",
       "L 600.165818 131.901037 \n",
       "L 592.573091 131.901037 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_76\">\n",
       "    <path d=\"M 600.165818 192.164125 \n",
       "L 607.758545 192.164125 \n",
       "L 607.758545 111.239407 \n",
       "L 600.165818 111.239407 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_77\">\n",
       "    <path d=\"M 607.758545 192.164125 \n",
       "L 615.351273 192.164125 \n",
       "L 615.351273 92.29958 \n",
       "L 607.758545 92.29958 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_78\">\n",
       "    <path d=\"M 615.351273 192.164125 \n",
       "L 622.944 192.164125 \n",
       "L 622.944 85.41237 \n",
       "L 615.351273 85.41237 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_79\">\n",
       "    <path d=\"M 622.944 192.164125 \n",
       "L 630.536727 192.164125 \n",
       "L 630.536727 57.86353 \n",
       "L 622.944 57.86353 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_80\">\n",
       "    <path d=\"M 630.536727 192.164125 \n",
       "L 638.129455 192.164125 \n",
       "L 638.129455 88.855975 \n",
       "L 630.536727 88.855975 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_81\">\n",
       "    <path d=\"M 638.129455 192.164125 \n",
       "L 645.722182 192.164125 \n",
       "L 645.722182 126.73563 \n",
       "L 638.129455 126.73563 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_82\">\n",
       "    <path d=\"M 645.722182 192.164125 \n",
       "L 653.314909 192.164125 \n",
       "L 653.314909 145.675457 \n",
       "L 645.722182 145.675457 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_83\">\n",
       "    <path d=\"M 653.314909 192.164125 \n",
       "L 660.907636 192.164125 \n",
       "L 660.907636 159.449877 \n",
       "L 653.314909 159.449877 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_84\">\n",
       "    <path d=\"M 660.907636 192.164125 \n",
       "L 668.500364 192.164125 \n",
       "L 668.500364 173.224297 \n",
       "L 660.907636 173.224297 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_85\">\n",
       "    <path d=\"M 668.500364 192.164125 \n",
       "L 676.093091 192.164125 \n",
       "L 676.093091 174.9461 \n",
       "L 668.500364 174.9461 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_86\">\n",
       "    <path d=\"M 676.093091 192.164125 \n",
       "L 683.685818 192.164125 \n",
       "L 683.685818 186.998717 \n",
       "L 676.093091 186.998717 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_87\">\n",
       "    <path d=\"M 683.685818 192.164125 \n",
       "L 691.278545 192.164125 \n",
       "L 691.278545 190.442322 \n",
       "L 683.685818 190.442322 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_88\">\n",
       "    <path d=\"M 691.278545 192.164125 \n",
       "L 698.871273 192.164125 \n",
       "L 698.871273 188.72052 \n",
       "L 691.278545 188.72052 \n",
       "z\n",
       "\" clip-path=\"url(#pce55c9fdf0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_89\">\n",
       "    <path d=\"M 556.31573 192.164125 \n",
       "L 685.383078 192.164125 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(561.04575 45.1485) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_16\">\n",
       "   <!-- Standardized errors -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(286.5795 18.6525) scale(0.16 -0.16)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-53\" d=\"M 288 1472 \n",
       "L 859 1522 \n",
       "Q 900 1178 1048 958 \n",
       "Q 1197 738 1509 602 \n",
       "Q 1822 466 2213 466 \n",
       "Q 2559 466 2825 569 \n",
       "Q 3091 672 3220 851 \n",
       "Q 3350 1031 3350 1244 \n",
       "Q 3350 1459 3225 1620 \n",
       "Q 3100 1781 2813 1891 \n",
       "Q 2628 1963 1997 2114 \n",
       "Q 1366 2266 1113 2400 \n",
       "Q 784 2572 623 2826 \n",
       "Q 463 3081 463 3397 \n",
       "Q 463 3744 659 4045 \n",
       "Q 856 4347 1234 4503 \n",
       "Q 1613 4659 2075 4659 \n",
       "Q 2584 4659 2973 4495 \n",
       "Q 3363 4331 3572 4012 \n",
       "Q 3781 3694 3797 3291 \n",
       "L 3216 3247 \n",
       "Q 3169 3681 2898 3903 \n",
       "Q 2628 4125 2100 4125 \n",
       "Q 1550 4125 1298 3923 \n",
       "Q 1047 3722 1047 3438 \n",
       "Q 1047 3191 1225 3031 \n",
       "Q 1400 2872 2139 2705 \n",
       "Q 2878 2538 3153 2413 \n",
       "Q 3553 2228 3743 1945 \n",
       "Q 3934 1663 3934 1294 \n",
       "Q 3934 928 3725 604 \n",
       "Q 3516 281 3123 101 \n",
       "Q 2731 -78 2241 -78 \n",
       "Q 1619 -78 1198 103 \n",
       "Q 778 284 539 648 \n",
       "Q 300 1013 288 1472 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-7a\" d=\"M 125 0 \n",
       "L 125 456 \n",
       "L 2238 2881 \n",
       "Q 1878 2863 1603 2863 \n",
       "L 250 2863 \n",
       "L 250 3319 \n",
       "L 2963 3319 \n",
       "L 2963 2947 \n",
       "L 1166 841 \n",
       "L 819 456 \n",
       "Q 1197 484 1528 484 \n",
       "L 3063 484 \n",
       "L 3063 0 \n",
       "L 125 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-53\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"66.699219\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"94.482422\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"150.097656\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"205.712891\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"261.328125\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"316.943359\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"350.244141\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"405.859375\"/>\n",
       "    <use xlink:href=\"#ArialMT-7a\" x=\"428.076172\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"478.076172\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"533.691406\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"589.306641\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"617.089844\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"672.705078\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"706.005859\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"739.306641\"/>\n",
       "    <use xlink:href=\"#ArialMT-72\" x=\"794.921875\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"828.222656\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"paec8eba238\">\n",
       "   <rect x=\"7.2\" y=\"51.1485\" width=\"167.04\" height=\"141.015625\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pd3da8410e9\">\n",
       "   <rect x=\"184.608\" y=\"51.1485\" width=\"167.04\" height=\"141.015625\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pd32a520041\">\n",
       "   <rect x=\"362.016\" y=\"51.1485\" width=\"167.04\" height=\"141.015625\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pce55c9fdf0\">\n",
       "   <rect x=\"539.424\" y=\"51.1485\" width=\"167.04\" height=\"141.015625\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1000x300 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(10, 3), tight_layout=True)\n",
    "fig.suptitle('Standardized errors', fontsize=16)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].hist(standardized_errors[:, i], bins=20)\n",
    "    ax[i].set_title(o_name)\n",
    "    ax[i].set_yticks([])\n",
    "    sns.despine(trim=True, ax=ax[i], left=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "#### QQ plot\n",
    "\n",
    "The histograms above look like normal distributions, but it's sometimes hard to tell.\n",
    "A quantile-quantile (QQ) plot is another way to check normality:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "metadata": {},
   "outputs": [],
   "source": [
    "quantiles = jnp.linspace(0.01, 0.99, 40)\n",
    "normal_quantiles = jstats.norm.ppf(quantiles)\n",
    "error_quantiles = jnp.quantile(standardized_errors, quantiles, axis=0)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"713.664pt\" height=\"215.712pt\" viewBox=\"0 0 713.664 215.712\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:39.935347</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M -0 215.712 \n",
       "L 713.664 215.712 \n",
       "L 713.664 0 \n",
       "L -0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 179.384625 \n",
       "L 178.320844 179.384625 \n",
       "L 178.320844 51.3535 \n",
       "L 38.312875 51.3535 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mee9bf26eb8\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"53.604504\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.587817 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"108.316859\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(105.870047 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"163.029215\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(160.582402 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_4\">\n",
       "     <!-- Normal quantiles -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(72.302609 206.604) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4e\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"72.216797\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"127.832031\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"161.132812\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"244.433594\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"300.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"322.265625\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"350.048828\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"405.664062\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"461.279297\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"516.894531\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"572.509766\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"600.292969\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"622.509766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"644.726562\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"700.341797\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <defs>\n",
       "       <path id=\"m3ad55e17d1\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"162.40686\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 165.556297) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"144.687561\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 147.836999) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"126.968263\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 130.1177) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"109.248964\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 112.398401) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"91.529665\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 94.679103) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"73.810367\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 76.959804) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"38.312875\" y=\"56.091068\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 59.240505) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-36\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_12\">\n",
       "     <!-- Error quantiles -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(14.0715 146.581063) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-45\" d=\"M 506 0 \n",
       "L 506 4581 \n",
       "L 3819 4581 \n",
       "L 3819 4041 \n",
       "L 1113 4041 \n",
       "L 1113 2638 \n",
       "L 3647 2638 \n",
       "L 3647 2100 \n",
       "L 1113 2100 \n",
       "L 1113 541 \n",
       "L 3925 541 \n",
       "L 3925 0 \n",
       "L 506 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-45\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"100\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"133.300781\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"188.916016\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"222.216797\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"250\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"305.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"361.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"416.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"472.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"522.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"544.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"600.292969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"me4039abeed\" d=\"M 0 2.4 \n",
       "C 0.636487 2.4 1.246992 2.147121 1.697056 1.697056 \n",
       "C 2.147121 1.246992 2.4 0.636487 2.4 0 \n",
       "C 2.4 -0.636487 2.147121 -1.246992 1.697056 -1.697056 \n",
       "C 1.246992 -2.147121 0.636487 -2.4 0 -2.4 \n",
       "C -0.636487 -2.4 -1.246992 -2.147121 -1.697056 -1.697056 \n",
       "C -2.147121 -1.246992 -2.4 -0.636487 -2.4 0 \n",
       "C -2.4 0.636487 -2.147121 1.246992 -1.697056 1.697056 \n",
       "C -1.246992 2.147121 -0.636487 2.4 0 2.4 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p53ef8d1ae7)\">\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"44.676874\" y=\"173.565028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"58.79523\" y=\"156.75018\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"65.842982\" y=\"146.695067\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"70.84611\" y=\"137.320214\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"74.838221\" y=\"133.398038\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"78.22192\" y=\"131.415699\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"81.198644\" y=\"128.494848\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"83.88461\" y=\"127.104116\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"86.353471\" y=\"125.544426\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"88.655171\" y=\"123.983536\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"90.825376\" y=\"122.28321\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"92.890643\" y=\"121.384821\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"94.871456\" y=\"120.032059\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"96.784107\" y=\"118.538489\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"98.641929\" y=\"117.28914\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"100.456126\" y=\"115.990334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"102.236362\" y=\"115.138768\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"103.991187\" y=\"113.989255\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"105.728374\" y=\"112.568214\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"107.455174\" y=\"111.425842\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"109.178545\" y=\"110.448808\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"110.905345\" y=\"109.304494\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"112.642532\" y=\"108.201456\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"114.397357\" y=\"107.054228\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"116.177592\" y=\"106.191765\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"117.99179\" y=\"104.88987\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"119.849612\" y=\"103.352006\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"121.762263\" y=\"101.7334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"123.743075\" y=\"100.381053\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"125.808342\" y=\"99.294291\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"127.978547\" y=\"97.210243\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"130.280247\" y=\"95.250791\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"132.749109\" y=\"94.017814\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"135.435075\" y=\"92.083917\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"138.411799\" y=\"90.315907\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"141.795498\" y=\"86.094462\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"145.787609\" y=\"82.926543\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"150.790737\" y=\"78.365424\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"157.838489\" y=\"72.30686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"171.956845\" y=\"57.173097\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 162.40686 \n",
       "L 38.312875 56.091068 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 53.604504 179.384625 \n",
       "L 163.029215 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_13\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(56.287109 45.3535) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 214.360594 179.384625 \n",
       "L 354.368562 179.384625 \n",
       "L 354.368562 51.3535 \n",
       "L 214.360594 51.3535 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"229.652223\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(224.635535 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"284.364578\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(281.917766 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"339.076933\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(336.630121 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"168.719762\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −15 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(191.133594 171.869199) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"151.66975\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(191.133594 154.819188) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"134.619739\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- −5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.027219 137.769176) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"117.569727\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.166969 120.719164) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"100.519715\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.166969 103.669153) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-35\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"83.469704\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.273344 86.619141) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"214.360594\" y=\"66.419692\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 15 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.273344 69.56913) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_2\">\n",
       "    <g clip-path=\"url(#pd3c67039a6)\">\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"220.724592\" y=\"173.565028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"234.842949\" y=\"146.656188\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"241.890701\" y=\"136.56801\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"246.893828\" y=\"133.197711\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"250.88594\" y=\"130.418107\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"254.269639\" y=\"127.776261\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"257.246363\" y=\"126.829266\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"259.932329\" y=\"124.957371\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"262.40119\" y=\"124.242247\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"264.70289\" y=\"123.281009\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"266.873095\" y=\"122.77388\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"268.938362\" y=\"121.996685\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"270.919174\" y=\"121.085913\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"272.831825\" y=\"120.582892\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"274.689648\" y=\"120.077412\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"276.503845\" y=\"119.210517\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"278.28408\" y=\"118.650017\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"280.038906\" y=\"118.227138\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"281.776093\" y=\"117.769546\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"283.502893\" y=\"116.948639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"285.226263\" y=\"116.354142\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"286.953064\" y=\"115.893447\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"288.69025\" y=\"115.312089\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"290.445076\" y=\"114.835332\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"292.225311\" y=\"114.296832\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"294.039508\" y=\"113.897815\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"295.897331\" y=\"113.216617\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"297.809982\" y=\"112.411333\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"299.790794\" y=\"111.319991\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"301.856061\" y=\"110.487448\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"304.026266\" y=\"109.703448\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"306.327966\" y=\"108.832527\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"308.796827\" y=\"107.859012\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"311.482794\" y=\"106.306056\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"314.459518\" y=\"103.843366\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"317.843217\" y=\"101.005732\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"321.835328\" y=\"96.273684\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"326.838455\" y=\"93.459448\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"333.886208\" y=\"88.200751\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"348.004564\" y=\"57.173097\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 214.360594 168.719762 \n",
       "L 214.360594 66.419692 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 229.652223 179.384625 \n",
       "L 339.076933 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_24\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(249.948578 45.3535) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 390.408313 179.384625 \n",
       "L 530.416281 179.384625 \n",
       "L 530.416281 51.3535 \n",
       "L 390.408313 51.3535 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"405.699942\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(400.683254 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"460.412297\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(457.965484 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"515.124652\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(512.67784 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"172.04388\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074938 175.193318) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"157.448634\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074938 160.598072) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"142.853389\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074938 146.002826) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"128.258143\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.074938 131.40758) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_19\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"113.662897\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 116.812334) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_20\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"99.067651\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 102.217088) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_21\">\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"84.472405\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 87.621843) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_22\">\n",
       "     <g id=\"line2d_31\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"69.877159\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- 6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 73.026597) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-36\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_23\">\n",
       "     <g id=\"line2d_32\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"390.408313\" y=\"55.281913\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_36\">\n",
       "      <!-- 8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.214688 58.431351) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-38\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_3\">\n",
       "    <g clip-path=\"url(#pb4822b4d4b)\">\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"396.772311\" y=\"173.565028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"410.890667\" y=\"144.612492\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"417.93842\" y=\"138.526819\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"422.941547\" y=\"133.734031\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"426.933658\" y=\"129.930656\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"430.317357\" y=\"127.524745\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"433.294081\" y=\"126.391481\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"435.980048\" y=\"123.985471\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"438.448909\" y=\"122.764156\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"440.750609\" y=\"121.615538\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"442.920814\" y=\"120.732065\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"444.986081\" y=\"119.865512\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"446.966893\" y=\"119.163898\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"448.879544\" y=\"118.341705\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"450.737367\" y=\"117.004767\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"452.551564\" y=\"116.230223\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"454.331799\" y=\"115.011984\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"456.086625\" y=\"114.33092\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"457.823811\" y=\"113.594228\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"459.550612\" y=\"112.706129\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"461.273982\" y=\"112.264258\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"463.000782\" y=\"111.545619\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"464.737969\" y=\"110.731497\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"466.492795\" y=\"109.779453\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"468.27303\" y=\"108.852912\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"470.087227\" y=\"108.208648\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"471.94505\" y=\"107.275344\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"473.857701\" y=\"106.517003\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"475.838513\" y=\"105.787963\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"477.90378\" y=\"104.752425\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"480.073985\" y=\"103.644622\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"482.375685\" y=\"102.480436\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"484.844546\" y=\"100.674162\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"487.530512\" y=\"99.531286\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"490.507236\" y=\"97.537801\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"493.890935\" y=\"95.237044\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"497.883047\" y=\"92.317673\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"502.886174\" y=\"89.21106\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"509.933926\" y=\"77.239626\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"524.052283\" y=\"57.173097\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 390.408313 172.04388 \n",
       "L 390.408313 55.281913 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 405.699942 179.384625 \n",
       "L 515.124652 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_37\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(398.783297 45.3535) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 566.456031 179.384625 \n",
       "L 706.464 179.384625 \n",
       "L 706.464 51.3535 \n",
       "L 566.456031 51.3535 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"581.74766\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_38\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(576.730973 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_34\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"636.460016\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(634.013203 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mee9bf26eb8\" x=\"691.172371\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_40\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(688.725558 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_24\">\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"170.815678\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_41\">\n",
       "      <!-- −7.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 173.965115) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_25\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"153.380247\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_42\">\n",
       "      <!-- −5.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 156.529684) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_26\">\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"135.944816\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_43\">\n",
       "      <!-- −2.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(540.784281 139.094254) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_27\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"118.509385\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_44\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 121.658823) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_28\">\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"101.073954\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_45\">\n",
       "      <!-- 2.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 104.223392) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_29\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"83.638523\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_46\">\n",
       "      <!-- 5.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 86.787961) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-35\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_30\">\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3ad55e17d1\" x=\"566.456031\" y=\"66.203093\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_47\">\n",
       "      <!-- 7.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(545.924031 69.35253) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-37\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_4\">\n",
       "    <g clip-path=\"url(#pf1b26f8750)\">\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"572.82003\" y=\"173.565028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"586.938386\" y=\"161.434064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"593.986138\" y=\"155.81509\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"598.989266\" y=\"150.856791\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"602.981377\" y=\"147.367535\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"606.365076\" y=\"144.221433\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"609.3418\" y=\"141.658179\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"612.027766\" y=\"138.389704\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"614.496628\" y=\"136.524061\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"616.798328\" y=\"134.183612\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"618.968533\" y=\"132.589043\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"621.0338\" y=\"130.608726\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"623.014612\" y=\"128.765516\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"624.927263\" y=\"127.888807\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"626.785085\" y=\"125.731395\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"628.599283\" y=\"123.790663\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"630.379518\" y=\"121.769636\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"632.134343\" y=\"120.242815\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"633.87153\" y=\"118.824574\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"635.59833\" y=\"117.492995\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"637.321701\" y=\"115.74994\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"639.048501\" y=\"114.354155\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"640.785688\" y=\"113.238849\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"642.540513\" y=\"111.703226\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"644.320749\" y=\"110.50464\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"646.134946\" y=\"109.335155\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"647.992768\" y=\"107.861238\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"649.905419\" y=\"106.247764\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"651.886232\" y=\"104.925651\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"653.951499\" y=\"103.786324\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"656.121704\" y=\"100.912445\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"658.423404\" y=\"98.559776\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"660.892265\" y=\"95.774277\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"663.578231\" y=\"92.912724\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"666.554955\" y=\"90.258958\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"669.938654\" y=\"86.656219\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"673.930765\" y=\"81.856552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"678.933893\" y=\"78.123292\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"685.981645\" y=\"68.088702\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#me4039abeed\" x=\"700.100001\" y=\"57.173097\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 566.456031 170.815678 \n",
       "L 566.456031 66.203093 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 581.74766 179.384625 \n",
       "L 691.172371 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_48\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(574.561766 45.3535) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_49\">\n",
       "   <!-- QQ plot -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(329.267 18.8575) scale(0.16 -0.16)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-51\" d=\"M 3966 491 \n",
       "Q 4388 200 4744 66 \n",
       "L 4566 -356 \n",
       "Q 4072 -178 3581 206 \n",
       "Q 3072 -78 2456 -78 \n",
       "Q 1834 -78 1328 222 \n",
       "Q 822 522 548 1065 \n",
       "Q 275 1609 275 2291 \n",
       "Q 275 2969 550 3525 \n",
       "Q 825 4081 1333 4372 \n",
       "Q 1841 4663 2469 4663 \n",
       "Q 3103 4663 3612 4361 \n",
       "Q 4122 4059 4389 3517 \n",
       "Q 4656 2975 4656 2294 \n",
       "Q 4656 1728 4484 1276 \n",
       "Q 4313 825 3966 491 \n",
       "z\n",
       "M 2631 1266 \n",
       "Q 3156 1119 3497 828 \n",
       "Q 4031 1316 4031 2294 \n",
       "Q 4031 2850 3842 3265 \n",
       "Q 3653 3681 3289 3911 \n",
       "Q 2925 4141 2472 4141 \n",
       "Q 1794 4141 1347 3677 \n",
       "Q 900 3213 900 2291 \n",
       "Q 900 1397 1342 919 \n",
       "Q 1784 441 2472 441 \n",
       "Q 2797 441 3084 563 \n",
       "Q 2800 747 2484 825 \n",
       "L 2631 1266 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-51\"/>\n",
       "    <use xlink:href=\"#ArialMT-51\" x=\"77.783203\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"155.566406\"/>\n",
       "    <use xlink:href=\"#ArialMT-70\" x=\"183.349609\"/>\n",
       "    <use xlink:href=\"#ArialMT-6c\" x=\"238.964844\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"261.181641\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"316.796875\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p53ef8d1ae7\">\n",
       "   <rect x=\"38.312875\" y=\"51.3535\" width=\"140.007969\" height=\"128.031125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pd3c67039a6\">\n",
       "   <rect x=\"214.360594\" y=\"51.3535\" width=\"140.007969\" height=\"128.031125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pb4822b4d4b\">\n",
       "   <rect x=\"390.408313\" y=\"51.3535\" width=\"140.007969\" height=\"128.031125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pf1b26f8750\">\n",
       "   <rect x=\"566.456031\" y=\"51.3535\" width=\"140.007969\" height=\"128.031125\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1000x300 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(10, 3), tight_layout=True)\n",
    "fig.suptitle('QQ plot', fontsize=16)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].scatter(normal_quantiles, error_quantiles[:, i])\n",
    "    ax[i].set_title(o_name)\n",
    "    sns.despine(trim=True, ax=ax[i])\n",
    "ax[0].set_xlabel('Normal quantiles')\n",
    "ax[0].set_ylabel('Error quantiles');"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The straighter the line, the more \"normal\" the errors are. They look decent.\n",
    "\n",
    "#### Residuals plot\n",
    "\n",
    "Another assumption in our GP model is that the noise is *homoscedastic*&mdash;i.e., the same across all input/output values. We can check this assumption by plotting the error against the model prediction. This is called a *residual plot*. (Note that *residuals* is just another name for the errors.)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"713.664pt\" height=\"215.712pt\" viewBox=\"0 0 713.664 215.712\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:40:40.169658</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 215.712 \n",
       "L 713.664 215.712 \n",
       "L 713.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 45.65125 179.384625 \n",
       "L 185.658187 179.384625 \n",
       "L 185.658187 51.1485 \n",
       "L 45.65125 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m2c5f12540c\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"59.279061\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(54.262374 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"125.80455\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(123.357737 193.9835) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_3\">\n",
       "     <!-- Predicted -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(95.377719 206.604) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"100\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"155.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"211.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"233.447266\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"283.447266\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"366.845703\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <defs>\n",
       "       <path id=\"ma549b9d4c9\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"166.875045\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- −7.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 170.024483) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"151.519884\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- −5.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 154.669322) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"136.164723\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- −2.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 139.314161) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"141.796875\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"120.809562\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 123.958999) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"105.454401\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 2.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 108.603838) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"90.09924\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- 5.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 93.248677) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-35\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"74.744078\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- 7.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 77.893516) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-37\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"45.65125\" y=\"59.388917\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 10.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(20.225625 62.538355) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_12\">\n",
       "     <!-- Standardized error -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(14.0715 155.018062) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-53\" d=\"M 288 1472 \n",
       "L 859 1522 \n",
       "Q 900 1178 1048 958 \n",
       "Q 1197 738 1509 602 \n",
       "Q 1822 466 2213 466 \n",
       "Q 2559 466 2825 569 \n",
       "Q 3091 672 3220 851 \n",
       "Q 3350 1031 3350 1244 \n",
       "Q 3350 1459 3225 1620 \n",
       "Q 3100 1781 2813 1891 \n",
       "Q 2628 1963 1997 2114 \n",
       "Q 1366 2266 1113 2400 \n",
       "Q 784 2572 623 2826 \n",
       "Q 463 3081 463 3397 \n",
       "Q 463 3744 659 4045 \n",
       "Q 856 4347 1234 4503 \n",
       "Q 1613 4659 2075 4659 \n",
       "Q 2584 4659 2973 4495 \n",
       "Q 3363 4331 3572 4012 \n",
       "Q 3781 3694 3797 3291 \n",
       "L 3216 3247 \n",
       "Q 3169 3681 2898 3903 \n",
       "Q 2628 4125 2100 4125 \n",
       "Q 1550 4125 1298 3923 \n",
       "Q 1047 3722 1047 3438 \n",
       "Q 1047 3191 1225 3031 \n",
       "Q 1400 2872 2139 2705 \n",
       "Q 2878 2538 3153 2413 \n",
       "Q 3553 2228 3743 1945 \n",
       "Q 3934 1663 3934 1294 \n",
       "Q 3934 928 3725 604 \n",
       "Q 3516 281 3123 101 \n",
       "Q 2731 -78 2241 -78 \n",
       "Q 1619 -78 1198 103 \n",
       "Q 778 284 539 648 \n",
       "Q 300 1013 288 1472 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-7a\" d=\"M 125 0 \n",
       "L 125 456 \n",
       "L 2238 2881 \n",
       "Q 1878 2863 1603 2863 \n",
       "L 250 2863 \n",
       "L 250 3319 \n",
       "L 2963 3319 \n",
       "L 2963 2947 \n",
       "L 1166 841 \n",
       "L 819 456 \n",
       "Q 1197 484 1528 484 \n",
       "L 3063 484 \n",
       "L 3063 0 \n",
       "L 125 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-53\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"94.482422\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"150.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"205.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"261.328125\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"316.943359\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"350.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.859375\"/>\n",
       "      <use xlink:href=\"#ArialMT-7a\" x=\"428.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"478.076172\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" x=\"533.691406\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"589.306641\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"617.089844\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"672.705078\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"706.005859\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"739.306641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"794.921875\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m62a9b659b5\" d=\"M 0 0.5 \n",
       "C 0.132602 0.5 0.25979 0.447317 0.353553 0.353553 \n",
       "C 0.447317 0.25979 0.5 0.132602 0.5 0 \n",
       "C 0.5 -0.132602 0.447317 -0.25979 0.353553 -0.353553 \n",
       "C 0.25979 -0.447317 0.132602 -0.5 0 -0.5 \n",
       "C -0.132602 -0.5 -0.25979 -0.447317 -0.353553 -0.353553 \n",
       "C -0.447317 -0.25979 -0.5 -0.132602 -0.5 0 \n",
       "C -0.5 0.132602 -0.447317 0.25979 -0.353553 0.353553 \n",
       "C -0.25979 0.447317 -0.132602 0.5 0 0.5 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p1a9c64e532)\">\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"90.809623\" y=\"161.220605\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.597418\" y=\"114.719738\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.229522\" y=\"128.007051\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.21129\" y=\"125.760668\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"105.166959\" y=\"136.283641\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.847574\" y=\"123.738318\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"88.140695\" y=\"120.898696\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.444014\" y=\"124.583177\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"110.2721\" y=\"132.029867\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"111.048256\" y=\"126.399028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.809693\" y=\"118.680435\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"123.312758\" y=\"128.255556\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.514581\" y=\"120.332595\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"98.400355\" y=\"124.626623\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"81.879228\" y=\"106.025904\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.89761\" y=\"129.865955\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"107.42601\" y=\"130.497947\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.856845\" y=\"114.961734\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.236094\" y=\"122.675552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.872302\" y=\"122.389278\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.897803\" y=\"127.465803\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.642343\" y=\"118.075509\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"131.318639\" y=\"104.573344\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.643014\" y=\"122.63297\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.341428\" y=\"123.162711\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.998357\" y=\"110.301774\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.81725\" y=\"128.099212\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.019334\" y=\"124.954756\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"122.736704\" y=\"154.549449\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.517714\" y=\"112.850457\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"133.692118\" y=\"113.936779\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.96915\" y=\"127.248962\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.888007\" y=\"129.096362\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.714005\" y=\"122.230639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.998439\" y=\"127.881717\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.667922\" y=\"137.139487\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"88.662755\" y=\"133.684686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.028189\" y=\"126.655128\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"86.864419\" y=\"127.612151\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.078495\" y=\"121.618668\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"120.613493\" y=\"128.598404\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.945111\" y=\"140.06887\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"101.713336\" y=\"128.293359\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.813364\" y=\"126.370069\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"101.380274\" y=\"119.584639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"110.460156\" y=\"121.036964\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"60.975448\" y=\"104.552263\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"111.041815\" y=\"138.631242\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"78.774028\" y=\"124.832696\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.828119\" y=\"129.070664\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"75.090818\" y=\"124.217192\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.354304\" y=\"103.210856\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"137.240667\" y=\"109.092407\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"87.662133\" y=\"130.373226\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.905831\" y=\"137.184545\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"121.529369\" y=\"56.977415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"111.789034\" y=\"100.304854\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"120.530238\" y=\"119.805369\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"118.116756\" y=\"152.947632\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.108465\" y=\"132.85652\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.868983\" y=\"109.514417\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.476227\" y=\"126.472325\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"69.316552\" y=\"109.485618\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"69.144116\" y=\"118.578671\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.280087\" y=\"133.824004\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"94.582002\" y=\"144.524091\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"92.263293\" y=\"136.680634\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.220684\" y=\"129.625179\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.962544\" y=\"119.013282\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.844567\" y=\"110.330994\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"113.39052\" y=\"117.296115\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.587136\" y=\"126.342276\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.736405\" y=\"107.280454\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.393272\" y=\"120.026577\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"115.069136\" y=\"134.211387\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"64.527502\" y=\"102.81694\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"167.228975\" y=\"131.280221\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"77.401107\" y=\"121.059948\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.714672\" y=\"121.033414\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"171.84364\" y=\"149.168612\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"95.493426\" y=\"129.021723\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"111.820477\" y=\"124.139785\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"99.498567\" y=\"141.010404\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.627918\" y=\"121.863198\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.097529\" y=\"121.268803\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"61.963002\" y=\"85.962872\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"142.267221\" y=\"112.410692\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"86.245134\" y=\"124.949986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"119.853331\" y=\"125.284455\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"113.93369\" y=\"133.341599\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.43603\" y=\"107.757886\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.629746\" y=\"108.014088\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"130.853607\" y=\"121.612107\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"126.978577\" y=\"130.050923\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"123.875543\" y=\"122.277512\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.760254\" y=\"121.857297\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"99.40829\" y=\"128.657575\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.909644\" y=\"134.175407\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"142.831528\" y=\"98.624157\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"72.744346\" y=\"121.981273\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"136.834299\" y=\"164.464299\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.606349\" y=\"129.054629\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.398484\" y=\"127.138883\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.151415\" y=\"95.438469\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"119.646659\" y=\"97.405836\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"100.539219\" y=\"126.302423\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"111.752179\" y=\"131.656869\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"112.09882\" y=\"146.773005\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"109.203434\" y=\"168.732076\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"75.884412\" y=\"113.239116\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"77.624448\" y=\"125.856289\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.79202\" y=\"129.68364\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"113.819592\" y=\"129.257659\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.558026\" y=\"125.939327\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.481971\" y=\"129.72212\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.246568\" y=\"109.429266\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.815351\" y=\"112.914334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"64.827573\" y=\"98.977623\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.638523\" y=\"132.903397\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.70327\" y=\"113.986601\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"110.401668\" y=\"151.285623\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"167.320011\" y=\"137.25554\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.053147\" y=\"122.543599\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.013886\" y=\"107.891711\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.609195\" y=\"137.551517\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"71.603507\" y=\"108.31719\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.588599\" y=\"108.057269\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.794069\" y=\"107.005865\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"119.419474\" y=\"168.268174\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"99.296763\" y=\"117.776894\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"76.863739\" y=\"110.6901\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"131.036889\" y=\"131.059449\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.363332\" y=\"127.540144\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.982751\" y=\"104.652265\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"86.722097\" y=\"128.27527\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"105.017673\" y=\"126.721597\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.429742\" y=\"93.36539\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"109.288506\" y=\"98.793557\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.513982\" y=\"117.466972\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"118.375179\" y=\"132.738494\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"129.853746\" y=\"92.829028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.434332\" y=\"134.551237\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"126.524682\" y=\"115.892029\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"171.010558\" y=\"154.035236\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.716374\" y=\"127.201269\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"128.649002\" y=\"104.479789\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"154.568078\" y=\"113.586055\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.113393\" y=\"120.524022\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.83403\" y=\"131.434532\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"138.101369\" y=\"100.843252\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"145.824325\" y=\"111.11528\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"131.152524\" y=\"94.112174\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.75544\" y=\"111.190218\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"68.70801\" y=\"110.634472\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.379214\" y=\"114.853943\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"124.719544\" y=\"115.039608\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"119.123457\" y=\"118.291102\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.988827\" y=\"111.906986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"117.797362\" y=\"121.853694\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"105.737418\" y=\"140.443301\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.175112\" y=\"115.978851\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.891599\" y=\"109.140207\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"137.647033\" y=\"98.387687\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"94.356838\" y=\"114.663064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.936619\" y=\"116.691003\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.89068\" y=\"124.160273\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.83192\" y=\"119.04169\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.521253\" y=\"112.473579\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.547417\" y=\"131.059505\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.353676\" y=\"120.674552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.386833\" y=\"115.572112\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"77.635201\" y=\"126.04631\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.721709\" y=\"128.389911\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.392025\" y=\"121.41686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"84.084262\" y=\"119.068034\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"64.958231\" y=\"108.555118\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"129.921193\" y=\"109.278368\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"128.258041\" y=\"91.677283\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.986543\" y=\"137.267003\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.518833\" y=\"116.045495\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"168.95697\" y=\"132.545693\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.521208\" y=\"108.631745\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"91.729112\" y=\"134.070909\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"60.603928\" y=\"105.760534\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.792339\" y=\"94.069745\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"97.301322\" y=\"132.139765\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"95.729113\" y=\"146.722145\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"136.310082\" y=\"108.181084\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"102.131314\" y=\"145.290167\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.863718\" y=\"127.656758\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.774234\" y=\"103.998023\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"53.96716\" y=\"71.343873\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"119.333464\" y=\"125.078202\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"141.295664\" y=\"110.120822\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"142.106545\" y=\"125.115782\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"113.158874\" y=\"129.219824\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.414356\" y=\"131.829154\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"75.60213\" y=\"108.957598\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.432827\" y=\"132.750385\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"74.630219\" y=\"115.631519\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"130.961712\" y=\"123.125172\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"176.544187\" y=\"160.660245\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.353733\" y=\"129.218118\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.016143\" y=\"110.302613\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"78.907323\" y=\"118.607818\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"91.300447\" y=\"133.140075\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.62622\" y=\"117.830228\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.165462\" y=\"125.959048\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.44199\" y=\"133.88395\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.047463\" y=\"163.981445\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.212185\" y=\"120.691673\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"141.562856\" y=\"109.31803\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"129.783782\" y=\"112.51511\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"117.47918\" y=\"129.428217\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.62815\" y=\"135.675492\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"116.04552\" y=\"112.961917\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.332698\" y=\"120.077937\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"88.014343\" y=\"129.689299\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"108.462012\" y=\"167.435597\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"170.309828\" y=\"130.701244\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"170.216914\" y=\"132.932844\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"81.457822\" y=\"130.083045\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"98.594953\" y=\"132.907961\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"138.461348\" y=\"100.037501\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.409354\" y=\"110.229895\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.819105\" y=\"119.613822\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.911532\" y=\"121.171645\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"120.946245\" y=\"115.360911\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.699321\" y=\"133.580436\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"154.639846\" y=\"119.859596\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.019204\" y=\"122.786971\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.45104\" y=\"131.017871\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.477862\" y=\"120.113508\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"131.663205\" y=\"83.072337\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.909663\" y=\"122.656108\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"178.6191\" y=\"138.769549\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"99.623871\" y=\"124.220342\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.903096\" y=\"109.974907\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.884021\" y=\"123.269821\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"129.504933\" y=\"114.019348\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.808727\" y=\"129.762894\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"99.291534\" y=\"125.196338\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"87.887186\" y=\"137.95146\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"96.231234\" y=\"120.407491\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.968181\" y=\"117.283385\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.848222\" y=\"123.651704\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.752183\" y=\"136.981287\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"102.184571\" y=\"143.864517\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"100.290039\" y=\"127.454508\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"88.563511\" y=\"118.123944\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"108.273212\" y=\"173.55571\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.601381\" y=\"122.813184\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.614517\" y=\"103.431833\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.541172\" y=\"105.892439\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.610409\" y=\"104.100535\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"60.256423\" y=\"84.72382\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.560328\" y=\"125.062865\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.184467\" y=\"110.919446\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"56.027639\" y=\"96.824976\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"155.711606\" y=\"117.827086\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.114096\" y=\"86.204997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.250771\" y=\"131.435648\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.137847\" y=\"108.883317\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.793965\" y=\"124.53262\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"98.535529\" y=\"113.246219\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"124.047624\" y=\"92.065461\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"78.397791\" y=\"124.263385\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"71.99954\" y=\"120.64504\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"146.375714\" y=\"117.790484\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.641007\" y=\"124.988387\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.783195\" y=\"124.977612\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.564289\" y=\"121.867392\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"78.756881\" y=\"125.922324\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"118.724907\" y=\"117.644751\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.524291\" y=\"115.465529\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.953715\" y=\"118.957295\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.593128\" y=\"109.371348\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.116971\" y=\"126.512341\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.994055\" y=\"124.856695\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.343618\" y=\"106.526023\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"133.37614\" y=\"119.683031\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"101.493824\" y=\"132.602564\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.240188\" y=\"126.961285\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.187919\" y=\"110.327992\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"91.769913\" y=\"116.586568\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.587042\" y=\"147.744282\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.700435\" y=\"129.582881\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"76.960709\" y=\"112.393761\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"170.932433\" y=\"144.012371\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"85.468923\" y=\"124.64964\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"96.681097\" y=\"134.473259\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.153283\" y=\"116.721523\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.150997\" y=\"119.065834\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.60239\" y=\"127.453208\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.83865\" y=\"136.008277\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"109.514782\" y=\"135.413106\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.338922\" y=\"108.622161\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.116042\" y=\"129.723941\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.272743\" y=\"129.626348\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.969561\" y=\"140.246911\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"127.967092\" y=\"169.336381\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.618538\" y=\"116.548942\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.88848\" y=\"114.647148\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"127.254482\" y=\"90.613955\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.449332\" y=\"121.374659\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"173.923764\" y=\"142.47019\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.839473\" y=\"125.495133\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"52.015202\" y=\"94.930024\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"97.818986\" y=\"117.915303\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.432803\" y=\"123.437798\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"115.353279\" y=\"114.247068\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.182082\" y=\"135.163986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"85.364757\" y=\"131.093694\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"91.83365\" y=\"122.605737\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.43227\" y=\"119.001063\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"102.377745\" y=\"129.812666\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.866694\" y=\"122.539106\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.034473\" y=\"135.968706\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"116.023694\" y=\"151.599599\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.336899\" y=\"113.649026\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"126.35635\" y=\"164.213786\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.932305\" y=\"119.180901\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"85.914799\" y=\"133.064128\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"99.808038\" y=\"132.480542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.322273\" y=\"101.64687\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.986995\" y=\"119.920947\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.275164\" y=\"116.344454\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.435181\" y=\"133.599628\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.397395\" y=\"107.448639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"124.268682\" y=\"93.790961\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"103.154213\" y=\"127.052088\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.54921\" y=\"115.091719\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.176732\" y=\"116.780958\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"146.971214\" y=\"106.61219\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.628248\" y=\"119.328833\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"61.051586\" y=\"99.352618\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"167.706022\" y=\"138.345336\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.332018\" y=\"111.259641\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.089116\" y=\"124.005017\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"95.32184\" y=\"115.569065\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.690824\" y=\"118.810227\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"124.088121\" y=\"121.71715\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.760043\" y=\"115.950471\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.981737\" y=\"125.932206\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.451905\" y=\"119.220484\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"65.026346\" y=\"111.709966\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.933422\" y=\"120.195624\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.8306\" y=\"112.228374\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.835304\" y=\"110.67441\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"68.418047\" y=\"101.202814\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.59007\" y=\"120.789695\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"87.058069\" y=\"99.250729\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"115.333282\" y=\"126.966561\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"142.385226\" y=\"110.483874\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.943718\" y=\"111.041975\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.406536\" y=\"114.177452\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"112.537477\" y=\"118.139599\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.879397\" y=\"111.620384\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"109.533225\" y=\"126.688908\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.262957\" y=\"125.253354\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"56.587968\" y=\"97.42305\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"102.920094\" y=\"150.588401\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.444987\" y=\"119.453942\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"152.90834\" y=\"116.908153\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"76.421759\" y=\"113.976542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"167.205402\" y=\"148.480917\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.275493\" y=\"126.164075\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"74.939182\" y=\"103.830711\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"85.002341\" y=\"122.013744\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.127342\" y=\"130.671769\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"131.951383\" y=\"113.339288\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.418866\" y=\"111.100772\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"167.66945\" y=\"138.284429\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"132.348607\" y=\"127.580546\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.73318\" y=\"113.847429\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.000822\" y=\"102.627809\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"71.132524\" y=\"116.426967\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"138.130936\" y=\"99.262075\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"103.936216\" y=\"153.477832\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"175.638163\" y=\"159.360609\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.393644\" y=\"122.044955\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"112.153015\" y=\"126.940817\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"118.30934\" y=\"107.523359\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.937281\" y=\"128.843216\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.66484\" y=\"119.906634\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.694234\" y=\"101.587057\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"84.511024\" y=\"118.241184\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"109.92115\" y=\"165.376904\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"137.042935\" y=\"136.86293\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"120.257252\" y=\"124.95473\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"122.712127\" y=\"153.158313\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.112371\" y=\"119.223247\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"158.779951\" y=\"115.659819\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"116.750123\" y=\"134.068202\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"167.982025\" y=\"137.182014\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.63385\" y=\"123.526687\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"74.710785\" y=\"112.372425\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"81.89823\" y=\"130.398881\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.180539\" y=\"113.890958\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"110.624457\" y=\"149.963072\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.075984\" y=\"123.914985\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"67.604644\" y=\"101.197151\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"169.588036\" y=\"140.306446\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"73.84833\" y=\"104.071497\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.321\" y=\"120.874092\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"125.402377\" y=\"131.144103\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.419018\" y=\"114.21952\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"162.107206\" y=\"128.927944\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"75.723874\" y=\"115.513528\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"146.548965\" y=\"102.458377\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.304024\" y=\"134.053696\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.708959\" y=\"136.127833\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"179.294236\" y=\"156.588595\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"177.841811\" y=\"139.052094\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.055175\" y=\"105.791591\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.598676\" y=\"130.551519\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"96.04411\" y=\"122.331052\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"70.264338\" y=\"118.456613\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"61.343865\" y=\"110.961652\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"85.654735\" y=\"133.491984\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"165.16964\" y=\"134.394971\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.014629\" y=\"110.256741\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"89.368374\" y=\"125.333905\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.500861\" y=\"130.063124\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.200614\" y=\"121.28791\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"123.088408\" y=\"136.60651\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"107.731565\" y=\"137.549444\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"137.934518\" y=\"96.328775\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"148.68395\" y=\"114.176174\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"68.300136\" y=\"106.059149\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.539798\" y=\"153.04824\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"114.095696\" y=\"59.3804\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"97.039301\" y=\"123.247444\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"142.05523\" y=\"100.539501\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.918989\" y=\"113.185402\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"104.846339\" y=\"136.718589\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"79.419562\" y=\"119.652935\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"82.349443\" y=\"132.162591\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"138.699542\" y=\"102.164594\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.608568\" y=\"118.997238\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"123.454243\" y=\"151.790062\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.353569\" y=\"139.852523\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"172.344337\" y=\"138.486655\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"161.104095\" y=\"131.797767\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.028474\" y=\"129.179032\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.585492\" y=\"117.784197\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"83.441567\" y=\"123.104208\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"77.075287\" y=\"119.201096\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"88.389738\" y=\"141.842415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"130.887899\" y=\"164.75383\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"164.037547\" y=\"123.640672\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.385241\" y=\"115.208644\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"85.642437\" y=\"121.864931\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.75258\" y=\"111.408427\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.499219\" y=\"120.161576\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"80.00711\" y=\"115.148552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.38724\" y=\"115.849224\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.480458\" y=\"129.647941\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"145.112261\" y=\"114.442759\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"149.317174\" y=\"107.987932\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"103.450316\" y=\"120.455213\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"128.162625\" y=\"139.449103\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"106.663996\" y=\"123.70904\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"151.891293\" y=\"120.733516\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"69.710991\" y=\"94.0822\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"139.127188\" y=\"101.133422\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"170.688443\" y=\"135.863982\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.897077\" y=\"120.973116\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"119.76449\" y=\"133.738986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"73.163558\" y=\"116.792875\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.030513\" y=\"108.895854\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"98.916321\" y=\"117.412159\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"169.427357\" y=\"161.532388\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"153.858131\" y=\"114.043372\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"157.786452\" y=\"117.611899\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"147.888785\" y=\"111.692702\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"105.790967\" y=\"130.362235\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"110.920124\" y=\"145.41923\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.098998\" y=\"101.110292\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.715907\" y=\"103.544091\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"128.830346\" y=\"64.282633\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"74.958023\" y=\"117.057108\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"163.897749\" y=\"133.687588\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.909428\" y=\"97.483566\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"92.842479\" y=\"125.680628\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"145.401907\" y=\"105.37294\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"120.935527\" y=\"160.685047\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"143.42245\" y=\"107.938892\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"115.304006\" y=\"130.23\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"154.252997\" y=\"119.48022\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"100.460706\" y=\"122.405756\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"150.978173\" y=\"114.458646\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"159.414765\" y=\"124.686186\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"134.03431\" y=\"122.436436\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"93.49159\" y=\"124.112178\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"166.405753\" y=\"131.836826\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"160.053366\" y=\"122.218521\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"170.735589\" y=\"143.489656\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"144.602804\" y=\"135.860239\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"156.397472\" y=\"140.237533\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_11\">\n",
       "    <path d=\"M 45.65125 133.093691 \n",
       "L 185.658187 133.093691 \n",
       "\" clip-path=\"url(#p1a9c64e532)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_12\">\n",
       "    <path d=\"M 45.65125 108.525433 \n",
       "L 185.658187 108.525433 \n",
       "\" clip-path=\"url(#p1a9c64e532)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 45.65125 166.875045 \n",
       "L 45.65125 59.388917 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.279061 179.384625 \n",
       "L 125.80455 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_13\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(63.624969 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.81125 70.636375 \n",
       "L 108.828375 70.636375 \n",
       "Q 110.588375 70.636375 110.588375 68.876375 \n",
       "L 110.588375 57.3085 \n",
       "Q 110.588375 55.5485 108.828375 55.5485 \n",
       "L 51.81125 55.5485 \n",
       "Q 50.05125 55.5485 50.05125 57.3085 \n",
       "L 50.05125 68.876375 \n",
       "Q 50.05125 70.636375 51.81125 70.636375 \n",
       "z\n",
       "\" style=\"fill: #ffffff; opacity: 0.8; stroke: #cccccc; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"line2d_13\">\n",
       "     <path d=\"M 53.57125 62.287375 \n",
       "L 62.37125 62.287375 \n",
       "L 71.17125 62.287375 \n",
       "\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- 95% CI -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(78.21125 65.367375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-43\" d=\"M 3763 1606 \n",
       "L 4369 1453 \n",
       "Q 4178 706 3683 314 \n",
       "Q 3188 -78 2472 -78 \n",
       "Q 1731 -78 1267 223 \n",
       "Q 803 525 561 1097 \n",
       "Q 319 1669 319 2325 \n",
       "Q 319 3041 592 3573 \n",
       "Q 866 4106 1370 4382 \n",
       "Q 1875 4659 2481 4659 \n",
       "Q 3169 4659 3637 4309 \n",
       "Q 4106 3959 4291 3325 \n",
       "L 3694 3184 \n",
       "Q 3534 3684 3231 3912 \n",
       "Q 2928 4141 2469 4141 \n",
       "Q 1941 4141 1586 3887 \n",
       "Q 1231 3634 1087 3207 \n",
       "Q 944 2781 944 2328 \n",
       "Q 944 1744 1114 1308 \n",
       "Q 1284 872 1643 656 \n",
       "Q 2003 441 2422 441 \n",
       "Q 2931 441 3284 734 \n",
       "Q 3638 1028 3763 1606 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-39\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" x=\"55.615234\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" x=\"111.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"200.146484\"/>\n",
       "      <use xlink:href=\"#ArialMT-43\" x=\"227.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-49\" x=\"300.146484\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 219.253188 179.384625 \n",
       "L 359.260125 179.384625 \n",
       "L 359.260125 51.1485 \n",
       "L 219.253188 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"241.410328\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(236.39364 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"292.170575\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(289.723763 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"342.930822\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(340.48401 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"172.993394\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- −30 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.026188 176.142831) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"153.811912\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- −20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.026188 156.961349) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"134.63043\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(196.026188 137.779867) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"115.448948\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(206.059563 118.598386) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"96.267466\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.165938 99.416904) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"77.085985\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.165938 80.235422) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"219.253188\" y=\"57.904503\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 30 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(201.165938 61.05394) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-33\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_2\">\n",
       "    <g clip-path=\"url(#pa5eb991221)\">\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"246.909489\" y=\"73.609225\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"262.177007\" y=\"113.267862\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.2294\" y=\"109.16368\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.277389\" y=\"114.644473\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.558396\" y=\"112.802706\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.642841\" y=\"105.094025\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.816368\" y=\"113.634415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"325.457563\" y=\"112.739929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.386266\" y=\"132.556469\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.36403\" y=\"119.213608\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.98197\" y=\"115.203289\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.253919\" y=\"111.091037\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"308.051141\" y=\"116.054771\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"251.44977\" y=\"107.373388\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"262.392175\" y=\"107.686708\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"249.033179\" y=\"123.110662\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.791334\" y=\"119.756838\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"293.534133\" y=\"108.400118\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"332.838064\" y=\"113.250694\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.794126\" y=\"113.154788\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"351.50133\" y=\"115.996639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"337.36404\" y=\"113.991666\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.723417\" y=\"116.394969\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"331.046412\" y=\"114.923279\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"295.925043\" y=\"116.104624\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"263.564553\" y=\"140.096721\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"312.946409\" y=\"119.219801\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"319.151428\" y=\"115.396741\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"267.079213\" y=\"101.645106\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"328.599034\" y=\"116.97198\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.330757\" y=\"130.358779\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"296.210628\" y=\"103.145093\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"296.507248\" y=\"117.529294\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.7049\" y=\"112.495578\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"340.291945\" y=\"114.008271\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.759669\" y=\"115.973123\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"263.130516\" y=\"117.937252\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.774944\" y=\"120.678404\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.834636\" y=\"131.271718\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"331.672603\" y=\"111.430789\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.404405\" y=\"107.14633\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.081605\" y=\"116.047075\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.570681\" y=\"117.492478\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"312.529159\" y=\"119.312009\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.565536\" y=\"110.632106\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"263.504533\" y=\"117.807455\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.699117\" y=\"118.62476\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"269.737913\" y=\"109.601066\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"265.33996\" y=\"90.20875\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"281.204236\" y=\"128.849249\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.342209\" y=\"117.371788\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.56792\" y=\"115.580497\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.832941\" y=\"106.022358\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"281.544078\" y=\"116.351482\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"330.642053\" y=\"120.679761\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"308.337964\" y=\"113.468662\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"315.564734\" y=\"112.816273\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"260.126433\" y=\"112.746145\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.04711\" y=\"118.040484\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"323.419833\" y=\"118.560578\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"296.241445\" y=\"98.688389\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.922465\" y=\"118.826636\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"264.493825\" y=\"173.55571\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"266.921406\" y=\"118.790583\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"338.928523\" y=\"110.17137\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.032266\" y=\"117.290696\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"270.545897\" y=\"121.842777\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.895749\" y=\"117.181385\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"315.483365\" y=\"126.963494\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"319.159399\" y=\"121.167071\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.332429\" y=\"111.759153\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"321.108575\" y=\"105.418175\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.09431\" y=\"116.815438\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.030592\" y=\"110.505476\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.168007\" y=\"114.611064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.017128\" y=\"102.701777\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"322.665885\" y=\"109.098462\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.431019\" y=\"116.343295\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"332.856603\" y=\"114.839203\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.35927\" y=\"119.656632\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.338789\" y=\"137.676546\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"295.341688\" y=\"119.391627\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.862072\" y=\"120.455709\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"300.816276\" y=\"115.053025\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.954376\" y=\"107.746681\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.780509\" y=\"116.752377\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.631234\" y=\"122.47289\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.729719\" y=\"108.15825\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.035251\" y=\"80.210843\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"275.606119\" y=\"115.222561\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"316.304187\" y=\"127.196523\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"261.54094\" y=\"98.622032\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"300.315296\" y=\"123.734288\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.698803\" y=\"114.689563\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.83512\" y=\"89.60858\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"244.660369\" y=\"89.142678\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.096278\" y=\"119.095672\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"322.059556\" y=\"115.378937\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"329.685609\" y=\"119.266394\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"232.345035\" y=\"92.635589\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.820036\" y=\"116.329264\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"300.101607\" y=\"117.241858\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"317.005691\" y=\"114.178391\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.337976\" y=\"109.750045\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.199513\" y=\"113.998547\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.643695\" y=\"113.862342\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"264.553393\" y=\"134.461757\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.810947\" y=\"107.199767\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.802319\" y=\"113.23514\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"248.582828\" y=\"108.275512\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"234.48289\" y=\"118.377151\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.895213\" y=\"121.757331\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"268.732778\" y=\"102.398547\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.386986\" y=\"109.199386\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"320.847652\" y=\"115.053988\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"326.25018\" y=\"123.102477\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.244499\" y=\"123.622096\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"270.32574\" y=\"97.030334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.632381\" y=\"116.896652\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.183678\" y=\"115.798912\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.849599\" y=\"117.637534\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"317.171516\" y=\"113.467611\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"300.260613\" y=\"116.885435\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.97969\" y=\"119.658584\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.234133\" y=\"109.355499\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"253.205801\" y=\"99.142706\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"316.754934\" y=\"123.401207\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"300.037697\" y=\"116.345693\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.530368\" y=\"106.92776\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"244.45907\" y=\"114.573817\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.837435\" y=\"152.495954\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"281.211785\" y=\"111.597834\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"237.028465\" y=\"106.921773\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.743541\" y=\"113.395627\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"275.465388\" y=\"112.551588\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"263.575687\" y=\"100.965202\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.831473\" y=\"117.388946\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.473015\" y=\"116.373122\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"320.967674\" y=\"115.070272\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"305.753277\" y=\"117.302931\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.010321\" y=\"90.250879\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.856787\" y=\"106.090515\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.839437\" y=\"111.876563\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.445203\" y=\"113.2299\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"328.879503\" y=\"116.579171\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"286.077794\" y=\"115.712665\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.545083\" y=\"115.791413\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.872067\" y=\"126.136314\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.523139\" y=\"109.490631\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"304.147243\" y=\"110.882434\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.242308\" y=\"114.733045\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"286.498216\" y=\"116.479339\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.436585\" y=\"115.552806\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.976794\" y=\"118.628589\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.854447\" y=\"120.077526\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.724545\" y=\"117.662453\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.668362\" y=\"107.387775\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"244.355772\" y=\"101.858929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"265.771121\" y=\"129.041392\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.758425\" y=\"114.680941\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"286.205261\" y=\"115.149313\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.171072\" y=\"110.584844\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.7303\" y=\"116.984719\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.989561\" y=\"106.860724\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"321.139878\" y=\"115.888557\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.009764\" y=\"105.043189\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.17788\" y=\"113.440245\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"319.967189\" y=\"120.763575\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"327.221277\" y=\"111.299858\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"257.028752\" y=\"118.374956\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.445268\" y=\"111.243791\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.86819\" y=\"114.276692\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.446362\" y=\"118.129362\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"297.729903\" y=\"113.041422\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"251.028791\" y=\"134.58386\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"258.515737\" y=\"118.034703\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"270.683413\" y=\"119.297541\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.786314\" y=\"107.772248\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.733148\" y=\"116.962237\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"319.348757\" y=\"119.267899\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"287.114322\" y=\"117.851242\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.917209\" y=\"111.75903\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.975012\" y=\"122.467893\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.869517\" y=\"121.517733\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"307.844371\" y=\"112.691214\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.722757\" y=\"117.579357\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.719213\" y=\"125.701552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.651828\" y=\"117.458795\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.257828\" y=\"118.511266\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"304.350619\" y=\"123.538233\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.529622\" y=\"120.789596\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.021669\" y=\"111.692126\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"262.594515\" y=\"109.006092\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"332.638446\" y=\"116.068342\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.201033\" y=\"102.871649\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"281.180591\" y=\"113.001217\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.589668\" y=\"113.674261\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.056227\" y=\"119.37274\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.178043\" y=\"120.010422\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.367938\" y=\"110.435514\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.178712\" y=\"122.95804\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.581667\" y=\"115.871553\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"337.529975\" y=\"115.669782\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.712311\" y=\"116.977597\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"245.293877\" y=\"57.41082\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.41514\" y=\"116.008819\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"239.331052\" y=\"56.977415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.897624\" y=\"119.991207\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"261.570541\" y=\"125.725623\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"345.599738\" y=\"121.081333\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"310.330006\" y=\"103.574663\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"270.949467\" y=\"117.051639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.656188\" y=\"111.938463\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.874047\" y=\"112.286347\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"327.652536\" y=\"112.543715\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.143211\" y=\"116.059552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"329.854072\" y=\"118.116475\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"275.993488\" y=\"113.586998\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.388008\" y=\"110.978416\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.073227\" y=\"113.893223\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.941671\" y=\"114.430519\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"295.418129\" y=\"110.085841\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"264.584841\" y=\"135.002114\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"327.07878\" y=\"114.238172\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"285.217001\" y=\"114.459467\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"260.298853\" y=\"132.415076\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.498002\" y=\"113.98236\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"257.930834\" y=\"109.273243\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"332.803767\" y=\"112.356581\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"325.208803\" y=\"117.725886\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.175817\" y=\"114.323094\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.739043\" y=\"114.860797\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"320.402222\" y=\"119.595077\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"336.241136\" y=\"115.963631\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"305.7778\" y=\"121.910949\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.690059\" y=\"116.747702\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"287.509515\" y=\"106.372083\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.4917\" y=\"99.808722\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.663535\" y=\"119.06966\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"270.35731\" y=\"115.771857\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"332.830484\" y=\"116.713438\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.475814\" y=\"119.194819\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.19219\" y=\"103.307856\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.361037\" y=\"110.64638\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.234128\" y=\"114.869865\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.928816\" y=\"109.700492\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"347.77157\" y=\"121.062876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.38517\" y=\"115.895811\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"232.3835\" y=\"103.864463\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"257.600979\" y=\"100.230143\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.177087\" y=\"114.033179\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"324.055072\" y=\"113.714831\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.672382\" y=\"111.440525\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.561558\" y=\"123.95678\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.765403\" y=\"113.51997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.679684\" y=\"100.283445\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"317.641334\" y=\"109.20484\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.503568\" y=\"122.337261\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.607779\" y=\"113.723078\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.665298\" y=\"111.039935\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.130514\" y=\"114.036223\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"335.714096\" y=\"113.369456\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"315.385433\" y=\"111.442405\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"329.737065\" y=\"120.631257\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"286.069507\" y=\"113.762793\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.627377\" y=\"102.38826\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"257.226306\" y=\"95.246865\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"226.17346\" y=\"161.192114\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"352.896173\" y=\"122.023364\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"293.975997\" y=\"110.909733\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"315.130399\" y=\"124.115093\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"287.896265\" y=\"112.167444\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"282.649674\" y=\"112.655584\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.294099\" y=\"120.782282\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.266318\" y=\"115.38114\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"334.911483\" y=\"124.295925\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.341265\" y=\"118.557194\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.516296\" y=\"117.119287\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.745054\" y=\"117.104574\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.612154\" y=\"106.915566\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.399052\" y=\"119.466328\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"261.936104\" y=\"120.167044\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.94361\" y=\"110.391625\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"297.59332\" y=\"112.024742\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"235.627683\" y=\"80.790691\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"315.434454\" y=\"118.607788\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.259667\" y=\"139.867845\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.880424\" y=\"118.399552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"316.242356\" y=\"110.881288\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"268.824484\" y=\"121.8215\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"286.293505\" y=\"115.275483\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.62184\" y=\"113.231401\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"252.279187\" y=\"110.934575\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.796934\" y=\"111.090153\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"326.28827\" y=\"124.248327\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.870587\" y=\"124.809754\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"324.239877\" y=\"118.84823\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.816367\" y=\"114.656048\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"304.329993\" y=\"113.017342\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"337.089394\" y=\"113.831633\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"282.483815\" y=\"107.254804\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.186826\" y=\"116.310399\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"326.332521\" y=\"110.283986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.582083\" y=\"113.661102\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.71234\" y=\"108.067679\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.400191\" y=\"120.928534\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.677118\" y=\"113.921924\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"267.373172\" y=\"120.729424\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"281.591043\" y=\"126.686252\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.571331\" y=\"81.482373\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"257.084825\" y=\"124.367129\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"265.91471\" y=\"103.125966\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"249.318714\" y=\"105.52171\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"264.473533\" y=\"122.710981\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.059676\" y=\"111.677191\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.727318\" y=\"105.79928\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"335.151973\" y=\"112.451861\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"325.921314\" y=\"113.791964\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.875032\" y=\"114.989637\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.791347\" y=\"97.215156\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"304.042742\" y=\"118.367665\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.915823\" y=\"118.549843\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"256.692225\" y=\"118.103896\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.2987\" y=\"111.842061\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.808287\" y=\"118.486479\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"308.245418\" y=\"118.959331\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"337.331921\" y=\"118.067437\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"286.105138\" y=\"100.470268\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"322.656584\" y=\"115.034929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.402307\" y=\"118.287017\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"264.450912\" y=\"118.522893\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.928831\" y=\"112.440338\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"335.047623\" y=\"114.729818\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"340.628412\" y=\"126.008077\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.112554\" y=\"113.307933\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.301017\" y=\"114.083015\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.848587\" y=\"116.837086\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.229382\" y=\"103.129115\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.869001\" y=\"115.63732\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.33417\" y=\"110.655969\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.047875\" y=\"134.966807\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"273.774223\" y=\"115.65916\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"312.221759\" y=\"114.992347\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"287.362349\" y=\"114.969445\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"322.355886\" y=\"120.106657\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.634924\" y=\"110.000159\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"338.278171\" y=\"119.182467\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.215894\" y=\"111.789369\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.635015\" y=\"126.125862\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"269.016325\" y=\"146.930342\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.020874\" y=\"115.947155\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.236766\" y=\"111.810773\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"248.205323\" y=\"103.859296\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"346.714135\" y=\"115.491293\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"305.448729\" y=\"116.657779\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.206343\" y=\"110.906074\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.665488\" y=\"111.82343\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"249.160558\" y=\"121.539503\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"266.223172\" y=\"121.240431\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.754373\" y=\"114.337227\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.357876\" y=\"110.512334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"284.204964\" y=\"119.634996\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"276.326627\" y=\"114.055126\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"296.440339\" y=\"117.964497\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.483912\" y=\"130.185185\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"327.70589\" y=\"107.84866\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"304.318275\" y=\"116.127071\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.514632\" y=\"112.532395\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.538201\" y=\"103.133065\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.556046\" y=\"120.974667\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"259.201236\" y=\"127.973158\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.076723\" y=\"122.883749\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.21884\" y=\"108.045593\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.212562\" y=\"110.338128\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.913722\" y=\"101.70134\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"330.434437\" y=\"113.39749\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.427796\" y=\"116.741534\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.115374\" y=\"115.108363\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.456533\" y=\"113.467542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.394453\" y=\"113.462741\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"321.283236\" y=\"119.689458\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.483634\" y=\"112.072557\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"254.362482\" y=\"124.980146\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"305.313022\" y=\"114.751514\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.862559\" y=\"115.296799\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.933162\" y=\"112.815952\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"266.944909\" y=\"113.578136\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.204394\" y=\"118.906414\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.276973\" y=\"103.632986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.851827\" y=\"110.052735\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.15945\" y=\"117.25022\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.28041\" y=\"117.100203\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"322.959238\" y=\"117.172232\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.029736\" y=\"114.675553\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"317.87486\" y=\"116.295516\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"342.115075\" y=\"114.018739\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"230.367091\" y=\"144.881436\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"247.665379\" y=\"88.886265\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.482767\" y=\"121.120287\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"287.88662\" y=\"115.822317\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.020474\" y=\"118.868064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.748544\" y=\"102.969032\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"294.464027\" y=\"119.20551\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"287.099692\" y=\"111.378039\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"289.051341\" y=\"110.643177\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.497356\" y=\"112.305903\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.19913\" y=\"117.745882\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.86878\" y=\"102.795619\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"253.095857\" y=\"113.00042\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"325.190979\" y=\"117.585529\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"282.810531\" y=\"115.699425\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.427762\" y=\"117.558384\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"310.282588\" y=\"111.29739\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"336.858069\" y=\"113.58324\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"308.32119\" y=\"118.431508\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"299.578939\" y=\"115.472913\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"268.20239\" y=\"117.36883\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"225.617139\" y=\"168.217083\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"260.835089\" y=\"146.073316\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"259.806409\" y=\"126.31585\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"332.045236\" y=\"110.634177\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"306.238433\" y=\"114.70381\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.489986\" y=\"120.665067\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.325042\" y=\"113.020805\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"310.154228\" y=\"117.143778\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"267.111038\" y=\"115.492987\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"265.85276\" y=\"107.789143\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.184196\" y=\"115.834876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"323.022034\" y=\"100.213501\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"258.332054\" y=\"100.592527\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"347.986594\" y=\"117.034679\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.204114\" y=\"124.053763\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"262.848639\" y=\"116.749964\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"322.576387\" y=\"109.989316\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"292.028347\" y=\"113.847064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"274.974638\" y=\"119.46423\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.588284\" y=\"106.994385\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"258.066064\" y=\"104.671377\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"340.882213\" y=\"111.941453\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"325.738973\" y=\"113.986591\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"271.12728\" y=\"115.714468\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"302.864749\" y=\"124.845867\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"303.406635\" y=\"111.502224\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"318.068151\" y=\"117.05874\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"266.389441\" y=\"128.945649\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"249.219125\" y=\"102.268533\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"265.840123\" y=\"112.709943\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"260.603336\" y=\"86.906322\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"253.785283\" y=\"111.159909\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.584093\" y=\"114.574215\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.583145\" y=\"117.300354\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"319.627218\" y=\"111.110732\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"264.47368\" y=\"105.775293\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.784248\" y=\"113.605788\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"288.466418\" y=\"118.009558\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"261.955654\" y=\"148.562545\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"298.285043\" y=\"111.799886\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"275.965251\" y=\"108.927135\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"282.120091\" y=\"111.032771\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"319.662007\" y=\"109.632415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"277.674308\" y=\"112.963339\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.061418\" y=\"117.96048\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"255.896853\" y=\"109.977904\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"330.43996\" y=\"116.288825\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"267.305989\" y=\"136.782188\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"310.297167\" y=\"118.638717\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"313.006033\" y=\"114.440962\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"262.153245\" y=\"118.782304\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"259.1281\" y=\"99.344034\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"269.735904\" y=\"114.45361\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"279.220898\" y=\"114.217956\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"262.50519\" y=\"125.236519\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"320.973095\" y=\"113.997379\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.78208\" y=\"114.810772\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"293.810343\" y=\"116.512125\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"296.887919\" y=\"114.19797\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"295.126582\" y=\"114.526799\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"281.880702\" y=\"112.807175\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"310.375779\" y=\"119.40875\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"316.296209\" y=\"118.946557\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"297.077862\" y=\"117.310469\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"258.447971\" y=\"99.261667\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"311.587225\" y=\"109.793686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"334.029629\" y=\"114.182463\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"278.719967\" y=\"126.072865\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"309.475785\" y=\"124.23426\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"283.854766\" y=\"112.879904\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"331.034545\" y=\"113.458088\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"280.449673\" y=\"129.389076\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"335.264934\" y=\"115.654287\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"272.639021\" y=\"116.356791\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"312.776311\" y=\"115.60708\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"314.670931\" y=\"115.969719\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"291.75752\" y=\"108.363914\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"294.018491\" y=\"121.362575\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"301.616876\" y=\"110.337666\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"290.888651\" y=\"117.251931\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"317.409138\" y=\"110.161739\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"265.548137\" y=\"114.275707\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"339.809538\" y=\"113.687424\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 219.253188 119.285244 \n",
       "L 359.260125 119.285244 \n",
       "\" clip-path=\"url(#pa5eb991221)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 219.253188 111.612652 \n",
       "L 359.260125 111.612652 \n",
       "\" clip-path=\"url(#pa5eb991221)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 219.253188 172.993394 \n",
       "L 219.253188 57.904503 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 241.410328 179.384625 \n",
       "L 342.930822 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_25\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(254.840656 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 392.855125 179.384625 \n",
       "L 532.862062 179.384625 \n",
       "L 532.862062 51.1485 \n",
       "L 392.855125 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"419.851158\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(414.834471 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"474.848742\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(472.40193 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"529.846326\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(527.399514 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"392.855125\" y=\"169.886675\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- −20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(369.628125 173.036112) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"392.855125\" y=\"141.590935\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(369.628125 144.740373) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_31\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"392.855125\" y=\"113.295196\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(379.6615 116.444634) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_19\">\n",
       "     <g id=\"line2d_32\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"392.855125\" y=\"84.999457\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- 10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(374.767875 88.148894) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_20\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"392.855125\" y=\"56.703718\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- 20 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(374.767875 59.853155) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_3\">\n",
       "    <g clip-path=\"url(#p9e4b86b8fe)\">\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"513.492553\" y=\"115.457731\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.442549\" y=\"115.700128\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"456.662547\" y=\"160.692848\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.520805\" y=\"109.018097\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"519.480593\" y=\"111.249077\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"482.951196\" y=\"111.886675\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.677377\" y=\"113.925111\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.111549\" y=\"104.856503\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"467.736781\" y=\"108.627106\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.78443\" y=\"109.315267\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"454.262312\" y=\"120.704552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"452.273853\" y=\"120.95847\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"443.801198\" y=\"118.572692\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"473.421738\" y=\"115.485919\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.673704\" y=\"120.505137\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.052074\" y=\"108.492915\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.759024\" y=\"115.72399\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"450.623918\" y=\"115.646274\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.61843\" y=\"111.194862\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.802678\" y=\"111.813311\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"464.088654\" y=\"145.634383\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"410.386024\" y=\"119.656811\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.136131\" y=\"107.186351\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.125423\" y=\"112.618251\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"464.280526\" y=\"115.203656\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.969218\" y=\"117.419029\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"417.569618\" y=\"125.787559\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"472.117292\" y=\"113.732695\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.879549\" y=\"118.739698\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.318604\" y=\"110.504326\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"465.227117\" y=\"109.327151\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.002053\" y=\"110.141561\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"504.732991\" y=\"115.862847\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"439.891359\" y=\"112.257479\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"476.186252\" y=\"108.571483\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"439.129829\" y=\"118.350245\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"511.164319\" y=\"115.440779\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"421.626124\" y=\"96.77632\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.543978\" y=\"113.601872\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"415.375506\" y=\"100.095939\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.416002\" y=\"119.644573\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"486.228172\" y=\"122.846331\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"447.658359\" y=\"113.338161\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.339849\" y=\"116.896932\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.760153\" y=\"111.141467\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"448.429233\" y=\"107.721758\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"500.650801\" y=\"118.479174\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"472.952473\" y=\"124.206702\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"493.705179\" y=\"104.516308\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"427.102484\" y=\"98.674634\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"513.256025\" y=\"112.622259\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.068864\" y=\"117.108233\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"431.709213\" y=\"111.424176\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.402614\" y=\"121.870587\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"520.258844\" y=\"115.2315\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"469.705901\" y=\"113.815568\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"443.793452\" y=\"104.329823\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"434.625786\" y=\"127.744676\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.442809\" y=\"114.764716\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"504.57253\" y=\"112.358057\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"479.804004\" y=\"115.282687\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"481.472104\" y=\"111.065882\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.57399\" y=\"111.731713\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"508.129874\" y=\"111.988344\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"410.827553\" y=\"89.437608\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.939755\" y=\"111.885621\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"493.057954\" y=\"105.659647\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.203838\" y=\"125.211216\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"491.555995\" y=\"113.371319\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.050509\" y=\"119.684308\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"446.319647\" y=\"107.891978\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.814389\" y=\"112.841025\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.890061\" y=\"116.666876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"448.439879\" y=\"106.623016\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.621408\" y=\"112.941963\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.020901\" y=\"123.077396\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.830175\" y=\"120.188008\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.58697\" y=\"112.466615\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.892236\" y=\"112.498334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"435.65409\" y=\"114.499797\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"481.484219\" y=\"112.75332\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"478.032219\" y=\"106.129025\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"493.130091\" y=\"115.516064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"444.688943\" y=\"116.764316\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"515.137596\" y=\"122.090499\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.402988\" y=\"109.426546\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"450.512662\" y=\"107.134176\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"515.12793\" y=\"106.925224\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"437.969037\" y=\"116.068885\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"443.28115\" y=\"110.143171\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"452.578354\" y=\"116.287088\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"459.79414\" y=\"106.572601\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"425.537545\" y=\"126.224738\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.043561\" y=\"120.380671\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"482.224985\" y=\"109.634768\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.535556\" y=\"107.397797\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"465.609751\" y=\"107.883553\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"459.043423\" y=\"112.664476\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"481.20088\" y=\"112.75276\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.270272\" y=\"108.73185\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.520151\" y=\"119.68941\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"418.337535\" y=\"81.020226\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"443.677983\" y=\"112.158427\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"466.522772\" y=\"115.73232\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"490.287498\" y=\"111.504606\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.679171\" y=\"112.898886\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"445.662186\" y=\"112.3235\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"516.889014\" y=\"114.706233\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.132323\" y=\"105.772859\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.920587\" y=\"112.523138\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"511.569391\" y=\"109.215997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"449.638483\" y=\"104.435136\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"429.336429\" y=\"141.294482\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"436.423026\" y=\"118.990312\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.067432\" y=\"109.509578\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"502.240579\" y=\"106.019889\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"467.8466\" y=\"106.278081\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.78606\" y=\"116.075855\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.413383\" y=\"112.885173\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"508.069088\" y=\"118.553765\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"487.276335\" y=\"111.94399\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"468.436947\" y=\"122.923131\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"463.860299\" y=\"108.259191\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"428.240833\" y=\"125.941132\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.046285\" y=\"112.159414\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.380371\" y=\"117.80043\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.443407\" y=\"110.090723\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"449.028789\" y=\"113.139844\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.147525\" y=\"115.249686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"439.801967\" y=\"115.108455\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.544135\" y=\"121.043373\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"442.011422\" y=\"107.81876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.490205\" y=\"115.488134\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.720951\" y=\"107.26944\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.060055\" y=\"93.605432\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"439.74348\" y=\"111.535316\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"462.426246\" y=\"109.967032\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"460.479124\" y=\"108.933912\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"460.944347\" y=\"111.333568\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"504.691618\" y=\"112.786832\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"433.706727\" y=\"90.008299\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"449.791047\" y=\"117.081988\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"430.866753\" y=\"117.483736\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"487.759511\" y=\"116.640784\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"427.371679\" y=\"105.929257\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.001987\" y=\"110.051471\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.322595\" y=\"109.714678\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.870434\" y=\"112.926935\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.746404\" y=\"113.233718\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.864952\" y=\"115.666072\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.984813\" y=\"110.836129\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.047092\" y=\"112.417921\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.249045\" y=\"113.764539\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.076766\" y=\"110.426183\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.140236\" y=\"118.420683\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.503377\" y=\"110.959699\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"441.092827\" y=\"118.777951\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.650617\" y=\"121.318158\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"429.941671\" y=\"125.266032\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"461.026455\" y=\"114.971611\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"468.569601\" y=\"111.724389\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.948381\" y=\"112.345538\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"516.932286\" y=\"109.147483\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.006623\" y=\"114.876826\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"452.558292\" y=\"106.460612\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.433658\" y=\"103.701484\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.177837\" y=\"110.761421\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.532618\" y=\"116.800929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.945599\" y=\"111.037424\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.900931\" y=\"112.531713\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.61008\" y=\"110.661968\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"508.61596\" y=\"108.286827\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.949053\" y=\"116.73597\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"500.343885\" y=\"115.278856\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.802955\" y=\"123.35875\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"510.437361\" y=\"113.379377\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.182789\" y=\"136.513398\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"435.983469\" y=\"119.092949\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.793432\" y=\"114.106826\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"500.393633\" y=\"116.967188\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"497.926694\" y=\"104.127108\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"424.904546\" y=\"110.00339\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"513.016995\" y=\"113.748235\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.760479\" y=\"111.967521\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"469.533668\" y=\"113.359402\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.750447\" y=\"111.691748\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"513.829525\" y=\"112.069416\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"447.393614\" y=\"99.367078\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"525.771725\" y=\"118.331035\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.610826\" y=\"113.115154\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"500.445613\" y=\"111.713984\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"526.498111\" y=\"112.174513\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.945505\" y=\"116.008745\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"461.609278\" y=\"111.788797\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.106137\" y=\"112.991469\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"434.81222\" y=\"106.638603\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.79527\" y=\"121.168985\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.840359\" y=\"110.106505\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"490.974004\" y=\"106.417454\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.738238\" y=\"111.822761\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"478.26992\" y=\"109.881276\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"508.479775\" y=\"115.109144\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"463.314281\" y=\"116.177083\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.843637\" y=\"108.097597\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"491.730541\" y=\"117.747256\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.282017\" y=\"115.230609\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"462.875329\" y=\"112.885211\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"449.751739\" y=\"105.204821\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.138471\" y=\"118.140308\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"442.394706\" y=\"104.008533\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"436.958687\" y=\"112.477648\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"412.581752\" y=\"56.977415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.184985\" y=\"105.434343\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.468625\" y=\"118.64761\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.06358\" y=\"109.155298\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"505.380441\" y=\"113.518915\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"435.458811\" y=\"110.595075\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"516.784566\" y=\"116.054538\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"517.067452\" y=\"113.51684\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"472.157777\" y=\"117.2353\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"476.87406\" y=\"105.49109\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.385475\" y=\"111.241823\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.566903\" y=\"111.415147\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"454.202272\" y=\"100.643545\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"473.961004\" y=\"115.734368\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"459.799741\" y=\"116.740389\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.749055\" y=\"114.80505\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"466.966371\" y=\"123.511043\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"490.530833\" y=\"113.558295\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"479.624815\" y=\"115.700925\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.850296\" y=\"121.246192\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"444.957766\" y=\"114.727242\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.729002\" y=\"117.113314\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.721629\" y=\"115.570848\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"422.346675\" y=\"98.503263\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"476.411765\" y=\"113.225501\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.237543\" y=\"100.331458\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.706622\" y=\"123.227046\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"465.228592\" y=\"116.430783\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"430.22207\" y=\"113.281764\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"460.841382\" y=\"121.906437\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"460.723344\" y=\"116.767985\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"513.716313\" y=\"118.02973\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"433.218194\" y=\"115.744714\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.296915\" y=\"118.241651\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"486.579464\" y=\"108.094732\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"500.345422\" y=\"113.073625\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.853625\" y=\"113.52539\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"447.675099\" y=\"115.63846\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"481.302387\" y=\"106.980913\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.801194\" y=\"114.406784\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"430.446098\" y=\"115.910757\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"486.446764\" y=\"115.264548\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"435.711947\" y=\"114.44176\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.716918\" y=\"115.9755\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.158903\" y=\"109.549209\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.080957\" y=\"111.346981\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"448.29026\" y=\"107.947384\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.738044\" y=\"116.66284\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.835226\" y=\"112.489733\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.965116\" y=\"114.987823\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"497.608226\" y=\"120.892621\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"425.871511\" y=\"112.58876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"476.735758\" y=\"111.814461\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.623079\" y=\"99.173161\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.202014\" y=\"111.316241\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.307741\" y=\"115.429317\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.293413\" y=\"108.586658\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"462.553708\" y=\"110.322107\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.189828\" y=\"112.518686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"521.187224\" y=\"117.564443\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.158205\" y=\"105.889274\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.266043\" y=\"114.050713\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"421.747769\" y=\"110.272568\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.355206\" y=\"108.061146\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.066421\" y=\"110.280761\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.42991\" y=\"110.7688\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.889886\" y=\"128.994205\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.890343\" y=\"125.328731\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"430.010631\" y=\"108.666008\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.342213\" y=\"116.332299\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"466.063992\" y=\"114.415068\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.633876\" y=\"114.354261\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"456.156457\" y=\"110.549383\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.900887\" y=\"118.372831\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.906002\" y=\"111.744786\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.780905\" y=\"114.139363\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"502.067257\" y=\"113.630201\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.639422\" y=\"110.990699\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.23419\" y=\"116.245427\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.229051\" y=\"110.771786\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"449.45111\" y=\"124.845917\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.14826\" y=\"115.171777\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"450.801773\" y=\"104.613286\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"437.933572\" y=\"118.718587\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.058458\" y=\"120.892985\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"491.334779\" y=\"109.844485\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"446.261382\" y=\"104.757657\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"457.715306\" y=\"111.817632\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"432.696438\" y=\"109.683764\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.828316\" y=\"111.163654\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.787293\" y=\"116.080975\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.913856\" y=\"108.2582\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.326956\" y=\"118.842503\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"430.966492\" y=\"103.861063\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"493.891624\" y=\"105.829515\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"452.724632\" y=\"121.130346\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.902551\" y=\"119.173911\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.591615\" y=\"111.789834\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"509.964745\" y=\"113.700843\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"436.692278\" y=\"124.576749\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"505.137638\" y=\"114.544028\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"509.304079\" y=\"113.841255\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"465.015048\" y=\"109.853263\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"487.166729\" y=\"109.111132\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"455.877155\" y=\"109.049307\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"431.02413\" y=\"173.55571\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.3412\" y=\"116.217984\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.101472\" y=\"113.286582\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"481.641124\" y=\"113.262685\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"505.190374\" y=\"111.665344\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"478.426585\" y=\"115.870285\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"512.560615\" y=\"107.071372\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"468.518255\" y=\"108.449382\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"417.735144\" y=\"63.449181\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"455.358401\" y=\"107.39583\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.487653\" y=\"110.374972\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.337394\" y=\"110.550466\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"500.070507\" y=\"111.018486\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.141547\" y=\"106.420968\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"462.468228\" y=\"110.299552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"458.371421\" y=\"121.230496\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"444.347682\" y=\"117.94586\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.245198\" y=\"119.358552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"444.8137\" y=\"107.782465\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"520.266297\" y=\"112.298885\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"467.408066\" y=\"118.44319\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.646717\" y=\"114.411166\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"505.669947\" y=\"114.300284\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"436.985041\" y=\"102.712278\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.436293\" y=\"107.905111\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.230134\" y=\"95.195514\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"466.003222\" y=\"110.548302\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.645371\" y=\"114.291508\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"416.578473\" y=\"95.377065\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"519.559051\" y=\"112.625589\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.381206\" y=\"110.653311\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.53395\" y=\"114.106905\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"464.381916\" y=\"110.976285\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.244492\" y=\"111.273287\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.50495\" y=\"113.440482\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"486.385842\" y=\"113.73436\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"427.386724\" y=\"117.402528\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.906805\" y=\"116.285861\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.748994\" y=\"117.265056\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"446.916498\" y=\"95.72314\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"447.184531\" y=\"100.812265\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"441.874844\" y=\"115.515762\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"451.00696\" y=\"122.936843\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"516.724823\" y=\"106.408722\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.659693\" y=\"108.712136\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"509.348381\" y=\"112.873913\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"469.283702\" y=\"115.353305\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.669378\" y=\"109.655023\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"482.956027\" y=\"116.834131\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.187594\" y=\"110.322313\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"429.925904\" y=\"91.405866\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.200964\" y=\"117.254553\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"461.24694\" y=\"105.560051\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"448.194082\" y=\"121.973724\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"432.486816\" y=\"99.918533\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.727806\" y=\"103.810851\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"453.481981\" y=\"111.537939\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"422.333355\" y=\"106.960412\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.320507\" y=\"122.477946\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"469.089882\" y=\"107.814969\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"502.938116\" y=\"119.126579\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.69117\" y=\"112.329414\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.3895\" y=\"114.197968\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"478.441789\" y=\"113.828339\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.180483\" y=\"131.066793\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"441.411052\" y=\"109.701186\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"441.538055\" y=\"129.594999\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"517.34463\" y=\"113.645335\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"497.821724\" y=\"114.67029\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"499.733953\" y=\"110.330057\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.820252\" y=\"114.735027\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.227982\" y=\"116.531262\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"399.219077\" y=\"100.199575\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.032896\" y=\"107.491526\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"504.95876\" y=\"114.279994\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"507.53011\" y=\"111.262024\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"470.075408\" y=\"106.739529\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"461.038093\" y=\"128.99232\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.978272\" y=\"112.885879\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"504.709315\" y=\"113.655168\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"472.384386\" y=\"109.837669\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.875054\" y=\"110.184138\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.450705\" y=\"114.554253\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.856873\" y=\"105.200122\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.467725\" y=\"116.865377\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"505.951747\" y=\"112.973857\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"442.475055\" y=\"129.631927\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"479.45973\" y=\"119.078093\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.961314\" y=\"109.626774\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"462.244612\" y=\"108.208629\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"487.42884\" y=\"112.872962\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"463.567946\" y=\"115.016258\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.419905\" y=\"116.364514\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.461885\" y=\"112.522315\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"461.416864\" y=\"103.303786\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.29898\" y=\"112.803254\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"418.980302\" y=\"110.912395\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"514.736575\" y=\"110.691852\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.857745\" y=\"113.822612\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"451.977845\" y=\"109.059997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"478.408518\" y=\"123.361533\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"504.00174\" y=\"111.572446\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"522.84791\" y=\"115.87389\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"497.325106\" y=\"111.635019\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.907504\" y=\"111.264647\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"463.561461\" y=\"109.273744\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"482.905171\" y=\"107.643082\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"410.570676\" y=\"115.443717\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"485.92292\" y=\"112.29463\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"437.167751\" y=\"98.815523\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.605718\" y=\"115.744802\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"472.74915\" y=\"116.476336\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"452.903419\" y=\"111.052764\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"488.434007\" y=\"117.096567\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.450416\" y=\"110.5929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"525.931127\" y=\"111.930313\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"468.625282\" y=\"99.171692\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"464.152736\" y=\"107.339186\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.061709\" y=\"112.915155\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.096353\" y=\"113.350999\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.859396\" y=\"111.334699\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"501.29217\" y=\"118.260242\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"468.451816\" y=\"117.181685\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"523.823297\" y=\"112.168234\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"478.901593\" y=\"124.823359\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"518.742583\" y=\"113.147245\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"496.251133\" y=\"104.901944\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"459.052514\" y=\"113.663594\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"509.246206\" y=\"115.3072\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.788998\" y=\"114.523597\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"514.741215\" y=\"109.532175\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.819776\" y=\"116.368891\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"526.327273\" y=\"107.252217\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"492.137021\" y=\"114.633324\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.320831\" y=\"109.11864\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.299567\" y=\"110.324771\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"479.739857\" y=\"108.61941\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"475.829778\" y=\"124.756928\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"502.228726\" y=\"110.818648\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"487.437719\" y=\"111.315365\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"432.010698\" y=\"111.073521\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"480.949926\" y=\"101.502631\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"434.378509\" y=\"104.258946\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"510.385106\" y=\"119.916528\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"452.973441\" y=\"109.549579\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"435.251884\" y=\"118.826102\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.555904\" y=\"110.477534\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"463.985428\" y=\"113.028578\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"494.054839\" y=\"131.629231\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"418.329997\" y=\"103.952128\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"465.95219\" y=\"118.321584\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"493.012322\" y=\"110.246876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"419.990439\" y=\"118.364999\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.82367\" y=\"115.426767\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"487.872053\" y=\"110.368087\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"445.801352\" y=\"97.868736\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"491.268616\" y=\"116.052992\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"489.192766\" y=\"113.623862\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.839533\" y=\"113.531549\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"483.138991\" y=\"113.915367\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"462.509499\" y=\"108.220747\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"471.267057\" y=\"126.427374\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"520.809373\" y=\"109.444214\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"484.647085\" y=\"114.090577\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"506.169932\" y=\"108.125955\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"520.545851\" y=\"119.135557\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"436.460109\" y=\"117.005901\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"495.886702\" y=\"112.758034\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"477.561739\" y=\"109.934089\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"411.571866\" y=\"108.879556\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"498.747927\" y=\"117.991677\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"447.66078\" y=\"114.440815\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"451.252851\" y=\"98.03327\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"461.93725\" y=\"116.742591\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"464.841955\" y=\"109.032074\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"429.420093\" y=\"113.256187\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"440.305196\" y=\"110.666197\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"419.943764\" y=\"115.226127\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"474.923034\" y=\"105.094511\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"429.438299\" y=\"97.466275\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"460.973371\" y=\"117.609553\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"503.32274\" y=\"114.478394\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"428.170081\" y=\"137.333231\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"519.432551\" y=\"118.192131\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_34\">\n",
       "    <path d=\"M 392.855125 118.954344 \n",
       "L 532.862062 118.954344 \n",
       "\" clip-path=\"url(#p9e4b86b8fe)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_35\">\n",
       "    <path d=\"M 392.855125 107.636048 \n",
       "L 532.862062 107.636048 \n",
       "\" clip-path=\"url(#p9e4b86b8fe)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 392.855125 169.886675 \n",
       "L 392.855125 56.703718 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 419.851158 179.384625 \n",
       "L 529.846326 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_34\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(401.229594 45.1485) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 566.457063 179.384625 \n",
       "L 706.464 179.384625 \n",
       "L 706.464 51.1485 \n",
       "L 566.457063 51.1485 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"570.555537\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(565.538849 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"636.766127\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_36\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(634.319315 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2c5f12540c\" x=\"702.976718\" y=\"179.384625\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_37\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(700.529905 193.9835) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_21\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"566.457063\" y=\"166.416893\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_38\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(543.230063 169.56633) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_22\">\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"566.457063\" y=\"141.645735\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- −5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(548.123688 144.795173) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_23\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"566.457063\" y=\"116.874578\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_40\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(553.263438 120.024015) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_24\">\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"566.457063\" y=\"92.10342\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_41\">\n",
       "      <!-- 5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(553.263438 95.252858) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-35\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_25\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma549b9d4c9\" x=\"566.457063\" y=\"67.332262\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_42\">\n",
       "      <!-- 10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(548.369813 70.4817) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"55.615234\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PathCollection_4\">\n",
       "    <g clip-path=\"url(#p7d199b2a87)\">\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.500512\" y=\"67.195839\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"594.916495\" y=\"135.096868\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"580.857338\" y=\"147.515389\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"633.664626\" y=\"125.708233\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"685.689469\" y=\"115.417459\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"575.728898\" y=\"126.140422\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"684.88608\" y=\"116.659086\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"602.364946\" y=\"152.712581\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.664259\" y=\"123.806011\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"613.149114\" y=\"117.25811\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"633.522009\" y=\"128.762722\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"604.094584\" y=\"123.888538\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"686.127722\" y=\"133.37674\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"660.404072\" y=\"103.866883\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"679.946083\" y=\"147.234701\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"637.820017\" y=\"99.097725\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"630.160536\" y=\"107.972374\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"593.946282\" y=\"106.770466\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.661681\" y=\"141.778973\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"676.514436\" y=\"126.539137\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"599.971732\" y=\"122.979277\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.212686\" y=\"105.869747\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"597.999998\" y=\"118.014387\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"598.755653\" y=\"133.372758\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.60758\" y=\"103.560499\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"658.64557\" y=\"138.63067\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"640.38971\" y=\"135.300456\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"596.322884\" y=\"124.093377\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"668.673137\" y=\"109.517469\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.101248\" y=\"92.785098\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"650.836493\" y=\"113.371689\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"633.368539\" y=\"87.591626\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"599.845415\" y=\"111.575644\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"691.92769\" y=\"143.312701\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"598.651365\" y=\"120.871993\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"598.46573\" y=\"100.094221\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"673.829389\" y=\"131.896935\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"663.24043\" y=\"111.546386\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.356977\" y=\"92.756099\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"591.045301\" y=\"107.124302\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"657.220485\" y=\"128.42722\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.824558\" y=\"134.028709\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"610.446504\" y=\"135.486716\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"683.561478\" y=\"107.783576\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"604.211591\" y=\"95.698905\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.165676\" y=\"127.25332\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"648.915949\" y=\"97.336616\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.880564\" y=\"100.952397\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.810352\" y=\"100.777124\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"572.821014\" y=\"97.048098\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.023525\" y=\"99.658467\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"668.220247\" y=\"161.780933\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"579.552857\" y=\"129.699797\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"685.758794\" y=\"107.359853\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"614.118701\" y=\"92.582086\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"639.089425\" y=\"97.763054\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"587.749738\" y=\"112.985522\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"652.878908\" y=\"121.708126\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"619.325959\" y=\"138.437254\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"610.805922\" y=\"108.941457\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"648.646495\" y=\"125.142149\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.272652\" y=\"104.763399\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"645.261822\" y=\"116.944706\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.478847\" y=\"109.942159\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"573.82718\" y=\"111.844693\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"620.324987\" y=\"99.856794\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"689.505613\" y=\"116.946687\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"659.284989\" y=\"94.17911\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.902794\" y=\"121.201476\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"614.443195\" y=\"118.170565\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"603.71582\" y=\"104.409222\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"673.233225\" y=\"123.537403\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.047529\" y=\"119.116734\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.92474\" y=\"121.315009\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"683.819583\" y=\"93.992127\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"665.617057\" y=\"128.904639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"674.755852\" y=\"110.648666\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"607.61611\" y=\"126.18722\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"627.794617\" y=\"139.594209\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"600.199802\" y=\"126.946081\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.114242\" y=\"114.713151\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"636.734142\" y=\"150.92029\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"582.21897\" y=\"125.367908\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.938833\" y=\"134.098297\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"665.016218\" y=\"122.398071\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"645.093892\" y=\"112.386058\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"592.154993\" y=\"102.974757\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"667.479636\" y=\"124.726085\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"575.590013\" y=\"114.139439\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"585.465614\" y=\"99.775261\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"657.811969\" y=\"130.942744\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"668.657497\" y=\"118.374752\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.318173\" y=\"128.202938\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.065491\" y=\"127.31005\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"696.695905\" y=\"116.458625\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"615.418686\" y=\"94.910578\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"652.861099\" y=\"108.156146\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"581.59815\" y=\"115.004518\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"595.202665\" y=\"108.304195\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"620.63237\" y=\"98.850251\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"632.030678\" y=\"130.725671\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"604.033025\" y=\"131.432473\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"608.331899\" y=\"113.617895\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"622.239266\" y=\"106.649237\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"638.614726\" y=\"118.10883\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"644.251352\" y=\"108.772467\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"608.727579\" y=\"114.65542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"675.357792\" y=\"123.55759\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.56941\" y=\"112.134144\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"700.100048\" y=\"147.939621\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"637.325157\" y=\"98.289556\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"593.200445\" y=\"119.162855\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"601.038491\" y=\"123.965455\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"631.232111\" y=\"124.549226\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"666.872075\" y=\"104.194886\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"654.734489\" y=\"128.916516\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.357537\" y=\"111.889724\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.582777\" y=\"133.628939\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"645.330519\" y=\"112.610671\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"682.874725\" y=\"114.912105\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"587.789516\" y=\"90.347922\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"630.460382\" y=\"135.966206\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"585.514065\" y=\"129.606479\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"677.122438\" y=\"117.706064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"617.111273\" y=\"122.842855\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"596.485982\" y=\"112.328565\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"657.293549\" y=\"133.33221\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"599.710884\" y=\"131.521674\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.753725\" y=\"93.891083\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"661.414427\" y=\"98.64574\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.750124\" y=\"94.645093\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"674.325621\" y=\"119.979508\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"605.370781\" y=\"113.279417\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"665.020357\" y=\"95.247944\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"645.85477\" y=\"95.08382\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"607.23906\" y=\"100.373466\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.993654\" y=\"126.317299\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"594.438414\" y=\"107.226419\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"590.552998\" y=\"124.581147\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"645.815756\" y=\"111.047971\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.532002\" y=\"126.76238\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"692.054683\" y=\"100.537618\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"577.042707\" y=\"106.109296\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"689.389446\" y=\"116.728513\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"591.179335\" y=\"109.741522\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"606.442754\" y=\"110.226416\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.243764\" y=\"129.045542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"693.644227\" y=\"129.782913\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"609.84368\" y=\"107.710307\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.590534\" y=\"79.662837\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.641052\" y=\"121.969151\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"682.702023\" y=\"140.242941\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"639.199242\" y=\"119.849334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"618.505024\" y=\"100.933414\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.374777\" y=\"134.352756\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.44156\" y=\"135.573542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.775016\" y=\"117.491414\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"693.738526\" y=\"127.907587\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"582.198133\" y=\"104.70852\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"576.478069\" y=\"102.585543\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"602.413226\" y=\"87.442088\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"642.989344\" y=\"81.592608\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"671.009613\" y=\"110.929177\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"638.394231\" y=\"95.065615\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.739765\" y=\"120.726498\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"682.404287\" y=\"62.397669\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.065688\" y=\"84.478494\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.631409\" y=\"119.851417\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"585.081653\" y=\"120.172565\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"686.269578\" y=\"103.869463\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.362397\" y=\"116.581816\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.229624\" y=\"106.375262\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.620159\" y=\"153.093509\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"639.66579\" y=\"101.849492\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"685.01043\" y=\"106.258633\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"600.651025\" y=\"105.905847\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"587.01924\" y=\"141.568237\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"580.069219\" y=\"117.184514\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"607.230927\" y=\"110.810135\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"659.835313\" y=\"138.969126\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"661.10711\" y=\"143.210396\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"676.456911\" y=\"89.912125\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"607.20633\" y=\"90.510877\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.526515\" y=\"99.338379\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"610.441254\" y=\"113.57644\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"625.512155\" y=\"118.964306\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"584.958942\" y=\"79.164986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"600.226896\" y=\"108.193573\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"638.156116\" y=\"150.416314\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.600051\" y=\"137.277083\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.163081\" y=\"108.36974\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.246358\" y=\"127.315239\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.447919\" y=\"75.306301\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"600.907024\" y=\"130.507899\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"577.075333\" y=\"103.609122\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"594.411382\" y=\"92.632527\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"652.946915\" y=\"120.838413\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"668.798026\" y=\"139.790486\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"648.117238\" y=\"130.552593\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.265749\" y=\"94.812064\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"685.460261\" y=\"111.210868\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.697924\" y=\"111.21354\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"576.07692\" y=\"104.011683\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.284994\" y=\"131.171194\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"633.56513\" y=\"130.357195\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"663.678479\" y=\"144.564618\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.63637\" y=\"144.935596\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"620.331781\" y=\"131.562226\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"683.424379\" y=\"113.598654\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.717756\" y=\"137.958363\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"583.086857\" y=\"120.536075\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.030441\" y=\"92.720937\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"670.465443\" y=\"112.618727\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"674.064692\" y=\"143.37994\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"627.558634\" y=\"129.754051\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"657.555745\" y=\"121.48714\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"588.924129\" y=\"117.231387\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.249705\" y=\"135.30536\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.792142\" y=\"83.76719\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"692.266345\" y=\"110.277176\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"665.47474\" y=\"89.065656\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.515187\" y=\"90.047707\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"679.382544\" y=\"118.054893\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.141229\" y=\"127.624652\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"618.217135\" y=\"88.961608\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"581.196967\" y=\"104.495441\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"600.399087\" y=\"143.098732\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.398465\" y=\"138.005458\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"615.741774\" y=\"127.215551\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"593.884858\" y=\"121.355172\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"635.323394\" y=\"143.498707\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"658.791986\" y=\"163.93891\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"613.896661\" y=\"125.465121\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"619.257531\" y=\"112.927157\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"576.887692\" y=\"98.218183\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"684.341787\" y=\"122.628616\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.725792\" y=\"109.346141\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"632.073992\" y=\"149.520407\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"675.723804\" y=\"107.713779\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"583.371962\" y=\"120.631477\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"581.381511\" y=\"139.203869\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"612.778162\" y=\"111.046554\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"635.323665\" y=\"93.544755\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"605.870654\" y=\"116.47543\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.903408\" y=\"128.629811\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"663.55333\" y=\"109.079366\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"609.407186\" y=\"127.80345\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.904313\" y=\"106.500583\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"618.595195\" y=\"126.326677\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"689.325587\" y=\"56.977415\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"601.30257\" y=\"111.08049\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"595.148233\" y=\"110.419123\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"651.256541\" y=\"111.218621\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"615.710274\" y=\"126.973713\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.414646\" y=\"83.531153\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"593.140135\" y=\"107.677399\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.317576\" y=\"103.320374\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.149889\" y=\"150.314997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.642733\" y=\"111.333304\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"661.055829\" y=\"124.450589\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"633.777612\" y=\"116.179309\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"659.891413\" y=\"106.346755\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"576.461316\" y=\"109.224087\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.530609\" y=\"132.886751\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"638.375453\" y=\"124.216613\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"587.226562\" y=\"111.655688\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"645.52543\" y=\"109.310507\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.065934\" y=\"103.302399\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"597.815746\" y=\"143.055582\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"641.650135\" y=\"106.84634\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"658.090689\" y=\"108.173983\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.843012\" y=\"78.342851\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"590.56977\" y=\"96.438446\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"594.326562\" y=\"110.43948\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"635.719926\" y=\"120.532963\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"580.351367\" y=\"119.234546\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.727936\" y=\"132.794337\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.147622\" y=\"125.519822\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.605447\" y=\"113.670447\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"671.503071\" y=\"137.796947\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"591.767618\" y=\"109.082542\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"677.578428\" y=\"145.841805\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"659.048543\" y=\"90.753154\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"598.084784\" y=\"104.381382\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"650.06794\" y=\"109.750433\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"603.489856\" y=\"139.813051\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.651449\" y=\"114.912761\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"646.742188\" y=\"113.569562\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.058148\" y=\"115.479693\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"676.853586\" y=\"83.847949\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"637.608515\" y=\"113.107802\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"670.043009\" y=\"93.168368\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"676.958263\" y=\"120.349505\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"648.901429\" y=\"123.949955\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"599.731527\" y=\"123.693625\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"626.897056\" y=\"142.674146\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"640.579892\" y=\"136.394744\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"584.784897\" y=\"119.786512\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"671.412598\" y=\"161.279034\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"579.383325\" y=\"106.601815\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"603.101035\" y=\"78.240909\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"601.499875\" y=\"107.9722\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"670.162687\" y=\"144.552198\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"691.569688\" y=\"140.704164\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.639144\" y=\"118.304334\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"671.00327\" y=\"129.792254\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"621.502632\" y=\"121.256495\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"667.637045\" y=\"120.56116\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"644.770347\" y=\"122.046061\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"641.64601\" y=\"116.967323\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"582.350224\" y=\"118.966907\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"627.801206\" y=\"95.372552\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"687.021578\" y=\"127.470725\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.479159\" y=\"85.709149\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.755491\" y=\"108.193211\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"680.677797\" y=\"96.896726\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"620.997657\" y=\"125.866367\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"613.15505\" y=\"122.428209\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.777611\" y=\"98.119395\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.207827\" y=\"114.326338\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"640.796179\" y=\"113.788205\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"670.694723\" y=\"122.616512\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"625.602164\" y=\"106.481962\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"606.415627\" y=\"110.770499\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"627.538028\" y=\"96.60999\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"651.934024\" y=\"145.76666\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"596.751228\" y=\"123.543092\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.931042\" y=\"82.483367\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.981286\" y=\"114.431709\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"591.979987\" y=\"88.156493\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"687.01467\" y=\"73.30397\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"637.328996\" y=\"107.252507\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"591.884814\" y=\"148.568205\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"608.996774\" y=\"117.488221\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"577.632646\" y=\"131.766762\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"636.517604\" y=\"123.773736\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"615.886652\" y=\"80.456175\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"622.446112\" y=\"107.144012\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"625.838384\" y=\"89.169994\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"615.601259\" y=\"124.376584\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"679.278966\" y=\"101.67005\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"632.615983\" y=\"147.899233\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"594.950846\" y=\"123.268914\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.825159\" y=\"131.729167\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"577.497638\" y=\"107.706416\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.055763\" y=\"99.393318\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"596.18018\" y=\"137.97304\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.036647\" y=\"103.136394\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.797512\" y=\"107.895814\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"666.098055\" y=\"120.266791\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"628.478458\" y=\"115.210924\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"579.608005\" y=\"130.451416\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"615.823651\" y=\"124.643481\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"580.824457\" y=\"109.299394\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"681.510938\" y=\"116.063297\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.279738\" y=\"118.992592\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"679.400386\" y=\"155.965921\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"641.736609\" y=\"113.501977\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"579.677087\" y=\"123.268596\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.109355\" y=\"100.773271\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"584.135143\" y=\"131.666559\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"639.539652\" y=\"111.063926\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"683.716091\" y=\"114.918444\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"604.213584\" y=\"139.91507\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"586.722272\" y=\"111.186437\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"599.992748\" y=\"98.307874\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.942028\" y=\"112.996516\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"616.255899\" y=\"130.631997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"663.239748\" y=\"128.98763\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"597.33865\" y=\"133.5137\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"592.530459\" y=\"130.434724\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"668.154512\" y=\"135.013288\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"679.198806\" y=\"134.478539\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"622.664065\" y=\"73.01293\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.30295\" y=\"113.436612\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"682.36145\" y=\"78.305839\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"629.432333\" y=\"114.042237\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.688839\" y=\"107.210466\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"638.688373\" y=\"140.595592\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"630.543693\" y=\"90.176524\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"610.453906\" y=\"116.254997\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"635.004945\" y=\"114.523769\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"613.595826\" y=\"133.272078\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.207336\" y=\"118.089962\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"682.361091\" y=\"114.501416\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"636.337455\" y=\"104.0876\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.015425\" y=\"126.148272\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"642.375268\" y=\"148.109565\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"646.440393\" y=\"102.551587\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"596.479826\" y=\"124.942768\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"659.255683\" y=\"104.3367\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"635.570559\" y=\"119.06043\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"680.84544\" y=\"79.068986\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.346874\" y=\"113.256943\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"587.556952\" y=\"88.584478\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"626.371471\" y=\"110.021579\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"632.85083\" y=\"111.033887\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"665.956587\" y=\"146.317061\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"658.547413\" y=\"123.093268\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"675.428763\" y=\"90.892233\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"650.36755\" y=\"128.255494\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"627.976812\" y=\"107.622632\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"581.045194\" y=\"142.063145\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"631.356198\" y=\"115.52473\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"675.177002\" y=\"173.55571\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"657.164734\" y=\"116.023572\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"667.808427\" y=\"124.571851\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"612.180733\" y=\"80.428492\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"592.333718\" y=\"108.316409\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"660.902892\" y=\"131.203122\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"607.893525\" y=\"100.946796\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"614.857977\" y=\"112.704896\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"610.999511\" y=\"120.821608\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"624.298022\" y=\"115.195373\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.692669\" y=\"78.381812\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"653.720864\" y=\"144.945338\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"648.177999\" y=\"115.882117\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"632.061271\" y=\"102.244145\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"604.025017\" y=\"95.802228\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"642.608983\" y=\"109.579675\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"604.133782\" y=\"114.91313\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"635.810066\" y=\"123.985544\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"696.294037\" y=\"99.268929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.251519\" y=\"105.92112\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.368017\" y=\"137.228958\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"647.503603\" y=\"123.205972\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.293162\" y=\"109.35208\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"632.390797\" y=\"121.136727\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"576.917978\" y=\"128.391138\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"670.760795\" y=\"125.002952\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"594.702727\" y=\"126.264884\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"617.20706\" y=\"90.294633\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"687.576409\" y=\"80.062642\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"626.08837\" y=\"109.952929\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.353519\" y=\"113.36971\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.327445\" y=\"101.388157\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.859623\" y=\"112.734024\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"612.928136\" y=\"157.810446\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"609.044752\" y=\"144.586026\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"643.730896\" y=\"127.972333\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"675.803689\" y=\"88.046521\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"660.112222\" y=\"135.310664\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"655.040592\" y=\"135.232482\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"578.274312\" y=\"136.880119\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.792391\" y=\"118.768715\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.74368\" y=\"126.419423\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.724443\" y=\"98.540771\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"679.300219\" y=\"115.849187\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"687.314447\" y=\"129.207639\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"666.284903\" y=\"135.608539\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"688.519371\" y=\"96.930476\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.269397\" y=\"106.713208\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"606.311513\" y=\"101.841179\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"625.91531\" y=\"98.195044\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"636.098459\" y=\"95.664137\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.87251\" y=\"112.416993\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"581.591104\" y=\"137.485778\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.740457\" y=\"91.855272\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"619.859001\" y=\"123.0179\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"674.29407\" y=\"100.566696\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"634.105935\" y=\"118.84972\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"681.665455\" y=\"111.682177\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"639.081531\" y=\"91.742217\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"586.006027\" y=\"115.082861\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"672.758853\" y=\"117.971686\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"579.623991\" y=\"111.320828\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"656.420526\" y=\"110.286406\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"616.595494\" y=\"101.114462\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"636.007595\" y=\"75.736933\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"667.778238\" y=\"116.439966\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"678.454595\" y=\"107.192131\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"650.640137\" y=\"134.271057\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"602.619703\" y=\"152.513413\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"629.040703\" y=\"137.391134\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"670.674235\" y=\"127.421713\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"598.742587\" y=\"117.146054\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"623.360908\" y=\"118.528633\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"620.293702\" y=\"117.077256\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"680.721381\" y=\"118.051871\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"626.320686\" y=\"84.972908\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.619784\" y=\"89.904187\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"666.661975\" y=\"111.633594\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"582.171495\" y=\"116.193175\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"649.442626\" y=\"145.017411\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"638.041261\" y=\"127.617394\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"611.910391\" y=\"110.560621\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"676.842747\" y=\"73.228699\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"583.21502\" y=\"124.081738\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"659.172303\" y=\"119.444047\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"673.155023\" y=\"104.411577\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"658.621551\" y=\"84.348274\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"619.284606\" y=\"114.070632\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"584.615213\" y=\"112.842674\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"603.440151\" y=\"123.798822\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"669.086166\" y=\"113.982884\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"572.871722\" y=\"106.908586\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"650.792926\" y=\"134.321937\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"637.08155\" y=\"145.914745\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"664.372931\" y=\"98.181185\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "     <use xlink:href=\"#m62a9b659b5\" x=\"662.194481\" y=\"130.188937\" style=\"fill: #1f77b4; stroke: #1f77b4; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_44\">\n",
       "    <path d=\"M 566.457063 126.783041 \n",
       "L 706.464 126.783041 \n",
       "\" clip-path=\"url(#p7d199b2a87)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_45\">\n",
       "    <path d=\"M 566.457063 106.966115 \n",
       "L 706.464 106.966115 \n",
       "\" clip-path=\"url(#p7d199b2a87)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 566.457063 166.416893 \n",
       "L 566.457063 67.332262 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 570.555537 179.384625 \n",
       "L 702.976718 179.384625 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_43\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(574.562281 45.1485) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_44\">\n",
       "   <!-- Residual plot -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(310.5845 18.6525) scale(0.16 -0.16)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-52\" d=\"M 503 0 \n",
       "L 503 4581 \n",
       "L 2534 4581 \n",
       "Q 3147 4581 3465 4457 \n",
       "Q 3784 4334 3975 4021 \n",
       "Q 4166 3709 4166 3331 \n",
       "Q 4166 2844 3850 2509 \n",
       "Q 3534 2175 2875 2084 \n",
       "Q 3116 1969 3241 1856 \n",
       "Q 3506 1613 3744 1247 \n",
       "L 4541 0 \n",
       "L 3778 0 \n",
       "L 3172 953 \n",
       "Q 2906 1366 2734 1584 \n",
       "Q 2563 1803 2427 1890 \n",
       "Q 2291 1978 2150 2013 \n",
       "Q 2047 2034 1813 2034 \n",
       "L 1109 2034 \n",
       "L 1109 0 \n",
       "L 503 0 \n",
       "z\n",
       "M 1109 2559 \n",
       "L 2413 2559 \n",
       "Q 2828 2559 3062 2645 \n",
       "Q 3297 2731 3419 2920 \n",
       "Q 3541 3109 3541 3331 \n",
       "Q 3541 3656 3305 3865 \n",
       "Q 3069 4075 2559 4075 \n",
       "L 1109 4075 \n",
       "L 1109 2559 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-52\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"72.216797\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"127.832031\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"177.832031\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"200.048828\"/>\n",
       "    <use xlink:href=\"#ArialMT-75\" x=\"255.664062\"/>\n",
       "    <use xlink:href=\"#ArialMT-61\" x=\"311.279297\"/>\n",
       "    <use xlink:href=\"#ArialMT-6c\" x=\"366.894531\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"389.111328\"/>\n",
       "    <use xlink:href=\"#ArialMT-70\" x=\"416.894531\"/>\n",
       "    <use xlink:href=\"#ArialMT-6c\" x=\"472.509766\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"494.726562\"/>\n",
       "    <use xlink:href=\"#ArialMT-74\" x=\"550.341797\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p1a9c64e532\">\n",
       "   <rect x=\"45.65125\" y=\"51.1485\" width=\"140.006937\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pa5eb991221\">\n",
       "   <rect x=\"219.253188\" y=\"51.1485\" width=\"140.006937\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p9e4b86b8fe\">\n",
       "   <rect x=\"392.855125\" y=\"51.1485\" width=\"140.006937\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p7d199b2a87\">\n",
       "   <rect x=\"566.457063\" y=\"51.1485\" width=\"140.006937\" height=\"128.236125\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1000x300 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(10, 3), tight_layout=True)\n",
    "fig.suptitle('Residual plot', fontsize=16)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].scatter(means_test[:, i], standardized_errors[:, i], 1)\n",
    "    ax[i].set_title(o_name)\n",
    "    ax[i].axhline(-2, color='r', lw=0.5, label=r'95% CI')\n",
    "    ax[i].axhline(2, color='r', lw=0.5)\n",
    "    sns.despine(trim=True, ax=ax[i])\n",
    "ax[0].set_xlabel('Predicted')\n",
    "ax[0].set_ylabel('Standardized error')\n",
    "ax[0].legend();"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The variance in the errors seems to change with the output value. Similar to the parity plots, this basically tells us that the GP fit is somewhat off and we may need more training data. (Whether we actually use more data depends, of course, on how accurate we need our surrogate to be.)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Sensitivity analysis with surrogate\n",
    "\n",
    "Now that we have a trained and tested surrogate, there are many useful things we can do with it. As in the neural network surrogate hands-on activity, we'll demonstrate using the surrogate to do Sobol sensitivity analysis.\n",
    "\n",
    "Now, let's create bounds for the inputs (based on physical intuition and/or literature values):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 28,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "The input bounds are:\n",
      " [[1.00e+00 2.00e+01]\n",
      " [1.00e+00 1.05e+00]\n",
      " [4.00e+00 5.00e+00]\n",
      " [8.00e+00 1.59e+01]\n",
      " [1.33e-01 2.10e-01]\n",
      " [1.80e+01 3.60e+01]\n",
      " [1.50e+02 2.50e+02]\n",
      " [0.00e+00 3.00e+00]\n",
      " [0.00e+00 4.00e+00]\n",
      " [0.00e+00 1.00e-01]]\n"
     ]
    }
   ],
   "source": [
    "import SALib.sample.sobol as sobol\n",
    "import SALib.analyze.sobol as analyze_sobol\n",
    "\n",
    "input_bounds_dict = {\n",
    "    'viscosity_cP': [1.0, 20.0],\n",
    "    'fill_volume_mL': [1.0, 1.05],\n",
    "    'air_gap_height_mm': [4.0, 5.0],\n",
    "    'needle_length_mm': [8.0, 15.9],\n",
    "    'needle_diameter_mm': [0.133, 0.21],\n",
    "    'spring_force_N': [18.0, 36.0],\n",
    "    'spring_constant_N_per_mm': [150.0, 250.0],\n",
    "    'kappa5': [0.0, 3.0],\n",
    "    'kappa6': [0.0, 4.0],\n",
    "    'kappa7': [0.0, 0.1]\n",
    "}\n",
    "input_bounds = np.array([[input_bounds_dict[i][0], input_bounds_dict[i][1]] for i in INPUT_NAMES])\n",
    "print('The input bounds are:\\n', input_bounds)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Next, we create Sobol samples of the inputs and pass them through the surrogate:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "metadata": {},
   "outputs": [],
   "source": [
    "problem = {\n",
    "    'num_vars': len(INPUT_NAMES),\n",
    "    'names': INPUT_NAMES,\n",
    "    'bounds': input_bounds\n",
    "}\n",
    "\n",
    "# The number of samples to generate (should be a power of 2).\n",
    "N = 512\n",
    "\n",
    "# Generate the samples.\n",
    "sobol_samples = sobol.sample(problem, N, calc_second_order=False)\n",
    "\n",
    "# Evaluate the surrogate model at the Sobol samples.\n",
    "sobol_outputs = surrogate(sobol_samples)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Finally, we calculate and plot the Sobol indices:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "metadata": {},
   "outputs": [],
   "source": [
    "sobol_indices = {}\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    sobol_indices[o_name] = analyze_sobol.analyze(problem, sobol_outputs[:, i], calc_second_order=False, print_to_console=False)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 31,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"1073.664pt\" height=\"286.272pt\" viewBox=\"0 0 1073.664 286.272\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2024-10-09T14:41:18.487587</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.9.2, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 286.272 \n",
       "L 1073.664 286.272 \n",
       "L 1073.664 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 27.732 160.234375 \n",
       "L 276.039 160.234375 \n",
       "L 276.039 49.7085 \n",
       "L 27.732 49.7085 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m3c4f3bef32\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"48.2323\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- viscosity_cP -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(50.455675 216.94675) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-79\" d=\"M 397 -1278 \n",
       "L 334 -750 \n",
       "Q 519 -800 656 -800 \n",
       "Q 844 -800 956 -737 \n",
       "Q 1069 -675 1141 -563 \n",
       "Q 1194 -478 1313 -144 \n",
       "Q 1328 -97 1363 -6 \n",
       "L 103 3319 \n",
       "L 709 3319 \n",
       "L 1400 1397 \n",
       "Q 1534 1031 1641 628 \n",
       "Q 1738 1016 1872 1384 \n",
       "L 2581 3319 \n",
       "L 3144 3319 \n",
       "L 1881 -56 \n",
       "Q 1678 -603 1566 -809 \n",
       "Q 1416 -1088 1222 -1217 \n",
       "Q 1028 -1347 759 -1347 \n",
       "Q 597 -1347 397 -1278 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-5f\" d=\"M -97 -1272 \n",
       "L -97 -866 \n",
       "L 3631 -866 \n",
       "L 3631 -1272 \n",
       "L -97 -1272 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-76\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"122.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"172.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"227.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"277.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"300.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-79\" x=\"327.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"377.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"433.447266\"/>\n",
       "       <use xlink:href=\"#ArialMT-50\" x=\"483.447266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"71.266344\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- fill_volume_mL -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(73.594907 227.222125) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-4c\" d=\"M 469 0 \n",
       "L 469 4581 \n",
       "L 1075 4581 \n",
       "L 1075 541 \n",
       "L 3331 541 \n",
       "L 3331 0 \n",
       "L 469 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-66\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"27.783203\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"94.433594\"/>\n",
       "       <use xlink:href=\"#ArialMT-76\" x=\"150.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"200.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"255.664062\"/>\n",
       "       <use xlink:href=\"#ArialMT-75\" x=\"277.880859\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"333.496094\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"416.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"472.412109\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"528.027344\"/>\n",
       "       <use xlink:href=\"#ArialMT-4c\" x=\"611.328125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"94.300389\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- air_gap_height_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(96.523764 246.309875) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-67\" d=\"M 319 -275 \n",
       "L 866 -356 \n",
       "Q 900 -609 1056 -725 \n",
       "Q 1266 -881 1628 -881 \n",
       "Q 2019 -881 2231 -725 \n",
       "Q 2444 -569 2519 -288 \n",
       "Q 2563 -116 2559 434 \n",
       "Q 2191 0 1641 0 \n",
       "Q 956 0 581 494 \n",
       "Q 206 988 206 1678 \n",
       "Q 206 2153 378 2554 \n",
       "Q 550 2956 876 3175 \n",
       "Q 1203 3394 1644 3394 \n",
       "Q 2231 3394 2613 2919 \n",
       "L 2613 3319 \n",
       "L 3131 3319 \n",
       "L 3131 450 \n",
       "Q 3131 -325 2973 -648 \n",
       "Q 2816 -972 2473 -1159 \n",
       "Q 2131 -1347 1631 -1347 \n",
       "Q 1038 -1347 672 -1080 \n",
       "Q 306 -813 319 -275 \n",
       "z\n",
       "M 784 1719 \n",
       "Q 784 1066 1043 766 \n",
       "Q 1303 466 1694 466 \n",
       "Q 2081 466 2343 764 \n",
       "Q 2606 1063 2606 1700 \n",
       "Q 2606 2309 2336 2618 \n",
       "Q 2066 2928 1684 2928 \n",
       "Q 1309 2928 1046 2623 \n",
       "Q 784 2319 784 1719 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-68\" d=\"M 422 0 \n",
       "L 422 4581 \n",
       "L 984 4581 \n",
       "L 984 2938 \n",
       "Q 1378 3394 1978 3394 \n",
       "Q 2347 3394 2619 3248 \n",
       "Q 2891 3103 3008 2847 \n",
       "Q 3125 2591 3125 2103 \n",
       "L 3125 0 \n",
       "L 2563 0 \n",
       "L 2563 2103 \n",
       "Q 2563 2525 2380 2717 \n",
       "Q 2197 2909 1863 2909 \n",
       "Q 1613 2909 1392 2779 \n",
       "Q 1172 2650 1078 2428 \n",
       "Q 984 2206 984 1816 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-61\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"77.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"111.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"166.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"222.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"277.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"333.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"389.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"444.824219\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"500.439453\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"522.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"578.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"633.886719\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"661.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"717.285156\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"117.334433\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- needle_length_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(119.557808 243.37975) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"378.125\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"544.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"572.753906\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"628.369141\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"683.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"767.285156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"140.368478\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- needle_diameter_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(142.643415 253.64) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"572.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"628.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"656.054688\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"711.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"744.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"883.886719\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"163.402522\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- spring_force_N -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(165.679522 228.20525) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-66\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"355.761719\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"411.376953\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"444.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"494.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"550.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"605.908203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"186.436567\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- spring_constant_N_per_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(188.659942 279.072) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"377.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"489.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"539.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"566.992188\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"622.607422\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"678.222656\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"706.005859\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"761.621094\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"833.837891\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"889.453125\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"945.068359\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"1000.683594\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"1033.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1089.599609\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1172.900391\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"209.470611\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- kappa5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(211.745549 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-6b\" d=\"M 425 0 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 1969 \n",
       "L 2319 3319 \n",
       "L 3047 3319 \n",
       "L 1778 2088 \n",
       "L 3175 0 \n",
       "L 2481 0 \n",
       "L 1384 1697 \n",
       "L 988 1316 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_9\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"232.504656\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- kappa6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(234.792656 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_10\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"255.5387\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- kappa7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(257.813638 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <defs>\n",
       "       <path id=\"mc252d56267\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"27.732\" y=\"153.779221\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 156.928658) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"27.732\" y=\"143.375684\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0.1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 146.525121) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"27.732\" y=\"132.972147\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 136.121584) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"27.732\" y=\"122.56861\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 125.718047) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"27.732\" y=\"112.165073\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(7.2 115.31451) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 39.018682 153.779221 \n",
       "L 57.445917 153.779221 \n",
       "L 57.445917 108.4525 \n",
       "L 39.018682 108.4525 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 62.052726 153.779221 \n",
       "L 80.479962 153.779221 \n",
       "L 80.479962 154.103252 \n",
       "L 62.052726 154.103252 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_5\">\n",
       "    <path d=\"M 85.086771 153.779221 \n",
       "L 103.514006 153.779221 \n",
       "L 103.514006 154.599586 \n",
       "L 85.086771 154.599586 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_6\">\n",
       "    <path d=\"M 108.120815 153.779221 \n",
       "L 126.548051 153.779221 \n",
       "L 126.548051 139.866802 \n",
       "L 108.120815 139.866802 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 131.15486 153.779221 \n",
       "L 149.582096 153.779221 \n",
       "L 149.582096 151.228778 \n",
       "L 131.15486 151.228778 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 154.188904 153.779221 \n",
       "L 172.61614 153.779221 \n",
       "L 172.61614 152.175632 \n",
       "L 154.188904 152.175632 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 177.222949 153.779221 \n",
       "L 195.650185 153.779221 \n",
       "L 195.650185 154.774081 \n",
       "L 177.222949 154.774081 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 200.256994 153.779221 \n",
       "L 218.684229 153.779221 \n",
       "L 218.684229 153.669699 \n",
       "L 200.256994 153.669699 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_11\">\n",
       "    <path d=\"M 223.291038 153.779221 \n",
       "L 241.718274 153.779221 \n",
       "L 241.718274 145.72927 \n",
       "L 223.291038 145.72927 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_12\">\n",
       "    <path d=\"M 246.325083 153.779221 \n",
       "L 264.752318 153.779221 \n",
       "L 264.752318 153.989864 \n",
       "L 246.325083 153.989864 \n",
       "z\n",
       "\" clip-path=\"url(#p0d0cabefbc)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_13\">\n",
       "    <path d=\"M 27.732 153.779221 \n",
       "L 27.732 112.165073 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_14\">\n",
       "    <path d=\"M 48.2323 160.234375 \n",
       "L 255.5387 160.234375 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- needle_displacement_m -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(99.85575 43.7085) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6e\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"433.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"483.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"539.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"561.572266\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"617.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"667.1875\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"722.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"806.103516\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"861.71875\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"917.333984\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"945.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"1000.732422\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"patch_15\">\n",
       "    <path d=\"M 291.207 160.234375 \n",
       "L 539.514 160.234375 \n",
       "L 539.514 49.7085 \n",
       "L 291.207 49.7085 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"xtick_11\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"311.7073\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- viscosity_cP -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.930675 216.94675) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-76\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"122.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"172.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"227.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"277.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"300.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-79\" x=\"327.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"377.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"433.447266\"/>\n",
       "       <use xlink:href=\"#ArialMT-50\" x=\"483.447266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_12\">\n",
       "     <g id=\"line2d_17\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"334.741344\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_18\">\n",
       "      <!-- fill_volume_mL -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(337.069907 227.222125) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-66\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"27.783203\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"94.433594\"/>\n",
       "       <use xlink:href=\"#ArialMT-76\" x=\"150.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"200.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"255.664062\"/>\n",
       "       <use xlink:href=\"#ArialMT-75\" x=\"277.880859\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"333.496094\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"416.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"472.412109\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"528.027344\"/>\n",
       "       <use xlink:href=\"#ArialMT-4c\" x=\"611.328125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_13\">\n",
       "     <g id=\"line2d_18\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"357.775389\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_19\">\n",
       "      <!-- air_gap_height_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(359.998764 246.309875) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-61\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"77.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"111.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"166.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"222.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"277.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"333.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"389.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"444.824219\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"500.439453\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"522.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"578.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"633.886719\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"661.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"717.285156\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_14\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"380.809433\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_20\">\n",
       "      <!-- needle_length_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(383.032808 243.37975) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"378.125\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"544.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"572.753906\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"628.369141\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"683.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"767.285156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_15\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"403.843478\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- needle_diameter_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(406.118415 253.64) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"572.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"628.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"656.054688\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"711.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"744.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"883.886719\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_16\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"426.877522\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- spring_force_N -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(429.154522 228.20525) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-66\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"355.761719\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"411.376953\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"444.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"494.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"550.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"605.908203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_17\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"449.911567\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- spring_constant_N_per_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(452.134942 279.072) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"377.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"489.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"539.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"566.992188\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"622.607422\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"678.222656\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"706.005859\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"761.621094\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"833.837891\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"889.453125\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"945.068359\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"1000.683594\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"1033.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1089.599609\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1172.900391\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_18\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"472.945611\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- kappa5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(475.220549 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_19\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"495.979656\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- kappa6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(498.267656 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_20\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"519.0137\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- kappa7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(521.288638 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_4\">\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"291.207\" y=\"153.779221\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"291.207\" y=\"143.375684\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"291.207\" y=\"132.972147\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_29\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"291.207\" y=\"122.56861\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_30\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"291.207\" y=\"112.165073\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_16\">\n",
       "    <path d=\"M 302.493682 153.779221 \n",
       "L 320.920917 153.779221 \n",
       "L 320.920917 116.804093 \n",
       "L 302.493682 116.804093 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_17\">\n",
       "    <path d=\"M 325.527726 153.779221 \n",
       "L 343.954962 153.779221 \n",
       "L 343.954962 153.720959 \n",
       "L 325.527726 153.720959 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_18\">\n",
       "    <path d=\"M 348.561771 153.779221 \n",
       "L 366.989006 153.779221 \n",
       "L 366.989006 153.730383 \n",
       "L 348.561771 153.730383 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_19\">\n",
       "    <path d=\"M 371.595815 153.779221 \n",
       "L 390.023051 153.779221 \n",
       "L 390.023051 148.838603 \n",
       "L 371.595815 148.838603 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_20\">\n",
       "    <path d=\"M 394.62986 153.779221 \n",
       "L 413.057096 153.779221 \n",
       "L 413.057096 119.099736 \n",
       "L 394.62986 119.099736 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_21\">\n",
       "    <path d=\"M 417.663904 153.779221 \n",
       "L 436.09114 153.779221 \n",
       "L 436.09114 145.394868 \n",
       "L 417.663904 145.394868 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_22\">\n",
       "    <path d=\"M 440.697949 153.779221 \n",
       "L 459.125185 153.779221 \n",
       "L 459.125185 153.787126 \n",
       "L 440.697949 153.787126 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_23\">\n",
       "    <path d=\"M 463.731994 153.779221 \n",
       "L 482.159229 153.779221 \n",
       "L 482.159229 153.835199 \n",
       "L 463.731994 153.835199 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_24\">\n",
       "    <path d=\"M 486.766038 153.779221 \n",
       "L 505.193274 153.779221 \n",
       "L 505.193274 153.820536 \n",
       "L 486.766038 153.820536 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_25\">\n",
       "    <path d=\"M 509.800083 153.779221 \n",
       "L 528.227318 153.779221 \n",
       "L 528.227318 153.832171 \n",
       "L 509.800083 153.832171 \n",
       "z\n",
       "\" clip-path=\"url(#pa2774eefb0)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_26\">\n",
       "    <path d=\"M 291.207 153.779221 \n",
       "L 291.207 112.165073 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_27\">\n",
       "    <path d=\"M 311.7073 160.234375 \n",
       "L 519.0137 160.234375 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_27\">\n",
       "    <!-- injection_time_s -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(380.9445 43.7085) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-6a\" d=\"M 419 3928 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 3928 \n",
       "L 419 3928 \n",
       "z\n",
       "M -294 -1288 \n",
       "L -188 -809 \n",
       "Q -19 -853 78 -853 \n",
       "Q 250 -853 334 -739 \n",
       "Q 419 -625 419 -169 \n",
       "L 419 3319 \n",
       "L 981 3319 \n",
       "L 981 -181 \n",
       "Q 981 -794 822 -1034 \n",
       "Q 619 -1347 147 -1347 \n",
       "Q -81 -1347 -294 -1288 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-69\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"22.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-6a\" x=\"77.832031\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"100.048828\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"155.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"205.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"233.447266\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"255.664062\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"311.279297\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"366.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"422.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"450.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"472.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"555.810547\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"611.425781\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"667.041016\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_3\">\n",
       "   <g id=\"patch_28\">\n",
       "    <path d=\"M 554.682 160.234375 \n",
       "L 802.989 160.234375 \n",
       "L 802.989 49.7085 \n",
       "L 554.682 49.7085 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_5\">\n",
       "    <g id=\"xtick_21\">\n",
       "     <g id=\"line2d_31\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"575.1823\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- viscosity_cP -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(577.405675 216.94675) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-76\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"122.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"172.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"227.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"277.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"300.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-79\" x=\"327.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"377.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"433.447266\"/>\n",
       "       <use xlink:href=\"#ArialMT-50\" x=\"483.447266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_22\">\n",
       "     <g id=\"line2d_32\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"598.216344\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- fill_volume_mL -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(600.544907 227.222125) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-66\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"27.783203\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"94.433594\"/>\n",
       "       <use xlink:href=\"#ArialMT-76\" x=\"150.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"200.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"255.664062\"/>\n",
       "       <use xlink:href=\"#ArialMT-75\" x=\"277.880859\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"333.496094\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"416.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"472.412109\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"528.027344\"/>\n",
       "       <use xlink:href=\"#ArialMT-4c\" x=\"611.328125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_23\">\n",
       "     <g id=\"line2d_33\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"621.250389\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- air_gap_height_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(623.473764 246.309875) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-61\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"77.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"111.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"166.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"222.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"277.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"333.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"389.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"444.824219\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"500.439453\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"522.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"578.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"633.886719\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"661.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"717.285156\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_24\">\n",
       "     <g id=\"line2d_34\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"644.284433\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_31\">\n",
       "      <!-- needle_length_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(646.507808 243.37975) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"378.125\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"544.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"572.753906\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"628.369141\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"683.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"767.285156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_25\">\n",
       "     <g id=\"line2d_35\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"667.318478\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_32\">\n",
       "      <!-- needle_diameter_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(669.593415 253.64) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"572.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"628.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"656.054688\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"711.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"744.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"883.886719\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_26\">\n",
       "     <g id=\"line2d_36\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"690.352522\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_33\">\n",
       "      <!-- spring_force_N -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(692.629522 228.20525) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-66\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"355.761719\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"411.376953\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"444.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"494.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"550.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"605.908203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_27\">\n",
       "     <g id=\"line2d_37\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"713.386567\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_34\">\n",
       "      <!-- spring_constant_N_per_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(715.609942 279.072) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"377.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"489.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"539.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"566.992188\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"622.607422\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"678.222656\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"706.005859\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"761.621094\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"833.837891\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"889.453125\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"945.068359\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"1000.683594\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"1033.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1089.599609\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1172.900391\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_28\">\n",
       "     <g id=\"line2d_38\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"736.420611\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_35\">\n",
       "      <!-- kappa5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(738.695549 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_29\">\n",
       "     <g id=\"line2d_39\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"759.454656\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_36\">\n",
       "      <!-- kappa6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(761.742656 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_30\">\n",
       "     <g id=\"line2d_40\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"782.4887\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_37\">\n",
       "      <!-- kappa7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(784.763638 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_6\">\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_41\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"554.682\" y=\"153.779221\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_42\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"554.682\" y=\"143.375684\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_43\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"554.682\" y=\"132.972147\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_44\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"554.682\" y=\"122.56861\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_45\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"554.682\" y=\"112.165073\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_29\">\n",
       "    <path d=\"M 565.968682 153.779221 \n",
       "L 584.395917 153.779221 \n",
       "L 584.395917 153.680126 \n",
       "L 565.968682 153.680126 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_30\">\n",
       "    <path d=\"M 589.002726 153.779221 \n",
       "L 607.429962 153.779221 \n",
       "L 607.429962 151.880069 \n",
       "L 589.002726 151.880069 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_31\">\n",
       "    <path d=\"M 612.036771 153.779221 \n",
       "L 630.464006 153.779221 \n",
       "L 630.464006 153.52635 \n",
       "L 612.036771 153.52635 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_32\">\n",
       "    <path d=\"M 635.070815 153.779221 \n",
       "L 653.498051 153.779221 \n",
       "L 653.498051 153.618067 \n",
       "L 635.070815 153.618067 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_33\">\n",
       "    <path d=\"M 658.10486 153.779221 \n",
       "L 676.532096 153.779221 \n",
       "L 676.532096 153.945253 \n",
       "L 658.10486 153.945253 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_34\">\n",
       "    <path d=\"M 681.138904 153.779221 \n",
       "L 699.56614 153.779221 \n",
       "L 699.56614 145.836901 \n",
       "L 681.138904 145.836901 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_35\">\n",
       "    <path d=\"M 704.172949 153.779221 \n",
       "L 722.600185 153.779221 \n",
       "L 722.600185 153.723906 \n",
       "L 704.172949 153.723906 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_36\">\n",
       "    <path d=\"M 727.206994 153.779221 \n",
       "L 745.634229 153.779221 \n",
       "L 745.634229 151.693445 \n",
       "L 727.206994 151.693445 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_37\">\n",
       "    <path d=\"M 750.241038 153.779221 \n",
       "L 768.668274 153.779221 \n",
       "L 768.668274 76.422644 \n",
       "L 750.241038 76.422644 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_38\">\n",
       "    <path d=\"M 773.275083 153.779221 \n",
       "L 791.702318 153.779221 \n",
       "L 791.702318 145.6277 \n",
       "L 773.275083 145.6277 \n",
       "z\n",
       "\" clip-path=\"url(#p7763e6102c)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_39\">\n",
       "    <path d=\"M 554.682 153.779221 \n",
       "L 554.682 112.165073 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_40\">\n",
       "    <path d=\"M 575.1823 160.234375 \n",
       "L 782.4887 160.234375 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_38\">\n",
       "    <!-- max_acceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(617.2065 43.7085) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-78\" d=\"M 47 0 \n",
       "L 1259 1725 \n",
       "L 138 3319 \n",
       "L 841 3319 \n",
       "L 1350 2541 \n",
       "Q 1494 2319 1581 2169 \n",
       "Q 1719 2375 1834 2534 \n",
       "L 2394 3319 \n",
       "L 3066 3319 \n",
       "L 1919 1756 \n",
       "L 3153 0 \n",
       "L 2463 0 \n",
       "L 1781 1031 \n",
       "L 1600 1309 \n",
       "L 728 0 \n",
       "L 47 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"350.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"400.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"455.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"477.978516\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"533.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"566.894531\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"622.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"650.292969\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"672.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"728.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"783.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"839.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"922.65625\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"978.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1033.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1089.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1122.802734\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1178.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1228.417969\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_4\">\n",
       "   <g id=\"patch_41\">\n",
       "    <path d=\"M 818.157 160.234375 \n",
       "L 1066.464 160.234375 \n",
       "L 1066.464 49.7085 \n",
       "L 818.157 49.7085 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_7\">\n",
       "    <g id=\"xtick_31\">\n",
       "     <g id=\"line2d_46\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"838.6573\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_39\">\n",
       "      <!-- viscosity_cP -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(840.880675 216.94675) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-76\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"122.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"172.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"227.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"277.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"300.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-79\" x=\"327.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"377.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"433.447266\"/>\n",
       "       <use xlink:href=\"#ArialMT-50\" x=\"483.447266\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_32\">\n",
       "     <g id=\"line2d_47\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"861.691344\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_40\">\n",
       "      <!-- fill_volume_mL -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(864.019907 227.222125) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-66\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"27.783203\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"72.216797\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"94.433594\"/>\n",
       "       <use xlink:href=\"#ArialMT-76\" x=\"150.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"200.048828\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"255.664062\"/>\n",
       "       <use xlink:href=\"#ArialMT-75\" x=\"277.880859\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"333.496094\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"416.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"472.412109\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"528.027344\"/>\n",
       "       <use xlink:href=\"#ArialMT-4c\" x=\"611.328125\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_33\">\n",
       "     <g id=\"line2d_48\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"884.725389\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_41\">\n",
       "      <!-- air_gap_height_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(886.948764 246.309875) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-61\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"77.832031\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"111.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"166.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"222.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"277.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"333.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"389.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"444.824219\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"500.439453\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"522.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"578.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"633.886719\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"661.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"717.285156\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_34\">\n",
       "     <g id=\"line2d_49\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"907.759433\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_42\">\n",
       "      <!-- needle_length_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(909.982808 243.37975) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"378.125\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"544.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-68\" x=\"572.753906\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"628.369141\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"683.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"767.285156\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_35\">\n",
       "     <g id=\"line2d_50\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"930.793478\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_43\">\n",
       "      <!-- needle_diameter_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(933.068415 253.64) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6e\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"111.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"166.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6c\" x=\"222.460938\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"244.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"300.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-64\" x=\"355.908203\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"411.523438\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"433.740234\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"489.355469\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"572.65625\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"628.271484\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"656.054688\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"711.669922\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"744.970703\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"800.585938\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"883.886719\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_36\">\n",
       "     <g id=\"line2d_51\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"953.827522\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_44\">\n",
       "      <!-- spring_force_N -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(956.104522 228.20525) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-66\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"355.761719\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"411.376953\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"444.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"494.677734\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"550.292969\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"605.908203\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_37\">\n",
       "     <g id=\"line2d_52\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"976.861567\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_45\">\n",
       "      <!-- spring_constant_N_per_mm -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(979.084942 279.072) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-73\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-69\" x=\"138.916016\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"161.132812\"/>\n",
       "       <use xlink:href=\"#ArialMT-67\" x=\"216.748047\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"272.363281\"/>\n",
       "       <use xlink:href=\"#ArialMT-63\" x=\"327.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6f\" x=\"377.978516\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"433.59375\"/>\n",
       "       <use xlink:href=\"#ArialMT-73\" x=\"489.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"539.208984\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"566.992188\"/>\n",
       "       <use xlink:href=\"#ArialMT-6e\" x=\"622.607422\"/>\n",
       "       <use xlink:href=\"#ArialMT-74\" x=\"678.222656\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"706.005859\"/>\n",
       "       <use xlink:href=\"#ArialMT-4e\" x=\"761.621094\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"833.837891\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"889.453125\"/>\n",
       "       <use xlink:href=\"#ArialMT-65\" x=\"945.068359\"/>\n",
       "       <use xlink:href=\"#ArialMT-72\" x=\"1000.683594\"/>\n",
       "       <use xlink:href=\"#ArialMT-5f\" x=\"1033.984375\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1089.599609\"/>\n",
       "       <use xlink:href=\"#ArialMT-6d\" x=\"1172.900391\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_38\">\n",
       "     <g id=\"line2d_53\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"999.895611\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_46\">\n",
       "      <!-- kappa5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(1002.170549 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_39\">\n",
       "     <g id=\"line2d_54\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"1022.929656\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_47\">\n",
       "      <!-- kappa6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(1025.217656 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_40\">\n",
       "     <g id=\"line2d_55\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m3c4f3bef32\" x=\"1045.9637\" y=\"160.234375\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_48\">\n",
       "      <!-- kappa7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(1048.238638 197.4025) rotate(-90) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-6b\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"50\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"105.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-70\" x=\"161.230469\"/>\n",
       "       <use xlink:href=\"#ArialMT-61\" x=\"216.845703\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"272.460938\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_8\">\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_56\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"818.157\" y=\"153.779221\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_17\">\n",
       "     <g id=\"line2d_57\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"818.157\" y=\"143.375684\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_18\">\n",
       "     <g id=\"line2d_58\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"818.157\" y=\"132.972147\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_19\">\n",
       "     <g id=\"line2d_59\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"818.157\" y=\"122.56861\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_20\">\n",
       "     <g id=\"line2d_60\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mc252d56267\" x=\"818.157\" y=\"112.165073\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_42\">\n",
       "    <path d=\"M 829.443682 153.779221 \n",
       "L 847.870917 153.779221 \n",
       "L 847.870917 153.774236 \n",
       "L 829.443682 153.774236 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_43\">\n",
       "    <path d=\"M 852.477726 153.779221 \n",
       "L 870.904962 153.779221 \n",
       "L 870.904962 153.118495 \n",
       "L 852.477726 153.118495 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_44\">\n",
       "    <path d=\"M 875.511771 153.779221 \n",
       "L 893.939006 153.779221 \n",
       "L 893.939006 153.163951 \n",
       "L 875.511771 153.163951 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_45\">\n",
       "    <path d=\"M 898.545815 153.779221 \n",
       "L 916.973051 153.779221 \n",
       "L 916.973051 153.93644 \n",
       "L 898.545815 153.93644 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_46\">\n",
       "    <path d=\"M 921.57986 153.779221 \n",
       "L 940.007096 153.779221 \n",
       "L 940.007096 153.893534 \n",
       "L 921.57986 153.893534 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_47\">\n",
       "    <path d=\"M 944.613904 153.779221 \n",
       "L 963.04114 153.779221 \n",
       "L 963.04114 54.732403 \n",
       "L 944.613904 54.732403 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_48\">\n",
       "    <path d=\"M 967.647949 153.779221 \n",
       "L 986.075185 153.779221 \n",
       "L 986.075185 153.505896 \n",
       "L 967.647949 153.505896 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_49\">\n",
       "    <path d=\"M 990.681994 153.779221 \n",
       "L 1009.109229 153.779221 \n",
       "L 1009.109229 153.415331 \n",
       "L 990.681994 153.415331 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_50\">\n",
       "    <path d=\"M 1013.716038 153.779221 \n",
       "L 1032.143274 153.779221 \n",
       "L 1032.143274 152.96624 \n",
       "L 1013.716038 152.96624 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_51\">\n",
       "    <path d=\"M 1036.750083 153.779221 \n",
       "L 1055.177318 153.779221 \n",
       "L 1055.177318 155.210472 \n",
       "L 1036.750083 155.210472 \n",
       "z\n",
       "\" clip-path=\"url(#paa9e17c3e3)\" style=\"fill: #1f77b4; stroke: #ffffff; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_52\">\n",
       "    <path d=\"M 818.157 153.779221 \n",
       "L 818.157 112.165073 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_53\">\n",
       "    <path d=\"M 838.6573 160.234375 \n",
       "L 1045.9637 160.234375 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_49\">\n",
       "    <!-- max_deceleration_m_per_s2 -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(880.41225 43.7085) scale(0.096 -0.096)\">\n",
       "     <use xlink:href=\"#ArialMT-6d\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"83.300781\"/>\n",
       "     <use xlink:href=\"#ArialMT-78\" x=\"138.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"188.916016\"/>\n",
       "     <use xlink:href=\"#ArialMT-64\" x=\"244.53125\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"300.146484\"/>\n",
       "     <use xlink:href=\"#ArialMT-63\" x=\"355.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"405.761719\"/>\n",
       "     <use xlink:href=\"#ArialMT-6c\" x=\"461.376953\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"483.59375\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"539.208984\"/>\n",
       "     <use xlink:href=\"#ArialMT-61\" x=\"572.509766\"/>\n",
       "     <use xlink:href=\"#ArialMT-74\" x=\"628.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-69\" x=\"655.908203\"/>\n",
       "     <use xlink:href=\"#ArialMT-6f\" x=\"678.125\"/>\n",
       "     <use xlink:href=\"#ArialMT-6e\" x=\"733.740234\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"789.355469\"/>\n",
       "     <use xlink:href=\"#ArialMT-6d\" x=\"844.970703\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"928.271484\"/>\n",
       "     <use xlink:href=\"#ArialMT-70\" x=\"983.886719\"/>\n",
       "     <use xlink:href=\"#ArialMT-65\" x=\"1039.501953\"/>\n",
       "     <use xlink:href=\"#ArialMT-72\" x=\"1095.117188\"/>\n",
       "     <use xlink:href=\"#ArialMT-5f\" x=\"1128.417969\"/>\n",
       "     <use xlink:href=\"#ArialMT-73\" x=\"1184.033203\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"1234.033203\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"text_50\">\n",
       "   <!-- Sobol indices -->\n",
       "   <g style=\"fill: #262626\" transform=\"translate(489.24825 18.6525) scale(0.16 -0.16)\">\n",
       "    <defs>\n",
       "     <path id=\"ArialMT-53\" d=\"M 288 1472 \n",
       "L 859 1522 \n",
       "Q 900 1178 1048 958 \n",
       "Q 1197 738 1509 602 \n",
       "Q 1822 466 2213 466 \n",
       "Q 2559 466 2825 569 \n",
       "Q 3091 672 3220 851 \n",
       "Q 3350 1031 3350 1244 \n",
       "Q 3350 1459 3225 1620 \n",
       "Q 3100 1781 2813 1891 \n",
       "Q 2628 1963 1997 2114 \n",
       "Q 1366 2266 1113 2400 \n",
       "Q 784 2572 623 2826 \n",
       "Q 463 3081 463 3397 \n",
       "Q 463 3744 659 4045 \n",
       "Q 856 4347 1234 4503 \n",
       "Q 1613 4659 2075 4659 \n",
       "Q 2584 4659 2973 4495 \n",
       "Q 3363 4331 3572 4012 \n",
       "Q 3781 3694 3797 3291 \n",
       "L 3216 3247 \n",
       "Q 3169 3681 2898 3903 \n",
       "Q 2628 4125 2100 4125 \n",
       "Q 1550 4125 1298 3923 \n",
       "Q 1047 3722 1047 3438 \n",
       "Q 1047 3191 1225 3031 \n",
       "Q 1400 2872 2139 2705 \n",
       "Q 2878 2538 3153 2413 \n",
       "Q 3553 2228 3743 1945 \n",
       "Q 3934 1663 3934 1294 \n",
       "Q 3934 928 3725 604 \n",
       "Q 3516 281 3123 101 \n",
       "Q 2731 -78 2241 -78 \n",
       "Q 1619 -78 1198 103 \n",
       "Q 778 284 539 648 \n",
       "Q 300 1013 288 1472 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "     <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "    </defs>\n",
       "    <use xlink:href=\"#ArialMT-53\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"66.699219\"/>\n",
       "    <use xlink:href=\"#ArialMT-62\" x=\"122.314453\"/>\n",
       "    <use xlink:href=\"#ArialMT-6f\" x=\"177.929688\"/>\n",
       "    <use xlink:href=\"#ArialMT-6c\" x=\"233.544922\"/>\n",
       "    <use xlink:href=\"#ArialMT-20\" x=\"255.761719\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"283.544922\"/>\n",
       "    <use xlink:href=\"#ArialMT-6e\" x=\"305.761719\"/>\n",
       "    <use xlink:href=\"#ArialMT-64\" x=\"361.376953\"/>\n",
       "    <use xlink:href=\"#ArialMT-69\" x=\"416.992188\"/>\n",
       "    <use xlink:href=\"#ArialMT-63\" x=\"439.208984\"/>\n",
       "    <use xlink:href=\"#ArialMT-65\" x=\"489.208984\"/>\n",
       "    <use xlink:href=\"#ArialMT-73\" x=\"544.824219\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p0d0cabefbc\">\n",
       "   <rect x=\"27.732\" y=\"49.7085\" width=\"248.307\" height=\"110.525875\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"pa2774eefb0\">\n",
       "   <rect x=\"291.207\" y=\"49.7085\" width=\"248.307\" height=\"110.525875\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"p7763e6102c\">\n",
       "   <rect x=\"554.682\" y=\"49.7085\" width=\"248.307\" height=\"110.525875\"/>\n",
       "  </clipPath>\n",
       "  <clipPath id=\"paa9e17c3e3\">\n",
       "   <rect x=\"818.157\" y=\"49.7085\" width=\"248.307\" height=\"110.525875\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 1500x400 with 4 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# Plot sobol indices\n",
    "fig, ax = plt.subplots(1, len(OUTPUT_NAMES), figsize=(15, 4), tight_layout=True, sharey=True)\n",
    "fig.suptitle('Sobol indices', fontsize=16)\n",
    "for i, o_name in enumerate(OUTPUT_NAMES):\n",
    "    ax[i].bar(problem['names'], sobol_indices[o_name]['S1'])\n",
    "    ax[i].set_title(o_name)\n",
    "    for tick in ax[i].get_xticklabels():\n",
    "        tick.set_rotation(90)\n",
    "    sns.despine(trim=True, ax=ax[i])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Excellent! We now know to which inputs the outputs are most sensitive. For example, we can see that the injection time is *very* sensitive to the drug viscosity and needle diameter, *somewhat* sensitive to needle length and injector spring force, and *not* sensitive to any other inputs. This information can be used, for example, to further study and understand the physics behind the model, or to investigate how identifiable each parameter is given an experimental dataset.\n",
    "\n",
    "Remember that **sensitivity analysis would *not* have been feasible without a surrogate model**&mdash;the true physical model was just too expensive. With a surrogate however, we can do sensitivity analysis, design optimization, uncertainty quantification, etc. all at a reasonable computational cost."
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": ".venv",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.9"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
